;;;*****************************************************************
;traiettoria circolare
;f=g*m1*m2/d^2
;f=m*v^2/r
;v1/r1=v2/r2-->r1*m1=r2*m2
;-->v1=sqrt(f*r1/m1)
;m1=2000
;m2=16000
;x1=-10000
;x2=1250
;v1=11.2436539
;v2=-1.405456738

;traiettoria ellittica
;u=m*g costante di gravitazione planetaria 
;v=sqrt(2*u*(1/r-1/2a))
;a=semiasse maggiore
;e=sqrt(1-b^2/a^2) =eccentricita, b=semiasse minore
;m1=10
;m2=1000000
;x1=-10000
;x2=8000
;v1=100
;;;*****************************************************************
;;;*****************************************************************
;simula il moto di 10 oggetti sottoposti a forza gravitazionale
;gravita2 ver 1.5 23/07/2010
;Dott. Ing. Emanuele Ballasina
;cell 349-1813748
;mail ballacr75@libero.it

(defun c:gravita2 ()
(setvar "osmode" 0)
(setvar "dimzin" 0)
(setvar "cmdecho" 0)

(command "_-layer" "n" "m1" "_c" 10 "m1" "_s" "m1" "")
(command "_-layer" "n" "m2" "_c" 50 "m2" "_s" "m2" "")

(setq t 1) ;scansione tempo
(setq kdi 1) ;riduzione diametro cilindri
(setq scan 1) ;scansione posizione (non funziona >1 se ker=1)

(setq m1 100.0) ;massa
(setq m2 100.0)
(setq d1 0.1) ;densita
(setq d2 0.1)
(setq r1 (expt (/ m1 d1) 0.3333)) ;raggio
(setq r2 (expt (/ m2 d2) 0.3333))
(setq r12 (+ r1 r2)) ;distanza di sfioro
(setq r13 (+ r1 r3))

(setq k1 1) ;abilita movimento pianeta
(setq k2 1)
(setq kur 1) ;abilita urti, con coefficente di rimbalzo, <1 smorza
(setq kbi 1) ;abilita rimbalzo tipo biliardo contro pareti dello schermo, <1 smorza
(setq ker 1) ;1=cancella pianeti vecchi, 0=mantiene tutti i pianeti
(setq c (getvar "VIEWCTR"))
(setq xsc (car c))
(setq ysc (cadr c))
(setq zsc (caddr c))
(setq currh (getvar "viewsize"))
(setq sizex (nth 0 (getvar "screensize")))
(setq sizey (nth 1 (getvar "screensize")))
(setq j (/ sizex sizey))
(setq currw (* j currh))
(setq h2 (/ currh 2.0))
(setq w2 (/ currw 2.0))
(setq xsa (- xsc w2))
(setq ysa (- ysc h2))
(setq zsa (- zsc h2))
(setq xsb (+ xsc w2))
(setq ysb (+ ysc h2))
(setq zsb (+ zsc h2))
(if (/= kbi 0) (command "_rectangle" (list xsa ysa) (list xsb ysb)))

(setq pc "c") ;punti,cerchi,sfere
(setq lc "n") ;abilita disegno linee tra un pianeta e gli altri
(setq tc "n") ;abilita disegno linee traiettoria

(setq x1 0) ;posizione
(setq y1 0)
(setq z1 0)
(setq x2 100)
(setq y2 0)
(setq z2 0)

(setq v1x 0.0) ;velocita
(setq v1y 0.0)
(setq v1z 0.0)
(setq v2x 0.0)
(setq v2y 0.0)
(setq v2z 0.0)

(setq p1 (list x1 y1 z1))
(setq p2 (list x2 y2 z2))

(if (= pc "p")
    (progn
     (setvar "clayer" "m1") (command "_point" p1) (setq o1 (cdr (car (entget (entlast)))))
     (setvar "clayer" "m2") (command "_point" p2) (setq o2 (cdr (car (entget (entlast)))))
    )
    (if (= pc "c")
        (progn
         (setvar "clayer" "m1") (command "_circle" p1 r1) (setq o1 (cdr (car (entget (entlast)))))
         (setvar "clayer" "m2") (command "_circle" p2 r2) (setq o2 (cdr (car (entget (entlast)))))
        )
        (if (= pc "s")
            (progn
             (setvar "clayer" "m1") (command "_sphere" p1 r1) (setq o1 (cdr (car (entget (entlast)))))
             (setvar "clayer" "m2") (command "_sphere" p2 r2) (setq o2 (cdr (car (entget (entlast)))))
            )
        )
    )
)

(setq va 1000)
(setq iscan 0)
 (while (> va 0.0001) ;scansione velocit ed accelerazione, se = 0 si ferma il lisp

  (setq v1 (sqrt (+ (* v1x v1x) (* v1y v1y) (* v1z v1z))))
  (setq v2 (sqrt (+ (* v2x v2x) (* v2y v2y) (* v2z v2z))))
  
  (setq d12 (distance p1 p2))
  (setq d13 (distance p1 p3))

  (setq dx12 (- x2 x1))  (setq dy12 (- y2 y1))  (setq dz12 (- z2 z1))
  (setq dx13 (- x3 x1))  (setq dy13 (- y3 y1))  (setq dz13 (- z3 z1))

;                   GRAVITA              REPULSIONE           ELASTICO       MOLLA
  (if (<= d12 r12) (setq d12 r12))
  (if (<= d13 r13) (setq d13 r13))
  (setq f12 (+ (* 1 (fgr m1 m2 d12)) (* 1 (fre m1 m2 d12)) (* 1 (fel d12)) (* 1 (fmo d12)) ))
  (setq f13 (+ (* 1 (fgr m1 m3 d13)) (* 1 (fre m1 m3 d13)) (* 1 (fel d13)) (* 1 (fmo d13)) ))

  (setq a12 (/ f12 m1))  (setq a21 (* -1 (/ f12 m2)))
  (setq a13 (/ f13 m1))  (setq a31 (* -1 (/ f13 m3)))
 
  (setq a1x (+ (* 1 (/ (fsx x1 y1 z1) m1)) (* 1 (/ (fwx r1) m1)) (* 1 v1x (/ (fvi m1 r1 v1) m1)) (/ (* a12 dx12) d12) ))
  (setq a1y (+ (* 1 (/ (fsy x1 y1 z1) m1)) (* 1 (/ (fwy r1) m1)) (* 1 v1y (/ (fvi m1 r1 v1) m1)) (/ (* a12 dy12) d12) ))
  (setq a1z (+ (* 1 (/ (fsz x1 y1 z1) m1)) (* 1 (/ (fwz r1) m1)) (* 1 v1z (/ (fvi m1 r1 v1) m1)) (/ (* a12 dz12) d12) ))
  (setq a2x (+ (* 1 (/ (fsx x2 y2 z2) m2)) (* 1 (/ (fwx r2) m2)) (* 1 v2x (/ (fvi m2 r2 v2) m2)) (/ (* a21 dx12) d12) ))
  (setq a2y (+ (* 1 (/ (fsy x2 y2 z2) m2)) (* 1 (/ (fwy r2) m2)) (* 1 v2y (/ (fvi m2 r2 v2) m2)) (/ (* a21 dy12) d12) ))
  (setq a2z (+ (* 1 (/ (fsz x2 y2 z2) m2)) (* 1 (/ (fwz r2) m2)) (* 1 v2z (/ (fvi m2 r2 v2) m2)) (/ (* a21 dz12) d12) ))

  (if (> d12 r12)
   (progn 
    (setq v1x (+ v1x (* a1x t)))  (setq v1y (+ v1y (* a1y t)))  (setq v1z (+ v1z (* a1z t)))
    (setq v2x (+ v2x (* a2x t)))  (setq v2y (+ v2y (* a2y t)))  (setq v2z (+ v2z (* a2z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v1i (list v1x v1y v1z)) ;velocita 1 prima dello scontro
     (setq v2i (list v2x v2y v2z)) ;velocita 2 prima dello scontro
     (setq v1i* (trans v1i 0 (list dx12 dy12 dz12)))
     (setq v2i* (trans v2i 0 (list dx12 dy12 dz12)))
     (setq v1i*x (car v1i*) v1i*y (cadr v1i*) v1i*z (caddr v1i*))
     (setq v2i*x (car v2i*) v2i*y (cadr v2i*) v2i*z (caddr v2i*))
     (setq v1f*z (* kur (/ (+ (* (- m1 m2) v1i*z) (* 2 m2 v2i*z)) (+ m1 m2))))
     (setq v2f*z (* kur (/ (+ (* (- m2 m1) v2i*z) (* 2 m1 v1i*z)) (+ m1 m2))))
     (setq v1f* (list v1i*x v1i*y v1f*z))
     (setq v2f* (list v2i*x v2i*y v2f*z))
     (setq v1f (trans v1f* (list dx12 dy12 dz12) 0))
     (setq v2f (trans v2f* (list dx12 dy12 dz12) 0))
     (setq v1x (car v1f) v1y (cadr v1f) v1z (caddr v1f))
     (setq v2x (car v2f) v2y (cadr v2f) v2z (caddr v2f))
    )
   )
  )

  (if (< (- x1 r1) xsa) (setq v1x (* (+ (* -2 kbi) 1) v1x) ) )
  (if (< (- y1 r1) ysa) (setq v1y (* (+ (* -2 kbi) 1) v1y) ) )   
  (if (< (- z1 r1) zsa) (setq v1z (* (+ (* -2 kbi) 1) v1z) ) )   
  (if (> (+ x1 r1) xsb) (setq v1x (* (+ (* -2 kbi) 1) v1x) ) )   
  (if (> (+ y1 r1) ysb) (setq v1y (* (+ (* -2 kbi) 1) v1y) ) )   
  (if (> (+ z1 r1) zsb) (setq v1z (* (+ (* -2 kbi) 1) v1z) ) )   
  (if (< (- x2 r2) xsa) (setq v2x (* (+ (* -2 kbi) 1) v2x) ) )   
  (if (< (- y2 r2) ysa) (setq v2y (* (+ (* -2 kbi) 1) v2y) ) )   
  (if (< (- z2 r2) zsa) (setq v2z (* (+ (* -2 kbi) 1) v2z) ) )   
  (if (> (+ x2 r2) xsb) (setq v2x (* (+ (* -2 kbi) 1) v2x) ) )   
  (if (> (+ y2 r2) ysb) (setq v2y (* (+ (* -2 kbi) 1) v2y) ) )   
  (if (> (+ z2 r2) zsb) (setq v2z (* (+ (* -2 kbi) 1) v2z) ) )   

  (setq s1x (+ (* v1x t) (* 0.5 a1x t t)))  (setq s1y (+ (* v1y t) (* 0.5 a1y t t)))  (setq s1z (+ (* v1z t) (* 0.5 a1z t t)))
  (setq s2x (+ (* v2x t) (* 0.5 a2x t t)))  (setq s2y (+ (* v2y t) (* 0.5 a2y t t)))  (setq s2z (+ (* v2z t) (* 0.5 a2z t t)))

  (setq x1 (+ x1 (* k1 s1x)))  (setq y1 (+ y1 (* k1 s1y)))  (setq z1 (+ z1 (* k1 s1z)))
  (setq x2 (+ x2 (* k2 s2x)))  (setq y2 (+ y2 (* k2 s2y)))  (setq z2 (+ z2 (* k2 s2z)))

  (setq a1 (sqrt (+ (* a1x a1x) (* a1y a1y) (* a1z a1z))))
  (setq a2 (sqrt (+ (* a2x a2x) (* a2y a2y) (* a2z a2z))))

  (setq va (+ (abs a1) (abs a2)
              (abs v1) (abs v2)
           )
  )
  (princ "\n")
  (princ va)
  (princ)

  (setq q1 (list x1 y1 z1))
  (setq q2 (list x2 y2 z2))

  (if (= iscan 0)
   (progn
 
   (if (= ker 0)
    (progn
    (if (= pc "p")
        (progn
         (setvar "clayer" "m1") (command "_point" p1)
         (setvar "clayer" "m2") (command "_point" p2)
        )
        (if (= pc "c")
            (progn
             (setvar "clayer" "m1") (command "_circle" p1 r1)
             (setvar "clayer" "m2") (command "_circle" p2 r2)
            )
            (if (= pc "s")
                (progn
                 (setvar "clayer" "m1") (command "_sphere" p1 r1)
                 (setvar "clayer" "m2") (command "_sphere" p2 r2)
                )
            )
        )
    )
    )
    (progn
             (command "_move" o1 "" p1 q1)
             (command "_move" o2 "" p2 q2)
    )    
   )
    
   )

  )
 
  (setq p1 q1)
  (setq p2 q2)  

  (setq iscan (+ 1 iscan))
  (if (= iscan scan) (setq iscan 0))

 )
 (setvar "clayer" "0")
 (command "_pline" p1 p2 p1 "")
)

;;;*****************************************************************
;simula il moto di 10 oggetti sottoposti a forza gravitazionale
;gravita3 ver 1.5 23/07/2010
;Dott. Ing. Emanuele Ballasina
;cell 349-1813748
;mail ballacr75@libero.it

(defun c:gravita3 ()
(setvar "osmode" 0)
(setvar "dimzin" 0)
(setvar "cmdecho" 0)

(command "_-layer" "n" "m1" "_c" 10 "m1" "_s" "m1" "")
(command "_-layer" "n" "m2" "_c" 50 "m2" "_s" "m2" "")
(command "_-layer" "n" "m3" "_c" 90 "m3" "_s" "m3" "")

(setq t 1) ;scansione tempo
(setq kdi 1) ;riduzione diametro cilindri
(setq scan 1) ;scansione posizione (non funziona >1 se ker=1)

(setq m1 100.0) ;massa
(setq m2 100.0)
(setq m3 100.0)
(setq d1 0.1) ;densita
(setq d2 0.1)
(setq d3 0.1) 
(setq r1 (expt (/ m1 d1) 0.3333)) ;raggio
(setq r2 (expt (/ m2 d2) 0.3333))
(setq r3 (expt (/ m3 d3) 0.3333))
(setq r12 (+ r1 r2)) ;distanza di sfioro
(setq r13 (+ r1 r3))
(setq r23 (+ r2 r3))

(setq k1 1) ;abilita movimento pianeta
(setq k2 1)
(setq k3 1)
(setq kur 0) ;abilita urti, con coefficente di rimbalzo, <1 smorza
(setq kbi 0) ;abilita rimbalzo tipo biliardo contro pareti dello schermo, <1 smorza
(setq ker 0) ;1=cancella pianeti vecchi, 0=mantiene tutti i pianeti
(setq c (getvar "VIEWCTR"))
(setq xsc (car c))
(setq ysc (cadr c))
(setq zsc (caddr c))
(setq currh (getvar "viewsize"))
(setq sizex (nth 0 (getvar "screensize")))
(setq sizey (nth 1 (getvar "screensize")))
(setq j (/ sizex sizey))
(setq currw (* j currh))
(setq h2 (/ currh 2.0))
(setq w2 (/ currw 2.0))
(setq xsa (- xsc w2))
(setq ysa (- ysc h2))
(setq zsa (- zsc h2))
(setq xsb (+ xsc w2))
(setq ysb (+ ysc h2))
(setq zsb (+ zsc h2))
(if (/= kbi 0) (command "_rectangle" (list xsa ysa) (list xsb ysb)))

(setq pc "p") ;punti,cerchi,sfere
(setq lc "n") ;abilita disegno linee tra un pianeta e gli altri
(setq tc "n") ;abilita disegno linee traiettoria

(setq x1 100) ;posizione
(setq y1 0)
(setq z1 0)
(setq x2 0)
(setq y2 100)
(setq z2 0)
(setq x3 0)
(setq y3 0)
(setq z3 100)

(setq v1x 0.0) ;velocita
(setq v1y 1.0)
(setq v1z 0.0)
(setq v2x 0.0)
(setq v2y 0.0)
(setq v2z 1.0)
(setq v3x 1.0)
(setq v3y 0.0)
(setq v3z 0.0)

(setq p1 (list x1 y1 z1))
(setq p2 (list x2 y2 z2))
(setq p3 (list x3 y3 z3))

(if (= pc "p")
    (progn
     (setvar "clayer" "m1") (command "_point" p1) (setq o1 (cdr (car (entget (entlast)))))
     (setvar "clayer" "m2") (command "_point" p2) (setq o2 (cdr (car (entget (entlast)))))
     (setvar "clayer" "m3") (command "_point" p3) (setq o3 (cdr (car (entget (entlast)))))
    )
    (if (= pc "c")
        (progn
         (setvar "clayer" "m1") (command "_circle" p1 r1) (setq o1 (cdr (car (entget (entlast)))))
         (setvar "clayer" "m2") (command "_circle" p2 r2) (setq o2 (cdr (car (entget (entlast)))))
         (setvar "clayer" "m3") (command "_circle" p3 r3) (setq o3 (cdr (car (entget (entlast)))))
        )
        (if (= pc "s")
            (progn
             (setvar "clayer" "m1") (command "_sphere" p1 r1) (setq o1 (cdr (car (entget (entlast)))))
             (setvar "clayer" "m2") (command "_sphere" p2 r2) (setq o2 (cdr (car (entget (entlast)))))
             (setvar "clayer" "m3") (command "_sphere" p3 r3) (setq o3 (cdr (car (entget (entlast)))))
            )
        )
    )
)

(setq va 1000)
(setq iscan 0)
 (while (> va 0.0001) ;scansione velocit ed accelerazione, se = 0 si ferma il lisp

  (setq v1 (sqrt (+ (* v1x v1x) (* v1y v1y) (* v1z v1z))))
  (setq v2 (sqrt (+ (* v2x v2x) (* v2y v2y) (* v2z v2z))))
  (setq v3 (sqrt (+ (* v3x v3x) (* v3y v3y) (* v3z v3z))))
  
  (setq d12 (distance p1 p2))
  (setq d13 (distance p1 p3))
  (setq d23 (distance p2 p3))

  (setq dx12 (- x2 x1))  (setq dy12 (- y2 y1))  (setq dz12 (- z2 z1))
  (setq dx13 (- x3 x1))  (setq dy13 (- y3 y1))  (setq dz13 (- z3 z1))
  (setq dx23 (- x3 x2))  (setq dy23 (- y3 y2))  (setq dz23 (- z3 z2))

;                   GRAVITA              REPULSIONE           ELASTICO       MOLLA
  (if (<= d12 r12) (setq d12 r12))
  (if (<= d13 r13) (setq d13 r13))
  (if (<= d23 r23) (setq d23 r23))
  (setq f12 (+ (* 1 (fgr m1 m2 d12)) (* 1 (fre m1 m2 d12)) (* 1 (fel d12)) (* 1 (fmo d12)) ))
  (setq f13 (+ (* 1 (fgr m1 m3 d13)) (* 1 (fre m1 m3 d13)) (* 1 (fel d13)) (* 1 (fmo d13)) ))
  (setq f23 (+ (* 1 (fgr m2 m3 d23)) (* 1 (fre m2 m3 d23)) (* 1 (fel d23)) (* 1 (fmo d23)) ))

  (setq a12 (/ f12 m1))  (setq a21 (* -1 (/ f12 m2)))
  (setq a13 (/ f13 m1))  (setq a31 (* -1 (/ f13 m3)))
  (setq a23 (/ f23 m2))  (setq a32 (* -1 (/ f23 m3)))
 
  (setq a1x (+ (* 1 (/ (fsx x1 y1 z1) m1)) (* 1 (/ (fwx r1) m1)) (* 1 v1x (/ (fvi m1 r1 v1) m1)) (/ (* a12 dx12) d12) (/ (* a13 dx13) d13) ))
  (setq a1y (+ (* 1 (/ (fsy x1 y1 z1) m1)) (* 1 (/ (fwy r1) m1)) (* 1 v1y (/ (fvi m1 r1 v1) m1)) (/ (* a12 dy12) d12) (/ (* a13 dy13) d13) ))
  (setq a1z (+ (* 1 (/ (fsz x1 y1 z1) m1)) (* 1 (/ (fwz r1) m1)) (* 1 v1z (/ (fvi m1 r1 v1) m1)) (/ (* a12 dz12) d12) (/ (* a13 dz13) d13) ))
  (setq a2x (+ (* 1 (/ (fsx x2 y2 z2) m2)) (* 1 (/ (fwx r2) m2)) (* 1 v2x (/ (fvi m2 r2 v2) m2)) (/ (* a21 dx12) d12) (/ (* a23 dx23) d23) ))
  (setq a2y (+ (* 1 (/ (fsy x2 y2 z2) m2)) (* 1 (/ (fwy r2) m2)) (* 1 v2y (/ (fvi m2 r2 v2) m2)) (/ (* a21 dy12) d12) (/ (* a23 dy23) d23) ))
  (setq a2z (+ (* 1 (/ (fsz x2 y2 z2) m2)) (* 1 (/ (fwz r2) m2)) (* 1 v2z (/ (fvi m2 r2 v2) m2)) (/ (* a21 dz12) d12) (/ (* a23 dz23) d23) ))
  (setq a3x (+ (* 1 (/ (fsx x3 y3 z3) m3)) (* 1 (/ (fwx r3) m3)) (* 1 v3x (/ (fvi m3 r3 v3) m3)) (/ (* a31 dx13) d13) (/ (* a32 dx23) d23) ))
  (setq a3y (+ (* 1 (/ (fsy x3 y3 z3) m3)) (* 1 (/ (fwy r3) m3)) (* 1 v3y (/ (fvi m3 r3 v3) m3)) (/ (* a31 dy13) d13) (/ (* a32 dy23) d23) ))
  (setq a3z (+ (* 1 (/ (fsz x3 y3 z3) m3)) (* 1 (/ (fwz r3) m3)) (* 1 v3z (/ (fvi m3 r3 v3) m3)) (/ (* a31 dz13) d13) (/ (* a32 dz23) d23) ))

  (if (> d12 r12)
   (progn 
    (setq v1x (+ v1x (* a1x t)))  (setq v1y (+ v1y (* a1y t)))  (setq v1z (+ v1z (* a1z t)))
    (setq v2x (+ v2x (* a2x t)))  (setq v2y (+ v2y (* a2y t)))  (setq v2z (+ v2z (* a2z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v1i (list v1x v1y v1z)) ;velocita 1 prima dello scontro
     (setq v2i (list v2x v2y v2z)) ;velocita 2 prima dello scontro
     (setq v1i* (trans v1i 0 (list dx12 dy12 dz12)))
     (setq v2i* (trans v2i 0 (list dx12 dy12 dz12)))
     (setq v1i*x (car v1i*) v1i*y (cadr v1i*) v1i*z (caddr v1i*))
     (setq v2i*x (car v2i*) v2i*y (cadr v2i*) v2i*z (caddr v2i*))
     (setq v1f*z (* kur (/ (+ (* (- m1 m2) v1i*z) (* 2 m2 v2i*z)) (+ m1 m2))))
     (setq v2f*z (* kur (/ (+ (* (- m2 m1) v2i*z) (* 2 m1 v1i*z)) (+ m1 m2))))
     (setq v1f* (list v1i*x v1i*y v1f*z))
     (setq v2f* (list v2i*x v2i*y v2f*z))
     (setq v1f (trans v1f* (list dx12 dy12 dz12) 0))
     (setq v2f (trans v2f* (list dx12 dy12 dz12) 0))
     (setq v1x (car v1f) v1y (cadr v1f) v1z (caddr v1f))
     (setq v2x (car v2f) v2y (cadr v2f) v2z (caddr v2f))
    )
   )
  )
  (if (> d13 r13)
   (progn 
    (setq v1x (+ v1x (* a1x t)))  (setq v1y (+ v1y (* a1y t)))  (setq v1z (+ v1z (* a1z t)))
    (setq v3x (+ v3x (* a3x t)))  (setq v3y (+ v3y (* a3y t)))  (setq v3z (+ v3z (* a3z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v1i (list v1x v1y v1z)) ;velocita 1 prima dello scontro
     (setq v3i (list v3x v3y v3z)) ;velocita 3 prima dello scontro
     (setq v1i* (trans v1i 0 (list dx13 dy13 dz13)))
     (setq v3i* (trans v3i 0 (list dx13 dy13 dz13)))
     (setq v1i*x (car v1i*) v1i*y (cadr v1i*) v1i*z (caddr v1i*))
     (setq v3i*x (car v3i*) v3i*y (cadr v3i*) v3i*z (caddr v3i*))
     (setq v1f*z (* kur (/ (+ (* (- m1 m3) v1i*z) (* 2 m3 v3i*z)) (+ m1 m3))))
     (setq v3f*z (* kur (/ (+ (* (- m3 m1) v3i*z) (* 2 m1 v1i*z)) (+ m1 m3))))
     (setq v1f* (list v1i*x v1i*y v1f*z))
     (setq v3f* (list v3i*x v3i*y v3f*z))
     (setq v1f (trans v1f* (list dx13 dy13 dz13) 0))
     (setq v3f (trans v3f* (list dx13 dy13 dz13) 0))
     (setq v1x (car v1f) v1y (cadr v1f) v1z (caddr v1f))
     (setq v3x (car v3f) v3y (cadr v3f) v3z (caddr v3f))
    )
   )
  )
  (if (> d23 r23)
   (progn 
    (setq v2x (+ v2x (* a2x t)))  (setq v2y (+ v2y (* a2y t)))  (setq v2z (+ v2z (* a2z t)))
    (setq v3x (+ v3x (* a3x t)))  (setq v3y (+ v3y (* a3y t)))  (setq v3z (+ v3z (* a3z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v2i (list v2x v2y v2z)) ;velocita 2 prima dello scontro
     (setq v3i (list v3x v3y v3z)) ;velocita 3 prima dello scontro
     (setq v2i* (trans v2i 0 (list dx23 dy23 dz23)))
     (setq v3i* (trans v3i 0 (list dx23 dy23 dz23)))
     (setq v2i*x (car v2i*) v2i*y (cadr v2i*) v2i*z (caddr v2i*))
     (setq v3i*x (car v3i*) v3i*y (cadr v3i*) v3i*z (caddr v3i*))
     (setq v2f*z (* kur (/ (+ (* (- m2 m3) v2i*z) (* 2 m3 v3i*z)) (+ m2 m3))))
     (setq v3f*z (* kur (/ (+ (* (- m3 m2) v3i*z) (* 2 m2 v2i*z)) (+ m2 m3))))
     (setq v2f* (list v2i*x v2i*y v2f*z))
     (setq v3f* (list v3i*x v3i*y v3f*z))
     (setq v2f (trans v2f* (list dx23 dy23 dz23) 0))
     (setq v3f (trans v3f* (list dx23 dy23 dz23) 0))
     (setq v2x (car v2f) v2y (cadr v2f) v2z (caddr v2f))
     (setq v3x (car v3f) v3y (cadr v3f) v3z (caddr v3f))
    )
   )
  )

  (if (< (- x1 r1) xsa) (setq v1x (* (+ (* -2 kbi) 1) v1x) ) )
  (if (< (- y1 r1) ysa) (setq v1y (* (+ (* -2 kbi) 1) v1y) ) )   
  (if (< (- z1 r1) zsa) (setq v1z (* (+ (* -2 kbi) 1) v1z) ) )   
  (if (> (+ x1 r1) xsb) (setq v1x (* (+ (* -2 kbi) 1) v1x) ) )   
  (if (> (+ y1 r1) ysb) (setq v1y (* (+ (* -2 kbi) 1) v1y) ) )   
  (if (> (+ z1 r1) zsb) (setq v1z (* (+ (* -2 kbi) 1) v1z) ) )   
  (if (< (- x2 r2) xsa) (setq v2x (* (+ (* -2 kbi) 1) v2x) ) )   
  (if (< (- y2 r2) ysa) (setq v2y (* (+ (* -2 kbi) 1) v2y) ) )   
  (if (< (- z2 r2) zsa) (setq v2z (* (+ (* -2 kbi) 1) v2z) ) )   
  (if (> (+ x2 r2) xsb) (setq v2x (* (+ (* -2 kbi) 1) v2x) ) )   
  (if (> (+ y2 r2) ysb) (setq v2y (* (+ (* -2 kbi) 1) v2y) ) )   
  (if (> (+ z2 r2) zsb) (setq v2z (* (+ (* -2 kbi) 1) v2z) ) )   
  (if (< (- x3 r3) xsa) (setq v3x (* (+ (* -2 kbi) 1) v3x) ) )   
  (if (< (- y3 r3) ysa) (setq v3y (* (+ (* -2 kbi) 1) v3y) ) )   
  (if (< (- z3 r3) zsa) (setq v3z (* (+ (* -2 kbi) 1) v3z) ) )   
  (if (> (+ x3 r3) xsb) (setq v3x (* (+ (* -2 kbi) 1) v3x) ) )   
  (if (> (+ y3 r3) ysb) (setq v3y (* (+ (* -2 kbi) 1) v3y) ) )   
  (if (> (+ z3 r3) zsb) (setq v3z (* (+ (* -2 kbi) 1) v3z) ) )   

  (setq s1x (+ (* v1x t) (* 0.5 a1x t t)))  (setq s1y (+ (* v1y t) (* 0.5 a1y t t)))  (setq s1z (+ (* v1z t) (* 0.5 a1z t t)))
  (setq s2x (+ (* v2x t) (* 0.5 a2x t t)))  (setq s2y (+ (* v2y t) (* 0.5 a2y t t)))  (setq s2z (+ (* v2z t) (* 0.5 a2z t t)))
  (setq s3x (+ (* v3x t) (* 0.5 a3x t t)))  (setq s3y (+ (* v3y t) (* 0.5 a3y t t)))  (setq s3z (+ (* v3z t) (* 0.5 a3z t t)))

  (setq x1 (+ x1 (* k1 s1x)))  (setq y1 (+ y1 (* k1 s1y)))  (setq z1 (+ z1 (* k1 s1z)))
  (setq x2 (+ x2 (* k2 s2x)))  (setq y2 (+ y2 (* k2 s2y)))  (setq z2 (+ z2 (* k2 s2z)))
  (setq x3 (+ x3 (* k3 s3x)))  (setq y3 (+ y3 (* k3 s3y)))  (setq z3 (+ z3 (* k3 s3z)))

  (setq a1 (sqrt (+ (* a1x a1x) (* a1y a1y) (* a1z a1z))))
  (setq a2 (sqrt (+ (* a2x a2x) (* a2y a2y) (* a2z a2z))))
  (setq a3 (sqrt (+ (* a3x a3x) (* a3y a3y) (* a3z a3z))))

  (setq va (+ (abs a1) (abs a2) (abs a3)
              (abs v1) (abs v2) (abs v3)
           )
  )
  (princ "\n")
  (princ va)
  (princ)

  (setq q1 (list x1 y1 z1))
  (setq q2 (list x2 y2 z2))
  (setq q3 (list x3 y3 z3))

  (if (= iscan 0)
   (progn
 
   (if (= ker 0)
    (progn
    (if (= pc "p")
        (progn
         (setvar "clayer" "m1") (command "_point" p1)
         (setvar "clayer" "m2") (command "_point" p2)
         (setvar "clayer" "m3") (command "_point" p3)
        )
        (if (= pc "c")
            (progn
             (setvar "clayer" "m1") (command "_circle" p1 r1)
             (setvar "clayer" "m2") (command "_circle" p2 r2)
             (setvar "clayer" "m3") (command "_circle" p3 r3)
            )
            (if (= pc "s")
                (progn
                 (setvar "clayer" "m1") (command "_sphere" p1 r1)
                 (setvar "clayer" "m2") (command "_sphere" p2 r2)
                 (setvar "clayer" "m3") (command "_sphere" p3 r3)
                )
            )
        )
    )
    )
    (progn
             (command "_move" o1 "" p1 q1)
             (command "_move" o2 "" p2 q2)
             (command "_move" o3 "" p3 q3)
    )    
   )
    
   )

  )
 
  (setq p1 q1)
  (setq p2 q2)  
  (setq p3 q3)  

  (setq iscan (+ 1 iscan))
  (if (= iscan scan) (setq iscan 0))

 )
 (setvar "clayer" "0")
 (command "_pline" p1 p2 p3 p1 "")
)


;;;*****************************************************************
;simula il moto di 10 oggetti sottoposti a forza gravitazionale
;gravita4 ver 1.5 23/07/2010
;Dott. Ing. Emanuele Ballasina
;cell 349-1813748
;mail ballacr75@libero.it

(defun c:gravita4 ()
(setvar "osmode" 0)
(setvar "dimzin" 0)
(setvar "cmdecho" 0)

(command "_-layer" "n" "m1" "_c" 10 "m1" "_s" "m1" "")
(command "_-layer" "n" "m2" "_c" 50 "m2" "_s" "m2" "")
(command "_-layer" "n" "m3" "_c" 90 "m3" "_s" "m3" "")
(command "_-layer" "n" "m4" "_c" 130 "m4" "_s" "m4" "")

(setq t 1) ;scansione tempo
(setq kdi 1) ;riduzione diametro cilindri
(setq scan 1) ;scansione posizione (non funziona >1 se ker=1)

(setq m1 100.0) ;massa
(setq m2 100.0)
(setq m3 100.0)
(setq m4 100.0)
(setq d1 0.1) ;densita
(setq d2 0.1)
(setq d3 0.1) 
(setq d4 0.1)
(setq r1 (expt (/ m1 d1) 0.3333)) ;raggio
(setq r2 (expt (/ m2 d2) 0.3333))
(setq r3 (expt (/ m3 d3) 0.3333))
(setq r4 (expt (/ m4 d4) 0.3333))
(setq r12 (+ r1 r2)) ;distanza di sfioro
(setq r13 (+ r1 r3))
(setq r23 (+ r2 r3))
(setq r14 (+ r1 r4))
(setq r24 (+ r2 r4))
(setq r34 (+ r3 r4))

(setq k1 1) ;abilita movimento pianeta
(setq k2 1)
(setq k3 1)
(setq k4 1)
(setq kur 1) ;abilita urti, con coefficente di rimbalzo, <1 smorza
(setq kbi 1) ;abilita rimbalzo tipo biliardo contro pareti dello schermo, <1 smorza
(setq ker 1) ;1=cancella pianeti vecchi, 0=mantiene tutti i pianeti
(setq c (getvar "VIEWCTR"))
(setq xsc (car c))
(setq ysc (cadr c))
(setq zsc (caddr c))
(setq currh (getvar "viewsize"))
(setq sizex (nth 0 (getvar "screensize")))
(setq sizey (nth 1 (getvar "screensize")))
(setq j (/ sizex sizey))
(setq currw (* j currh))
(setq h2 (/ currh 2.0))
(setq w2 (/ currw 2.0))
(setq xsa (- xsc w2))
(setq ysa (- ysc h2))
(setq zsa (- zsc h2))
(setq xsb (+ xsc w2))
(setq ysb (+ ysc h2))
(setq zsb (+ zsc h2))
(if (/= kbi 0) (command "_rectangle" (list xsa ysa) (list xsb ysb)))

(setq pc "c") ;punti,cerchi,sfere
(setq lc "n") ;abilita disegno linee tra un pianeta e gli altri
(setq tc "n") ;abilita disegno linee traiettoria

(setq x1 0) ;posizione
(setq y1 0)
(setq z1 0)
(setq x2 100)
(setq y2 0)
(setq z2 0)
(setq x3 200)
(setq y3 0)
(setq z3 0)
(setq x4 300)
(setq y4 0)
(setq z4 0)

(setq v1x 0.0) ;velocita
(setq v1y 0.0)
(setq v1z 0.0)
(setq v2x 0.0)
(setq v2y 0.0)
(setq v2z 0.0)
(setq v3x 0.0)
(setq v3y 0.0)
(setq v3z 0.0)
(setq v4x 0.0)
(setq v4y 0.0)
(setq v4z 0.0)

(setq p1 (list x1 y1 z1))
(setq p2 (list x2 y2 z2))
(setq p3 (list x3 y3 z3))
(setq p4 (list x4 y4 z4))

(if (= pc "p")
    (progn
     (setvar "clayer" "m1") (command "_point" p1) (setq o1 (cdr (car (entget (entlast)))))
     (setvar "clayer" "m2") (command "_point" p2) (setq o2 (cdr (car (entget (entlast)))))
     (setvar "clayer" "m3") (command "_point" p3) (setq o3 (cdr (car (entget (entlast)))))
     (setvar "clayer" "m4") (command "_point" p4) (setq o4 (cdr (car (entget (entlast)))))
    )
    (if (= pc "c")
        (progn
         (setvar "clayer" "m1") (command "_circle" p1 r1) (setq o1 (cdr (car (entget (entlast)))))
         (setvar "clayer" "m2") (command "_circle" p2 r2) (setq o2 (cdr (car (entget (entlast)))))
         (setvar "clayer" "m3") (command "_circle" p3 r3) (setq o3 (cdr (car (entget (entlast)))))
         (setvar "clayer" "m4") (command "_circle" p4 r4) (setq o4 (cdr (car (entget (entlast)))))
        )
        (if (= pc "s")
            (progn
             (setvar "clayer" "m1") (command "_sphere" p1 r1) (setq o1 (cdr (car (entget (entlast)))))
             (setvar "clayer" "m2") (command "_sphere" p2 r2) (setq o2 (cdr (car (entget (entlast)))))
             (setvar "clayer" "m3") (command "_sphere" p3 r3) (setq o3 (cdr (car (entget (entlast)))))
             (setvar "clayer" "m4") (command "_sphere" p4 r4) (setq o4 (cdr (car (entget (entlast)))))
            )
        )
    )
)

(setq va 1000)
(setq iscan 0)
 (while (> va 0.0001) ;scansione velocit ed accelerazione, se = 0 si ferma il lisp

  (setq v1 (sqrt (+ (* v1x v1x) (* v1y v1y) (* v1z v1z))))
  (setq v2 (sqrt (+ (* v2x v2x) (* v2y v2y) (* v2z v2z))))
  (setq v3 (sqrt (+ (* v3x v3x) (* v3y v3y) (* v3z v3z))))
  (setq v4 (sqrt (+ (* v4x v4x) (* v4y v4y) (* v4z v4z))))
  
  (setq d12 (distance p1 p2))
  (setq d13 (distance p1 p3))
  (setq d23 (distance p2 p3))
  (setq d14 (distance p1 p4))
  (setq d24 (distance p2 p4))
  (setq d34 (distance p3 p4))

  (setq dx12 (- x2 x1))  (setq dy12 (- y2 y1))  (setq dz12 (- z2 z1))
  (setq dx13 (- x3 x1))  (setq dy13 (- y3 y1))  (setq dz13 (- z3 z1))
  (setq dx23 (- x3 x2))  (setq dy23 (- y3 y2))  (setq dz23 (- z3 z2))
  (setq dx14 (- x4 x1))  (setq dy14 (- y4 y1))  (setq dz14 (- z4 z1))
  (setq dx24 (- x4 x2))  (setq dy24 (- y4 y2))  (setq dz24 (- z4 z2))
  (setq dx34 (- x4 x3))  (setq dy34 (- y4 y3))  (setq dz34 (- z4 z3))

;                   GRAVITA              REPULSIONE           ELASTICO       MOLLA
  (if (<= d12 r12) (setq d12 r12))
  (if (<= d13 r13) (setq d13 r13))
  (if (<= d23 r23) (setq d23 r23))
  (if (<= d14 r14) (setq d14 r14))
  (if (<= d24 r24) (setq d24 r24))
  (if (<= d34 r34) (setq d34 r34))
  (setq f12 (+ (* 1 (fgr m1 m2 d12)) (* 1 (fre m1 m2 d12)) (* 1 (fel d12)) (* 1 (fmo d12)) ))
  (setq f13 (+ (* 1 (fgr m1 m3 d13)) (* 1 (fre m1 m3 d13)) (* 1 (fel d13)) (* 1 (fmo d13)) ))
  (setq f23 (+ (* 1 (fgr m2 m3 d23)) (* 1 (fre m2 m3 d23)) (* 1 (fel d23)) (* 1 (fmo d23)) ))
  (setq f14 (+ (* 1 (fgr m1 m4 d14)) (* 1 (fre m1 m4 d14)) (* 1 (fel d14)) (* 1 (fmo d14)) ))
  (setq f24 (+ (* 1 (fgr m2 m4 d24)) (* 1 (fre m2 m4 d24)) (* 1 (fel d24)) (* 1 (fmo d24)) ))
  (setq f34 (+ (* 1 (fgr m3 m4 d34)) (* 1 (fre m3 m4 d34)) (* 1 (fel d34)) (* 1 (fmo d34)) ))

  (setq a12 (/ f12 m1))  (setq a21 (* -1 (/ f12 m2)))
  (setq a13 (/ f13 m1))  (setq a31 (* -1 (/ f13 m3)))
  (setq a23 (/ f23 m2))  (setq a32 (* -1 (/ f23 m3)))
  (setq a14 (/ f14 m1))  (setq a41 (* -1 (/ f14 m4)))
  (setq a24 (/ f24 m2))  (setq a42 (* -1 (/ f24 m4)))
  (setq a34 (/ f34 m3))  (setq a43 (* -1 (/ f34 m4)))
 
  (setq a1x (+ (* 1 (/ (fsx x1 y1 z1) m1)) (* 1 (/ (fwx r1) m1)) (* 1 v1x (/ (fvi m1 r1 v1) m1)) (/ (* a12 dx12) d12) (/ (* a13 dx13) d13) (/ (* a14 dx14) d14) ))
  (setq a1y (+ (* 1 (/ (fsy x1 y1 z1) m1)) (* 1 (/ (fwy r1) m1)) (* 1 v1y (/ (fvi m1 r1 v1) m1)) (/ (* a12 dy12) d12) (/ (* a13 dy13) d13) (/ (* a14 dy14) d14) ))
  (setq a1z (+ (* 1 (/ (fsz x1 y1 z1) m1)) (* 1 (/ (fwz r1) m1)) (* 1 v1z (/ (fvi m1 r1 v1) m1)) (/ (* a12 dz12) d12) (/ (* a13 dz13) d13) (/ (* a14 dz14) d14) ))
  (setq a2x (+ (* 1 (/ (fsx x2 y2 z2) m2)) (* 1 (/ (fwx r2) m2)) (* 1 v2x (/ (fvi m2 r2 v2) m2)) (/ (* a21 dx12) d12) (/ (* a23 dx23) d23) (/ (* a24 dx24) d24) ))
  (setq a2y (+ (* 1 (/ (fsy x2 y2 z2) m2)) (* 1 (/ (fwy r2) m2)) (* 1 v2y (/ (fvi m2 r2 v2) m2)) (/ (* a21 dy12) d12) (/ (* a23 dy23) d23) (/ (* a24 dy24) d24) ))
  (setq a2z (+ (* 1 (/ (fsz x2 y2 z2) m2)) (* 1 (/ (fwz r2) m2)) (* 1 v2z (/ (fvi m2 r2 v2) m2)) (/ (* a21 dz12) d12) (/ (* a23 dz23) d23) (/ (* a24 dz24) d24) ))
  (setq a3x (+ (* 1 (/ (fsx x3 y3 z3) m3)) (* 1 (/ (fwx r3) m3)) (* 1 v3x (/ (fvi m3 r3 v3) m3)) (/ (* a31 dx13) d13) (/ (* a32 dx23) d23) (/ (* a34 dx34) d34) ))
  (setq a3y (+ (* 1 (/ (fsy x3 y3 z3) m3)) (* 1 (/ (fwy r3) m3)) (* 1 v3y (/ (fvi m3 r3 v3) m3)) (/ (* a31 dy13) d13) (/ (* a32 dy23) d23) (/ (* a34 dy34) d34) ))
  (setq a3z (+ (* 1 (/ (fsz x3 y3 z3) m3)) (* 1 (/ (fwz r3) m3)) (* 1 v3z (/ (fvi m3 r3 v3) m3)) (/ (* a31 dz13) d13) (/ (* a32 dz23) d23) (/ (* a34 dz34) d34) ))
  (setq a4x (+ (* 1 (/ (fsx x4 y4 z4) m4)) (* 1 (/ (fwx r4) m4)) (* 1 v4x (/ (fvi m4 r4 v4) m4)) (/ (* a41 dx14) d14) (/ (* a42 dx24) d24) (/ (* a43 dx34) d34) ))
  (setq a4y (+ (* 1 (/ (fsy x4 y4 z4) m4)) (* 1 (/ (fwy r4) m4)) (* 1 v4y (/ (fvi m4 r4 v4) m4)) (/ (* a41 dy14) d14) (/ (* a42 dy24) d24) (/ (* a43 dy34) d34) ))
  (setq a4z (+ (* 1 (/ (fsz x4 y4 z4) m4)) (* 1 (/ (fwz r4) m4)) (* 1 v4z (/ (fvi m4 r4 v4) m4)) (/ (* a41 dz14) d14) (/ (* a42 dz24) d24) (/ (* a43 dz34) d34) ))

  (if (> d12 r12)
   (progn 
    (setq v1x (+ v1x (* a1x t)))  (setq v1y (+ v1y (* a1y t)))  (setq v1z (+ v1z (* a1z t)))
    (setq v2x (+ v2x (* a2x t)))  (setq v2y (+ v2y (* a2y t)))  (setq v2z (+ v2z (* a2z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v1i (list v1x v1y v1z)) ;velocita 1 prima dello scontro
     (setq v2i (list v2x v2y v2z)) ;velocita 2 prima dello scontro
     (setq v1i* (trans v1i 0 (list dx12 dy12 dz12)))
     (setq v2i* (trans v2i 0 (list dx12 dy12 dz12)))
     (setq v1i*x (car v1i*) v1i*y (cadr v1i*) v1i*z (caddr v1i*))
     (setq v2i*x (car v2i*) v2i*y (cadr v2i*) v2i*z (caddr v2i*))
     (setq v1f*z (* kur (/ (+ (* (- m1 m2) v1i*z) (* 2 m2 v2i*z)) (+ m1 m2))))
     (setq v2f*z (* kur (/ (+ (* (- m2 m1) v2i*z) (* 2 m1 v1i*z)) (+ m1 m2))))
     (setq v1f* (list v1i*x v1i*y v1f*z))
     (setq v2f* (list v2i*x v2i*y v2f*z))
     (setq v1f (trans v1f* (list dx12 dy12 dz12) 0))
     (setq v2f (trans v2f* (list dx12 dy12 dz12) 0))
     (setq v1x (car v1f) v1y (cadr v1f) v1z (caddr v1f))
     (setq v2x (car v2f) v2y (cadr v2f) v2z (caddr v2f))
    )
   )
  )
  (if (> d13 r13)
   (progn 
    (setq v1x (+ v1x (* a1x t)))  (setq v1y (+ v1y (* a1y t)))  (setq v1z (+ v1z (* a1z t)))
    (setq v3x (+ v3x (* a3x t)))  (setq v3y (+ v3y (* a3y t)))  (setq v3z (+ v3z (* a3z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v1i (list v1x v1y v1z)) ;velocita 1 prima dello scontro
     (setq v3i (list v3x v3y v3z)) ;velocita 3 prima dello scontro
     (setq v1i* (trans v1i 0 (list dx13 dy13 dz13)))
     (setq v3i* (trans v3i 0 (list dx13 dy13 dz13)))
     (setq v1i*x (car v1i*) v1i*y (cadr v1i*) v1i*z (caddr v1i*))
     (setq v3i*x (car v3i*) v3i*y (cadr v3i*) v3i*z (caddr v3i*))
     (setq v1f*z (* kur (/ (+ (* (- m1 m3) v1i*z) (* 2 m3 v3i*z)) (+ m1 m3))))
     (setq v3f*z (* kur (/ (+ (* (- m3 m1) v3i*z) (* 2 m1 v1i*z)) (+ m1 m3))))
     (setq v1f* (list v1i*x v1i*y v1f*z))
     (setq v3f* (list v3i*x v3i*y v3f*z))
     (setq v1f (trans v1f* (list dx13 dy13 dz13) 0))
     (setq v3f (trans v3f* (list dx13 dy13 dz13) 0))
     (setq v1x (car v1f) v1y (cadr v1f) v1z (caddr v1f))
     (setq v3x (car v3f) v3y (cadr v3f) v3z (caddr v3f))
    )
   )
  )
  (if (> d23 r23)
   (progn 
    (setq v2x (+ v2x (* a2x t)))  (setq v2y (+ v2y (* a2y t)))  (setq v2z (+ v2z (* a2z t)))
    (setq v3x (+ v3x (* a3x t)))  (setq v3y (+ v3y (* a3y t)))  (setq v3z (+ v3z (* a3z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v2i (list v2x v2y v2z)) ;velocita 2 prima dello scontro
     (setq v3i (list v3x v3y v3z)) ;velocita 3 prima dello scontro
     (setq v2i* (trans v2i 0 (list dx23 dy23 dz23)))
     (setq v3i* (trans v3i 0 (list dx23 dy23 dz23)))
     (setq v2i*x (car v2i*) v2i*y (cadr v2i*) v2i*z (caddr v2i*))
     (setq v3i*x (car v3i*) v3i*y (cadr v3i*) v3i*z (caddr v3i*))
     (setq v2f*z (* kur (/ (+ (* (- m2 m3) v2i*z) (* 2 m3 v3i*z)) (+ m2 m3))))
     (setq v3f*z (* kur (/ (+ (* (- m3 m2) v3i*z) (* 2 m2 v2i*z)) (+ m2 m3))))
     (setq v2f* (list v2i*x v2i*y v2f*z))
     (setq v3f* (list v3i*x v3i*y v3f*z))
     (setq v2f (trans v2f* (list dx23 dy23 dz23) 0))
     (setq v3f (trans v3f* (list dx23 dy23 dz23) 0))
     (setq v2x (car v2f) v2y (cadr v2f) v2z (caddr v2f))
     (setq v3x (car v3f) v3y (cadr v3f) v3z (caddr v3f))
    )
   )
  )
  (if (> d14 r14)
   (progn 
    (setq v1x (+ v1x (* a1x t)))  (setq v1y (+ v1y (* a1y t)))  (setq v1z (+ v1z (* a1z t)))
    (setq v4x (+ v4x (* a4x t)))  (setq v4y (+ v4y (* a4y t)))  (setq v4z (+ v4z (* a4z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v1i (list v1x v1y v1z)) ;velocita 1 prima dello scontro
     (setq v4i (list v4x v4y v4z)) ;velocita 4 prima dello scontro
     (setq v1i* (trans v1i 0 (list dx14 dy14 dz14)))
     (setq v4i* (trans v4i 0 (list dx14 dy14 dz14)))
     (setq v1i*x (car v1i*) v1i*y (cadr v1i*) v1i*z (caddr v1i*))
     (setq v4i*x (car v4i*) v4i*y (cadr v4i*) v4i*z (caddr v4i*))
     (setq v1f*z (* kur (/ (+ (* (- m1 m4) v1i*z) (* 2 m4 v4i*z)) (+ m1 m4))))
     (setq v4f*z (* kur (/ (+ (* (- m4 m1) v4i*z) (* 2 m1 v1i*z)) (+ m1 m4))))
     (setq v1f* (list v1i*x v1i*y v1f*z))
     (setq v4f* (list v4i*x v4i*y v4f*z))
     (setq v1f (trans v1f* (list dx14 dy14 dz14) 0))
     (setq v4f (trans v4f* (list dx14 dy14 dz14) 0))
     (setq v1x (car v1f) v1y (cadr v1f) v1z (caddr v1f))
     (setq v4x (car v4f) v4y (cadr v4f) v4z (caddr v4f))
    )
   )
  )
  (if (> d24 r24)
   (progn 
    (setq v2x (+ v2x (* a2x t)))  (setq v2y (+ v2y (* a2y t)))  (setq v2z (+ v2z (* a2z t)))
    (setq v4x (+ v4x (* a4x t)))  (setq v4y (+ v4y (* a4y t)))  (setq v4z (+ v4z (* a4z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v2i (list v2x v2y v2z)) ;velocita 2 prima dello scontro
     (setq v4i (list v4x v4y v4z)) ;velocita 4 prima dello scontro
     (setq v2i* (trans v2i 0 (list dx24 dy24 dz24)))
     (setq v4i* (trans v4i 0 (list dx24 dy24 dz24)))
     (setq v2i*x (car v2i*) v2i*y (cadr v2i*) v2i*z (caddr v2i*))
     (setq v4i*x (car v4i*) v4i*y (cadr v4i*) v4i*z (caddr v4i*))
     (setq v2f*z (* kur (/ (+ (* (- m2 m4) v2i*z) (* 2 m4 v4i*z)) (+ m2 m4))))
     (setq v4f*z (* kur (/ (+ (* (- m4 m2) v4i*z) (* 2 m2 v2i*z)) (+ m2 m4))))
     (setq v2f* (list v2i*x v2i*y v2f*z))
     (setq v4f* (list v4i*x v4i*y v4f*z))
     (setq v2f (trans v2f* (list dx24 dy24 dz24) 0))
     (setq v4f (trans v4f* (list dx24 dy24 dz24) 0))
     (setq v2x (car v2f) v2y (cadr v2f) v2z (caddr v2f))
     (setq v4x (car v4f) v4y (cadr v4f) v4z (caddr v4f))
    )
   )
  )
  (if (> d34 r34)
   (progn 
    (setq v3x (+ v3x (* a3x t)))  (setq v3y (+ v3y (* a3y t)))  (setq v3z (+ v3z (* a3z t)))
    (setq v4x (+ v4x (* a4x t)))  (setq v4y (+ v4y (* a4y t)))  (setq v4z (+ v4z (* a4z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v3i (list v3x v3y v3z)) ;velocita 3 prima dello scontro
     (setq v4i (list v4x v4y v4z)) ;velocita 4 prima dello scontro
     (setq v3i* (trans v3i 0 (list dx34 dy34 dz34)))
     (setq v4i* (trans v4i 0 (list dx34 dy34 dz34)))
     (setq v3i*x (car v3i*) v3i*y (cadr v3i*) v3i*z (caddr v3i*))
     (setq v4i*x (car v4i*) v4i*y (cadr v4i*) v4i*z (caddr v4i*))
     (setq v3f*z (* kur (/ (+ (* (- m3 m4) v3i*z) (* 2 m4 v4i*z)) (+ m3 m4))))
     (setq v4f*z (* kur (/ (+ (* (- m4 m3) v4i*z) (* 2 m3 v3i*z)) (+ m3 m4))))
     (setq v3f* (list v3i*x v3i*y v3f*z))
     (setq v4f* (list v4i*x v4i*y v4f*z))
     (setq v3f (trans v3f* (list dx34 dy34 dz34) 0))
     (setq v4f (trans v4f* (list dx34 dy34 dz34) 0))
     (setq v3x (car v3f) v3y (cadr v3f) v3z (caddr v3f))
     (setq v4x (car v4f) v4y (cadr v4f) v4z (caddr v4f))
    )
   )
  )

  (if (< (- x1 r1) xsa) (setq v1x (* (+ (* -2 kbi) 1) v1x) ) )
  (if (< (- y1 r1) ysa) (setq v1y (* (+ (* -2 kbi) 1) v1y) ) )   
  (if (< (- z1 r1) zsa) (setq v1z (* (+ (* -2 kbi) 1) v1z) ) )   
  (if (> (+ x1 r1) xsb) (setq v1x (* (+ (* -2 kbi) 1) v1x) ) )   
  (if (> (+ y1 r1) ysb) (setq v1y (* (+ (* -2 kbi) 1) v1y) ) )   
  (if (> (+ z1 r1) zsb) (setq v1z (* (+ (* -2 kbi) 1) v1z) ) )   
  (if (< (- x2 r2) xsa) (setq v2x (* (+ (* -2 kbi) 1) v2x) ) )   
  (if (< (- y2 r2) ysa) (setq v2y (* (+ (* -2 kbi) 1) v2y) ) )   
  (if (< (- z2 r2) zsa) (setq v2z (* (+ (* -2 kbi) 1) v2z) ) )   
  (if (> (+ x2 r2) xsb) (setq v2x (* (+ (* -2 kbi) 1) v2x) ) )   
  (if (> (+ y2 r2) ysb) (setq v2y (* (+ (* -2 kbi) 1) v2y) ) )   
  (if (> (+ z2 r2) zsb) (setq v2z (* (+ (* -2 kbi) 1) v2z) ) )   
  (if (< (- x3 r3) xsa) (setq v3x (* (+ (* -2 kbi) 1) v3x) ) )   
  (if (< (- y3 r3) ysa) (setq v3y (* (+ (* -2 kbi) 1) v3y) ) )   
  (if (< (- z3 r3) zsa) (setq v3z (* (+ (* -2 kbi) 1) v3z) ) )   
  (if (> (+ x3 r3) xsb) (setq v3x (* (+ (* -2 kbi) 1) v3x) ) )   
  (if (> (+ y3 r3) ysb) (setq v3y (* (+ (* -2 kbi) 1) v3y) ) )   
  (if (> (+ z3 r3) zsb) (setq v3z (* (+ (* -2 kbi) 1) v3z) ) )   
  (if (< (- x4 r4) xsa) (setq v4x (* (+ (* -2 kbi) 1) v4x) ) )   
  (if (< (- y4 r4) ysa) (setq v4y (* (+ (* -2 kbi) 1) v4y) ) )   
  (if (< (- z4 r4) zsa) (setq v4z (* (+ (* -2 kbi) 1) v4z) ) )   
  (if (> (+ x4 r4) xsb) (setq v4x (* (+ (* -2 kbi) 1) v4x) ) )   
  (if (> (+ y4 r4) ysb) (setq v4y (* (+ (* -2 kbi) 1) v4y) ) )   
  (if (> (+ z4 r4) zsb) (setq v4z (* (+ (* -2 kbi) 1) v4z) ) )   

  (setq s1x (+ (* v1x t) (* 0.5 a1x t t)))  (setq s1y (+ (* v1y t) (* 0.5 a1y t t)))  (setq s1z (+ (* v1z t) (* 0.5 a1z t t)))
  (setq s2x (+ (* v2x t) (* 0.5 a2x t t)))  (setq s2y (+ (* v2y t) (* 0.5 a2y t t)))  (setq s2z (+ (* v2z t) (* 0.5 a2z t t)))
  (setq s3x (+ (* v3x t) (* 0.5 a3x t t)))  (setq s3y (+ (* v3y t) (* 0.5 a3y t t)))  (setq s3z (+ (* v3z t) (* 0.5 a3z t t)))
  (setq s4x (+ (* v4x t) (* 0.5 a4x t t)))  (setq s4y (+ (* v4y t) (* 0.5 a4y t t)))  (setq s4z (+ (* v4z t) (* 0.5 a4z t t)))

  (setq x1 (+ x1 (* k1 s1x)))  (setq y1 (+ y1 (* k1 s1y)))  (setq z1 (+ z1 (* k1 s1z)))
  (setq x2 (+ x2 (* k2 s2x)))  (setq y2 (+ y2 (* k2 s2y)))  (setq z2 (+ z2 (* k2 s2z)))
  (setq x3 (+ x3 (* k3 s3x)))  (setq y3 (+ y3 (* k3 s3y)))  (setq z3 (+ z3 (* k3 s3z)))
  (setq x4 (+ x4 (* k4 s4x)))  (setq y4 (+ y4 (* k4 s4y)))  (setq z4 (+ z4 (* k4 s4z)))

  (setq a1 (sqrt (+ (* a1x a1x) (* a1y a1y) (* a1z a1z))))
  (setq a2 (sqrt (+ (* a2x a2x) (* a2y a2y) (* a2z a2z))))
  (setq a3 (sqrt (+ (* a3x a3x) (* a3y a3y) (* a3z a3z))))
  (setq a4 (sqrt (+ (* a4x a4x) (* a4y a4y) (* a4z a4z))))

  (setq va (+ (abs a1) (abs a2) (abs a3) (abs a4)
              (abs v1) (abs v2) (abs v3) (abs v4)
           )
  )
  (princ "\n")
  (princ va)
  (princ)

  (setq q1 (list x1 y1 z1))
  (setq q2 (list x2 y2 z2))
  (setq q3 (list x3 y3 z3))
  (setq q4 (list x4 y4 z4))

  (if (= iscan 0)
   (progn
 
   (if (= ker 0)
    (progn
    (if (= pc "p")
        (progn
         (setvar "clayer" "m1") (command "_point" p1)
         (setvar "clayer" "m2") (command "_point" p2)
         (setvar "clayer" "m3") (command "_point" p3)
         (setvar "clayer" "m4") (command "_point" p4)
        )
        (if (= pc "c")
            (progn
             (setvar "clayer" "m1") (command "_circle" p1 r1)
             (setvar "clayer" "m2") (command "_circle" p2 r2)
             (setvar "clayer" "m3") (command "_circle" p3 r3)
             (setvar "clayer" "m4") (command "_circle" p4 r4)
            )
            (if (= pc "s")
                (progn
                 (setvar "clayer" "m1") (command "_sphere" p1 r1)
                 (setvar "clayer" "m2") (command "_sphere" p2 r2)
                 (setvar "clayer" "m3") (command "_sphere" p3 r3)
                 (setvar "clayer" "m4") (command "_sphere" p4 r4)
                )
            )
        )
    )
    )
    (progn
             (command "_move" o1 "" p1 q1)
             (command "_move" o2 "" p2 q2)
             (command "_move" o3 "" p3 q3)
             (command "_move" o4 "" p4 q4)
    )    
   )
    
   )

  )
 
  (setq p1 q1)
  (setq p2 q2)  
  (setq p3 q3)  
  (setq p4 q4)  

  (setq iscan (+ 1 iscan))
  (if (= iscan scan) (setq iscan 0))

 )
 (setvar "clayer" "0")
 (command "_pline" p1 p2 p3 p4 p1 "")
)


;;;*****************************************************************
;simula il moto di 10 oggetti sottoposti a forza gravitazionale
;gravita5 ver 1.5 23/07/2010
;Dott. Ing. Emanuele Ballasina
;cell 349-1813748
;mail ballacr75@libero.it

(defun c:gravita5 ()
(setvar "osmode" 0)
(setvar "dimzin" 0)
(setvar "cmdecho" 0)

(command "_-layer" "n" "m1" "_c" 10 "m1" "_s" "m1" "")
(command "_-layer" "n" "m2" "_c" 50 "m2" "_s" "m2" "")
(command "_-layer" "n" "m3" "_c" 90 "m3" "_s" "m3" "")
(command "_-layer" "n" "m4" "_c" 130 "m4" "_s" "m4" "")
(command "_-layer" "n" "m5" "_c" 160 "m5" "_s" "m5" "")

(setq t 1) ;scansione tempo
(setq kdi 1) ;riduzione diametro cilindri
(setq scan 1) ;scansione posizione (non funziona >1 se ker=1)

(setq m1 100.0) ;massa
(setq m2 100.0)
(setq m3 100.0)
(setq m4 100.0)
(setq m5 100.0)
(setq d1 0.1) ;densita
(setq d2 0.1)
(setq d3 0.1) 
(setq d4 0.1)
(setq d5 0.1)
(setq r1 (expt (/ m1 d1) 0.3333)) ;raggio
(setq r2 (expt (/ m2 d2) 0.3333))
(setq r3 (expt (/ m3 d3) 0.3333))
(setq r4 (expt (/ m4 d4) 0.3333))
(setq r5 (expt (/ m5 d5) 0.3333))
(setq r12 (+ r1 r2)) ;distanza di sfioro
(setq r13 (+ r1 r3))
(setq r23 (+ r2 r3))
(setq r14 (+ r1 r4))
(setq r24 (+ r2 r4))
(setq r34 (+ r3 r4))
(setq r15 (+ r1 r5))
(setq r25 (+ r2 r5))
(setq r35 (+ r3 r5))
(setq r45 (+ r4 r5))

(setq k1 1) ;abilita movimento pianeta
(setq k2 1)
(setq k3 1)
(setq k4 1)
(setq k5 1)
(setq kur 1) ;abilita urti, con coefficente di rimbalzo, <1 smorza
(setq kbi 1) ;abilita rimbalzo tipo biliardo contro pareti dello schermo, <1 smorza
(setq ker 1) ;1=cancella pianeti vecchi, 0=mantiene tutti i pianeti
(setq c (getvar "VIEWCTR"))
(setq xsc (car c))
(setq ysc (cadr c))
(setq zsc (caddr c))
(setq currh (getvar "viewsize"))
(setq sizex (nth 0 (getvar "screensize")))
(setq sizey (nth 1 (getvar "screensize")))
(setq j (/ sizex sizey))
(setq currw (* j currh))
(setq h2 (/ currh 2.0))
(setq w2 (/ currw 2.0))
(setq xsa (- xsc w2))
(setq ysa (- ysc h2))
(setq zsa (- zsc h2))
(setq xsb (+ xsc w2))
(setq ysb (+ ysc h2))
(setq zsb (+ zsc h2))
(if (/= kbi 0) (command "_rectangle" (list xsa ysa) (list xsb ysb)))

(setq pc "c") ;punti,cerchi,sfere
(setq lc "n") ;abilita disegno linee tra un pianeta e gli altri
(setq tc "n") ;abilita disegno linee traiettoria

(setq x1 0) ;posizione
(setq y1 0)
(setq z1 0)
(setq x2 100)
(setq y2 0)
(setq z2 0)
(setq x3 200)
(setq y3 30)
(setq z3 0)
(setq x4 300)
(setq y4 0)
(setq z4 0)
(setq x5 400)
(setq y5 0)
(setq z5 0)

(setq v1x 0.0) ;velocita
(setq v1y 0.0)
(setq v1z 0.0)
(setq v2x 0.0)
(setq v2y 0.0)
(setq v2z 0.0)
(setq v3x 0.0)
(setq v3y 0.0)
(setq v3z 0.0)
(setq v4x 0.0)
(setq v4y 0.0)
(setq v4z 0.0)
(setq v5x 0.0)
(setq v5y 0.0)
(setq v5z 0.0) 

(setq p1 (list x1 y1 z1))
(setq p2 (list x2 y2 z2))
(setq p3 (list x3 y3 z3))
(setq p4 (list x4 y4 z4))
(setq p5 (list x5 y5 z5))

(if (= pc "p")
    (progn
     (setvar "clayer" "m1") (command "_point" p1) (setq o1 (cdr (car (entget (entlast)))))
     (setvar "clayer" "m2") (command "_point" p2) (setq o2 (cdr (car (entget (entlast)))))
     (setvar "clayer" "m3") (command "_point" p3) (setq o3 (cdr (car (entget (entlast)))))
     (setvar "clayer" "m4") (command "_point" p4) (setq o4 (cdr (car (entget (entlast)))))
     (setvar "clayer" "m5") (command "_point" p5) (setq o5 (cdr (car (entget (entlast)))))
    )
    (if (= pc "c")
        (progn
         (setvar "clayer" "m1") (command "_circle" p1 r1) (setq o1 (cdr (car (entget (entlast)))))
         (setvar "clayer" "m2") (command "_circle" p2 r2) (setq o2 (cdr (car (entget (entlast)))))
         (setvar "clayer" "m3") (command "_circle" p3 r3) (setq o3 (cdr (car (entget (entlast)))))
         (setvar "clayer" "m4") (command "_circle" p4 r4) (setq o4 (cdr (car (entget (entlast)))))
         (setvar "clayer" "m5") (command "_circle" p5 r5) (setq o5 (cdr (car (entget (entlast)))))
        )
        (if (= pc "s")
            (progn
             (setvar "clayer" "m1") (command "_sphere" p1 r1) (setq o1 (cdr (car (entget (entlast)))))
             (setvar "clayer" "m2") (command "_sphere" p2 r2) (setq o2 (cdr (car (entget (entlast)))))
             (setvar "clayer" "m3") (command "_sphere" p3 r3) (setq o3 (cdr (car (entget (entlast)))))
             (setvar "clayer" "m4") (command "_sphere" p4 r4) (setq o4 (cdr (car (entget (entlast)))))
             (setvar "clayer" "m5") (command "_sphere" p5 r5) (setq o5 (cdr (car (entget (entlast)))))
            )
        )
    )
)

(setq va 1000)
(setq iscan 0)
 (while (> va 0.0001) ;scansione velocit ed accelerazione, se = 0 si ferma il lisp

  (setq v1 (sqrt (+ (* v1x v1x) (* v1y v1y) (* v1z v1z))))
  (setq v2 (sqrt (+ (* v2x v2x) (* v2y v2y) (* v2z v2z))))
  (setq v3 (sqrt (+ (* v3x v3x) (* v3y v3y) (* v3z v3z))))
  (setq v4 (sqrt (+ (* v4x v4x) (* v4y v4y) (* v4z v4z))))
  (setq v5 (sqrt (+ (* v5x v5x) (* v5y v5y) (* v5z v5z))))
  
  (setq d12 (distance p1 p2))
  (setq d13 (distance p1 p3))
  (setq d23 (distance p2 p3))
  (setq d14 (distance p1 p4))
  (setq d24 (distance p2 p4))
  (setq d34 (distance p3 p4))
  (setq d15 (distance p1 p5))
  (setq d25 (distance p2 p5))
  (setq d35 (distance p3 p5))
  (setq d45 (distance p4 p5))

  (setq dx12 (- x2 x1))  (setq dy12 (- y2 y1))  (setq dz12 (- z2 z1))
  (setq dx13 (- x3 x1))  (setq dy13 (- y3 y1))  (setq dz13 (- z3 z1))
  (setq dx23 (- x3 x2))  (setq dy23 (- y3 y2))  (setq dz23 (- z3 z2))
  (setq dx14 (- x4 x1))  (setq dy14 (- y4 y1))  (setq dz14 (- z4 z1))
  (setq dx24 (- x4 x2))  (setq dy24 (- y4 y2))  (setq dz24 (- z4 z2))
  (setq dx34 (- x4 x3))  (setq dy34 (- y4 y3))  (setq dz34 (- z4 z3))
  (setq dx15 (- x5 x1))  (setq dy15 (- y5 y1))  (setq dz15 (- z5 z1))
  (setq dx25 (- x5 x2))  (setq dy25 (- y5 y2))  (setq dz25 (- z5 z2))
  (setq dx35 (- x5 x3))  (setq dy35 (- y5 y3))  (setq dz35 (- z5 z3))
  (setq dx45 (- x5 x4))  (setq dy45 (- y5 y4))  (setq dz45 (- z5 z4))

;                   GRAVITA              REPULSIONE           ELASTICO       MOLLA
  (if (<= d12 r12) (setq d12 r12))
  (if (<= d13 r13) (setq d13 r13))
  (if (<= d23 r23) (setq d23 r23))
  (if (<= d14 r14) (setq d14 r14))
  (if (<= d24 r24) (setq d24 r24))
  (if (<= d34 r34) (setq d34 r34))
  (if (<= d15 r15) (setq d15 r15))
  (if (<= d25 r25) (setq d25 r25))
  (if (<= d35 r35) (setq d35 r35))
  (if (<= d45 r45) (setq d45 r45))
  (setq f12 (+ (* 1 (fgr m1 m2 d12)) (* 1 (fre m1 m2 d12)) (* 1 (fel d12)) (* 1 (fmo d12)) ))
  (setq f13 (+ (* 1 (fgr m1 m3 d13)) (* 1 (fre m1 m3 d13)) (* 1 (fel d13)) (* 1 (fmo d13)) ))
  (setq f23 (+ (* 1 (fgr m2 m3 d23)) (* 1 (fre m2 m3 d23)) (* 1 (fel d23)) (* 1 (fmo d23)) ))
  (setq f14 (+ (* 1 (fgr m1 m4 d14)) (* 1 (fre m1 m4 d14)) (* 1 (fel d14)) (* 1 (fmo d14)) ))
  (setq f24 (+ (* 1 (fgr m2 m4 d24)) (* 1 (fre m2 m4 d24)) (* 1 (fel d24)) (* 1 (fmo d24)) ))
  (setq f34 (+ (* 1 (fgr m3 m4 d34)) (* 1 (fre m3 m4 d34)) (* 1 (fel d34)) (* 1 (fmo d34)) ))
  (setq f15 (+ (* 1 (fgr m1 m5 d15)) (* 1 (fre m1 m5 d15)) (* 1 (fel d15)) (* 1 (fmo d15)) ))
  (setq f25 (+ (* 1 (fgr m2 m5 d25)) (* 1 (fre m2 m5 d25)) (* 1 (fel d25)) (* 1 (fmo d25)) ))
  (setq f35 (+ (* 1 (fgr m3 m5 d35)) (* 1 (fre m3 m5 d35)) (* 1 (fel d35)) (* 1 (fmo d35)) ))
  (setq f45 (+ (* 1 (fgr m4 m5 d45)) (* 1 (fre m4 m5 d45)) (* 1 (fel d45)) (* 1 (fmo d45)) ))

  (setq a12 (/ f12 m1))  (setq a21 (* -1 (/ f12 m2)))
  (setq a13 (/ f13 m1))  (setq a31 (* -1 (/ f13 m3)))
  (setq a23 (/ f23 m2))  (setq a32 (* -1 (/ f23 m3)))
  (setq a14 (/ f14 m1))  (setq a41 (* -1 (/ f14 m4)))
  (setq a24 (/ f24 m2))  (setq a42 (* -1 (/ f24 m4)))
  (setq a34 (/ f34 m3))  (setq a43 (* -1 (/ f34 m4)))
  (setq a15 (/ f15 m1))  (setq a51 (* -1 (/ f15 m5)))
  (setq a25 (/ f25 m2))  (setq a52 (* -1 (/ f25 m5)))
  (setq a35 (/ f35 m3))  (setq a53 (* -1 (/ f35 m5)))
  (setq a45 (/ f45 m4))  (setq a54 (* -1 (/ f45 m5)))
 
  (setq a1x (+ (* 1 (/ (fsx x1 y1 z1) m1)) (* 1 (/ (fwx r1) m1)) (* 1 v1x (/ (fvi m1 r1 v1) m1)) (/ (* a12 dx12) d12) (/ (* a13 dx13) d13) (/ (* a14 dx14) d14) (/ (* a15 dx15) d15) ))
  (setq a1y (+ (* 1 (/ (fsy x1 y1 z1) m1)) (* 1 (/ (fwy r1) m1)) (* 1 v1y (/ (fvi m1 r1 v1) m1)) (/ (* a12 dy12) d12) (/ (* a13 dy13) d13) (/ (* a14 dy14) d14) (/ (* a15 dy15) d15) ))
  (setq a1z (+ (* 1 (/ (fsz x1 y1 z1) m1)) (* 1 (/ (fwz r1) m1)) (* 1 v1z (/ (fvi m1 r1 v1) m1)) (/ (* a12 dz12) d12) (/ (* a13 dz13) d13) (/ (* a14 dz14) d14) (/ (* a15 dz15) d15) ))
  (setq a2x (+ (* 1 (/ (fsx x2 y2 z2) m2)) (* 1 (/ (fwx r2) m2)) (* 1 v2x (/ (fvi m2 r2 v2) m2)) (/ (* a21 dx12) d12) (/ (* a23 dx23) d23) (/ (* a24 dx24) d24) (/ (* a25 dx25) d25) ))
  (setq a2y (+ (* 1 (/ (fsy x2 y2 z2) m2)) (* 1 (/ (fwy r2) m2)) (* 1 v2y (/ (fvi m2 r2 v2) m2)) (/ (* a21 dy12) d12) (/ (* a23 dy23) d23) (/ (* a24 dy24) d24) (/ (* a25 dy25) d25) ))
  (setq a2z (+ (* 1 (/ (fsz x2 y2 z2) m2)) (* 1 (/ (fwz r2) m2)) (* 1 v2z (/ (fvi m2 r2 v2) m2)) (/ (* a21 dz12) d12) (/ (* a23 dz23) d23) (/ (* a24 dz24) d24) (/ (* a25 dz25) d25) ))
  (setq a3x (+ (* 1 (/ (fsx x3 y3 z3) m3)) (* 1 (/ (fwx r3) m3)) (* 1 v3x (/ (fvi m3 r3 v3) m3)) (/ (* a31 dx13) d13) (/ (* a32 dx23) d23) (/ (* a34 dx34) d34) (/ (* a35 dx35) d35) ))
  (setq a3y (+ (* 1 (/ (fsy x3 y3 z3) m3)) (* 1 (/ (fwy r3) m3)) (* 1 v3y (/ (fvi m3 r3 v3) m3)) (/ (* a31 dy13) d13) (/ (* a32 dy23) d23) (/ (* a34 dy34) d34) (/ (* a35 dy35) d35) ))
  (setq a3z (+ (* 1 (/ (fsz x3 y3 z3) m3)) (* 1 (/ (fwz r3) m3)) (* 1 v3z (/ (fvi m3 r3 v3) m3)) (/ (* a31 dz13) d13) (/ (* a32 dz23) d23) (/ (* a34 dz34) d34) (/ (* a35 dz35) d35) ))
  (setq a4x (+ (* 1 (/ (fsx x4 y4 z4) m4)) (* 1 (/ (fwx r4) m4)) (* 1 v4x (/ (fvi m4 r4 v4) m4)) (/ (* a41 dx14) d14) (/ (* a42 dx24) d24) (/ (* a43 dx34) d34) (/ (* a45 dx45) d45) ))
  (setq a4y (+ (* 1 (/ (fsy x4 y4 z4) m4)) (* 1 (/ (fwy r4) m4)) (* 1 v4y (/ (fvi m4 r4 v4) m4)) (/ (* a41 dy14) d14) (/ (* a42 dy24) d24) (/ (* a43 dy34) d34) (/ (* a45 dy45) d45) ))
  (setq a4z (+ (* 1 (/ (fsz x4 y4 z4) m4)) (* 1 (/ (fwz r4) m4)) (* 1 v4z (/ (fvi m4 r4 v4) m4)) (/ (* a41 dz14) d14) (/ (* a42 dz24) d24) (/ (* a43 dz34) d34) (/ (* a45 dz45) d45) ))
  (setq a5x (+ (* 1 (/ (fsx x5 y5 z5) m5)) (* 1 (/ (fwx r5) m5)) (* 1 v5x (/ (fvi m5 r5 v5) m5)) (/ (* a51 dx15) d15) (/ (* a52 dx25) d25) (/ (* a53 dx35) d35) (/ (* a54 dx45) d45) ))
  (setq a5y (+ (* 1 (/ (fsy x5 y5 z5) m5)) (* 1 (/ (fwy r5) m5)) (* 1 v5y (/ (fvi m5 r5 v5) m5)) (/ (* a51 dy15) d15) (/ (* a52 dy25) d25) (/ (* a53 dy35) d35) (/ (* a54 dy45) d45) ))
  (setq a5z (+ (* 1 (/ (fsz x5 y5 z5) m5)) (* 1 (/ (fwz r5) m5)) (* 1 v5z (/ (fvi m5 r5 v5) m5)) (/ (* a51 dz15) d15) (/ (* a52 dz25) d25) (/ (* a53 dz35) d35) (/ (* a54 dz45) d45) ))

  (if (> d12 r12)
   (progn 
    (setq v1x (+ v1x (* a1x t)))  (setq v1y (+ v1y (* a1y t)))  (setq v1z (+ v1z (* a1z t)))
    (setq v2x (+ v2x (* a2x t)))  (setq v2y (+ v2y (* a2y t)))  (setq v2z (+ v2z (* a2z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v1i (list v1x v1y v1z)) ;velocita 1 prima dello scontro
     (setq v2i (list v2x v2y v2z)) ;velocita 2 prima dello scontro
     (setq v1i* (trans v1i 0 (list dx12 dy12 dz12)))
     (setq v2i* (trans v2i 0 (list dx12 dy12 dz12)))
     (setq v1i*x (car v1i*) v1i*y (cadr v1i*) v1i*z (caddr v1i*))
     (setq v2i*x (car v2i*) v2i*y (cadr v2i*) v2i*z (caddr v2i*))
     (setq v1f*z (* kur (/ (+ (* (- m1 m2) v1i*z) (* 2 m2 v2i*z)) (+ m1 m2))))
     (setq v2f*z (* kur (/ (+ (* (- m2 m1) v2i*z) (* 2 m1 v1i*z)) (+ m1 m2))))
     (setq v1f* (list v1i*x v1i*y v1f*z))
     (setq v2f* (list v2i*x v2i*y v2f*z))
     (setq v1f (trans v1f* (list dx12 dy12 dz12) 0))
     (setq v2f (trans v2f* (list dx12 dy12 dz12) 0))
     (setq v1x (car v1f) v1y (cadr v1f) v1z (caddr v1f))
     (setq v2x (car v2f) v2y (cadr v2f) v2z (caddr v2f))
    )
   )
  )
  (if (> d13 r13)
   (progn 
    (setq v1x (+ v1x (* a1x t)))  (setq v1y (+ v1y (* a1y t)))  (setq v1z (+ v1z (* a1z t)))
    (setq v3x (+ v3x (* a3x t)))  (setq v3y (+ v3y (* a3y t)))  (setq v3z (+ v3z (* a3z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v1i (list v1x v1y v1z)) ;velocita 1 prima dello scontro
     (setq v3i (list v3x v3y v3z)) ;velocita 3 prima dello scontro
     (setq v1i* (trans v1i 0 (list dx13 dy13 dz13)))
     (setq v3i* (trans v3i 0 (list dx13 dy13 dz13)))
     (setq v1i*x (car v1i*) v1i*y (cadr v1i*) v1i*z (caddr v1i*))
     (setq v3i*x (car v3i*) v3i*y (cadr v3i*) v3i*z (caddr v3i*))
     (setq v1f*z (* kur (/ (+ (* (- m1 m3) v1i*z) (* 2 m3 v3i*z)) (+ m1 m3))))
     (setq v3f*z (* kur (/ (+ (* (- m3 m1) v3i*z) (* 2 m1 v1i*z)) (+ m1 m3))))
     (setq v1f* (list v1i*x v1i*y v1f*z))
     (setq v3f* (list v3i*x v3i*y v3f*z))
     (setq v1f (trans v1f* (list dx13 dy13 dz13) 0))
     (setq v3f (trans v3f* (list dx13 dy13 dz13) 0))
     (setq v1x (car v1f) v1y (cadr v1f) v1z (caddr v1f))
     (setq v3x (car v3f) v3y (cadr v3f) v3z (caddr v3f))
    )
   )
  )
  (if (> d23 r23)
   (progn 
    (setq v2x (+ v2x (* a2x t)))  (setq v2y (+ v2y (* a2y t)))  (setq v2z (+ v2z (* a2z t)))
    (setq v3x (+ v3x (* a3x t)))  (setq v3y (+ v3y (* a3y t)))  (setq v3z (+ v3z (* a3z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v2i (list v2x v2y v2z)) ;velocita 2 prima dello scontro
     (setq v3i (list v3x v3y v3z)) ;velocita 3 prima dello scontro
     (setq v2i* (trans v2i 0 (list dx23 dy23 dz23)))
     (setq v3i* (trans v3i 0 (list dx23 dy23 dz23)))
     (setq v2i*x (car v2i*) v2i*y (cadr v2i*) v2i*z (caddr v2i*))
     (setq v3i*x (car v3i*) v3i*y (cadr v3i*) v3i*z (caddr v3i*))
     (setq v2f*z (* kur (/ (+ (* (- m2 m3) v2i*z) (* 2 m3 v3i*z)) (+ m2 m3))))
     (setq v3f*z (* kur (/ (+ (* (- m3 m2) v3i*z) (* 2 m2 v2i*z)) (+ m2 m3))))
     (setq v2f* (list v2i*x v2i*y v2f*z))
     (setq v3f* (list v3i*x v3i*y v3f*z))
     (setq v2f (trans v2f* (list dx23 dy23 dz23) 0))
     (setq v3f (trans v3f* (list dx23 dy23 dz23) 0))
     (setq v2x (car v2f) v2y (cadr v2f) v2z (caddr v2f))
     (setq v3x (car v3f) v3y (cadr v3f) v3z (caddr v3f))
    )
   )
  )
  (if (> d14 r14)
   (progn 
    (setq v1x (+ v1x (* a1x t)))  (setq v1y (+ v1y (* a1y t)))  (setq v1z (+ v1z (* a1z t)))
    (setq v4x (+ v4x (* a4x t)))  (setq v4y (+ v4y (* a4y t)))  (setq v4z (+ v4z (* a4z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v1i (list v1x v1y v1z)) ;velocita 1 prima dello scontro
     (setq v4i (list v4x v4y v4z)) ;velocita 4 prima dello scontro
     (setq v1i* (trans v1i 0 (list dx14 dy14 dz14)))
     (setq v4i* (trans v4i 0 (list dx14 dy14 dz14)))
     (setq v1i*x (car v1i*) v1i*y (cadr v1i*) v1i*z (caddr v1i*))
     (setq v4i*x (car v4i*) v4i*y (cadr v4i*) v4i*z (caddr v4i*))
     (setq v1f*z (* kur (/ (+ (* (- m1 m4) v1i*z) (* 2 m4 v4i*z)) (+ m1 m4))))
     (setq v4f*z (* kur (/ (+ (* (- m4 m1) v4i*z) (* 2 m1 v1i*z)) (+ m1 m4))))
     (setq v1f* (list v1i*x v1i*y v1f*z))
     (setq v4f* (list v4i*x v4i*y v4f*z))
     (setq v1f (trans v1f* (list dx14 dy14 dz14) 0))
     (setq v4f (trans v4f* (list dx14 dy14 dz14) 0))
     (setq v1x (car v1f) v1y (cadr v1f) v1z (caddr v1f))
     (setq v4x (car v4f) v4y (cadr v4f) v4z (caddr v4f))
    )
   )
  )
  (if (> d24 r24)
   (progn 
    (setq v2x (+ v2x (* a2x t)))  (setq v2y (+ v2y (* a2y t)))  (setq v2z (+ v2z (* a2z t)))
    (setq v4x (+ v4x (* a4x t)))  (setq v4y (+ v4y (* a4y t)))  (setq v4z (+ v4z (* a4z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v2i (list v2x v2y v2z)) ;velocita 2 prima dello scontro
     (setq v4i (list v4x v4y v4z)) ;velocita 4 prima dello scontro
     (setq v2i* (trans v2i 0 (list dx24 dy24 dz24)))
     (setq v4i* (trans v4i 0 (list dx24 dy24 dz24)))
     (setq v2i*x (car v2i*) v2i*y (cadr v2i*) v2i*z (caddr v2i*))
     (setq v4i*x (car v4i*) v4i*y (cadr v4i*) v4i*z (caddr v4i*))
     (setq v2f*z (* kur (/ (+ (* (- m2 m4) v2i*z) (* 2 m4 v4i*z)) (+ m2 m4))))
     (setq v4f*z (* kur (/ (+ (* (- m4 m2) v4i*z) (* 2 m2 v2i*z)) (+ m2 m4))))
     (setq v2f* (list v2i*x v2i*y v2f*z))
     (setq v4f* (list v4i*x v4i*y v4f*z))
     (setq v2f (trans v2f* (list dx24 dy24 dz24) 0))
     (setq v4f (trans v4f* (list dx24 dy24 dz24) 0))
     (setq v2x (car v2f) v2y (cadr v2f) v2z (caddr v2f))
     (setq v4x (car v4f) v4y (cadr v4f) v4z (caddr v4f))
    )
   )
  )
  (if (> d34 r34)
   (progn 
    (setq v3x (+ v3x (* a3x t)))  (setq v3y (+ v3y (* a3y t)))  (setq v3z (+ v3z (* a3z t)))
    (setq v4x (+ v4x (* a4x t)))  (setq v4y (+ v4y (* a4y t)))  (setq v4z (+ v4z (* a4z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v3i (list v3x v3y v3z)) ;velocita 3 prima dello scontro
     (setq v4i (list v4x v4y v4z)) ;velocita 4 prima dello scontro
     (setq v3i* (trans v3i 0 (list dx34 dy34 dz34)))
     (setq v4i* (trans v4i 0 (list dx34 dy34 dz34)))
     (setq v3i*x (car v3i*) v3i*y (cadr v3i*) v3i*z (caddr v3i*))
     (setq v4i*x (car v4i*) v4i*y (cadr v4i*) v4i*z (caddr v4i*))
     (setq v3f*z (* kur (/ (+ (* (- m3 m4) v3i*z) (* 2 m4 v4i*z)) (+ m3 m4))))
     (setq v4f*z (* kur (/ (+ (* (- m4 m3) v4i*z) (* 2 m3 v3i*z)) (+ m3 m4))))
     (setq v3f* (list v3i*x v3i*y v3f*z))
     (setq v4f* (list v4i*x v4i*y v4f*z))
     (setq v3f (trans v3f* (list dx34 dy34 dz34) 0))
     (setq v4f (trans v4f* (list dx34 dy34 dz34) 0))
     (setq v3x (car v3f) v3y (cadr v3f) v3z (caddr v3f))
     (setq v4x (car v4f) v4y (cadr v4f) v4z (caddr v4f))
    )
   )
  )
  (if (> d15 r15)
   (progn 
    (setq v1x (+ v1x (* a1x t)))  (setq v1y (+ v1y (* a1y t)))  (setq v1z (+ v1z (* a1z t)))
    (setq v5x (+ v5x (* a5x t)))  (setq v5y (+ v5y (* a5y t)))  (setq v5z (+ v5z (* a5z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v1i (list v1x v1y v1z)) ;velocita 1 prima dello scontro
     (setq v5i (list v5x v5y v5z)) ;velocita 5 prima dello scontro
     (setq v1i* (trans v1i 0 (list dx15 dy15 dz15)))
     (setq v5i* (trans v5i 0 (list dx15 dy15 dz15)))
     (setq v1i*x (car v1i*) v1i*y (cadr v1i*) v1i*z (caddr v1i*))
     (setq v5i*x (car v5i*) v5i*y (cadr v5i*) v5i*z (caddr v5i*))
     (setq v1f*z (* kur (/ (+ (* (- m1 m5) v1i*z) (* 2 m5 v5i*z)) (+ m1 m5))))
     (setq v5f*z (* kur (/ (+ (* (- m5 m1) v5i*z) (* 2 m1 v1i*z)) (+ m1 m5))))
     (setq v1f* (list v1i*x v1i*y v1f*z))
     (setq v5f* (list v5i*x v5i*y v5f*z))
     (setq v1f (trans v1f* (list dx15 dy15 dz15) 0))
     (setq v5f (trans v5f* (list dx15 dy15 dz15) 0))
     (setq v1x (car v1f) v1y (cadr v1f) v1z (caddr v1f))
     (setq v5x (car v5f) v5y (cadr v5f) v5z (caddr v5f))
    )
   )
  )
  (if (> d25 r25)
   (progn 
    (setq v2x (+ v2x (* a2x t)))  (setq v2y (+ v2y (* a2y t)))  (setq v2z (+ v2z (* a2z t)))
    (setq v5x (+ v5x (* a5x t)))  (setq v5y (+ v5y (* a5y t)))  (setq v5z (+ v5z (* a5z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v2i (list v2x v2y v2z)) ;velocita 2 prima dello scontro
     (setq v5i (list v5x v5y v5z)) ;velocita 5 prima dello scontro
     (setq v2i* (trans v2i 0 (list dx25 dy25 dz25)))
     (setq v5i* (trans v5i 0 (list dx25 dy25 dz25)))
     (setq v2i*x (car v2i*) v2i*y (cadr v2i*) v2i*z (caddr v2i*))
     (setq v5i*x (car v5i*) v5i*y (cadr v5i*) v5i*z (caddr v5i*))
     (setq v2f*z (* kur (/ (+ (* (- m2 m5) v2i*z) (* 2 m5 v5i*z)) (+ m2 m5))))
     (setq v5f*z (* kur (/ (+ (* (- m5 m2) v5i*z) (* 2 m2 v2i*z)) (+ m2 m5))))
     (setq v2f* (list v2i*x v2i*y v2f*z))
     (setq v5f* (list v5i*x v5i*y v5f*z))
     (setq v2f (trans v2f* (list dx25 dy25 dz25) 0))
     (setq v5f (trans v5f* (list dx25 dy25 dz25) 0))
     (setq v2x (car v2f) v2y (cadr v2f) v2z (caddr v2f))
     (setq v5x (car v5f) v5y (cadr v5f) v5z (caddr v5f))
    )
   )
  )
  (if (> d35 r35)
   (progn 
    (setq v3x (+ v3x (* a3x t)))  (setq v3y (+ v3y (* a3y t)))  (setq v3z (+ v3z (* a3z t)))
    (setq v5x (+ v5x (* a5x t)))  (setq v5y (+ v5y (* a5y t)))  (setq v5z (+ v5z (* a5z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v3i (list v3x v3y v3z)) ;velocita 3 prima dello scontro
     (setq v5i (list v5x v5y v5z)) ;velocita 5 prima dello scontro
     (setq v3i* (trans v3i 0 (list dx35 dy35 dz35)))
     (setq v5i* (trans v5i 0 (list dx35 dy35 dz35)))
     (setq v3i*x (car v3i*) v3i*y (cadr v3i*) v3i*z (caddr v3i*))
     (setq v5i*x (car v5i*) v5i*y (cadr v5i*) v5i*z (caddr v5i*))
     (setq v3f*z (* kur (/ (+ (* (- m3 m5) v3i*z) (* 2 m5 v5i*z)) (+ m3 m5))))
     (setq v5f*z (* kur (/ (+ (* (- m5 m3) v5i*z) (* 2 m3 v3i*z)) (+ m3 m5))))
     (setq v3f* (list v3i*x v3i*y v3f*z))
     (setq v5f* (list v5i*x v5i*y v5f*z))
     (setq v3f (trans v3f* (list dx35 dy35 dz35) 0))
     (setq v5f (trans v5f* (list dx35 dy35 dz35) 0))
     (setq v3x (car v3f) v3y (cadr v3f) v3z (caddr v3f))
     (setq v5x (car v5f) v5y (cadr v5f) v5z (caddr v5f))
    )
   )
  )
  (if (> d45 r45)
   (progn 
    (setq v4x (+ v4x (* a4x t)))  (setq v4y (+ v4y (* a4y t)))  (setq v4z (+ v4z (* a4z t)))
    (setq v5x (+ v5x (* a5x t)))  (setq v5y (+ v5y (* a5y t)))  (setq v5z (+ v5z (* a5z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v4i (list v4x v4y v4z)) ;velocita 4 prima dello scontro
     (setq v5i (list v5x v5y v5z)) ;velocita 5 prima dello scontro
     (setq v4i* (trans v4i 0 (list dx45 dy45 dz45)))
     (setq v5i* (trans v5i 0 (list dx45 dy45 dz45)))
     (setq v4i*x (car v4i*) v4i*y (cadr v4i*) v4i*z (caddr v4i*))
     (setq v5i*x (car v5i*) v5i*y (cadr v5i*) v5i*z (caddr v5i*))
     (setq v4f*z (* kur (/ (+ (* (- m4 m5) v4i*z) (* 2 m5 v5i*z)) (+ m4 m5))))
     (setq v5f*z (* kur (/ (+ (* (- m5 m4) v5i*z) (* 2 m4 v4i*z)) (+ m4 m5))))
     (setq v4f* (list v4i*x v4i*y v4f*z))
     (setq v5f* (list v5i*x v5i*y v5f*z))
     (setq v4f (trans v4f* (list dx45 dy45 dz45) 0))
     (setq v5f (trans v5f* (list dx45 dy45 dz45) 0))
     (setq v4x (car v4f) v4y (cadr v4f) v4z (caddr v4f))
     (setq v5x (car v5f) v5y (cadr v5f) v5z (caddr v5f))
    )
   )
  )

  (if (< (- x1 r1) xsa) (setq v1x (* (+ (* -2 kbi) 1) v1x) ) )
  (if (< (- y1 r1) ysa) (setq v1y (* (+ (* -2 kbi) 1) v1y) ) )   
  (if (< (- z1 r1) zsa) (setq v1z (* (+ (* -2 kbi) 1) v1z) ) )   
  (if (> (+ x1 r1) xsb) (setq v1x (* (+ (* -2 kbi) 1) v1x) ) )   
  (if (> (+ y1 r1) ysb) (setq v1y (* (+ (* -2 kbi) 1) v1y) ) )   
  (if (> (+ z1 r1) zsb) (setq v1z (* (+ (* -2 kbi) 1) v1z) ) )   
  (if (< (- x2 r2) xsa) (setq v2x (* (+ (* -2 kbi) 1) v2x) ) )   
  (if (< (- y2 r2) ysa) (setq v2y (* (+ (* -2 kbi) 1) v2y) ) )   
  (if (< (- z2 r2) zsa) (setq v2z (* (+ (* -2 kbi) 1) v2z) ) )   
  (if (> (+ x2 r2) xsb) (setq v2x (* (+ (* -2 kbi) 1) v2x) ) )   
  (if (> (+ y2 r2) ysb) (setq v2y (* (+ (* -2 kbi) 1) v2y) ) )   
  (if (> (+ z2 r2) zsb) (setq v2z (* (+ (* -2 kbi) 1) v2z) ) )   
  (if (< (- x3 r3) xsa) (setq v3x (* (+ (* -2 kbi) 1) v3x) ) )   
  (if (< (- y3 r3) ysa) (setq v3y (* (+ (* -2 kbi) 1) v3y) ) )   
  (if (< (- z3 r3) zsa) (setq v3z (* (+ (* -2 kbi) 1) v3z) ) )   
  (if (> (+ x3 r3) xsb) (setq v3x (* (+ (* -2 kbi) 1) v3x) ) )   
  (if (> (+ y3 r3) ysb) (setq v3y (* (+ (* -2 kbi) 1) v3y) ) )   
  (if (> (+ z3 r3) zsb) (setq v3z (* (+ (* -2 kbi) 1) v3z) ) )   
  (if (< (- x4 r4) xsa) (setq v4x (* (+ (* -2 kbi) 1) v4x) ) )   
  (if (< (- y4 r4) ysa) (setq v4y (* (+ (* -2 kbi) 1) v4y) ) )   
  (if (< (- z4 r4) zsa) (setq v4z (* (+ (* -2 kbi) 1) v4z) ) )   
  (if (> (+ x4 r4) xsb) (setq v4x (* (+ (* -2 kbi) 1) v4x) ) )   
  (if (> (+ y4 r4) ysb) (setq v4y (* (+ (* -2 kbi) 1) v4y) ) )   
  (if (> (+ z4 r4) zsb) (setq v4z (* (+ (* -2 kbi) 1) v4z) ) )   
  (if (< (- x5 r5) xsa) (setq v5x (* (+ (* -2 kbi) 1) v5x) ) )   
  (if (< (- y5 r5) ysa) (setq v5y (* (+ (* -2 kbi) 1) v5y) ) )   
  (if (< (- z5 r5) zsa) (setq v5z (* (+ (* -2 kbi) 1) v5z) ) )   
  (if (> (+ x5 r5) xsb) (setq v5x (* (+ (* -2 kbi) 1) v5x) ) )   
  (if (> (+ y5 r5) ysb) (setq v5y (* (+ (* -2 kbi) 1) v5y) ) )   
  (if (> (+ z5 r5) zsb) (setq v5z (* (+ (* -2 kbi) 1) v5z) ) )   

  (setq s1x (+ (* v1x t) (* 0.5 a1x t t)))  (setq s1y (+ (* v1y t) (* 0.5 a1y t t)))  (setq s1z (+ (* v1z t) (* 0.5 a1z t t)))
  (setq s2x (+ (* v2x t) (* 0.5 a2x t t)))  (setq s2y (+ (* v2y t) (* 0.5 a2y t t)))  (setq s2z (+ (* v2z t) (* 0.5 a2z t t)))
  (setq s3x (+ (* v3x t) (* 0.5 a3x t t)))  (setq s3y (+ (* v3y t) (* 0.5 a3y t t)))  (setq s3z (+ (* v3z t) (* 0.5 a3z t t)))
  (setq s4x (+ (* v4x t) (* 0.5 a4x t t)))  (setq s4y (+ (* v4y t) (* 0.5 a4y t t)))  (setq s4z (+ (* v4z t) (* 0.5 a4z t t)))
  (setq s5x (+ (* v5x t) (* 0.5 a5x t t)))  (setq s5y (+ (* v5y t) (* 0.5 a5y t t)))  (setq s5z (+ (* v5z t) (* 0.5 a5z t t)))

  (setq x1 (+ x1 (* k1 s1x)))  (setq y1 (+ y1 (* k1 s1y)))  (setq z1 (+ z1 (* k1 s1z)))
  (setq x2 (+ x2 (* k2 s2x)))  (setq y2 (+ y2 (* k2 s2y)))  (setq z2 (+ z2 (* k2 s2z)))
  (setq x3 (+ x3 (* k3 s3x)))  (setq y3 (+ y3 (* k3 s3y)))  (setq z3 (+ z3 (* k3 s3z)))
  (setq x4 (+ x4 (* k4 s4x)))  (setq y4 (+ y4 (* k4 s4y)))  (setq z4 (+ z4 (* k4 s4z)))
  (setq x5 (+ x5 (* k5 s5x)))  (setq y5 (+ y5 (* k5 s5y)))  (setq z5 (+ z5 (* k5 s5z)))

  (setq a1 (sqrt (+ (* a1x a1x) (* a1y a1y) (* a1z a1z))))
  (setq a2 (sqrt (+ (* a2x a2x) (* a2y a2y) (* a2z a2z))))
  (setq a3 (sqrt (+ (* a3x a3x) (* a3y a3y) (* a3z a3z))))
  (setq a4 (sqrt (+ (* a4x a4x) (* a4y a4y) (* a4z a4z))))
  (setq a5 (sqrt (+ (* a5x a5x) (* a5y a5y) (* a5z a5z))))

  (setq va (+ (abs a1) (abs a2) (abs a3) (abs a4) (abs a5)
              (abs v1) (abs v2) (abs v3) (abs v4) (abs v5)
           )
  )
  (princ "\n")
  (princ va)
  (princ)

  (setq q1 (list x1 y1 z1))
  (setq q2 (list x2 y2 z2))
  (setq q3 (list x3 y3 z3))
  (setq q4 (list x4 y4 z4))
  (setq q5 (list x5 y5 z5))

  (if (= iscan 0)
   (progn
 
   (if (= ker 0)
    (progn
    (if (= pc "p")
        (progn
         (setvar "clayer" "m1") (command "_point" p1)
         (setvar "clayer" "m2") (command "_point" p2)
         (setvar "clayer" "m3") (command "_point" p3)
         (setvar "clayer" "m4") (command "_point" p4)
         (setvar "clayer" "m5") (command "_point" p5)
        )
        (if (= pc "c")
            (progn
             (setvar "clayer" "m1") (command "_circle" p1 r1)
             (setvar "clayer" "m2") (command "_circle" p2 r2)
             (setvar "clayer" "m3") (command "_circle" p3 r3)
             (setvar "clayer" "m4") (command "_circle" p4 r4)
             (setvar "clayer" "m5") (command "_circle" p5 r5)
            )
            (if (= pc "s")
                (progn
                 (setvar "clayer" "m1") (command "_sphere" p1 r1)
                 (setvar "clayer" "m2") (command "_sphere" p2 r2)
                 (setvar "clayer" "m3") (command "_sphere" p3 r3)
                 (setvar "clayer" "m4") (command "_sphere" p4 r4)
                 (setvar "clayer" "m5") (command "_sphere" p5 r5)
                )
            )
        )
    )
    )
    (progn
             (command "_move" o1 "" p1 q1)
             (command "_move" o2 "" p2 q2)
             (command "_move" o3 "" p3 q3)
             (command "_move" o4 "" p4 q4)
             (command "_move" o5 "" p5 q5)
    )    
   )
    
   )

  )
 
  (setq p1 q1)
  (setq p2 q2)  
  (setq p3 q3)  
  (setq p4 q4)  
  (setq p5 q5)  

  (setq iscan (+ 1 iscan))
  (if (= iscan scan) (setq iscan 0))

 )
 (setvar "clayer" "0")
 (command "_pline" p1 p2 p3 p4 p5 p1 "")
)

;;;*****************************************************************
;simula il moto di 10 oggetti sottoposti a forza gravitazionale
;gravita6 ver 1.5 23/07/2010
;Dott. Ing. Emanuele Ballasina
;cell 349-1813748
;mail ballacr75@libero.it

(defun c:gravita6 ()
(setvar "osmode" 0)
(setvar "dimzin" 0)
(setvar "cmdecho" 0)

(command "_-layer" "n" "m1" "_c" 10 "m1" "_s" "m1" "")
(command "_-layer" "n" "m2" "_c" 30 "m2" "_s" "m2" "")
(command "_-layer" "n" "m3" "_c" 60 "m3" "_s" "m3" "")
(command "_-layer" "n" "m4" "_c" 90 "m4" "_s" "m4" "")
(command "_-layer" "n" "m5" "_c" 110 "m5" "_s" "m5" "")
(command "_-layer" "n" "m6" "_c" 130 "m6" "_s" "m6" "")

(setq t 1) ;scansione tempo
(setq kdi 1) ;riduzione diametro cilindri
(setq scan 1) ;scansione posizione (non funziona >1 se ker=1)

(setq m1 100.0) ;massa
(setq m2 100.0)
(setq m3 100.0)
(setq m4 100.0)
(setq m5 100.0)
(setq m6 100.0)
(setq d1 0.1) ;densita
(setq d2 0.1)
(setq d3 0.1) 
(setq d4 0.1)
(setq d5 0.1)
(setq d6 0.1)
(setq r1 (expt (/ m1 d1) 0.3333)) ;raggio
(setq r2 (expt (/ m2 d2) 0.3333))
(setq r3 (expt (/ m3 d3) 0.3333))
(setq r4 (expt (/ m4 d4) 0.3333))
(setq r5 (expt (/ m5 d5) 0.3333))
(setq r6 (expt (/ m6 d6) 0.3333))
(setq r12 (+ r1 r2)) ;distanza di sfioro
(setq r13 (+ r1 r3))
(setq r23 (+ r2 r3))
(setq r14 (+ r1 r4))
(setq r24 (+ r2 r4))
(setq r34 (+ r3 r4))
(setq r15 (+ r1 r5))
(setq r25 (+ r2 r5))
(setq r35 (+ r3 r5))
(setq r45 (+ r4 r5))
(setq r16 (+ r1 r6))
(setq r26 (+ r2 r6))
(setq r36 (+ r3 r6))
(setq r46 (+ r4 r6))
(setq r56 (+ r5 r6))

(setq k1 1) ;abilita movimento pianeta
(setq k2 1)
(setq k3 1)
(setq k4 1)
(setq k5 1)
(setq k6 1)
(setq kur 0) ;abilita urti, con coefficente di rimbalzo, <1 smorza
(setq kbi 0) ;abilita rimbalzo tipo biliardo contro pareti dello schermo, <1 smorza
(setq ker 1) ;1=cancella pianeti vecchi, 0=mantiene tutti i pianeti
(setq c (getvar "VIEWCTR"))
(setq xsc (car c))
(setq ysc (cadr c))
(setq zsc (caddr c))
(setq currh (getvar "viewsize"))
(setq sizex (nth 0 (getvar "screensize")))
(setq sizey (nth 1 (getvar "screensize")))
(setq j (/ sizex sizey))
(setq currw (* j currh))
(setq h2 (/ currh 2.0))
(setq w2 (/ currw 2.0))
(setq xsa (- xsc w2))
(setq ysa (- ysc h2))
(setq zsa (- zsc h2))
(setq xsb (+ xsc w2))
(setq ysb (+ ysc h2))
(setq zsb (+ zsc h2))
(if (/= kbi 0) (command "_rectangle" (list xsa ysa) (list xsb ysb)))

(setq pc "c") ;punti,cerchi,sfere
(setq lc "n") ;abilita disegno linee tra un pianeta e gli altri
(setq tc "n") ;abilita disegno linee traiettoria

(setq x1 0) ;posizione
(setq y1 0)
(setq z1 0)
(setq x2 100)
(setq y2 100)
(setq z2 0)
(setq x3 200)
(setq y3 0)
(setq z3 0)
(setq x4 300)
(setq y4 1)
(setq z4 0)
(setq x5 400)
(setq y5 0)
(setq z5 0)
(setq x6 500)
(setq y6 0)
(setq z6 0)

(setq v1x 0.0) ;velocita
(setq v1y 0.0)
(setq v1z 0.0)
(setq v2x 0.0)
(setq v2y 0.0)
(setq v2z 0.0)
(setq v3x 0.0)
(setq v3y 0.0)
(setq v3z 0.0)
(setq v4x 0.0)
(setq v4y 0.0)
(setq v4z 0.0)
(setq v5x 0.0)
(setq v5y 0.0)
(setq v5z 0.0) 
(setq v6x 0.0)
(setq v6y 0.0)
(setq v6z 0.0)

(setq p1 (list x1 y1 z1))
(setq p2 (list x2 y2 z2))
(setq p3 (list x3 y3 z3))
(setq p4 (list x4 y4 z4))
(setq p5 (list x5 y5 z5))
(setq p6 (list x6 y6 z6))

(if (= pc "p")
    (progn
     (setvar "clayer" "m1") (command "_point" p1) (setq o1 (cdr (car (entget (entlast)))))
     (setvar "clayer" "m2") (command "_point" p2) (setq o2 (cdr (car (entget (entlast)))))
     (setvar "clayer" "m3") (command "_point" p3) (setq o3 (cdr (car (entget (entlast)))))
     (setvar "clayer" "m4") (command "_point" p4) (setq o4 (cdr (car (entget (entlast)))))
     (setvar "clayer" "m5") (command "_point" p5) (setq o5 (cdr (car (entget (entlast)))))
     (setvar "clayer" "m6") (command "_point" p6) (setq o6 (cdr (car (entget (entlast)))))
    )
    (if (= pc "c")
        (progn
         (setvar "clayer" "m1") (command "_circle" p1 r1) (setq o1 (cdr (car (entget (entlast)))))
         (setvar "clayer" "m2") (command "_circle" p2 r2) (setq o2 (cdr (car (entget (entlast)))))
         (setvar "clayer" "m3") (command "_circle" p3 r3) (setq o3 (cdr (car (entget (entlast)))))
         (setvar "clayer" "m4") (command "_circle" p4 r4) (setq o4 (cdr (car (entget (entlast)))))
         (setvar "clayer" "m5") (command "_circle" p5 r5) (setq o5 (cdr (car (entget (entlast)))))
         (setvar "clayer" "m6") (command "_circle" p6 r6) (setq o6 (cdr (car (entget (entlast)))))
        )
        (if (= pc "s")
            (progn
             (setvar "clayer" "m1") (command "_sphere" p1 r1) (setq o1 (cdr (car (entget (entlast)))))
             (setvar "clayer" "m2") (command "_sphere" p2 r2) (setq o2 (cdr (car (entget (entlast)))))
             (setvar "clayer" "m3") (command "_sphere" p3 r3) (setq o3 (cdr (car (entget (entlast)))))
             (setvar "clayer" "m4") (command "_sphere" p4 r4) (setq o4 (cdr (car (entget (entlast)))))
             (setvar "clayer" "m5") (command "_sphere" p5 r5) (setq o5 (cdr (car (entget (entlast)))))
             (setvar "clayer" "m6") (command "_sphere" p6 r6) (setq o6 (cdr (car (entget (entlast)))))
            )
        )
    )
)

(setq va 1000)
(setq iscan 0)
 (while (> va 0.0001) ;scansione velocit ed accelerazione, se = 0 si ferma il lisp

  (setq v1 (sqrt (+ (* v1x v1x) (* v1y v1y) (* v1z v1z))))
  (setq v2 (sqrt (+ (* v2x v2x) (* v2y v2y) (* v2z v2z))))
  (setq v3 (sqrt (+ (* v3x v3x) (* v3y v3y) (* v3z v3z))))
  (setq v4 (sqrt (+ (* v4x v4x) (* v4y v4y) (* v4z v4z))))
  (setq v5 (sqrt (+ (* v5x v5x) (* v5y v5y) (* v5z v5z))))
  (setq v6 (sqrt (+ (* v6x v6x) (* v6y v6y) (* v6z v6z))))
  
  (setq d12 (distance p1 p2))
  (setq d13 (distance p1 p3))
  (setq d23 (distance p2 p3))
  (setq d14 (distance p1 p4))
  (setq d24 (distance p2 p4))
  (setq d34 (distance p3 p4))
  (setq d15 (distance p1 p5))
  (setq d25 (distance p2 p5))
  (setq d35 (distance p3 p5))
  (setq d45 (distance p4 p5))
  (setq d16 (distance p1 p6))
  (setq d26 (distance p2 p6))
  (setq d36 (distance p3 p6))
  (setq d46 (distance p4 p6))
  (setq d56 (distance p5 p6))

  (setq dx12 (- x2 x1))  (setq dy12 (- y2 y1))  (setq dz12 (- z2 z1))
  (setq dx13 (- x3 x1))  (setq dy13 (- y3 y1))  (setq dz13 (- z3 z1))
  (setq dx23 (- x3 x2))  (setq dy23 (- y3 y2))  (setq dz23 (- z3 z2))
  (setq dx14 (- x4 x1))  (setq dy14 (- y4 y1))  (setq dz14 (- z4 z1))
  (setq dx24 (- x4 x2))  (setq dy24 (- y4 y2))  (setq dz24 (- z4 z2))
  (setq dx34 (- x4 x3))  (setq dy34 (- y4 y3))  (setq dz34 (- z4 z3))
  (setq dx15 (- x5 x1))  (setq dy15 (- y5 y1))  (setq dz15 (- z5 z1))
  (setq dx25 (- x5 x2))  (setq dy25 (- y5 y2))  (setq dz25 (- z5 z2))
  (setq dx35 (- x5 x3))  (setq dy35 (- y5 y3))  (setq dz35 (- z5 z3))
  (setq dx45 (- x5 x4))  (setq dy45 (- y5 y4))  (setq dz45 (- z5 z4))
  (setq dx16 (- x6 x1))  (setq dy16 (- y6 y1))  (setq dz16 (- z6 z1))
  (setq dx26 (- x6 x2))  (setq dy26 (- y6 y2))  (setq dz26 (- z6 z2))
  (setq dx36 (- x6 x3))  (setq dy36 (- y6 y3))  (setq dz36 (- z6 z3))
  (setq dx46 (- x6 x4))  (setq dy46 (- y6 y4))  (setq dz46 (- z6 z4))
  (setq dx56 (- x6 x5))  (setq dy56 (- y6 y5))  (setq dz56 (- z6 z5))

;                   GRAVITA              REPULSIONE           ELASTICO       MOLLA
  (if (<= d12 r12) (setq d12 r12))
  (if (<= d13 r13) (setq d13 r13))
  (if (<= d23 r23) (setq d23 r23))
  (if (<= d14 r14) (setq d14 r14))
  (if (<= d24 r24) (setq d24 r24))
  (if (<= d34 r34) (setq d34 r34))
  (if (<= d15 r15) (setq d15 r15))
  (if (<= d25 r25) (setq d25 r25))
  (if (<= d35 r35) (setq d35 r35))
  (if (<= d45 r45) (setq d45 r45))
  (if (<= d16 r16) (setq d16 r16))
  (if (<= d26 r26) (setq d26 r26))
  (if (<= d36 r36) (setq d36 r36))
  (if (<= d46 r46) (setq d46 r46))
  (if (<= d56 r56) (setq d56 r56))
  (setq f12 (+ (* 1 (fgr m1 m2 d12)) (* 1 (fre m1 m2 d12)) (* 1 (fel d12)) (* 1 (fmo d12)) ))
  (setq f13 (+ (* 1 (fgr m1 m3 d13)) (* 1 (fre m1 m3 d13)) (* 1 (fel d13)) (* 1 (fmo d13)) ))
  (setq f23 (+ (* 1 (fgr m2 m3 d23)) (* 1 (fre m2 m3 d23)) (* 1 (fel d23)) (* 1 (fmo d23)) ))
  (setq f14 (+ (* 1 (fgr m1 m4 d14)) (* 1 (fre m1 m4 d14)) (* 1 (fel d14)) (* 1 (fmo d14)) ))
  (setq f24 (+ (* 1 (fgr m2 m4 d24)) (* 1 (fre m2 m4 d24)) (* 1 (fel d24)) (* 1 (fmo d24)) ))
  (setq f34 (+ (* 1 (fgr m3 m4 d34)) (* 1 (fre m3 m4 d34)) (* 1 (fel d34)) (* 1 (fmo d34)) ))
  (setq f15 (+ (* 1 (fgr m1 m5 d15)) (* 1 (fre m1 m5 d15)) (* 1 (fel d15)) (* 1 (fmo d15)) ))
  (setq f25 (+ (* 1 (fgr m2 m5 d25)) (* 1 (fre m2 m5 d25)) (* 1 (fel d25)) (* 1 (fmo d25)) ))
  (setq f35 (+ (* 1 (fgr m3 m5 d35)) (* 1 (fre m3 m5 d35)) (* 1 (fel d35)) (* 1 (fmo d35)) ))
  (setq f45 (+ (* 1 (fgr m4 m5 d45)) (* 1 (fre m4 m5 d45)) (* 1 (fel d45)) (* 1 (fmo d45)) ))
  (setq f16 (+ (* 1 (fgr m1 m6 d16)) (* 1 (fre m1 m6 d16)) (* 1 (fel d16)) (* 1 (fmo d16)) ))
  (setq f26 (+ (* 1 (fgr m2 m6 d26)) (* 1 (fre m2 m6 d26)) (* 1 (fel d26)) (* 1 (fmo d26)) ))
  (setq f36 (+ (* 1 (fgr m3 m6 d36)) (* 1 (fre m3 m6 d36)) (* 1 (fel d36)) (* 1 (fmo d36)) ))
  (setq f46 (+ (* 1 (fgr m4 m6 d46)) (* 1 (fre m4 m6 d46)) (* 1 (fel d46)) (* 1 (fmo d46)) ))
  (setq f56 (+ (* 1 (fgr m5 m6 d56)) (* 1 (fre m5 m6 d56)) (* 1 (fel d56)) (* 1 (fmo d56)) ))

  (setq a12 (/ f12 m1))  (setq a21 (* -1 (/ f12 m2)))
  (setq a13 (/ f13 m1))  (setq a31 (* -1 (/ f13 m3)))
  (setq a23 (/ f23 m2))  (setq a32 (* -1 (/ f23 m3)))
  (setq a14 (/ f14 m1))  (setq a41 (* -1 (/ f14 m4)))
  (setq a24 (/ f24 m2))  (setq a42 (* -1 (/ f24 m4)))
  (setq a34 (/ f34 m3))  (setq a43 (* -1 (/ f34 m4)))
  (setq a15 (/ f15 m1))  (setq a51 (* -1 (/ f15 m5)))
  (setq a25 (/ f25 m2))  (setq a52 (* -1 (/ f25 m5)))
  (setq a35 (/ f35 m3))  (setq a53 (* -1 (/ f35 m5)))
  (setq a45 (/ f45 m4))  (setq a54 (* -1 (/ f45 m5)))
  (setq a16 (/ f16 m1))  (setq a61 (* -1 (/ f16 m6)))
  (setq a26 (/ f26 m2))  (setq a62 (* -1 (/ f26 m6)))
  (setq a36 (/ f36 m3))  (setq a63 (* -1 (/ f36 m6)))
  (setq a46 (/ f46 m4))  (setq a64 (* -1 (/ f46 m6)))
  (setq a56 (/ f56 m5))  (setq a65 (* -1 (/ f56 m6)))
 
  (setq a1x (+ (* 1 (/ (fsx x1 y1 z1) m1)) (* 1 (/ (fwx r1) m1)) (* 1 v1x (/ (fvi m1 r1 v1) m1)) (/ (* a12 dx12) d12) (/ (* a13 dx13) d13) (/ (* a14 dx14) d14) (/ (* a15 dx15) d15) (/ (* a16 dx16) d16) ))
  (setq a1y (+ (* 1 (/ (fsy x1 y1 z1) m1)) (* 1 (/ (fwy r1) m1)) (* 1 v1y (/ (fvi m1 r1 v1) m1)) (/ (* a12 dy12) d12) (/ (* a13 dy13) d13) (/ (* a14 dy14) d14) (/ (* a15 dy15) d15) (/ (* a16 dy16) d16) ))
  (setq a1z (+ (* 1 (/ (fsz x1 y1 z1) m1)) (* 1 (/ (fwz r1) m1)) (* 1 v1z (/ (fvi m1 r1 v1) m1)) (/ (* a12 dz12) d12) (/ (* a13 dz13) d13) (/ (* a14 dz14) d14) (/ (* a15 dz15) d15) (/ (* a16 dz16) d16) ))
  (setq a2x (+ (* 1 (/ (fsx x2 y2 z2) m2)) (* 1 (/ (fwx r2) m2)) (* 1 v2x (/ (fvi m2 r2 v2) m2)) (/ (* a21 dx12) d12) (/ (* a23 dx23) d23) (/ (* a24 dx24) d24) (/ (* a25 dx25) d25) (/ (* a26 dx26) d26) ))
  (setq a2y (+ (* 1 (/ (fsy x2 y2 z2) m2)) (* 1 (/ (fwy r2) m2)) (* 1 v2y (/ (fvi m2 r2 v2) m2)) (/ (* a21 dy12) d12) (/ (* a23 dy23) d23) (/ (* a24 dy24) d24) (/ (* a25 dy25) d25) (/ (* a26 dy26) d26) ))
  (setq a2z (+ (* 1 (/ (fsz x2 y2 z2) m2)) (* 1 (/ (fwz r2) m2)) (* 1 v2z (/ (fvi m2 r2 v2) m2)) (/ (* a21 dz12) d12) (/ (* a23 dz23) d23) (/ (* a24 dz24) d24) (/ (* a25 dz25) d25) (/ (* a26 dz26) d26) ))
  (setq a3x (+ (* 1 (/ (fsx x3 y3 z3) m3)) (* 1 (/ (fwx r3) m3)) (* 1 v3x (/ (fvi m3 r3 v3) m3)) (/ (* a31 dx13) d13) (/ (* a32 dx23) d23) (/ (* a34 dx34) d34) (/ (* a35 dx35) d35) (/ (* a36 dx36) d36) ))
  (setq a3y (+ (* 1 (/ (fsy x3 y3 z3) m3)) (* 1 (/ (fwy r3) m3)) (* 1 v3y (/ (fvi m3 r3 v3) m3)) (/ (* a31 dy13) d13) (/ (* a32 dy23) d23) (/ (* a34 dy34) d34) (/ (* a35 dy35) d35) (/ (* a36 dy36) d36) ))
  (setq a3z (+ (* 1 (/ (fsz x3 y3 z3) m3)) (* 1 (/ (fwz r3) m3)) (* 1 v3z (/ (fvi m3 r3 v3) m3)) (/ (* a31 dz13) d13) (/ (* a32 dz23) d23) (/ (* a34 dz34) d34) (/ (* a35 dz35) d35) (/ (* a36 dz36) d36) ))
  (setq a4x (+ (* 1 (/ (fsx x4 y4 z4) m4)) (* 1 (/ (fwx r4) m4)) (* 1 v4x (/ (fvi m4 r4 v4) m4)) (/ (* a41 dx14) d14) (/ (* a42 dx24) d24) (/ (* a43 dx34) d34) (/ (* a45 dx45) d45) (/ (* a46 dx46) d46) ))
  (setq a4y (+ (* 1 (/ (fsy x4 y4 z4) m4)) (* 1 (/ (fwy r4) m4)) (* 1 v4y (/ (fvi m4 r4 v4) m4)) (/ (* a41 dy14) d14) (/ (* a42 dy24) d24) (/ (* a43 dy34) d34) (/ (* a45 dy45) d45) (/ (* a46 dy46) d46) ))
  (setq a4z (+ (* 1 (/ (fsz x4 y4 z4) m4)) (* 1 (/ (fwz r4) m4)) (* 1 v4z (/ (fvi m4 r4 v4) m4)) (/ (* a41 dz14) d14) (/ (* a42 dz24) d24) (/ (* a43 dz34) d34) (/ (* a45 dz45) d45) (/ (* a46 dz46) d46) ))
  (setq a5x (+ (* 1 (/ (fsx x5 y5 z5) m5)) (* 1 (/ (fwx r5) m5)) (* 1 v5x (/ (fvi m5 r5 v5) m5)) (/ (* a51 dx15) d15) (/ (* a52 dx25) d25) (/ (* a53 dx35) d35) (/ (* a54 dx45) d45) (/ (* a56 dx56) d56) ))
  (setq a5y (+ (* 1 (/ (fsy x5 y5 z5) m5)) (* 1 (/ (fwy r5) m5)) (* 1 v5y (/ (fvi m5 r5 v5) m5)) (/ (* a51 dy15) d15) (/ (* a52 dy25) d25) (/ (* a53 dy35) d35) (/ (* a54 dy45) d45) (/ (* a56 dy56) d56) ))
  (setq a5z (+ (* 1 (/ (fsz x5 y5 z5) m5)) (* 1 (/ (fwz r5) m5)) (* 1 v5z (/ (fvi m5 r5 v5) m5)) (/ (* a51 dz15) d15) (/ (* a52 dz25) d25) (/ (* a53 dz35) d35) (/ (* a54 dz45) d45) (/ (* a56 dz56) d56) ))
  (setq a6x (+ (* 1 (/ (fsx x6 y6 z6) m6)) (* 1 (/ (fwx r6) m6)) (* 1 v6x (/ (fvi m6 r6 v6) m6)) (/ (* a61 dx16) d16) (/ (* a62 dx26) d26) (/ (* a63 dx36) d36) (/ (* a64 dx46) d46) (/ (* a65 dx56) d56) ))
  (setq a6y (+ (* 1 (/ (fsy x6 y6 z6) m6)) (* 1 (/ (fwy r6) m6)) (* 1 v6y (/ (fvi m6 r6 v6) m6)) (/ (* a61 dy16) d16) (/ (* a62 dy26) d26) (/ (* a63 dy36) d36) (/ (* a64 dy46) d46) (/ (* a65 dy56) d56) ))
  (setq a6z (+ (* 1 (/ (fsz x6 y6 z6) m6)) (* 1 (/ (fwz r6) m6)) (* 1 v6z (/ (fvi m6 r6 v6) m6)) (/ (* a61 dz16) d16) (/ (* a62 dz26) d26) (/ (* a63 dz36) d36) (/ (* a64 dz46) d46) (/ (* a65 dz56) d56) ))

  (if (> d12 r12)
   (progn 
    (setq v1x (+ v1x (* a1x t)))  (setq v1y (+ v1y (* a1y t)))  (setq v1z (+ v1z (* a1z t)))
    (setq v2x (+ v2x (* a2x t)))  (setq v2y (+ v2y (* a2y t)))  (setq v2z (+ v2z (* a2z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v1i (list v1x v1y v1z)) ;velocita 1 prima dello scontro
     (setq v2i (list v2x v2y v2z)) ;velocita 2 prima dello scontro
     (setq v1i* (trans v1i 0 (list dx12 dy12 dz12)))
     (setq v2i* (trans v2i 0 (list dx12 dy12 dz12)))
     (setq v1i*x (car v1i*) v1i*y (cadr v1i*) v1i*z (caddr v1i*))
     (setq v2i*x (car v2i*) v2i*y (cadr v2i*) v2i*z (caddr v2i*))
     (setq v1f*z (* kur (/ (+ (* (- m1 m2) v1i*z) (* 2 m2 v2i*z)) (+ m1 m2))))
     (setq v2f*z (* kur (/ (+ (* (- m2 m1) v2i*z) (* 2 m1 v1i*z)) (+ m1 m2))))
     (setq v1f* (list v1i*x v1i*y v1f*z))
     (setq v2f* (list v2i*x v2i*y v2f*z))
     (setq v1f (trans v1f* (list dx12 dy12 dz12) 0))
     (setq v2f (trans v2f* (list dx12 dy12 dz12) 0))
     (setq v1x (car v1f) v1y (cadr v1f) v1z (caddr v1f))
     (setq v2x (car v2f) v2y (cadr v2f) v2z (caddr v2f))
    )
   )
  )
  (if (> d13 r13)
   (progn 
    (setq v1x (+ v1x (* a1x t)))  (setq v1y (+ v1y (* a1y t)))  (setq v1z (+ v1z (* a1z t)))
    (setq v3x (+ v3x (* a3x t)))  (setq v3y (+ v3y (* a3y t)))  (setq v3z (+ v3z (* a3z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v1i (list v1x v1y v1z)) ;velocita 1 prima dello scontro
     (setq v3i (list v3x v3y v3z)) ;velocita 3 prima dello scontro
     (setq v1i* (trans v1i 0 (list dx13 dy13 dz13)))
     (setq v3i* (trans v3i 0 (list dx13 dy13 dz13)))
     (setq v1i*x (car v1i*) v1i*y (cadr v1i*) v1i*z (caddr v1i*))
     (setq v3i*x (car v3i*) v3i*y (cadr v3i*) v3i*z (caddr v3i*))
     (setq v1f*z (* kur (/ (+ (* (- m1 m3) v1i*z) (* 2 m3 v3i*z)) (+ m1 m3))))
     (setq v3f*z (* kur (/ (+ (* (- m3 m1) v3i*z) (* 2 m1 v1i*z)) (+ m1 m3))))
     (setq v1f* (list v1i*x v1i*y v1f*z))
     (setq v3f* (list v3i*x v3i*y v3f*z))
     (setq v1f (trans v1f* (list dx13 dy13 dz13) 0))
     (setq v3f (trans v3f* (list dx13 dy13 dz13) 0))
     (setq v1x (car v1f) v1y (cadr v1f) v1z (caddr v1f))
     (setq v3x (car v3f) v3y (cadr v3f) v3z (caddr v3f))
    )
   )
  )
  (if (> d23 r23)
   (progn 
    (setq v2x (+ v2x (* a2x t)))  (setq v2y (+ v2y (* a2y t)))  (setq v2z (+ v2z (* a2z t)))
    (setq v3x (+ v3x (* a3x t)))  (setq v3y (+ v3y (* a3y t)))  (setq v3z (+ v3z (* a3z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v2i (list v2x v2y v2z)) ;velocita 2 prima dello scontro
     (setq v3i (list v3x v3y v3z)) ;velocita 3 prima dello scontro
     (setq v2i* (trans v2i 0 (list dx23 dy23 dz23)))
     (setq v3i* (trans v3i 0 (list dx23 dy23 dz23)))
     (setq v2i*x (car v2i*) v2i*y (cadr v2i*) v2i*z (caddr v2i*))
     (setq v3i*x (car v3i*) v3i*y (cadr v3i*) v3i*z (caddr v3i*))
     (setq v2f*z (* kur (/ (+ (* (- m2 m3) v2i*z) (* 2 m3 v3i*z)) (+ m2 m3))))
     (setq v3f*z (* kur (/ (+ (* (- m3 m2) v3i*z) (* 2 m2 v2i*z)) (+ m2 m3))))
     (setq v2f* (list v2i*x v2i*y v2f*z))
     (setq v3f* (list v3i*x v3i*y v3f*z))
     (setq v2f (trans v2f* (list dx23 dy23 dz23) 0))
     (setq v3f (trans v3f* (list dx23 dy23 dz23) 0))
     (setq v2x (car v2f) v2y (cadr v2f) v2z (caddr v2f))
     (setq v3x (car v3f) v3y (cadr v3f) v3z (caddr v3f))
    )
   )
  )
  (if (> d14 r14)
   (progn 
    (setq v1x (+ v1x (* a1x t)))  (setq v1y (+ v1y (* a1y t)))  (setq v1z (+ v1z (* a1z t)))
    (setq v4x (+ v4x (* a4x t)))  (setq v4y (+ v4y (* a4y t)))  (setq v4z (+ v4z (* a4z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v1i (list v1x v1y v1z)) ;velocita 1 prima dello scontro
     (setq v4i (list v4x v4y v4z)) ;velocita 4 prima dello scontro
     (setq v1i* (trans v1i 0 (list dx14 dy14 dz14)))
     (setq v4i* (trans v4i 0 (list dx14 dy14 dz14)))
     (setq v1i*x (car v1i*) v1i*y (cadr v1i*) v1i*z (caddr v1i*))
     (setq v4i*x (car v4i*) v4i*y (cadr v4i*) v4i*z (caddr v4i*))
     (setq v1f*z (* kur (/ (+ (* (- m1 m4) v1i*z) (* 2 m4 v4i*z)) (+ m1 m4))))
     (setq v4f*z (* kur (/ (+ (* (- m4 m1) v4i*z) (* 2 m1 v1i*z)) (+ m1 m4))))
     (setq v1f* (list v1i*x v1i*y v1f*z))
     (setq v4f* (list v4i*x v4i*y v4f*z))
     (setq v1f (trans v1f* (list dx14 dy14 dz14) 0))
     (setq v4f (trans v4f* (list dx14 dy14 dz14) 0))
     (setq v1x (car v1f) v1y (cadr v1f) v1z (caddr v1f))
     (setq v4x (car v4f) v4y (cadr v4f) v4z (caddr v4f))
    )
   )
  )
  (if (> d24 r24)
   (progn 
    (setq v2x (+ v2x (* a2x t)))  (setq v2y (+ v2y (* a2y t)))  (setq v2z (+ v2z (* a2z t)))
    (setq v4x (+ v4x (* a4x t)))  (setq v4y (+ v4y (* a4y t)))  (setq v4z (+ v4z (* a4z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v2i (list v2x v2y v2z)) ;velocita 2 prima dello scontro
     (setq v4i (list v4x v4y v4z)) ;velocita 4 prima dello scontro
     (setq v2i* (trans v2i 0 (list dx24 dy24 dz24)))
     (setq v4i* (trans v4i 0 (list dx24 dy24 dz24)))
     (setq v2i*x (car v2i*) v2i*y (cadr v2i*) v2i*z (caddr v2i*))
     (setq v4i*x (car v4i*) v4i*y (cadr v4i*) v4i*z (caddr v4i*))
     (setq v2f*z (* kur (/ (+ (* (- m2 m4) v2i*z) (* 2 m4 v4i*z)) (+ m2 m4))))
     (setq v4f*z (* kur (/ (+ (* (- m4 m2) v4i*z) (* 2 m2 v2i*z)) (+ m2 m4))))
     (setq v2f* (list v2i*x v2i*y v2f*z))
     (setq v4f* (list v4i*x v4i*y v4f*z))
     (setq v2f (trans v2f* (list dx24 dy24 dz24) 0))
     (setq v4f (trans v4f* (list dx24 dy24 dz24) 0))
     (setq v2x (car v2f) v2y (cadr v2f) v2z (caddr v2f))
     (setq v4x (car v4f) v4y (cadr v4f) v4z (caddr v4f))
    )
   )
  )
  (if (> d34 r34)
   (progn 
    (setq v3x (+ v3x (* a3x t)))  (setq v3y (+ v3y (* a3y t)))  (setq v3z (+ v3z (* a3z t)))
    (setq v4x (+ v4x (* a4x t)))  (setq v4y (+ v4y (* a4y t)))  (setq v4z (+ v4z (* a4z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v3i (list v3x v3y v3z)) ;velocita 3 prima dello scontro
     (setq v4i (list v4x v4y v4z)) ;velocita 4 prima dello scontro
     (setq v3i* (trans v3i 0 (list dx34 dy34 dz34)))
     (setq v4i* (trans v4i 0 (list dx34 dy34 dz34)))
     (setq v3i*x (car v3i*) v3i*y (cadr v3i*) v3i*z (caddr v3i*))
     (setq v4i*x (car v4i*) v4i*y (cadr v4i*) v4i*z (caddr v4i*))
     (setq v3f*z (* kur (/ (+ (* (- m3 m4) v3i*z) (* 2 m4 v4i*z)) (+ m3 m4))))
     (setq v4f*z (* kur (/ (+ (* (- m4 m3) v4i*z) (* 2 m3 v3i*z)) (+ m3 m4))))
     (setq v3f* (list v3i*x v3i*y v3f*z))
     (setq v4f* (list v4i*x v4i*y v4f*z))
     (setq v3f (trans v3f* (list dx34 dy34 dz34) 0))
     (setq v4f (trans v4f* (list dx34 dy34 dz34) 0))
     (setq v3x (car v3f) v3y (cadr v3f) v3z (caddr v3f))
     (setq v4x (car v4f) v4y (cadr v4f) v4z (caddr v4f))
    )
   )
  )
  (if (> d15 r15)
   (progn 
    (setq v1x (+ v1x (* a1x t)))  (setq v1y (+ v1y (* a1y t)))  (setq v1z (+ v1z (* a1z t)))
    (setq v5x (+ v5x (* a5x t)))  (setq v5y (+ v5y (* a5y t)))  (setq v5z (+ v5z (* a5z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v1i (list v1x v1y v1z)) ;velocita 1 prima dello scontro
     (setq v5i (list v5x v5y v5z)) ;velocita 5 prima dello scontro
     (setq v1i* (trans v1i 0 (list dx15 dy15 dz15)))
     (setq v5i* (trans v5i 0 (list dx15 dy15 dz15)))
     (setq v1i*x (car v1i*) v1i*y (cadr v1i*) v1i*z (caddr v1i*))
     (setq v5i*x (car v5i*) v5i*y (cadr v5i*) v5i*z (caddr v5i*))
     (setq v1f*z (* kur (/ (+ (* (- m1 m5) v1i*z) (* 2 m5 v5i*z)) (+ m1 m5))))
     (setq v5f*z (* kur (/ (+ (* (- m5 m1) v5i*z) (* 2 m1 v1i*z)) (+ m1 m5))))
     (setq v1f* (list v1i*x v1i*y v1f*z))
     (setq v5f* (list v5i*x v5i*y v5f*z))
     (setq v1f (trans v1f* (list dx15 dy15 dz15) 0))
     (setq v5f (trans v5f* (list dx15 dy15 dz15) 0))
     (setq v1x (car v1f) v1y (cadr v1f) v1z (caddr v1f))
     (setq v5x (car v5f) v5y (cadr v5f) v5z (caddr v5f))
    )
   )
  )
  (if (> d25 r25)
   (progn 
    (setq v2x (+ v2x (* a2x t)))  (setq v2y (+ v2y (* a2y t)))  (setq v2z (+ v2z (* a2z t)))
    (setq v5x (+ v5x (* a5x t)))  (setq v5y (+ v5y (* a5y t)))  (setq v5z (+ v5z (* a5z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v2i (list v2x v2y v2z)) ;velocita 2 prima dello scontro
     (setq v5i (list v5x v5y v5z)) ;velocita 5 prima dello scontro
     (setq v2i* (trans v2i 0 (list dx25 dy25 dz25)))
     (setq v5i* (trans v5i 0 (list dx25 dy25 dz25)))
     (setq v2i*x (car v2i*) v2i*y (cadr v2i*) v2i*z (caddr v2i*))
     (setq v5i*x (car v5i*) v5i*y (cadr v5i*) v5i*z (caddr v5i*))
     (setq v2f*z (* kur (/ (+ (* (- m2 m5) v2i*z) (* 2 m5 v5i*z)) (+ m2 m5))))
     (setq v5f*z (* kur (/ (+ (* (- m5 m2) v5i*z) (* 2 m2 v2i*z)) (+ m2 m5))))
     (setq v2f* (list v2i*x v2i*y v2f*z))
     (setq v5f* (list v5i*x v5i*y v5f*z))
     (setq v2f (trans v2f* (list dx25 dy25 dz25) 0))
     (setq v5f (trans v5f* (list dx25 dy25 dz25) 0))
     (setq v2x (car v2f) v2y (cadr v2f) v2z (caddr v2f))
     (setq v5x (car v5f) v5y (cadr v5f) v5z (caddr v5f))
    )
   )
  )
  (if (> d35 r35)
   (progn 
    (setq v3x (+ v3x (* a3x t)))  (setq v3y (+ v3y (* a3y t)))  (setq v3z (+ v3z (* a3z t)))
    (setq v5x (+ v5x (* a5x t)))  (setq v5y (+ v5y (* a5y t)))  (setq v5z (+ v5z (* a5z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v3i (list v3x v3y v3z)) ;velocita 3 prima dello scontro
     (setq v5i (list v5x v5y v5z)) ;velocita 5 prima dello scontro
     (setq v3i* (trans v3i 0 (list dx35 dy35 dz35)))
     (setq v5i* (trans v5i 0 (list dx35 dy35 dz35)))
     (setq v3i*x (car v3i*) v3i*y (cadr v3i*) v3i*z (caddr v3i*))
     (setq v5i*x (car v5i*) v5i*y (cadr v5i*) v5i*z (caddr v5i*))
     (setq v3f*z (* kur (/ (+ (* (- m3 m5) v3i*z) (* 2 m5 v5i*z)) (+ m3 m5))))
     (setq v5f*z (* kur (/ (+ (* (- m5 m3) v5i*z) (* 2 m3 v3i*z)) (+ m3 m5))))
     (setq v3f* (list v3i*x v3i*y v3f*z))
     (setq v5f* (list v5i*x v5i*y v5f*z))
     (setq v3f (trans v3f* (list dx35 dy35 dz35) 0))
     (setq v5f (trans v5f* (list dx35 dy35 dz35) 0))
     (setq v3x (car v3f) v3y (cadr v3f) v3z (caddr v3f))
     (setq v5x (car v5f) v5y (cadr v5f) v5z (caddr v5f))
    )
   )
  )
  (if (> d45 r45)
   (progn 
    (setq v4x (+ v4x (* a4x t)))  (setq v4y (+ v4y (* a4y t)))  (setq v4z (+ v4z (* a4z t)))
    (setq v5x (+ v5x (* a5x t)))  (setq v5y (+ v5y (* a5y t)))  (setq v5z (+ v5z (* a5z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v4i (list v4x v4y v4z)) ;velocita 4 prima dello scontro
     (setq v5i (list v5x v5y v5z)) ;velocita 5 prima dello scontro
     (setq v4i* (trans v4i 0 (list dx45 dy45 dz45)))
     (setq v5i* (trans v5i 0 (list dx45 dy45 dz45)))
     (setq v4i*x (car v4i*) v4i*y (cadr v4i*) v4i*z (caddr v4i*))
     (setq v5i*x (car v5i*) v5i*y (cadr v5i*) v5i*z (caddr v5i*))
     (setq v4f*z (* kur (/ (+ (* (- m4 m5) v4i*z) (* 2 m5 v5i*z)) (+ m4 m5))))
     (setq v5f*z (* kur (/ (+ (* (- m5 m4) v5i*z) (* 2 m4 v4i*z)) (+ m4 m5))))
     (setq v4f* (list v4i*x v4i*y v4f*z))
     (setq v5f* (list v5i*x v5i*y v5f*z))
     (setq v4f (trans v4f* (list dx45 dy45 dz45) 0))
     (setq v5f (trans v5f* (list dx45 dy45 dz45) 0))
     (setq v4x (car v4f) v4y (cadr v4f) v4z (caddr v4f))
     (setq v5x (car v5f) v5y (cadr v5f) v5z (caddr v5f))
    )
   )
  )
  (if (> d16 r16)
   (progn 
    (setq v1x (+ v1x (* a1x t)))  (setq v1y (+ v1y (* a1y t)))  (setq v1z (+ v1z (* a1z t)))
    (setq v6x (+ v6x (* a6x t)))  (setq v6y (+ v6y (* a6y t)))  (setq v6z (+ v6z (* a6z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v1i (list v1x v1y v1z)) ;velocita 1 prima dello scontro
     (setq v6i (list v6x v6y v6z)) ;velocita 6 prima dello scontro
     (setq v1i* (trans v1i 0 (list dx16 dy16 dz16)))
     (setq v6i* (trans v6i 0 (list dx16 dy16 dz16)))
     (setq v1i*x (car v1i*) v1i*y (cadr v1i*) v1i*z (caddr v1i*))
     (setq v6i*x (car v6i*) v6i*y (cadr v6i*) v6i*z (caddr v6i*))
     (setq v1f*z (* kur (/ (+ (* (- m1 m6) v1i*z) (* 2 m6 v6i*z)) (+ m1 m6))))
     (setq v6f*z (* kur (/ (+ (* (- m6 m1) v6i*z) (* 2 m1 v1i*z)) (+ m1 m6))))
     (setq v1f* (list v1i*x v1i*y v1f*z))
     (setq v6f* (list v6i*x v6i*y v6f*z))
     (setq v1f (trans v1f* (list dx16 dy16 dz16) 0))
     (setq v6f (trans v6f* (list dx16 dy16 dz16) 0))
     (setq v1x (car v1f) v1y (cadr v1f) v1z (caddr v1f))
     (setq v6x (car v6f) v6y (cadr v6f) v6z (caddr v6f))
    )
   )
  )
  (if (> d26 r26)
   (progn 
    (setq v2x (+ v2x (* a2x t)))  (setq v2y (+ v2y (* a2y t)))  (setq v2z (+ v2z (* a2z t)))
    (setq v6x (+ v6x (* a6x t)))  (setq v6y (+ v6y (* a6y t)))  (setq v6z (+ v6z (* a6z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v2i (list v2x v2y v2z)) ;velocita 2 prima dello scontro
     (setq v6i (list v6x v6y v6z)) ;velocita 6 prima dello scontro
     (setq v2i* (trans v2i 0 (list dx26 dy26 dz26)))
     (setq v6i* (trans v6i 0 (list dx26 dy26 dz26)))
     (setq v2i*x (car v2i*) v2i*y (cadr v2i*) v2i*z (caddr v2i*))
     (setq v6i*x (car v6i*) v6i*y (cadr v6i*) v6i*z (caddr v6i*))
     (setq v2f*z (* kur (/ (+ (* (- m2 m6) v2i*z) (* 2 m6 v6i*z)) (+ m2 m6))))
     (setq v6f*z (* kur (/ (+ (* (- m6 m2) v6i*z) (* 2 m2 v2i*z)) (+ m2 m6))))
     (setq v2f* (list v2i*x v2i*y v2f*z))
     (setq v6f* (list v6i*x v6i*y v6f*z))
     (setq v2f (trans v2f* (list dx26 dy26 dz26) 0))
     (setq v6f (trans v6f* (list dx26 dy26 dz26) 0))
     (setq v2x (car v2f) v2y (cadr v2f) v2z (caddr v2f))
     (setq v6x (car v6f) v6y (cadr v6f) v6z (caddr v6f))
    )
   )
  )
  (if (> d36 r36)
   (progn 
    (setq v3x (+ v3x (* a3x t)))  (setq v3y (+ v3y (* a3y t)))  (setq v3z (+ v3z (* a3z t)))
    (setq v6x (+ v6x (* a6x t)))  (setq v6y (+ v6y (* a6y t)))  (setq v6z (+ v6z (* a6z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v3i (list v3x v3y v3z)) ;velocita 3 prima dello scontro
     (setq v6i (list v6x v6y v6z)) ;velocita 6 prima dello scontro
     (setq v3i* (trans v3i 0 (list dx36 dy36 dz36)))
     (setq v6i* (trans v6i 0 (list dx36 dy36 dz36)))
     (setq v3i*x (car v3i*) v3i*y (cadr v3i*) v3i*z (caddr v3i*))
     (setq v6i*x (car v6i*) v6i*y (cadr v6i*) v6i*z (caddr v6i*))
     (setq v3f*z (* kur (/ (+ (* (- m3 m6) v3i*z) (* 2 m6 v6i*z)) (+ m3 m6))))
     (setq v6f*z (* kur (/ (+ (* (- m6 m3) v6i*z) (* 2 m3 v3i*z)) (+ m3 m6))))
     (setq v3f* (list v3i*x v3i*y v3f*z))
     (setq v6f* (list v6i*x v6i*y v6f*z))
     (setq v3f (trans v3f* (list dx36 dy36 dz36) 0))
     (setq v6f (trans v6f* (list dx36 dy36 dz36) 0))
     (setq v3x (car v3f) v3y (cadr v3f) v3z (caddr v3f))
     (setq v6x (car v6f) v6y (cadr v6f) v6z (caddr v6f))
    )
   )
  )
  (if (> d46 r46)
   (progn 
    (setq v4x (+ v4x (* a4x t)))  (setq v4y (+ v4y (* a4y t)))  (setq v4z (+ v4z (* a4z t)))
    (setq v6x (+ v6x (* a6x t)))  (setq v6y (+ v6y (* a6y t)))  (setq v6z (+ v6z (* a6z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v4i (list v4x v4y v4z)) ;velocita 4 prima dello scontro
     (setq v6i (list v6x v6y v6z)) ;velocita 6 prima dello scontro
     (setq v4i* (trans v4i 0 (list dx46 dy46 dz46)))
     (setq v6i* (trans v6i 0 (list dx46 dy46 dz46)))
     (setq v4i*x (car v4i*) v4i*y (cadr v4i*) v4i*z (caddr v4i*))
     (setq v6i*x (car v6i*) v6i*y (cadr v6i*) v6i*z (caddr v6i*))
     (setq v4f*z (* kur (/ (+ (* (- m4 m6) v4i*z) (* 2 m6 v6i*z)) (+ m4 m6))))
     (setq v6f*z (* kur (/ (+ (* (- m6 m4) v6i*z) (* 2 m4 v4i*z)) (+ m4 m6))))
     (setq v4f* (list v4i*x v4i*y v4f*z))
     (setq v6f* (list v6i*x v6i*y v6f*z))
     (setq v4f (trans v4f* (list dx46 dy46 dz46) 0))
     (setq v6f (trans v6f* (list dx46 dy46 dz46) 0))
     (setq v4x (car v4f) v4y (cadr v4f) v4z (caddr v4f))
     (setq v6x (car v6f) v6y (cadr v6f) v6z (caddr v6f))
    )
   )
  )
  (if (> d56 r56)
   (progn 
    (setq v5x (+ v5x (* a5x t)))  (setq v5y (+ v5y (* a5y t)))  (setq v5z (+ v5z (* a5z t)))
    (setq v6x (+ v6x (* a6x t)))  (setq v6y (+ v6y (* a6y t)))  (setq v6z (+ v6z (* a6z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v5i (list v5x v5y v5z)) ;velocita 5 prima dello scontro
     (setq v6i (list v6x v6y v6z)) ;velocita 6 prima dello scontro
     (setq v5i* (trans v5i 0 (list dx56 dy56 dz56)))
     (setq v6i* (trans v6i 0 (list dx56 dy56 dz56)))
     (setq v5i*x (car v5i*) v5i*y (cadr v5i*) v5i*z (caddr v5i*))
     (setq v6i*x (car v6i*) v6i*y (cadr v6i*) v6i*z (caddr v6i*))
     (setq v5f*z (* kur (/ (+ (* (- m5 m6) v5i*z) (* 2 m6 v6i*z)) (+ m5 m6))))
     (setq v6f*z (* kur (/ (+ (* (- m6 m5) v6i*z) (* 2 m5 v5i*z)) (+ m5 m6))))
     (setq v5f* (list v5i*x v5i*y v5f*z))
     (setq v6f* (list v6i*x v6i*y v6f*z))
     (setq v5f (trans v5f* (list dx56 dy56 dz56) 0))
     (setq v6f (trans v6f* (list dx56 dy56 dz56) 0))
     (setq v5x (car v5f) v5y (cadr v5f) v5z (caddr v5f))
     (setq v6x (car v6f) v6y (cadr v6f) v6z (caddr v6f))
    )
   )
  )

  (if (< (- x1 r1) xsa) (setq v1x (* (+ (* -2 kbi) 1) v1x) ) )
  (if (< (- y1 r1) ysa) (setq v1y (* (+ (* -2 kbi) 1) v1y) ) )   
  (if (< (- z1 r1) zsa) (setq v1z (* (+ (* -2 kbi) 1) v1z) ) )   
  (if (> (+ x1 r1) xsb) (setq v1x (* (+ (* -2 kbi) 1) v1x) ) )   
  (if (> (+ y1 r1) ysb) (setq v1y (* (+ (* -2 kbi) 1) v1y) ) )   
  (if (> (+ z1 r1) zsb) (setq v1z (* (+ (* -2 kbi) 1) v1z) ) )   
  (if (< (- x2 r2) xsa) (setq v2x (* (+ (* -2 kbi) 1) v2x) ) )   
  (if (< (- y2 r2) ysa) (setq v2y (* (+ (* -2 kbi) 1) v2y) ) )   
  (if (< (- z2 r2) zsa) (setq v2z (* (+ (* -2 kbi) 1) v2z) ) )   
  (if (> (+ x2 r2) xsb) (setq v2x (* (+ (* -2 kbi) 1) v2x) ) )   
  (if (> (+ y2 r2) ysb) (setq v2y (* (+ (* -2 kbi) 1) v2y) ) )   
  (if (> (+ z2 r2) zsb) (setq v2z (* (+ (* -2 kbi) 1) v2z) ) )   
  (if (< (- x3 r3) xsa) (setq v3x (* (+ (* -2 kbi) 1) v3x) ) )   
  (if (< (- y3 r3) ysa) (setq v3y (* (+ (* -2 kbi) 1) v3y) ) )   
  (if (< (- z3 r3) zsa) (setq v3z (* (+ (* -2 kbi) 1) v3z) ) )   
  (if (> (+ x3 r3) xsb) (setq v3x (* (+ (* -2 kbi) 1) v3x) ) )   
  (if (> (+ y3 r3) ysb) (setq v3y (* (+ (* -2 kbi) 1) v3y) ) )   
  (if (> (+ z3 r3) zsb) (setq v3z (* (+ (* -2 kbi) 1) v3z) ) )   
  (if (< (- x4 r4) xsa) (setq v4x (* (+ (* -2 kbi) 1) v4x) ) )   
  (if (< (- y4 r4) ysa) (setq v4y (* (+ (* -2 kbi) 1) v4y) ) )   
  (if (< (- z4 r4) zsa) (setq v4z (* (+ (* -2 kbi) 1) v4z) ) )   
  (if (> (+ x4 r4) xsb) (setq v4x (* (+ (* -2 kbi) 1) v4x) ) )   
  (if (> (+ y4 r4) ysb) (setq v4y (* (+ (* -2 kbi) 1) v4y) ) )   
  (if (> (+ z4 r4) zsb) (setq v4z (* (+ (* -2 kbi) 1) v4z) ) )   
  (if (< (- x5 r5) xsa) (setq v5x (* (+ (* -2 kbi) 1) v5x) ) )   
  (if (< (- y5 r5) ysa) (setq v5y (* (+ (* -2 kbi) 1) v5y) ) )   
  (if (< (- z5 r5) zsa) (setq v5z (* (+ (* -2 kbi) 1) v5z) ) )   
  (if (> (+ x5 r5) xsb) (setq v5x (* (+ (* -2 kbi) 1) v5x) ) )   
  (if (> (+ y5 r5) ysb) (setq v5y (* (+ (* -2 kbi) 1) v5y) ) )   
  (if (> (+ z5 r5) zsb) (setq v5z (* (+ (* -2 kbi) 1) v5z) ) )   
  (if (< (- x6 r6) xsa) (setq v6x (* (+ (* -2 kbi) 1) v6x) ) )   
  (if (< (- y6 r6) ysa) (setq v6y (* (+ (* -2 kbi) 1) v6y) ) )   
  (if (< (- z6 r6) zsa) (setq v6z (* (+ (* -2 kbi) 1) v6z) ) )   
  (if (> (+ x6 r6) xsb) (setq v6x (* (+ (* -2 kbi) 1) v6x) ) )   
  (if (> (+ y6 r6) ysb) (setq v6y (* (+ (* -2 kbi) 1) v6y) ) )   
  (if (> (+ z6 r6) zsb) (setq v6z (* (+ (* -2 kbi) 1) v6z) ) )   

  (setq s1x (+ (* v1x t) (* 0.5 a1x t t)))  (setq s1y (+ (* v1y t) (* 0.5 a1y t t)))  (setq s1z (+ (* v1z t) (* 0.5 a1z t t)))
  (setq s2x (+ (* v2x t) (* 0.5 a2x t t)))  (setq s2y (+ (* v2y t) (* 0.5 a2y t t)))  (setq s2z (+ (* v2z t) (* 0.5 a2z t t)))
  (setq s3x (+ (* v3x t) (* 0.5 a3x t t)))  (setq s3y (+ (* v3y t) (* 0.5 a3y t t)))  (setq s3z (+ (* v3z t) (* 0.5 a3z t t)))
  (setq s4x (+ (* v4x t) (* 0.5 a4x t t)))  (setq s4y (+ (* v4y t) (* 0.5 a4y t t)))  (setq s4z (+ (* v4z t) (* 0.5 a4z t t)))
  (setq s5x (+ (* v5x t) (* 0.5 a5x t t)))  (setq s5y (+ (* v5y t) (* 0.5 a5y t t)))  (setq s5z (+ (* v5z t) (* 0.5 a5z t t)))
  (setq s6x (+ (* v6x t) (* 0.5 a6x t t)))  (setq s6y (+ (* v6y t) (* 0.5 a6y t t)))  (setq s6z (+ (* v6z t) (* 0.5 a6z t t)))

  (setq x1 (+ x1 (* k1 s1x)))  (setq y1 (+ y1 (* k1 s1y)))  (setq z1 (+ z1 (* k1 s1z)))
  (setq x2 (+ x2 (* k2 s2x)))  (setq y2 (+ y2 (* k2 s2y)))  (setq z2 (+ z2 (* k2 s2z)))
  (setq x3 (+ x3 (* k3 s3x)))  (setq y3 (+ y3 (* k3 s3y)))  (setq z3 (+ z3 (* k3 s3z)))
  (setq x4 (+ x4 (* k4 s4x)))  (setq y4 (+ y4 (* k4 s4y)))  (setq z4 (+ z4 (* k4 s4z)))
  (setq x5 (+ x5 (* k5 s5x)))  (setq y5 (+ y5 (* k5 s5y)))  (setq z5 (+ z5 (* k5 s5z)))
  (setq x6 (+ x6 (* k6 s6x)))  (setq y6 (+ y6 (* k6 s6y)))  (setq z6 (+ z6 (* k6 s6z)))

  (setq a1 (sqrt (+ (* a1x a1x) (* a1y a1y) (* a1z a1z))))
  (setq a2 (sqrt (+ (* a2x a2x) (* a2y a2y) (* a2z a2z))))
  (setq a3 (sqrt (+ (* a3x a3x) (* a3y a3y) (* a3z a3z))))
  (setq a4 (sqrt (+ (* a4x a4x) (* a4y a4y) (* a4z a4z))))
  (setq a5 (sqrt (+ (* a5x a5x) (* a5y a5y) (* a5z a5z))))
  (setq a6 (sqrt (+ (* a6x a6x) (* a6y a6y) (* a6z a6z))))

  (setq va (+ (abs a1) (abs a2) (abs a3) (abs a4) (abs a5) (abs a6)
              (abs v1) (abs v2) (abs v3) (abs v4) (abs v5) (abs v6)
           )
  )
  (princ "\n")
  (princ va)
  (princ)

  (setq q1 (list x1 y1 z1))
  (setq q2 (list x2 y2 z2))
  (setq q3 (list x3 y3 z3))
  (setq q4 (list x4 y4 z4))
  (setq q5 (list x5 y5 z5))
  (setq q6 (list x6 y6 z6))

  (if (= iscan 0)
   (progn
 
   (if (= ker 0)
    (progn
    (if (= pc "p")
        (progn
         (setvar "clayer" "m1") (command "_point" p1)
         (setvar "clayer" "m2") (command "_point" p2)
         (setvar "clayer" "m3") (command "_point" p3)
         (setvar "clayer" "m4") (command "_point" p4)
         (setvar "clayer" "m5") (command "_point" p5)
         (setvar "clayer" "m6") (command "_point" p6)
        )
        (if (= pc "c")
            (progn
             (setvar "clayer" "m1") (command "_circle" p1 r1)
             (setvar "clayer" "m2") (command "_circle" p2 r2)
             (setvar "clayer" "m3") (command "_circle" p3 r3)
             (setvar "clayer" "m4") (command "_circle" p4 r4)
             (setvar "clayer" "m5") (command "_circle" p5 r5)
             (setvar "clayer" "m6") (command "_circle" p6 r6)
            )
            (if (= pc "s")
                (progn
                 (setvar "clayer" "m1") (command "_sphere" p1 r1)
                 (setvar "clayer" "m2") (command "_sphere" p2 r2)
                 (setvar "clayer" "m3") (command "_sphere" p3 r3)
                 (setvar "clayer" "m4") (command "_sphere" p4 r4)
                 (setvar "clayer" "m5") (command "_sphere" p5 r5)
                 (setvar "clayer" "m6") (command "_sphere" p6 r6)
                )
            )
        )
    )
    )
    (progn
             (command "_move" o1 "" p1 q1)
             (command "_move" o2 "" p2 q2)
             (command "_move" o3 "" p3 q3)
             (command "_move" o4 "" p4 q4)
             (command "_move" o5 "" p5 q5)
             (command "_move" o6 "" p6 q6)
    )    
   )
    
   )

  )
 
  (setq p1 q1)
  (setq p2 q2)  
  (setq p3 q3)  
  (setq p4 q4)  
  (setq p5 q5)  
  (setq p6 q6)  

  (setq iscan (+ 1 iscan))
  (if (= iscan scan) (setq iscan 0))

 )
 (setvar "clayer" "0")
 (command "_pline" p1 p2 p3 p4 p5 p6 p1 "")
)


;;;*****************************************************************
;simula il moto di 10 oggetti sottoposti a forza gravitazionale
;gravita7 ver 1.5 23/07/2010
;Dott. Ing. Emanuele Ballasina
;cell 349-1813748
;mail ballacr75@libero.it

(defun c:gravita7 ()
(setvar "osmode" 0)
(setvar "dimzin" 0)
(setvar "cmdecho" 0)

(command "_-layer" "n" "m1" "_c" 10 "m1" "_s" "m1" "")
(command "_-layer" "n" "m2" "_c" 30 "m2" "_s" "m2" "")
(command "_-layer" "n" "m3" "_c" 50 "m3" "_s" "m3" "")
(command "_-layer" "n" "m4" "_c" 70 "m4" "_s" "m4" "")
(command "_-layer" "n" "m5" "_c" 90 "m5" "_s" "m5" "")
(command "_-layer" "n" "m6" "_c" 110 "m6" "_s" "m6" "")
(command "_-layer" "n" "m7" "_c" 130 "m7" "_s" "m7" "")

(setq t 1) ;scansione tempo
(setq kdi 1) ;riduzione diametro cilindri
(setq scan 1) ;scansione posizione (non funziona >1 se ker=1)

(setq m1 100.0) ;massa
(setq m2 100.0)
(setq m3 100.0)
(setq m4 100.0)
(setq m5 100.0)
(setq m6 100.0)
(setq m7 100.0)
(setq d1 0.1) ;densita
(setq d2 0.1)
(setq d3 0.1) 
(setq d4 0.1)
(setq d5 0.1)
(setq d6 0.1)
(setq d7 0.1)
(setq r1 (expt (/ m1 d1) 0.3333)) ;raggio
(setq r2 (expt (/ m2 d2) 0.3333))
(setq r3 (expt (/ m3 d3) 0.3333))
(setq r4 (expt (/ m4 d4) 0.3333))
(setq r5 (expt (/ m5 d5) 0.3333))
(setq r6 (expt (/ m6 d6) 0.3333))
(setq r7 (expt (/ m7 d7) 0.3333))
(setq r12 (+ r1 r2)) ;distanza di sfioro
(setq r13 (+ r1 r3))
(setq r23 (+ r2 r3))
(setq r14 (+ r1 r4))
(setq r24 (+ r2 r4))
(setq r34 (+ r3 r4))
(setq r15 (+ r1 r5))
(setq r25 (+ r2 r5))
(setq r35 (+ r3 r5))
(setq r45 (+ r4 r5))
(setq r16 (+ r1 r6))
(setq r26 (+ r2 r6))
(setq r36 (+ r3 r6))
(setq r46 (+ r4 r6))
(setq r56 (+ r5 r6))
(setq r17 (+ r1 r7))
(setq r27 (+ r2 r7))
(setq r37 (+ r3 r7))
(setq r47 (+ r4 r7))
(setq r57 (+ r5 r7))
(setq r67 (+ r6 r7))

(setq k1 1) ;abilita movimento pianeta
(setq k2 1)
(setq k3 1)
(setq k4 1)
(setq k5 1)
(setq k6 1)
(setq k7 1)
(setq kur 1) ;abilita urti, con coefficente di rimbalzo, <1 smorza
(setq kbi 1) ;abilita rimbalzo tipo biliardo contro pareti dello schermo, <1 smorza
(setq ker 1) ;1=cancella pianeti vecchi, 0=mantiene tutti i pianeti
(setq c (getvar "VIEWCTR"))
(setq xsc (car c))
(setq ysc (cadr c))
(setq zsc (caddr c))
(setq currh (getvar "viewsize"))
(setq sizex (nth 0 (getvar "screensize")))
(setq sizey (nth 1 (getvar "screensize")))
(setq j (/ sizex sizey))
(setq currw (* j currh))
(setq h2 (/ currh 2.0))
(setq w2 (/ currw 2.0))
(setq xsa (- xsc w2))
(setq ysa (- ysc h2))
(setq zsa (- zsc h2))
(setq xsb (+ xsc w2))
(setq ysb (+ ysc h2))
(setq zsb (+ zsc h2))
(if (/= kbi 0) (command "_rectangle" (list xsa ysa) (list xsb ysb)))

(setq pc "c") ;punti,cerchi,sfere
(setq lc "n") ;abilita disegno linee tra un pianeta e gli altri
(setq tc "n") ;abilita disegno linee traiettoria

(setq x1 0) ;posizione
(setq y1 0)
(setq z1 0)
(setq x2 100)
(setq y2 0)
(setq z2 0)
(setq x3 200)
(setq y3 0)
(setq z3 0)
(setq x4 300)
(setq y4 0)
(setq z4 0)
(setq x5 400)
(setq y5 0)
(setq z5 0)
(setq x6 500)
(setq y6 0)
(setq z6 0)
(setq x7 600)
(setq y7 0) 
(setq z7 0) 

(setq v1x 0.0) ;velocita
(setq v1y 0.0)
(setq v1z 0.0)
(setq v2x 0.0)
(setq v2y 0.0)
(setq v2z 0.0)
(setq v3x 0.0)
(setq v3y 0.0)
(setq v3z 0.0)
(setq v4x 0.0)
(setq v4y 0.0)
(setq v4z 0.0)
(setq v5x 0.0)
(setq v5y 0.0)
(setq v5z 0.0) 
(setq v6x 0.0)
(setq v6y 0.0)
(setq v6z 0.0)
(setq v7x 0.0)
(setq v7y 0.0)
(setq v7z 0.0)

(setq p1 (list x1 y1 z1))
(setq p2 (list x2 y2 z2))
(setq p3 (list x3 y3 z3))
(setq p4 (list x4 y4 z4))
(setq p5 (list x5 y5 z5))
(setq p6 (list x6 y6 z6))
(setq p7 (list x7 y7 z7))

(if (= pc "p")
    (progn
     (setvar "clayer" "m1") (command "_point" p1) (setq o1 (cdr (car (entget (entlast)))))
     (setvar "clayer" "m2") (command "_point" p2) (setq o2 (cdr (car (entget (entlast)))))
     (setvar "clayer" "m3") (command "_point" p3) (setq o3 (cdr (car (entget (entlast)))))
     (setvar "clayer" "m4") (command "_point" p4) (setq o4 (cdr (car (entget (entlast)))))
     (setvar "clayer" "m5") (command "_point" p5) (setq o5 (cdr (car (entget (entlast)))))
     (setvar "clayer" "m6") (command "_point" p6) (setq o6 (cdr (car (entget (entlast)))))
     (setvar "clayer" "m7") (command "_point" p7) (setq o7 (cdr (car (entget (entlast)))))
    )
    (if (= pc "c")
        (progn
         (setvar "clayer" "m1") (command "_circle" p1 r1) (setq o1 (cdr (car (entget (entlast)))))
         (setvar "clayer" "m2") (command "_circle" p2 r2) (setq o2 (cdr (car (entget (entlast)))))
         (setvar "clayer" "m3") (command "_circle" p3 r3) (setq o3 (cdr (car (entget (entlast)))))
         (setvar "clayer" "m4") (command "_circle" p4 r4) (setq o4 (cdr (car (entget (entlast)))))
         (setvar "clayer" "m5") (command "_circle" p5 r5) (setq o5 (cdr (car (entget (entlast)))))
         (setvar "clayer" "m6") (command "_circle" p6 r6) (setq o6 (cdr (car (entget (entlast)))))
         (setvar "clayer" "m7") (command "_circle" p7 r7) (setq o7 (cdr (car (entget (entlast)))))
        )
        (if (= pc "s")
            (progn
             (setvar "clayer" "m1") (command "_sphere" p1 r1) (setq o1 (cdr (car (entget (entlast)))))
             (setvar "clayer" "m2") (command "_sphere" p2 r2) (setq o2 (cdr (car (entget (entlast)))))
             (setvar "clayer" "m3") (command "_sphere" p3 r3) (setq o3 (cdr (car (entget (entlast)))))
             (setvar "clayer" "m4") (command "_sphere" p4 r4) (setq o4 (cdr (car (entget (entlast)))))
             (setvar "clayer" "m5") (command "_sphere" p5 r5) (setq o5 (cdr (car (entget (entlast)))))
             (setvar "clayer" "m6") (command "_sphere" p6 r6) (setq o6 (cdr (car (entget (entlast)))))
             (setvar "clayer" "m7") (command "_sphere" p7 r7) (setq o7 (cdr (car (entget (entlast)))))
            )
        )
    )
)

(setq va 1000)
(setq iscan 0)
 (while (> va 0.0001) ;scansione velocit ed accelerazione, se = 0 si ferma il lisp

  (setq v1 (sqrt (+ (* v1x v1x) (* v1y v1y) (* v1z v1z))))
  (setq v2 (sqrt (+ (* v2x v2x) (* v2y v2y) (* v2z v2z))))
  (setq v3 (sqrt (+ (* v3x v3x) (* v3y v3y) (* v3z v3z))))
  (setq v4 (sqrt (+ (* v4x v4x) (* v4y v4y) (* v4z v4z))))
  (setq v5 (sqrt (+ (* v5x v5x) (* v5y v5y) (* v5z v5z))))
  (setq v6 (sqrt (+ (* v6x v6x) (* v6y v6y) (* v6z v6z))))
  (setq v7 (sqrt (+ (* v7x v7x) (* v7y v7y) (* v7z v7z))))
  
  (setq d12 (distance p1 p2))
  (setq d13 (distance p1 p3))
  (setq d23 (distance p2 p3))
  (setq d14 (distance p1 p4))
  (setq d24 (distance p2 p4))
  (setq d34 (distance p3 p4))
  (setq d15 (distance p1 p5))
  (setq d25 (distance p2 p5))
  (setq d35 (distance p3 p5))
  (setq d45 (distance p4 p5))
  (setq d16 (distance p1 p6))
  (setq d26 (distance p2 p6))
  (setq d36 (distance p3 p6))
  (setq d46 (distance p4 p6))
  (setq d56 (distance p5 p6))
  (setq d17 (distance p1 p7))
  (setq d27 (distance p2 p7))
  (setq d37 (distance p3 p7))
  (setq d47 (distance p4 p7))
  (setq d57 (distance p5 p7))
  (setq d67 (distance p6 p7))

  (setq dx12 (- x2 x1))  (setq dy12 (- y2 y1))  (setq dz12 (- z2 z1))
  (setq dx13 (- x3 x1))  (setq dy13 (- y3 y1))  (setq dz13 (- z3 z1))
  (setq dx23 (- x3 x2))  (setq dy23 (- y3 y2))  (setq dz23 (- z3 z2))
  (setq dx14 (- x4 x1))  (setq dy14 (- y4 y1))  (setq dz14 (- z4 z1))
  (setq dx24 (- x4 x2))  (setq dy24 (- y4 y2))  (setq dz24 (- z4 z2))
  (setq dx34 (- x4 x3))  (setq dy34 (- y4 y3))  (setq dz34 (- z4 z3))
  (setq dx15 (- x5 x1))  (setq dy15 (- y5 y1))  (setq dz15 (- z5 z1))
  (setq dx25 (- x5 x2))  (setq dy25 (- y5 y2))  (setq dz25 (- z5 z2))
  (setq dx35 (- x5 x3))  (setq dy35 (- y5 y3))  (setq dz35 (- z5 z3))
  (setq dx45 (- x5 x4))  (setq dy45 (- y5 y4))  (setq dz45 (- z5 z4))
  (setq dx16 (- x6 x1))  (setq dy16 (- y6 y1))  (setq dz16 (- z6 z1))
  (setq dx26 (- x6 x2))  (setq dy26 (- y6 y2))  (setq dz26 (- z6 z2))
  (setq dx36 (- x6 x3))  (setq dy36 (- y6 y3))  (setq dz36 (- z6 z3))
  (setq dx46 (- x6 x4))  (setq dy46 (- y6 y4))  (setq dz46 (- z6 z4))
  (setq dx56 (- x6 x5))  (setq dy56 (- y6 y5))  (setq dz56 (- z6 z5))
  (setq dx17 (- x7 x1))  (setq dy17 (- y7 y1))  (setq dz17 (- z7 z1))
  (setq dx27 (- x7 x2))  (setq dy27 (- y7 y2))  (setq dz27 (- z7 z2))
  (setq dx37 (- x7 x3))  (setq dy37 (- y7 y3))  (setq dz37 (- z7 z3))
  (setq dx47 (- x7 x4))  (setq dy47 (- y7 y4))  (setq dz47 (- z7 z4))
  (setq dx57 (- x7 x5))  (setq dy57 (- y7 y5))  (setq dz57 (- z7 z5))
  (setq dx67 (- x7 x6))  (setq dy67 (- y7 y6))  (setq dz67 (- z7 z6))

;                   GRAVITA              REPULSIONE           ELASTICO       MOLLA
  (if (<= d12 r12) (setq d12 r12))
  (if (<= d13 r13) (setq d13 r13))
  (if (<= d23 r23) (setq d23 r23))
  (if (<= d14 r14) (setq d14 r14))
  (if (<= d24 r24) (setq d24 r24))
  (if (<= d34 r34) (setq d34 r34))
  (if (<= d15 r15) (setq d15 r15))
  (if (<= d25 r25) (setq d25 r25))
  (if (<= d35 r35) (setq d35 r35))
  (if (<= d45 r45) (setq d45 r45))
  (if (<= d16 r16) (setq d16 r16))
  (if (<= d26 r26) (setq d26 r26))
  (if (<= d36 r36) (setq d36 r36))
  (if (<= d46 r46) (setq d46 r46))
  (if (<= d56 r56) (setq d56 r56))
  (if (<= d17 r17) (setq d17 r17))
  (if (<= d27 r27) (setq d27 r27))
  (if (<= d37 r37) (setq d37 r37))
  (if (<= d47 r47) (setq d47 r47))
  (if (<= d57 r57) (setq d57 r57))
  (if (<= d67 r67) (setq d67 r67))
  (setq f12 (+ (* 1 (fgr m1 m2 d12)) (* 1 (fre m1 m2 d12)) (* 1 (fel d12)) (* 1 (fmo d12)) ))
  (setq f13 (+ (* 1 (fgr m1 m3 d13)) (* 1 (fre m1 m3 d13)) (* 1 (fel d13)) (* 1 (fmo d13)) ))
  (setq f23 (+ (* 1 (fgr m2 m3 d23)) (* 1 (fre m2 m3 d23)) (* 1 (fel d23)) (* 1 (fmo d23)) ))
  (setq f14 (+ (* 1 (fgr m1 m4 d14)) (* 1 (fre m1 m4 d14)) (* 1 (fel d14)) (* 1 (fmo d14)) ))
  (setq f24 (+ (* 1 (fgr m2 m4 d24)) (* 1 (fre m2 m4 d24)) (* 1 (fel d24)) (* 1 (fmo d24)) ))
  (setq f34 (+ (* 1 (fgr m3 m4 d34)) (* 1 (fre m3 m4 d34)) (* 1 (fel d34)) (* 1 (fmo d34)) ))
  (setq f15 (+ (* 1 (fgr m1 m5 d15)) (* 1 (fre m1 m5 d15)) (* 1 (fel d15)) (* 1 (fmo d15)) ))
  (setq f25 (+ (* 1 (fgr m2 m5 d25)) (* 1 (fre m2 m5 d25)) (* 1 (fel d25)) (* 1 (fmo d25)) ))
  (setq f35 (+ (* 1 (fgr m3 m5 d35)) (* 1 (fre m3 m5 d35)) (* 1 (fel d35)) (* 1 (fmo d35)) ))
  (setq f45 (+ (* 1 (fgr m4 m5 d45)) (* 1 (fre m4 m5 d45)) (* 1 (fel d45)) (* 1 (fmo d45)) ))
  (setq f16 (+ (* 1 (fgr m1 m6 d16)) (* 1 (fre m1 m6 d16)) (* 1 (fel d16)) (* 1 (fmo d16)) ))
  (setq f26 (+ (* 1 (fgr m2 m6 d26)) (* 1 (fre m2 m6 d26)) (* 1 (fel d26)) (* 1 (fmo d26)) ))
  (setq f36 (+ (* 1 (fgr m3 m6 d36)) (* 1 (fre m3 m6 d36)) (* 1 (fel d36)) (* 1 (fmo d36)) ))
  (setq f46 (+ (* 1 (fgr m4 m6 d46)) (* 1 (fre m4 m6 d46)) (* 1 (fel d46)) (* 1 (fmo d46)) ))
  (setq f56 (+ (* 1 (fgr m5 m6 d56)) (* 1 (fre m5 m6 d56)) (* 1 (fel d56)) (* 1 (fmo d56)) ))
  (setq f17 (+ (* 1 (fgr m1 m7 d17)) (* 1 (fre m1 m7 d17)) (* 1 (fel d17)) (* 1 (fmo d17)) ))
  (setq f27 (+ (* 1 (fgr m2 m7 d27)) (* 1 (fre m2 m7 d27)) (* 1 (fel d27)) (* 1 (fmo d27)) ))
  (setq f37 (+ (* 1 (fgr m3 m7 d37)) (* 1 (fre m3 m7 d37)) (* 1 (fel d37)) (* 1 (fmo d37)) ))
  (setq f47 (+ (* 1 (fgr m4 m7 d47)) (* 1 (fre m4 m7 d47)) (* 1 (fel d47)) (* 1 (fmo d47)) ))
  (setq f57 (+ (* 1 (fgr m5 m7 d57)) (* 1 (fre m5 m7 d57)) (* 1 (fel d57)) (* 1 (fmo d57)) ))
  (setq f67 (+ (* 1 (fgr m6 m7 d67)) (* 1 (fre m6 m7 d67)) (* 1 (fel d67)) (* 1 (fmo d67)) ))

  (setq a12 (/ f12 m1))  (setq a21 (* -1 (/ f12 m2)))
  (setq a13 (/ f13 m1))  (setq a31 (* -1 (/ f13 m3)))
  (setq a23 (/ f23 m2))  (setq a32 (* -1 (/ f23 m3)))
  (setq a14 (/ f14 m1))  (setq a41 (* -1 (/ f14 m4)))
  (setq a24 (/ f24 m2))  (setq a42 (* -1 (/ f24 m4)))
  (setq a34 (/ f34 m3))  (setq a43 (* -1 (/ f34 m4)))
  (setq a15 (/ f15 m1))  (setq a51 (* -1 (/ f15 m5)))
  (setq a25 (/ f25 m2))  (setq a52 (* -1 (/ f25 m5)))
  (setq a35 (/ f35 m3))  (setq a53 (* -1 (/ f35 m5)))
  (setq a45 (/ f45 m4))  (setq a54 (* -1 (/ f45 m5)))
  (setq a16 (/ f16 m1))  (setq a61 (* -1 (/ f16 m6)))
  (setq a26 (/ f26 m2))  (setq a62 (* -1 (/ f26 m6)))
  (setq a36 (/ f36 m3))  (setq a63 (* -1 (/ f36 m6)))
  (setq a46 (/ f46 m4))  (setq a64 (* -1 (/ f46 m6)))
  (setq a56 (/ f56 m5))  (setq a65 (* -1 (/ f56 m6)))
  (setq a17 (/ f17 m1))  (setq a71 (* -1 (/ f17 m7)))
  (setq a27 (/ f27 m2))  (setq a72 (* -1 (/ f27 m7)))
  (setq a37 (/ f37 m3))  (setq a73 (* -1 (/ f37 m7)))
  (setq a47 (/ f47 m4))  (setq a74 (* -1 (/ f47 m7)))
  (setq a57 (/ f57 m5))  (setq a75 (* -1 (/ f57 m7)))
  (setq a67 (/ f67 m6))  (setq a76 (* -1 (/ f67 m7)))
 
  (setq a1x (+ (* 1 (/ (fsx x1 y1 z1) m1)) (* 1 (/ (fwx r1) m1)) (* 1 v1x (/ (fvi m1 r1 v1) m1)) (/ (* a12 dx12) d12) (/ (* a13 dx13) d13) (/ (* a14 dx14) d14) (/ (* a15 dx15) d15) (/ (* a16 dx16) d16) (/ (* a17 dx17) d17) ))
  (setq a1y (+ (* 1 (/ (fsy x1 y1 z1) m1)) (* 1 (/ (fwy r1) m1)) (* 1 v1y (/ (fvi m1 r1 v1) m1)) (/ (* a12 dy12) d12) (/ (* a13 dy13) d13) (/ (* a14 dy14) d14) (/ (* a15 dy15) d15) (/ (* a16 dy16) d16) (/ (* a17 dy17) d17) ))
  (setq a1z (+ (* 1 (/ (fsz x1 y1 z1) m1)) (* 1 (/ (fwz r1) m1)) (* 1 v1z (/ (fvi m1 r1 v1) m1)) (/ (* a12 dz12) d12) (/ (* a13 dz13) d13) (/ (* a14 dz14) d14) (/ (* a15 dz15) d15) (/ (* a16 dz16) d16) (/ (* a17 dz17) d17) ))
  (setq a2x (+ (* 1 (/ (fsx x2 y2 z2) m2)) (* 1 (/ (fwx r2) m2)) (* 1 v2x (/ (fvi m2 r2 v2) m2)) (/ (* a21 dx12) d12) (/ (* a23 dx23) d23) (/ (* a24 dx24) d24) (/ (* a25 dx25) d25) (/ (* a26 dx26) d26) (/ (* a27 dx27) d27) ))
  (setq a2y (+ (* 1 (/ (fsy x2 y2 z2) m2)) (* 1 (/ (fwy r2) m2)) (* 1 v2y (/ (fvi m2 r2 v2) m2)) (/ (* a21 dy12) d12) (/ (* a23 dy23) d23) (/ (* a24 dy24) d24) (/ (* a25 dy25) d25) (/ (* a26 dy26) d26) (/ (* a27 dy27) d27) ))
  (setq a2z (+ (* 1 (/ (fsz x2 y2 z2) m2)) (* 1 (/ (fwz r2) m2)) (* 1 v2z (/ (fvi m2 r2 v2) m2)) (/ (* a21 dz12) d12) (/ (* a23 dz23) d23) (/ (* a24 dz24) d24) (/ (* a25 dz25) d25) (/ (* a26 dz26) d26) (/ (* a27 dz27) d27) ))
  (setq a3x (+ (* 1 (/ (fsx x3 y3 z3) m3)) (* 1 (/ (fwx r3) m3)) (* 1 v3x (/ (fvi m3 r3 v3) m3)) (/ (* a31 dx13) d13) (/ (* a32 dx23) d23) (/ (* a34 dx34) d34) (/ (* a35 dx35) d35) (/ (* a36 dx36) d36) (/ (* a37 dx37) d37) ))
  (setq a3y (+ (* 1 (/ (fsy x3 y3 z3) m3)) (* 1 (/ (fwy r3) m3)) (* 1 v3y (/ (fvi m3 r3 v3) m3)) (/ (* a31 dy13) d13) (/ (* a32 dy23) d23) (/ (* a34 dy34) d34) (/ (* a35 dy35) d35) (/ (* a36 dy36) d36) (/ (* a37 dy37) d37) ))
  (setq a3z (+ (* 1 (/ (fsz x3 y3 z3) m3)) (* 1 (/ (fwz r3) m3)) (* 1 v3z (/ (fvi m3 r3 v3) m3)) (/ (* a31 dz13) d13) (/ (* a32 dz23) d23) (/ (* a34 dz34) d34) (/ (* a35 dz35) d35) (/ (* a36 dz36) d36) (/ (* a37 dz37) d37) ))
  (setq a4x (+ (* 1 (/ (fsx x4 y4 z4) m4)) (* 1 (/ (fwx r4) m4)) (* 1 v4x (/ (fvi m4 r4 v4) m4)) (/ (* a41 dx14) d14) (/ (* a42 dx24) d24) (/ (* a43 dx34) d34) (/ (* a45 dx45) d45) (/ (* a46 dx46) d46) (/ (* a47 dx47) d47) ))
  (setq a4y (+ (* 1 (/ (fsy x4 y4 z4) m4)) (* 1 (/ (fwy r4) m4)) (* 1 v4y (/ (fvi m4 r4 v4) m4)) (/ (* a41 dy14) d14) (/ (* a42 dy24) d24) (/ (* a43 dy34) d34) (/ (* a45 dy45) d45) (/ (* a46 dy46) d46) (/ (* a47 dy47) d47) ))
  (setq a4z (+ (* 1 (/ (fsz x4 y4 z4) m4)) (* 1 (/ (fwz r4) m4)) (* 1 v4z (/ (fvi m4 r4 v4) m4)) (/ (* a41 dz14) d14) (/ (* a42 dz24) d24) (/ (* a43 dz34) d34) (/ (* a45 dz45) d45) (/ (* a46 dz46) d46) (/ (* a47 dz47) d47) ))
  (setq a5x (+ (* 1 (/ (fsx x5 y5 z5) m5)) (* 1 (/ (fwx r5) m5)) (* 1 v5x (/ (fvi m5 r5 v5) m5)) (/ (* a51 dx15) d15) (/ (* a52 dx25) d25) (/ (* a53 dx35) d35) (/ (* a54 dx45) d45) (/ (* a56 dx56) d56) (/ (* a57 dx57) d57) ))
  (setq a5y (+ (* 1 (/ (fsy x5 y5 z5) m5)) (* 1 (/ (fwy r5) m5)) (* 1 v5y (/ (fvi m5 r5 v5) m5)) (/ (* a51 dy15) d15) (/ (* a52 dy25) d25) (/ (* a53 dy35) d35) (/ (* a54 dy45) d45) (/ (* a56 dy56) d56) (/ (* a57 dy57) d57) ))
  (setq a5z (+ (* 1 (/ (fsz x5 y5 z5) m5)) (* 1 (/ (fwz r5) m5)) (* 1 v5z (/ (fvi m5 r5 v5) m5)) (/ (* a51 dz15) d15) (/ (* a52 dz25) d25) (/ (* a53 dz35) d35) (/ (* a54 dz45) d45) (/ (* a56 dz56) d56) (/ (* a57 dz57) d57) ))
  (setq a6x (+ (* 1 (/ (fsx x6 y6 z6) m6)) (* 1 (/ (fwx r6) m6)) (* 1 v6x (/ (fvi m6 r6 v6) m6)) (/ (* a61 dx16) d16) (/ (* a62 dx26) d26) (/ (* a63 dx36) d36) (/ (* a64 dx46) d46) (/ (* a65 dx56) d56) (/ (* a67 dx67) d67) ))
  (setq a6y (+ (* 1 (/ (fsy x6 y6 z6) m6)) (* 1 (/ (fwy r6) m6)) (* 1 v6y (/ (fvi m6 r6 v6) m6)) (/ (* a61 dy16) d16) (/ (* a62 dy26) d26) (/ (* a63 dy36) d36) (/ (* a64 dy46) d46) (/ (* a65 dy56) d56) (/ (* a67 dy67) d67) ))
  (setq a6z (+ (* 1 (/ (fsz x6 y6 z6) m6)) (* 1 (/ (fwz r6) m6)) (* 1 v6z (/ (fvi m6 r6 v6) m6)) (/ (* a61 dz16) d16) (/ (* a62 dz26) d26) (/ (* a63 dz36) d36) (/ (* a64 dz46) d46) (/ (* a65 dz56) d56) (/ (* a67 dz67) d67) ))
  (setq a7x (+ (* 1 (/ (fsx x7 y7 z7) m7)) (* 1 (/ (fwx r7) m7)) (* 1 v7x (/ (fvi m7 r7 v7) m7)) (/ (* a71 dx17) d17) (/ (* a72 dx27) d27) (/ (* a73 dx37) d37) (/ (* a74 dx47) d47) (/ (* a75 dx57) d57) (/ (* a76 dx67) d67) ))
  (setq a7y (+ (* 1 (/ (fsy x7 y7 z7) m7)) (* 1 (/ (fwy r7) m7)) (* 1 v7y (/ (fvi m7 r7 v7) m7)) (/ (* a71 dy17) d17) (/ (* a72 dy27) d27) (/ (* a73 dy37) d37) (/ (* a74 dy47) d47) (/ (* a75 dy57) d57) (/ (* a76 dy67) d67) ))
  (setq a7z (+ (* 1 (/ (fsz x7 y7 z7) m7)) (* 1 (/ (fwz r7) m7)) (* 1 v7z (/ (fvi m7 r7 v7) m7)) (/ (* a71 dz17) d17) (/ (* a72 dz27) d27) (/ (* a73 dz37) d37) (/ (* a74 dz47) d47) (/ (* a75 dz57) d57) (/ (* a76 dz67) d67) ))

  (if (> d12 r12)
   (progn 
    (setq v1x (+ v1x (* a1x t)))  (setq v1y (+ v1y (* a1y t)))  (setq v1z (+ v1z (* a1z t)))
    (setq v2x (+ v2x (* a2x t)))  (setq v2y (+ v2y (* a2y t)))  (setq v2z (+ v2z (* a2z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v1i (list v1x v1y v1z)) ;velocita 1 prima dello scontro
     (setq v2i (list v2x v2y v2z)) ;velocita 2 prima dello scontro
     (setq v1i* (trans v1i 0 (list dx12 dy12 dz12)))
     (setq v2i* (trans v2i 0 (list dx12 dy12 dz12)))
     (setq v1i*x (car v1i*) v1i*y (cadr v1i*) v1i*z (caddr v1i*))
     (setq v2i*x (car v2i*) v2i*y (cadr v2i*) v2i*z (caddr v2i*))
     (setq v1f*z (* kur (/ (+ (* (- m1 m2) v1i*z) (* 2 m2 v2i*z)) (+ m1 m2))))
     (setq v2f*z (* kur (/ (+ (* (- m2 m1) v2i*z) (* 2 m1 v1i*z)) (+ m1 m2))))
     (setq v1f* (list v1i*x v1i*y v1f*z))
     (setq v2f* (list v2i*x v2i*y v2f*z))
     (setq v1f (trans v1f* (list dx12 dy12 dz12) 0))
     (setq v2f (trans v2f* (list dx12 dy12 dz12) 0))
     (setq v1x (car v1f) v1y (cadr v1f) v1z (caddr v1f))
     (setq v2x (car v2f) v2y (cadr v2f) v2z (caddr v2f))
    )
   )
  )
  (if (> d13 r13)
   (progn 
    (setq v1x (+ v1x (* a1x t)))  (setq v1y (+ v1y (* a1y t)))  (setq v1z (+ v1z (* a1z t)))
    (setq v3x (+ v3x (* a3x t)))  (setq v3y (+ v3y (* a3y t)))  (setq v3z (+ v3z (* a3z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v1i (list v1x v1y v1z)) ;velocita 1 prima dello scontro
     (setq v3i (list v3x v3y v3z)) ;velocita 3 prima dello scontro
     (setq v1i* (trans v1i 0 (list dx13 dy13 dz13)))
     (setq v3i* (trans v3i 0 (list dx13 dy13 dz13)))
     (setq v1i*x (car v1i*) v1i*y (cadr v1i*) v1i*z (caddr v1i*))
     (setq v3i*x (car v3i*) v3i*y (cadr v3i*) v3i*z (caddr v3i*))
     (setq v1f*z (* kur (/ (+ (* (- m1 m3) v1i*z) (* 2 m3 v3i*z)) (+ m1 m3))))
     (setq v3f*z (* kur (/ (+ (* (- m3 m1) v3i*z) (* 2 m1 v1i*z)) (+ m1 m3))))
     (setq v1f* (list v1i*x v1i*y v1f*z))
     (setq v3f* (list v3i*x v3i*y v3f*z))
     (setq v1f (trans v1f* (list dx13 dy13 dz13) 0))
     (setq v3f (trans v3f* (list dx13 dy13 dz13) 0))
     (setq v1x (car v1f) v1y (cadr v1f) v1z (caddr v1f))
     (setq v3x (car v3f) v3y (cadr v3f) v3z (caddr v3f))
    )
   )
  )
  (if (> d23 r23)
   (progn 
    (setq v2x (+ v2x (* a2x t)))  (setq v2y (+ v2y (* a2y t)))  (setq v2z (+ v2z (* a2z t)))
    (setq v3x (+ v3x (* a3x t)))  (setq v3y (+ v3y (* a3y t)))  (setq v3z (+ v3z (* a3z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v2i (list v2x v2y v2z)) ;velocita 2 prima dello scontro
     (setq v3i (list v3x v3y v3z)) ;velocita 3 prima dello scontro
     (setq v2i* (trans v2i 0 (list dx23 dy23 dz23)))
     (setq v3i* (trans v3i 0 (list dx23 dy23 dz23)))
     (setq v2i*x (car v2i*) v2i*y (cadr v2i*) v2i*z (caddr v2i*))
     (setq v3i*x (car v3i*) v3i*y (cadr v3i*) v3i*z (caddr v3i*))
     (setq v2f*z (* kur (/ (+ (* (- m2 m3) v2i*z) (* 2 m3 v3i*z)) (+ m2 m3))))
     (setq v3f*z (* kur (/ (+ (* (- m3 m2) v3i*z) (* 2 m2 v2i*z)) (+ m2 m3))))
     (setq v2f* (list v2i*x v2i*y v2f*z))
     (setq v3f* (list v3i*x v3i*y v3f*z))
     (setq v2f (trans v2f* (list dx23 dy23 dz23) 0))
     (setq v3f (trans v3f* (list dx23 dy23 dz23) 0))
     (setq v2x (car v2f) v2y (cadr v2f) v2z (caddr v2f))
     (setq v3x (car v3f) v3y (cadr v3f) v3z (caddr v3f))
    )
   )
  )
  (if (> d14 r14)
   (progn 
    (setq v1x (+ v1x (* a1x t)))  (setq v1y (+ v1y (* a1y t)))  (setq v1z (+ v1z (* a1z t)))
    (setq v4x (+ v4x (* a4x t)))  (setq v4y (+ v4y (* a4y t)))  (setq v4z (+ v4z (* a4z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v1i (list v1x v1y v1z)) ;velocita 1 prima dello scontro
     (setq v4i (list v4x v4y v4z)) ;velocita 4 prima dello scontro
     (setq v1i* (trans v1i 0 (list dx14 dy14 dz14)))
     (setq v4i* (trans v4i 0 (list dx14 dy14 dz14)))
     (setq v1i*x (car v1i*) v1i*y (cadr v1i*) v1i*z (caddr v1i*))
     (setq v4i*x (car v4i*) v4i*y (cadr v4i*) v4i*z (caddr v4i*))
     (setq v1f*z (* kur (/ (+ (* (- m1 m4) v1i*z) (* 2 m4 v4i*z)) (+ m1 m4))))
     (setq v4f*z (* kur (/ (+ (* (- m4 m1) v4i*z) (* 2 m1 v1i*z)) (+ m1 m4))))
     (setq v1f* (list v1i*x v1i*y v1f*z))
     (setq v4f* (list v4i*x v4i*y v4f*z))
     (setq v1f (trans v1f* (list dx14 dy14 dz14) 0))
     (setq v4f (trans v4f* (list dx14 dy14 dz14) 0))
     (setq v1x (car v1f) v1y (cadr v1f) v1z (caddr v1f))
     (setq v4x (car v4f) v4y (cadr v4f) v4z (caddr v4f))
    )
   )
  )
  (if (> d24 r24)
   (progn 
    (setq v2x (+ v2x (* a2x t)))  (setq v2y (+ v2y (* a2y t)))  (setq v2z (+ v2z (* a2z t)))
    (setq v4x (+ v4x (* a4x t)))  (setq v4y (+ v4y (* a4y t)))  (setq v4z (+ v4z (* a4z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v2i (list v2x v2y v2z)) ;velocita 2 prima dello scontro
     (setq v4i (list v4x v4y v4z)) ;velocita 4 prima dello scontro
     (setq v2i* (trans v2i 0 (list dx24 dy24 dz24)))
     (setq v4i* (trans v4i 0 (list dx24 dy24 dz24)))
     (setq v2i*x (car v2i*) v2i*y (cadr v2i*) v2i*z (caddr v2i*))
     (setq v4i*x (car v4i*) v4i*y (cadr v4i*) v4i*z (caddr v4i*))
     (setq v2f*z (* kur (/ (+ (* (- m2 m4) v2i*z) (* 2 m4 v4i*z)) (+ m2 m4))))
     (setq v4f*z (* kur (/ (+ (* (- m4 m2) v4i*z) (* 2 m2 v2i*z)) (+ m2 m4))))
     (setq v2f* (list v2i*x v2i*y v2f*z))
     (setq v4f* (list v4i*x v4i*y v4f*z))
     (setq v2f (trans v2f* (list dx24 dy24 dz24) 0))
     (setq v4f (trans v4f* (list dx24 dy24 dz24) 0))
     (setq v2x (car v2f) v2y (cadr v2f) v2z (caddr v2f))
     (setq v4x (car v4f) v4y (cadr v4f) v4z (caddr v4f))
    )
   )
  )
  (if (> d34 r34)
   (progn 
    (setq v3x (+ v3x (* a3x t)))  (setq v3y (+ v3y (* a3y t)))  (setq v3z (+ v3z (* a3z t)))
    (setq v4x (+ v4x (* a4x t)))  (setq v4y (+ v4y (* a4y t)))  (setq v4z (+ v4z (* a4z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v3i (list v3x v3y v3z)) ;velocita 3 prima dello scontro
     (setq v4i (list v4x v4y v4z)) ;velocita 4 prima dello scontro
     (setq v3i* (trans v3i 0 (list dx34 dy34 dz34)))
     (setq v4i* (trans v4i 0 (list dx34 dy34 dz34)))
     (setq v3i*x (car v3i*) v3i*y (cadr v3i*) v3i*z (caddr v3i*))
     (setq v4i*x (car v4i*) v4i*y (cadr v4i*) v4i*z (caddr v4i*))
     (setq v3f*z (* kur (/ (+ (* (- m3 m4) v3i*z) (* 2 m4 v4i*z)) (+ m3 m4))))
     (setq v4f*z (* kur (/ (+ (* (- m4 m3) v4i*z) (* 2 m3 v3i*z)) (+ m3 m4))))
     (setq v3f* (list v3i*x v3i*y v3f*z))
     (setq v4f* (list v4i*x v4i*y v4f*z))
     (setq v3f (trans v3f* (list dx34 dy34 dz34) 0))
     (setq v4f (trans v4f* (list dx34 dy34 dz34) 0))
     (setq v3x (car v3f) v3y (cadr v3f) v3z (caddr v3f))
     (setq v4x (car v4f) v4y (cadr v4f) v4z (caddr v4f))
    )
   )
  )
  (if (> d15 r15)
   (progn 
    (setq v1x (+ v1x (* a1x t)))  (setq v1y (+ v1y (* a1y t)))  (setq v1z (+ v1z (* a1z t)))
    (setq v5x (+ v5x (* a5x t)))  (setq v5y (+ v5y (* a5y t)))  (setq v5z (+ v5z (* a5z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v1i (list v1x v1y v1z)) ;velocita 1 prima dello scontro
     (setq v5i (list v5x v5y v5z)) ;velocita 5 prima dello scontro
     (setq v1i* (trans v1i 0 (list dx15 dy15 dz15)))
     (setq v5i* (trans v5i 0 (list dx15 dy15 dz15)))
     (setq v1i*x (car v1i*) v1i*y (cadr v1i*) v1i*z (caddr v1i*))
     (setq v5i*x (car v5i*) v5i*y (cadr v5i*) v5i*z (caddr v5i*))
     (setq v1f*z (* kur (/ (+ (* (- m1 m5) v1i*z) (* 2 m5 v5i*z)) (+ m1 m5))))
     (setq v5f*z (* kur (/ (+ (* (- m5 m1) v5i*z) (* 2 m1 v1i*z)) (+ m1 m5))))
     (setq v1f* (list v1i*x v1i*y v1f*z))
     (setq v5f* (list v5i*x v5i*y v5f*z))
     (setq v1f (trans v1f* (list dx15 dy15 dz15) 0))
     (setq v5f (trans v5f* (list dx15 dy15 dz15) 0))
     (setq v1x (car v1f) v1y (cadr v1f) v1z (caddr v1f))
     (setq v5x (car v5f) v5y (cadr v5f) v5z (caddr v5f))
    )
   )
  )
  (if (> d25 r25)
   (progn 
    (setq v2x (+ v2x (* a2x t)))  (setq v2y (+ v2y (* a2y t)))  (setq v2z (+ v2z (* a2z t)))
    (setq v5x (+ v5x (* a5x t)))  (setq v5y (+ v5y (* a5y t)))  (setq v5z (+ v5z (* a5z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v2i (list v2x v2y v2z)) ;velocita 2 prima dello scontro
     (setq v5i (list v5x v5y v5z)) ;velocita 5 prima dello scontro
     (setq v2i* (trans v2i 0 (list dx25 dy25 dz25)))
     (setq v5i* (trans v5i 0 (list dx25 dy25 dz25)))
     (setq v2i*x (car v2i*) v2i*y (cadr v2i*) v2i*z (caddr v2i*))
     (setq v5i*x (car v5i*) v5i*y (cadr v5i*) v5i*z (caddr v5i*))
     (setq v2f*z (* kur (/ (+ (* (- m2 m5) v2i*z) (* 2 m5 v5i*z)) (+ m2 m5))))
     (setq v5f*z (* kur (/ (+ (* (- m5 m2) v5i*z) (* 2 m2 v2i*z)) (+ m2 m5))))
     (setq v2f* (list v2i*x v2i*y v2f*z))
     (setq v5f* (list v5i*x v5i*y v5f*z))
     (setq v2f (trans v2f* (list dx25 dy25 dz25) 0))
     (setq v5f (trans v5f* (list dx25 dy25 dz25) 0))
     (setq v2x (car v2f) v2y (cadr v2f) v2z (caddr v2f))
     (setq v5x (car v5f) v5y (cadr v5f) v5z (caddr v5f))
    )
   )
  )
  (if (> d35 r35)
   (progn 
    (setq v3x (+ v3x (* a3x t)))  (setq v3y (+ v3y (* a3y t)))  (setq v3z (+ v3z (* a3z t)))
    (setq v5x (+ v5x (* a5x t)))  (setq v5y (+ v5y (* a5y t)))  (setq v5z (+ v5z (* a5z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v3i (list v3x v3y v3z)) ;velocita 3 prima dello scontro
     (setq v5i (list v5x v5y v5z)) ;velocita 5 prima dello scontro
     (setq v3i* (trans v3i 0 (list dx35 dy35 dz35)))
     (setq v5i* (trans v5i 0 (list dx35 dy35 dz35)))
     (setq v3i*x (car v3i*) v3i*y (cadr v3i*) v3i*z (caddr v3i*))
     (setq v5i*x (car v5i*) v5i*y (cadr v5i*) v5i*z (caddr v5i*))
     (setq v3f*z (* kur (/ (+ (* (- m3 m5) v3i*z) (* 2 m5 v5i*z)) (+ m3 m5))))
     (setq v5f*z (* kur (/ (+ (* (- m5 m3) v5i*z) (* 2 m3 v3i*z)) (+ m3 m5))))
     (setq v3f* (list v3i*x v3i*y v3f*z))
     (setq v5f* (list v5i*x v5i*y v5f*z))
     (setq v3f (trans v3f* (list dx35 dy35 dz35) 0))
     (setq v5f (trans v5f* (list dx35 dy35 dz35) 0))
     (setq v3x (car v3f) v3y (cadr v3f) v3z (caddr v3f))
     (setq v5x (car v5f) v5y (cadr v5f) v5z (caddr v5f))
    )
   )
  )
  (if (> d45 r45)
   (progn 
    (setq v4x (+ v4x (* a4x t)))  (setq v4y (+ v4y (* a4y t)))  (setq v4z (+ v4z (* a4z t)))
    (setq v5x (+ v5x (* a5x t)))  (setq v5y (+ v5y (* a5y t)))  (setq v5z (+ v5z (* a5z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v4i (list v4x v4y v4z)) ;velocita 4 prima dello scontro
     (setq v5i (list v5x v5y v5z)) ;velocita 5 prima dello scontro
     (setq v4i* (trans v4i 0 (list dx45 dy45 dz45)))
     (setq v5i* (trans v5i 0 (list dx45 dy45 dz45)))
     (setq v4i*x (car v4i*) v4i*y (cadr v4i*) v4i*z (caddr v4i*))
     (setq v5i*x (car v5i*) v5i*y (cadr v5i*) v5i*z (caddr v5i*))
     (setq v4f*z (* kur (/ (+ (* (- m4 m5) v4i*z) (* 2 m5 v5i*z)) (+ m4 m5))))
     (setq v5f*z (* kur (/ (+ (* (- m5 m4) v5i*z) (* 2 m4 v4i*z)) (+ m4 m5))))
     (setq v4f* (list v4i*x v4i*y v4f*z))
     (setq v5f* (list v5i*x v5i*y v5f*z))
     (setq v4f (trans v4f* (list dx45 dy45 dz45) 0))
     (setq v5f (trans v5f* (list dx45 dy45 dz45) 0))
     (setq v4x (car v4f) v4y (cadr v4f) v4z (caddr v4f))
     (setq v5x (car v5f) v5y (cadr v5f) v5z (caddr v5f))
    )
   )
  )
  (if (> d16 r16)
   (progn 
    (setq v1x (+ v1x (* a1x t)))  (setq v1y (+ v1y (* a1y t)))  (setq v1z (+ v1z (* a1z t)))
    (setq v6x (+ v6x (* a6x t)))  (setq v6y (+ v6y (* a6y t)))  (setq v6z (+ v6z (* a6z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v1i (list v1x v1y v1z)) ;velocita 1 prima dello scontro
     (setq v6i (list v6x v6y v6z)) ;velocita 6 prima dello scontro
     (setq v1i* (trans v1i 0 (list dx16 dy16 dz16)))
     (setq v6i* (trans v6i 0 (list dx16 dy16 dz16)))
     (setq v1i*x (car v1i*) v1i*y (cadr v1i*) v1i*z (caddr v1i*))
     (setq v6i*x (car v6i*) v6i*y (cadr v6i*) v6i*z (caddr v6i*))
     (setq v1f*z (* kur (/ (+ (* (- m1 m6) v1i*z) (* 2 m6 v6i*z)) (+ m1 m6))))
     (setq v6f*z (* kur (/ (+ (* (- m6 m1) v6i*z) (* 2 m1 v1i*z)) (+ m1 m6))))
     (setq v1f* (list v1i*x v1i*y v1f*z))
     (setq v6f* (list v6i*x v6i*y v6f*z))
     (setq v1f (trans v1f* (list dx16 dy16 dz16) 0))
     (setq v6f (trans v6f* (list dx16 dy16 dz16) 0))
     (setq v1x (car v1f) v1y (cadr v1f) v1z (caddr v1f))
     (setq v6x (car v6f) v6y (cadr v6f) v6z (caddr v6f))
    )
   )
  )
  (if (> d26 r26)
   (progn 
    (setq v2x (+ v2x (* a2x t)))  (setq v2y (+ v2y (* a2y t)))  (setq v2z (+ v2z (* a2z t)))
    (setq v6x (+ v6x (* a6x t)))  (setq v6y (+ v6y (* a6y t)))  (setq v6z (+ v6z (* a6z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v2i (list v2x v2y v2z)) ;velocita 2 prima dello scontro
     (setq v6i (list v6x v6y v6z)) ;velocita 6 prima dello scontro
     (setq v2i* (trans v2i 0 (list dx26 dy26 dz26)))
     (setq v6i* (trans v6i 0 (list dx26 dy26 dz26)))
     (setq v2i*x (car v2i*) v2i*y (cadr v2i*) v2i*z (caddr v2i*))
     (setq v6i*x (car v6i*) v6i*y (cadr v6i*) v6i*z (caddr v6i*))
     (setq v2f*z (* kur (/ (+ (* (- m2 m6) v2i*z) (* 2 m6 v6i*z)) (+ m2 m6))))
     (setq v6f*z (* kur (/ (+ (* (- m6 m2) v6i*z) (* 2 m2 v2i*z)) (+ m2 m6))))
     (setq v2f* (list v2i*x v2i*y v2f*z))
     (setq v6f* (list v6i*x v6i*y v6f*z))
     (setq v2f (trans v2f* (list dx26 dy26 dz26) 0))
     (setq v6f (trans v6f* (list dx26 dy26 dz26) 0))
     (setq v2x (car v2f) v2y (cadr v2f) v2z (caddr v2f))
     (setq v6x (car v6f) v6y (cadr v6f) v6z (caddr v6f))
    )
   )
  )
  (if (> d36 r36)
   (progn 
    (setq v3x (+ v3x (* a3x t)))  (setq v3y (+ v3y (* a3y t)))  (setq v3z (+ v3z (* a3z t)))
    (setq v6x (+ v6x (* a6x t)))  (setq v6y (+ v6y (* a6y t)))  (setq v6z (+ v6z (* a6z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v3i (list v3x v3y v3z)) ;velocita 3 prima dello scontro
     (setq v6i (list v6x v6y v6z)) ;velocita 6 prima dello scontro
     (setq v3i* (trans v3i 0 (list dx36 dy36 dz36)))
     (setq v6i* (trans v6i 0 (list dx36 dy36 dz36)))
     (setq v3i*x (car v3i*) v3i*y (cadr v3i*) v3i*z (caddr v3i*))
     (setq v6i*x (car v6i*) v6i*y (cadr v6i*) v6i*z (caddr v6i*))
     (setq v3f*z (* kur (/ (+ (* (- m3 m6) v3i*z) (* 2 m6 v6i*z)) (+ m3 m6))))
     (setq v6f*z (* kur (/ (+ (* (- m6 m3) v6i*z) (* 2 m3 v3i*z)) (+ m3 m6))))
     (setq v3f* (list v3i*x v3i*y v3f*z))
     (setq v6f* (list v6i*x v6i*y v6f*z))
     (setq v3f (trans v3f* (list dx36 dy36 dz36) 0))
     (setq v6f (trans v6f* (list dx36 dy36 dz36) 0))
     (setq v3x (car v3f) v3y (cadr v3f) v3z (caddr v3f))
     (setq v6x (car v6f) v6y (cadr v6f) v6z (caddr v6f))
    )
   )
  )
  (if (> d46 r46)
   (progn 
    (setq v4x (+ v4x (* a4x t)))  (setq v4y (+ v4y (* a4y t)))  (setq v4z (+ v4z (* a4z t)))
    (setq v6x (+ v6x (* a6x t)))  (setq v6y (+ v6y (* a6y t)))  (setq v6z (+ v6z (* a6z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v4i (list v4x v4y v4z)) ;velocita 4 prima dello scontro
     (setq v6i (list v6x v6y v6z)) ;velocita 6 prima dello scontro
     (setq v4i* (trans v4i 0 (list dx46 dy46 dz46)))
     (setq v6i* (trans v6i 0 (list dx46 dy46 dz46)))
     (setq v4i*x (car v4i*) v4i*y (cadr v4i*) v4i*z (caddr v4i*))
     (setq v6i*x (car v6i*) v6i*y (cadr v6i*) v6i*z (caddr v6i*))
     (setq v4f*z (* kur (/ (+ (* (- m4 m6) v4i*z) (* 2 m6 v6i*z)) (+ m4 m6))))
     (setq v6f*z (* kur (/ (+ (* (- m6 m4) v6i*z) (* 2 m4 v4i*z)) (+ m4 m6))))
     (setq v4f* (list v4i*x v4i*y v4f*z))
     (setq v6f* (list v6i*x v6i*y v6f*z))
     (setq v4f (trans v4f* (list dx46 dy46 dz46) 0))
     (setq v6f (trans v6f* (list dx46 dy46 dz46) 0))
     (setq v4x (car v4f) v4y (cadr v4f) v4z (caddr v4f))
     (setq v6x (car v6f) v6y (cadr v6f) v6z (caddr v6f))
    )
   )
  )
  (if (> d56 r56)
   (progn 
    (setq v5x (+ v5x (* a5x t)))  (setq v5y (+ v5y (* a5y t)))  (setq v5z (+ v5z (* a5z t)))
    (setq v6x (+ v6x (* a6x t)))  (setq v6y (+ v6y (* a6y t)))  (setq v6z (+ v6z (* a6z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v5i (list v5x v5y v5z)) ;velocita 5 prima dello scontro
     (setq v6i (list v6x v6y v6z)) ;velocita 6 prima dello scontro
     (setq v5i* (trans v5i 0 (list dx56 dy56 dz56)))
     (setq v6i* (trans v6i 0 (list dx56 dy56 dz56)))
     (setq v5i*x (car v5i*) v5i*y (cadr v5i*) v5i*z (caddr v5i*))
     (setq v6i*x (car v6i*) v6i*y (cadr v6i*) v6i*z (caddr v6i*))
     (setq v5f*z (* kur (/ (+ (* (- m5 m6) v5i*z) (* 2 m6 v6i*z)) (+ m5 m6))))
     (setq v6f*z (* kur (/ (+ (* (- m6 m5) v6i*z) (* 2 m5 v5i*z)) (+ m5 m6))))
     (setq v5f* (list v5i*x v5i*y v5f*z))
     (setq v6f* (list v6i*x v6i*y v6f*z))
     (setq v5f (trans v5f* (list dx56 dy56 dz56) 0))
     (setq v6f (trans v6f* (list dx56 dy56 dz56) 0))
     (setq v5x (car v5f) v5y (cadr v5f) v5z (caddr v5f))
     (setq v6x (car v6f) v6y (cadr v6f) v6z (caddr v6f))
    )
   )
  )
  (if (> d17 r17)
   (progn 
    (setq v1x (+ v1x (* a1x t)))  (setq v1y (+ v1y (* a1y t)))  (setq v1z (+ v1z (* a1z t)))
    (setq v7x (+ v7x (* a7x t)))  (setq v7y (+ v7y (* a7y t)))  (setq v7z (+ v7z (* a7z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v1i (list v1x v1y v1z)) ;velocita 1 prima dello scontro
     (setq v7i (list v7x v7y v7z)) ;velocita 7 prima dello scontro
     (setq v1i* (trans v1i 0 (list dx17 dy17 dz17)))
     (setq v7i* (trans v7i 0 (list dx17 dy17 dz17)))
     (setq v1i*x (car v1i*) v1i*y (cadr v1i*) v1i*z (caddr v1i*))
     (setq v7i*x (car v7i*) v7i*y (cadr v7i*) v7i*z (caddr v7i*))
     (setq v1f*z (* kur (/ (+ (* (- m1 m7) v1i*z) (* 2 m7 v7i*z)) (+ m1 m7))))
     (setq v7f*z (* kur (/ (+ (* (- m7 m1) v7i*z) (* 2 m1 v1i*z)) (+ m1 m7))))
     (setq v1f* (list v1i*x v1i*y v1f*z))
     (setq v7f* (list v7i*x v7i*y v7f*z))
     (setq v1f (trans v1f* (list dx17 dy17 dz17) 0))
     (setq v7f (trans v7f* (list dx17 dy17 dz17) 0))
     (setq v1x (car v1f) v1y (cadr v1f) v1z (caddr v1f))
     (setq v7x (car v7f) v7y (cadr v7f) v7z (caddr v7f))
    )
   )
  )
  (if (> d27 r27)
   (progn 
    (setq v2x (+ v2x (* a2x t)))  (setq v2y (+ v2y (* a2y t)))  (setq v2z (+ v2z (* a2z t)))
    (setq v7x (+ v7x (* a7x t)))  (setq v7y (+ v7y (* a7y t)))  (setq v7z (+ v7z (* a7z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v2i (list v2x v2y v2z)) ;velocita 2 prima dello scontro
     (setq v7i (list v7x v7y v7z)) ;velocita 7 prima dello scontro
     (setq v2i* (trans v2i 0 (list dx27 dy27 dz27)))
     (setq v7i* (trans v7i 0 (list dx27 dy27 dz27)))
     (setq v2i*x (car v2i*) v2i*y (cadr v2i*) v2i*z (caddr v2i*))
     (setq v7i*x (car v7i*) v7i*y (cadr v7i*) v7i*z (caddr v7i*))
     (setq v2f*z (* kur (/ (+ (* (- m2 m7) v2i*z) (* 2 m7 v7i*z)) (+ m2 m7))))
     (setq v7f*z (* kur (/ (+ (* (- m7 m2) v7i*z) (* 2 m2 v2i*z)) (+ m2 m7))))
     (setq v2f* (list v2i*x v2i*y v2f*z))
     (setq v7f* (list v7i*x v7i*y v7f*z))
     (setq v2f (trans v2f* (list dx27 dy27 dz27) 0))
     (setq v7f (trans v7f* (list dx27 dy27 dz27) 0))
     (setq v2x (car v2f) v2y (cadr v2f) v2z (caddr v2f))
     (setq v7x (car v7f) v7y (cadr v7f) v7z (caddr v7f))
    )
   )
  )
  (if (> d37 r37)
   (progn 
    (setq v3x (+ v3x (* a3x t)))  (setq v3y (+ v3y (* a3y t)))  (setq v3z (+ v3z (* a3z t)))
    (setq v7x (+ v7x (* a7x t)))  (setq v7y (+ v7y (* a7y t)))  (setq v7z (+ v7z (* a7z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v3i (list v3x v3y v3z)) ;velocita 3 prima dello scontro
     (setq v7i (list v7x v7y v7z)) ;velocita 7 prima dello scontro
     (setq v3i* (trans v3i 0 (list dx37 dy37 dz37)))
     (setq v7i* (trans v7i 0 (list dx37 dy37 dz37)))
     (setq v3i*x (car v3i*) v3i*y (cadr v3i*) v3i*z (caddr v3i*))
     (setq v7i*x (car v7i*) v7i*y (cadr v7i*) v7i*z (caddr v7i*))
     (setq v3f*z (* kur (/ (+ (* (- m3 m7) v3i*z) (* 2 m7 v7i*z)) (+ m3 m7))))
     (setq v7f*z (* kur (/ (+ (* (- m7 m3) v7i*z) (* 2 m3 v3i*z)) (+ m3 m7))))
     (setq v3f* (list v3i*x v3i*y v3f*z))
     (setq v7f* (list v7i*x v7i*y v7f*z))
     (setq v3f (trans v3f* (list dx37 dy37 dz37) 0))
     (setq v7f (trans v7f* (list dx37 dy37 dz37) 0))
     (setq v3x (car v3f) v3y (cadr v3f) v3z (caddr v3f))
     (setq v7x (car v7f) v7y (cadr v7f) v7z (caddr v7f))
    )
   )
  )
  (if (> d47 r47)
   (progn 
    (setq v4x (+ v4x (* a4x t)))  (setq v4y (+ v4y (* a4y t)))  (setq v4z (+ v4z (* a4z t)))
    (setq v7x (+ v7x (* a7x t)))  (setq v7y (+ v7y (* a7y t)))  (setq v7z (+ v7z (* a7z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v4i (list v4x v4y v4z)) ;velocita 4 prima dello scontro
     (setq v7i (list v7x v7y v7z)) ;velocita 7 prima dello scontro
     (setq v4i* (trans v4i 0 (list dx47 dy47 dz47)))
     (setq v7i* (trans v7i 0 (list dx47 dy47 dz47)))
     (setq v4i*x (car v4i*) v4i*y (cadr v4i*) v4i*z (caddr v4i*))
     (setq v7i*x (car v7i*) v7i*y (cadr v7i*) v7i*z (caddr v7i*))
     (setq v4f*z (* kur (/ (+ (* (- m4 m7) v4i*z) (* 2 m7 v7i*z)) (+ m4 m7))))
     (setq v7f*z (* kur (/ (+ (* (- m7 m4) v7i*z) (* 2 m4 v4i*z)) (+ m4 m7))))
     (setq v4f* (list v4i*x v4i*y v4f*z))
     (setq v7f* (list v7i*x v7i*y v7f*z))
     (setq v4f (trans v4f* (list dx47 dy47 dz47) 0))
     (setq v7f (trans v7f* (list dx47 dy47 dz47) 0))
     (setq v4x (car v4f) v4y (cadr v4f) v4z (caddr v4f))
     (setq v7x (car v7f) v7y (cadr v7f) v7z (caddr v7f))
    )
   )
  )
  (if (> d57 r57)
   (progn 
    (setq v5x (+ v5x (* a5x t)))  (setq v5y (+ v5y (* a5y t)))  (setq v5z (+ v5z (* a5z t)))
    (setq v7x (+ v7x (* a7x t)))  (setq v7y (+ v7y (* a7y t)))  (setq v7z (+ v7z (* a7z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v5i (list v5x v5y v5z)) ;velocita 5 prima dello scontro
     (setq v7i (list v7x v7y v7z)) ;velocita 7 prima dello scontro
     (setq v5i* (trans v5i 0 (list dx57 dy57 dz57)))
     (setq v7i* (trans v7i 0 (list dx57 dy57 dz57)))
     (setq v5i*x (car v5i*) v5i*y (cadr v5i*) v5i*z (caddr v5i*))
     (setq v7i*x (car v7i*) v7i*y (cadr v7i*) v7i*z (caddr v7i*))
     (setq v5f*z (* kur (/ (+ (* (- m5 m7) v5i*z) (* 2 m7 v7i*z)) (+ m5 m7))))
     (setq v7f*z (* kur (/ (+ (* (- m7 m5) v7i*z) (* 2 m5 v5i*z)) (+ m5 m7))))
     (setq v5f* (list v5i*x v5i*y v5f*z))
     (setq v7f* (list v7i*x v7i*y v7f*z))
     (setq v5f (trans v5f* (list dx57 dy57 dz57) 0))
     (setq v7f (trans v7f* (list dx57 dy57 dz57) 0))
     (setq v5x (car v5f) v5y (cadr v5f) v5z (caddr v5f))
     (setq v7x (car v7f) v7y (cadr v7f) v7z (caddr v7f))
    )
   )
  )
  (if (> d67 r67)
   (progn 
    (setq v6x (+ v6x (* a6x t)))  (setq v6y (+ v6y (* a6y t)))  (setq v6z (+ v6z (* a6z t)))
    (setq v7x (+ v7x (* a7x t)))  (setq v7y (+ v7y (* a7y t)))  (setq v7z (+ v7z (* a7z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v6i (list v6x v6y v6z)) ;velocita 6 prima dello scontro
     (setq v7i (list v7x v7y v7z)) ;velocita 7 prima dello scontro
     (setq v6i* (trans v6i 0 (list dx67 dy67 dz67)))
     (setq v7i* (trans v7i 0 (list dx67 dy67 dz67)))
     (setq v6i*x (car v6i*) v6i*y (cadr v6i*) v6i*z (caddr v6i*))
     (setq v7i*x (car v7i*) v7i*y (cadr v7i*) v7i*z (caddr v7i*))
     (setq v6f*z (* kur (/ (+ (* (- m6 m7) v6i*z) (* 2 m7 v7i*z)) (+ m6 m7))))
     (setq v7f*z (* kur (/ (+ (* (- m7 m6) v7i*z) (* 2 m6 v6i*z)) (+ m6 m7))))
     (setq v6f* (list v6i*x v6i*y v6f*z))
     (setq v7f* (list v7i*x v7i*y v7f*z))
     (setq v6f (trans v6f* (list dx67 dy67 dz67) 0))
     (setq v7f (trans v7f* (list dx67 dy67 dz67) 0))
     (setq v6x (car v6f) v6y (cadr v6f) v6z (caddr v6f))
     (setq v7x (car v7f) v7y (cadr v7f) v7z (caddr v7f))
    )
   )
  )

  (if (< (- x1 r1) xsa) (setq v1x (* (+ (* -2 kbi) 1) v1x) ) )
  (if (< (- y1 r1) ysa) (setq v1y (* (+ (* -2 kbi) 1) v1y) ) )   
  (if (< (- z1 r1) zsa) (setq v1z (* (+ (* -2 kbi) 1) v1z) ) )   
  (if (> (+ x1 r1) xsb) (setq v1x (* (+ (* -2 kbi) 1) v1x) ) )   
  (if (> (+ y1 r1) ysb) (setq v1y (* (+ (* -2 kbi) 1) v1y) ) )   
  (if (> (+ z1 r1) zsb) (setq v1z (* (+ (* -2 kbi) 1) v1z) ) )   
  (if (< (- x2 r2) xsa) (setq v2x (* (+ (* -2 kbi) 1) v2x) ) )   
  (if (< (- y2 r2) ysa) (setq v2y (* (+ (* -2 kbi) 1) v2y) ) )   
  (if (< (- z2 r2) zsa) (setq v2z (* (+ (* -2 kbi) 1) v2z) ) )   
  (if (> (+ x2 r2) xsb) (setq v2x (* (+ (* -2 kbi) 1) v2x) ) )   
  (if (> (+ y2 r2) ysb) (setq v2y (* (+ (* -2 kbi) 1) v2y) ) )   
  (if (> (+ z2 r2) zsb) (setq v2z (* (+ (* -2 kbi) 1) v2z) ) )   
  (if (< (- x3 r3) xsa) (setq v3x (* (+ (* -2 kbi) 1) v3x) ) )   
  (if (< (- y3 r3) ysa) (setq v3y (* (+ (* -2 kbi) 1) v3y) ) )   
  (if (< (- z3 r3) zsa) (setq v3z (* (+ (* -2 kbi) 1) v3z) ) )   
  (if (> (+ x3 r3) xsb) (setq v3x (* (+ (* -2 kbi) 1) v3x) ) )   
  (if (> (+ y3 r3) ysb) (setq v3y (* (+ (* -2 kbi) 1) v3y) ) )   
  (if (> (+ z3 r3) zsb) (setq v3z (* (+ (* -2 kbi) 1) v3z) ) )   
  (if (< (- x4 r4) xsa) (setq v4x (* (+ (* -2 kbi) 1) v4x) ) )   
  (if (< (- y4 r4) ysa) (setq v4y (* (+ (* -2 kbi) 1) v4y) ) )   
  (if (< (- z4 r4) zsa) (setq v4z (* (+ (* -2 kbi) 1) v4z) ) )   
  (if (> (+ x4 r4) xsb) (setq v4x (* (+ (* -2 kbi) 1) v4x) ) )   
  (if (> (+ y4 r4) ysb) (setq v4y (* (+ (* -2 kbi) 1) v4y) ) )   
  (if (> (+ z4 r4) zsb) (setq v4z (* (+ (* -2 kbi) 1) v4z) ) )   
  (if (< (- x5 r5) xsa) (setq v5x (* (+ (* -2 kbi) 1) v5x) ) )   
  (if (< (- y5 r5) ysa) (setq v5y (* (+ (* -2 kbi) 1) v5y) ) )   
  (if (< (- z5 r5) zsa) (setq v5z (* (+ (* -2 kbi) 1) v5z) ) )   
  (if (> (+ x5 r5) xsb) (setq v5x (* (+ (* -2 kbi) 1) v5x) ) )   
  (if (> (+ y5 r5) ysb) (setq v5y (* (+ (* -2 kbi) 1) v5y) ) )   
  (if (> (+ z5 r5) zsb) (setq v5z (* (+ (* -2 kbi) 1) v5z) ) )   
  (if (< (- x6 r6) xsa) (setq v6x (* (+ (* -2 kbi) 1) v6x) ) )   
  (if (< (- y6 r6) ysa) (setq v6y (* (+ (* -2 kbi) 1) v6y) ) )   
  (if (< (- z6 r6) zsa) (setq v6z (* (+ (* -2 kbi) 1) v6z) ) )   
  (if (> (+ x6 r6) xsb) (setq v6x (* (+ (* -2 kbi) 1) v6x) ) )   
  (if (> (+ y6 r6) ysb) (setq v6y (* (+ (* -2 kbi) 1) v6y) ) )   
  (if (> (+ z6 r6) zsb) (setq v6z (* (+ (* -2 kbi) 1) v6z) ) )   
  (if (< (- x7 r7) xsa) (setq v7x (* (+ (* -2 kbi) 1) v7x) ) )   
  (if (< (- y7 r7) ysa) (setq v7y (* (+ (* -2 kbi) 1) v7y) ) )   
  (if (< (- z7 r7) zsa) (setq v7z (* (+ (* -2 kbi) 1) v7z) ) )   
  (if (> (+ x7 r7) xsb) (setq v7x (* (+ (* -2 kbi) 1) v7x) ) )   
  (if (> (+ y7 r7) ysb) (setq v7y (* (+ (* -2 kbi) 1) v7y) ) )   
  (if (> (+ z7 r7) zsb) (setq v7z (* (+ (* -2 kbi) 1) v7z) ) )   

  (setq s1x (+ (* v1x t) (* 0.5 a1x t t)))  (setq s1y (+ (* v1y t) (* 0.5 a1y t t)))  (setq s1z (+ (* v1z t) (* 0.5 a1z t t)))
  (setq s2x (+ (* v2x t) (* 0.5 a2x t t)))  (setq s2y (+ (* v2y t) (* 0.5 a2y t t)))  (setq s2z (+ (* v2z t) (* 0.5 a2z t t)))
  (setq s3x (+ (* v3x t) (* 0.5 a3x t t)))  (setq s3y (+ (* v3y t) (* 0.5 a3y t t)))  (setq s3z (+ (* v3z t) (* 0.5 a3z t t)))
  (setq s4x (+ (* v4x t) (* 0.5 a4x t t)))  (setq s4y (+ (* v4y t) (* 0.5 a4y t t)))  (setq s4z (+ (* v4z t) (* 0.5 a4z t t)))
  (setq s5x (+ (* v5x t) (* 0.5 a5x t t)))  (setq s5y (+ (* v5y t) (* 0.5 a5y t t)))  (setq s5z (+ (* v5z t) (* 0.5 a5z t t)))
  (setq s6x (+ (* v6x t) (* 0.5 a6x t t)))  (setq s6y (+ (* v6y t) (* 0.5 a6y t t)))  (setq s6z (+ (* v6z t) (* 0.5 a6z t t)))
  (setq s7x (+ (* v7x t) (* 0.5 a7x t t)))  (setq s7y (+ (* v7y t) (* 0.5 a7y t t)))  (setq s7z (+ (* v7z t) (* 0.5 a7z t t)))

  (setq x1 (+ x1 (* k1 s1x)))  (setq y1 (+ y1 (* k1 s1y)))  (setq z1 (+ z1 (* k1 s1z)))
  (setq x2 (+ x2 (* k2 s2x)))  (setq y2 (+ y2 (* k2 s2y)))  (setq z2 (+ z2 (* k2 s2z)))
  (setq x3 (+ x3 (* k3 s3x)))  (setq y3 (+ y3 (* k3 s3y)))  (setq z3 (+ z3 (* k3 s3z)))
  (setq x4 (+ x4 (* k4 s4x)))  (setq y4 (+ y4 (* k4 s4y)))  (setq z4 (+ z4 (* k4 s4z)))
  (setq x5 (+ x5 (* k5 s5x)))  (setq y5 (+ y5 (* k5 s5y)))  (setq z5 (+ z5 (* k5 s5z)))
  (setq x6 (+ x6 (* k6 s6x)))  (setq y6 (+ y6 (* k6 s6y)))  (setq z6 (+ z6 (* k6 s6z)))
  (setq x7 (+ x7 (* k7 s7x)))  (setq y7 (+ y7 (* k7 s7y)))  (setq z7 (+ z7 (* k7 s7z)))

  (setq a1 (sqrt (+ (* a1x a1x) (* a1y a1y) (* a1z a1z))))
  (setq a2 (sqrt (+ (* a2x a2x) (* a2y a2y) (* a2z a2z))))
  (setq a3 (sqrt (+ (* a3x a3x) (* a3y a3y) (* a3z a3z))))
  (setq a4 (sqrt (+ (* a4x a4x) (* a4y a4y) (* a4z a4z))))
  (setq a5 (sqrt (+ (* a5x a5x) (* a5y a5y) (* a5z a5z))))
  (setq a6 (sqrt (+ (* a6x a6x) (* a6y a6y) (* a6z a6z))))
  (setq a7 (sqrt (+ (* a7x a7x) (* a7y a7y) (* a7z a7z))))

  (setq va (+ (abs a1) (abs a2) (abs a3) (abs a4) (abs a5) (abs a6) (abs a7)
              (abs v1) (abs v2) (abs v3) (abs v4) (abs v5) (abs v6) (abs v7)
           )
  )
  (princ "\n")
  (princ va)
  (princ)

  (setq q1 (list x1 y1 z1))
  (setq q2 (list x2 y2 z2))
  (setq q3 (list x3 y3 z3))
  (setq q4 (list x4 y4 z4))
  (setq q5 (list x5 y5 z5))
  (setq q6 (list x6 y6 z6))
  (setq q7 (list x7 y7 z7))

  (if (= iscan 0)
   (progn
 
   (if (= ker 0)
    (progn
    (if (= pc "p")
        (progn
         (setvar "clayer" "m1") (command "_point" p1)
         (setvar "clayer" "m2") (command "_point" p2)
         (setvar "clayer" "m3") (command "_point" p3)
         (setvar "clayer" "m4") (command "_point" p4)
         (setvar "clayer" "m5") (command "_point" p5)
         (setvar "clayer" "m6") (command "_point" p6)
         (setvar "clayer" "m7") (command "_point" p7)
        )
        (if (= pc "c")
            (progn
             (setvar "clayer" "m1") (command "_circle" p1 r1)
             (setvar "clayer" "m2") (command "_circle" p2 r2)
             (setvar "clayer" "m3") (command "_circle" p3 r3)
             (setvar "clayer" "m4") (command "_circle" p4 r4)
             (setvar "clayer" "m5") (command "_circle" p5 r5)
             (setvar "clayer" "m6") (command "_circle" p6 r6)
             (setvar "clayer" "m7") (command "_circle" p7 r7)
            )
            (if (= pc "s")
                (progn
                 (setvar "clayer" "m1") (command "_sphere" p1 r1)
                 (setvar "clayer" "m2") (command "_sphere" p2 r2)
                 (setvar "clayer" "m3") (command "_sphere" p3 r3)
                 (setvar "clayer" "m4") (command "_sphere" p4 r4)
                 (setvar "clayer" "m5") (command "_sphere" p5 r5)
                 (setvar "clayer" "m6") (command "_sphere" p6 r6)
                 (setvar "clayer" "m7") (command "_sphere" p7 r7)
                )
            )
        )
    )
    )
    (progn
             (command "_move" o1 "" p1 q1)
             (command "_move" o2 "" p2 q2)
             (command "_move" o3 "" p3 q3)
             (command "_move" o4 "" p4 q4)
             (command "_move" o5 "" p5 q5)
             (command "_move" o6 "" p6 q6)
             (command "_move" o7 "" p7 q7)
    )    
   )
    
   )

  )
 
  (setq p1 q1)
  (setq p2 q2)  
  (setq p3 q3)  
  (setq p4 q4)  
  (setq p5 q5)  
  (setq p6 q6)  
  (setq p7 q7)  

  (setq iscan (+ 1 iscan))
  (if (= iscan scan) (setq iscan 0))

 )
 (setvar "clayer" "0")
 (command "_pline" p1 p2 p3 p4 p5 p6 p7 p1 "")
)


;;;*****************************************************************
;simula il moto di 10 oggetti sottoposti a forza gravitazionale
;gravita8 ver 1.5 23/07/2010
;Dott. Ing. Emanuele Ballasina
;cell 349-1813748
;mail ballacr75@libero.it

(defun c:gravita8 ()
(setvar "osmode" 0)
(setvar "dimzin" 0)
(setvar "cmdecho" 0)

(command "_-layer" "n" "m1" "_c" 10 "m1" "_s" "m1" "")
(command "_-layer" "n" "m2" "_c" 30 "m2" "_s" "m2" "")
(command "_-layer" "n" "m3" "_c" 50 "m3" "_s" "m3" "")
(command "_-layer" "n" "m4" "_c" 70 "m4" "_s" "m4" "")
(command "_-layer" "n" "m5" "_c" 100 "m5" "_s" "m5" "")
(command "_-layer" "n" "m6" "_c" 140 "m6" "_s" "m6" "")
(command "_-layer" "n" "m7" "_c" 180 "m7" "_s" "m7" "")
(command "_-layer" "n" "m8" "_c" 220 "m8" "_s" "m8" "")

(setq t 1) ;scansione tempo
(setq kdi 1) ;riduzione diametro cilindri
(setq scan 1) ;scansione posizione (non funziona >1 se ker=1)

(setq m1 100.0) ;massa
(setq m2 100.0)
(setq m3 100.0)
(setq m4 100.0)
(setq m5 100.0)
(setq m6 100.0)
(setq m7 100.0)
(setq m8 100.0)
(setq d1 0.1) ;densita
(setq d2 0.1)
(setq d3 0.1) 
(setq d4 0.1)
(setq d5 0.1)
(setq d6 0.1)
(setq d7 0.1)
(setq d8 0.1)
(setq r1 (expt (/ m1 d1) 0.3333)) ;raggio
(setq r2 (expt (/ m2 d2) 0.3333))
(setq r3 (expt (/ m3 d3) 0.3333))
(setq r4 (expt (/ m4 d4) 0.3333))
(setq r5 (expt (/ m5 d5) 0.3333))
(setq r6 (expt (/ m6 d6) 0.3333))
(setq r7 (expt (/ m7 d7) 0.3333))
(setq r8 (expt (/ m8 d8) 0.3333))
(setq r12 (+ r1 r2)) ;distanza di sfioro
(setq r13 (+ r1 r3))
(setq r23 (+ r2 r3))
(setq r14 (+ r1 r4))
(setq r24 (+ r2 r4))
(setq r34 (+ r3 r4))
(setq r15 (+ r1 r5))
(setq r25 (+ r2 r5))
(setq r35 (+ r3 r5))
(setq r45 (+ r4 r5))
(setq r16 (+ r1 r6))
(setq r26 (+ r2 r6))
(setq r36 (+ r3 r6))
(setq r46 (+ r4 r6))
(setq r56 (+ r5 r6))
(setq r17 (+ r1 r7))
(setq r27 (+ r2 r7))
(setq r37 (+ r3 r7))
(setq r47 (+ r4 r7))
(setq r57 (+ r5 r7))
(setq r67 (+ r6 r7))
(setq r18 (+ r1 r8))
(setq r28 (+ r2 r8))
(setq r38 (+ r3 r8))
(setq r48 (+ r4 r8))
(setq r58 (+ r5 r8))
(setq r68 (+ r6 r8))
(setq r78 (+ r7 r8))

(setq k1 1) ;abilita movimento pianeta
(setq k2 1)
(setq k3 1)
(setq k4 1)
(setq k5 1)
(setq k6 1)
(setq k7 1)
(setq k8 1)
(setq kur 1) ;abilita urti, con coefficente di rimbalzo, <1 smorza
(setq kbi 1) ;abilita rimbalzo tipo biliardo contro pareti dello schermo, <1 smorza
(setq ker 1) ;1=cancella pianeti vecchi, 0=mantiene tutti i pianeti
(setq c (getvar "VIEWCTR"))
(setq xsc (car c))
(setq ysc (cadr c))
(setq zsc (caddr c))
(setq currh (getvar "viewsize"))
(setq sizex (nth 0 (getvar "screensize")))
(setq sizey (nth 1 (getvar "screensize")))
(setq j (/ sizex sizey))
(setq currw (* j currh))
(setq h2 (/ currh 2.0))
(setq w2 (/ currw 2.0))
(setq xsa (- xsc w2))
(setq ysa (- ysc h2))
(setq zsa (- zsc h2))
(setq xsb (+ xsc w2))
(setq ysb (+ ysc h2))
(setq zsb (+ zsc h2))
(if (/= kbi 0) (command "_rectangle" (list xsa ysa) (list xsb ysb)))

(setq pc "c") ;punti,cerchi,sfere
(setq lc "n") ;abilita disegno linee tra un pianeta e gli altri
(setq tc "n") ;abilita disegno linee traiettoria

(setq x1 0) ;posizione
(setq y1 0)
(setq z1 0)
(setq x2 100)
(setq y2 0)
(setq z2 0)
(setq x3 200)
(setq y3 0)
(setq z3 0)
(setq x4 300)
(setq y4 0)
(setq z4 0)
(setq x5 400)
(setq y5 0)
(setq z5 0)
(setq x6 500)
(setq y6 0)
(setq z6 0)
(setq x7 600)
(setq y7 0) 
(setq z7 0) 
(setq x8 700) 
(setq y8 0) 
(setq z8 0) 

(setq v1x 0.0) ;velocita
(setq v1y 0.0)
(setq v1z 0.0)
(setq v2x 0.0)
(setq v2y 0.0)
(setq v2z 0.0)
(setq v3x 0.0)
(setq v3y 0.0)
(setq v3z 0.0)
(setq v4x 0.0)
(setq v4y 0.0)
(setq v4z 0.0)
(setq v5x 0.0)
(setq v5y 0.0)
(setq v5z 0.0) 
(setq v6x 0.0)
(setq v6y 0.0)
(setq v6z 0.0)
(setq v7x 0.0)
(setq v7y 0.0)
(setq v7z 0.0)
(setq v8x 0.0)
(setq v8y 0.0)
(setq v8z 0.0)

(setq p1 (list x1 y1 z1))
(setq p2 (list x2 y2 z2))
(setq p3 (list x3 y3 z3))
(setq p4 (list x4 y4 z4))
(setq p5 (list x5 y5 z5))
(setq p6 (list x6 y6 z6))
(setq p7 (list x7 y7 z7))
(setq p8 (list x8 y8 z8))

(if (= pc "p")
    (progn
     (setvar "clayer" "m1") (command "_point" p1) (setq o1 (cdr (car (entget (entlast)))))
     (setvar "clayer" "m2") (command "_point" p2) (setq o2 (cdr (car (entget (entlast)))))
     (setvar "clayer" "m3") (command "_point" p3) (setq o3 (cdr (car (entget (entlast)))))
     (setvar "clayer" "m4") (command "_point" p4) (setq o4 (cdr (car (entget (entlast)))))
     (setvar "clayer" "m5") (command "_point" p5) (setq o5 (cdr (car (entget (entlast)))))
     (setvar "clayer" "m6") (command "_point" p6) (setq o6 (cdr (car (entget (entlast)))))
     (setvar "clayer" "m7") (command "_point" p7) (setq o7 (cdr (car (entget (entlast)))))
     (setvar "clayer" "m8") (command "_point" p8) (setq o8 (cdr (car (entget (entlast)))))
    )
    (if (= pc "c")
        (progn
         (setvar "clayer" "m1") (command "_circle" p1 r1) (setq o1 (cdr (car (entget (entlast)))))
         (setvar "clayer" "m2") (command "_circle" p2 r2) (setq o2 (cdr (car (entget (entlast)))))
         (setvar "clayer" "m3") (command "_circle" p3 r3) (setq o3 (cdr (car (entget (entlast)))))
         (setvar "clayer" "m4") (command "_circle" p4 r4) (setq o4 (cdr (car (entget (entlast)))))
         (setvar "clayer" "m5") (command "_circle" p5 r5) (setq o5 (cdr (car (entget (entlast)))))
         (setvar "clayer" "m6") (command "_circle" p6 r6) (setq o6 (cdr (car (entget (entlast)))))
         (setvar "clayer" "m7") (command "_circle" p7 r7) (setq o7 (cdr (car (entget (entlast)))))
         (setvar "clayer" "m8") (command "_circle" p8 r8) (setq o8 (cdr (car (entget (entlast)))))
        )
        (if (= pc "s")
            (progn
             (setvar "clayer" "m1") (command "_sphere" p1 r1) (setq o1 (cdr (car (entget (entlast)))))
             (setvar "clayer" "m2") (command "_sphere" p2 r2) (setq o2 (cdr (car (entget (entlast)))))
             (setvar "clayer" "m3") (command "_sphere" p3 r3) (setq o3 (cdr (car (entget (entlast)))))
             (setvar "clayer" "m4") (command "_sphere" p4 r4) (setq o4 (cdr (car (entget (entlast)))))
             (setvar "clayer" "m5") (command "_sphere" p5 r5) (setq o5 (cdr (car (entget (entlast)))))
             (setvar "clayer" "m6") (command "_sphere" p6 r6) (setq o6 (cdr (car (entget (entlast)))))
             (setvar "clayer" "m7") (command "_sphere" p7 r7) (setq o7 (cdr (car (entget (entlast)))))
             (setvar "clayer" "m8") (command "_sphere" p8 r8) (setq o8 (cdr (car (entget (entlast)))))
            )
        )
    )
)

(setq va 1000)
(setq iscan 0)
 (while (> va 0.0001) ;scansione velocit ed accelerazione, se = 0 si ferma il lisp

  (setq v1 (sqrt (+ (* v1x v1x) (* v1y v1y) (* v1z v1z))))
  (setq v2 (sqrt (+ (* v2x v2x) (* v2y v2y) (* v2z v2z))))
  (setq v3 (sqrt (+ (* v3x v3x) (* v3y v3y) (* v3z v3z))))
  (setq v4 (sqrt (+ (* v4x v4x) (* v4y v4y) (* v4z v4z))))
  (setq v5 (sqrt (+ (* v5x v5x) (* v5y v5y) (* v5z v5z))))
  (setq v6 (sqrt (+ (* v6x v6x) (* v6y v6y) (* v6z v6z))))
  (setq v7 (sqrt (+ (* v7x v7x) (* v7y v7y) (* v7z v7z))))
  (setq v8 (sqrt (+ (* v8x v8x) (* v8y v8y) (* v8z v8z))))
  
  (setq d12 (distance p1 p2))
  (setq d13 (distance p1 p3))
  (setq d23 (distance p2 p3))
  (setq d14 (distance p1 p4))
  (setq d24 (distance p2 p4))
  (setq d34 (distance p3 p4))
  (setq d15 (distance p1 p5))
  (setq d25 (distance p2 p5))
  (setq d35 (distance p3 p5))
  (setq d45 (distance p4 p5))
  (setq d16 (distance p1 p6))
  (setq d26 (distance p2 p6))
  (setq d36 (distance p3 p6))
  (setq d46 (distance p4 p6))
  (setq d56 (distance p5 p6))
  (setq d17 (distance p1 p7))
  (setq d27 (distance p2 p7))
  (setq d37 (distance p3 p7))
  (setq d47 (distance p4 p7))
  (setq d57 (distance p5 p7))
  (setq d67 (distance p6 p7))
  (setq d18 (distance p1 p8))
  (setq d28 (distance p2 p8))
  (setq d38 (distance p3 p8))
  (setq d48 (distance p4 p8))
  (setq d58 (distance p5 p8))
  (setq d68 (distance p6 p8))
  (setq d78 (distance p7 p8))

  (setq dx12 (- x2 x1))  (setq dy12 (- y2 y1))  (setq dz12 (- z2 z1))
  (setq dx13 (- x3 x1))  (setq dy13 (- y3 y1))  (setq dz13 (- z3 z1))
  (setq dx23 (- x3 x2))  (setq dy23 (- y3 y2))  (setq dz23 (- z3 z2))
  (setq dx14 (- x4 x1))  (setq dy14 (- y4 y1))  (setq dz14 (- z4 z1))
  (setq dx24 (- x4 x2))  (setq dy24 (- y4 y2))  (setq dz24 (- z4 z2))
  (setq dx34 (- x4 x3))  (setq dy34 (- y4 y3))  (setq dz34 (- z4 z3))
  (setq dx15 (- x5 x1))  (setq dy15 (- y5 y1))  (setq dz15 (- z5 z1))
  (setq dx25 (- x5 x2))  (setq dy25 (- y5 y2))  (setq dz25 (- z5 z2))
  (setq dx35 (- x5 x3))  (setq dy35 (- y5 y3))  (setq dz35 (- z5 z3))
  (setq dx45 (- x5 x4))  (setq dy45 (- y5 y4))  (setq dz45 (- z5 z4))
  (setq dx16 (- x6 x1))  (setq dy16 (- y6 y1))  (setq dz16 (- z6 z1))
  (setq dx26 (- x6 x2))  (setq dy26 (- y6 y2))  (setq dz26 (- z6 z2))
  (setq dx36 (- x6 x3))  (setq dy36 (- y6 y3))  (setq dz36 (- z6 z3))
  (setq dx46 (- x6 x4))  (setq dy46 (- y6 y4))  (setq dz46 (- z6 z4))
  (setq dx56 (- x6 x5))  (setq dy56 (- y6 y5))  (setq dz56 (- z6 z5))
  (setq dx17 (- x7 x1))  (setq dy17 (- y7 y1))  (setq dz17 (- z7 z1))
  (setq dx27 (- x7 x2))  (setq dy27 (- y7 y2))  (setq dz27 (- z7 z2))
  (setq dx37 (- x7 x3))  (setq dy37 (- y7 y3))  (setq dz37 (- z7 z3))
  (setq dx47 (- x7 x4))  (setq dy47 (- y7 y4))  (setq dz47 (- z7 z4))
  (setq dx57 (- x7 x5))  (setq dy57 (- y7 y5))  (setq dz57 (- z7 z5))
  (setq dx67 (- x7 x6))  (setq dy67 (- y7 y6))  (setq dz67 (- z7 z6))
  (setq dx18 (- x8 x1))  (setq dy18 (- y8 y1))  (setq dz18 (- z8 z1))
  (setq dx28 (- x8 x2))  (setq dy28 (- y8 y2))  (setq dz28 (- z8 z2))
  (setq dx38 (- x8 x3))  (setq dy38 (- y8 y3))  (setq dz38 (- z8 z3))
  (setq dx48 (- x8 x4))  (setq dy48 (- y8 y4))  (setq dz48 (- z8 z4))
  (setq dx58 (- x8 x5))  (setq dy58 (- y8 y5))  (setq dz58 (- z8 z5))
  (setq dx68 (- x8 x6))  (setq dy68 (- y8 y6))  (setq dz68 (- z8 z6))
  (setq dx78 (- x8 x7))  (setq dy78 (- y8 y7))  (setq dz78 (- z8 z7))

;                   GRAVITA              REPULSIONE           ELASTICO       MOLLA
  (if (<= d12 r12) (setq d12 r12))
  (if (<= d13 r13) (setq d13 r13))
  (if (<= d23 r23) (setq d23 r23))
  (if (<= d14 r14) (setq d14 r14))
  (if (<= d24 r24) (setq d24 r24))
  (if (<= d34 r34) (setq d34 r34))
  (if (<= d15 r15) (setq d15 r15))
  (if (<= d25 r25) (setq d25 r25))
  (if (<= d35 r35) (setq d35 r35))
  (if (<= d45 r45) (setq d45 r45))
  (if (<= d16 r16) (setq d16 r16))
  (if (<= d26 r26) (setq d26 r26))
  (if (<= d36 r36) (setq d36 r36))
  (if (<= d46 r46) (setq d46 r46))
  (if (<= d56 r56) (setq d56 r56))
  (if (<= d17 r17) (setq d17 r17))
  (if (<= d27 r27) (setq d27 r27))
  (if (<= d37 r37) (setq d37 r37))
  (if (<= d47 r47) (setq d47 r47))
  (if (<= d57 r57) (setq d57 r57))
  (if (<= d67 r67) (setq d67 r67))
  (if (<= d18 r18) (setq d18 r18))
  (if (<= d28 r28) (setq d28 r28))
  (if (<= d38 r38) (setq d38 r38))
  (if (<= d48 r48) (setq d48 r48))
  (if (<= d58 r58) (setq d58 r58))
  (if (<= d68 r68) (setq d68 r68))
  (if (<= d78 r78) (setq d78 r78))
  (setq f12 (+ (* 1 (fgr m1 m2 d12)) (* 1 (fre m1 m2 d12)) (* 1 (fel d12)) (* 1 (fmo d12)) ))
  (setq f13 (+ (* 1 (fgr m1 m3 d13)) (* 1 (fre m1 m3 d13)) (* 1 (fel d13)) (* 1 (fmo d13)) ))
  (setq f23 (+ (* 1 (fgr m2 m3 d23)) (* 1 (fre m2 m3 d23)) (* 1 (fel d23)) (* 1 (fmo d23)) ))
  (setq f14 (+ (* 1 (fgr m1 m4 d14)) (* 1 (fre m1 m4 d14)) (* 1 (fel d14)) (* 1 (fmo d14)) ))
  (setq f24 (+ (* 1 (fgr m2 m4 d24)) (* 1 (fre m2 m4 d24)) (* 1 (fel d24)) (* 1 (fmo d24)) ))
  (setq f34 (+ (* 1 (fgr m3 m4 d34)) (* 1 (fre m3 m4 d34)) (* 1 (fel d34)) (* 1 (fmo d34)) ))
  (setq f15 (+ (* 1 (fgr m1 m5 d15)) (* 1 (fre m1 m5 d15)) (* 1 (fel d15)) (* 1 (fmo d15)) ))
  (setq f25 (+ (* 1 (fgr m2 m5 d25)) (* 1 (fre m2 m5 d25)) (* 1 (fel d25)) (* 1 (fmo d25)) ))
  (setq f35 (+ (* 1 (fgr m3 m5 d35)) (* 1 (fre m3 m5 d35)) (* 1 (fel d35)) (* 1 (fmo d35)) ))
  (setq f45 (+ (* 1 (fgr m4 m5 d45)) (* 1 (fre m4 m5 d45)) (* 1 (fel d45)) (* 1 (fmo d45)) ))
  (setq f16 (+ (* 1 (fgr m1 m6 d16)) (* 1 (fre m1 m6 d16)) (* 1 (fel d16)) (* 1 (fmo d16)) ))
  (setq f26 (+ (* 1 (fgr m2 m6 d26)) (* 1 (fre m2 m6 d26)) (* 1 (fel d26)) (* 1 (fmo d26)) ))
  (setq f36 (+ (* 1 (fgr m3 m6 d36)) (* 1 (fre m3 m6 d36)) (* 1 (fel d36)) (* 1 (fmo d36)) ))
  (setq f46 (+ (* 1 (fgr m4 m6 d46)) (* 1 (fre m4 m6 d46)) (* 1 (fel d46)) (* 1 (fmo d46)) ))
  (setq f56 (+ (* 1 (fgr m5 m6 d56)) (* 1 (fre m5 m6 d56)) (* 1 (fel d56)) (* 1 (fmo d56)) ))
  (setq f17 (+ (* 1 (fgr m1 m7 d17)) (* 1 (fre m1 m7 d17)) (* 1 (fel d17)) (* 1 (fmo d17)) ))
  (setq f27 (+ (* 1 (fgr m2 m7 d27)) (* 1 (fre m2 m7 d27)) (* 1 (fel d27)) (* 1 (fmo d27)) ))
  (setq f37 (+ (* 1 (fgr m3 m7 d37)) (* 1 (fre m3 m7 d37)) (* 1 (fel d37)) (* 1 (fmo d37)) ))
  (setq f47 (+ (* 1 (fgr m4 m7 d47)) (* 1 (fre m4 m7 d47)) (* 1 (fel d47)) (* 1 (fmo d47)) ))
  (setq f57 (+ (* 1 (fgr m5 m7 d57)) (* 1 (fre m5 m7 d57)) (* 1 (fel d57)) (* 1 (fmo d57)) ))
  (setq f67 (+ (* 1 (fgr m6 m7 d67)) (* 1 (fre m6 m7 d67)) (* 1 (fel d67)) (* 1 (fmo d67)) ))
  (setq f18 (+ (* 1 (fgr m1 m8 d18)) (* 1 (fre m1 m8 d18)) (* 1 (fel d18)) (* 1 (fmo d18)) ))
  (setq f28 (+ (* 1 (fgr m2 m8 d28)) (* 1 (fre m2 m8 d28)) (* 1 (fel d28)) (* 1 (fmo d28)) ))
  (setq f38 (+ (* 1 (fgr m3 m8 d38)) (* 1 (fre m3 m8 d38)) (* 1 (fel d38)) (* 1 (fmo d38)) ))
  (setq f48 (+ (* 1 (fgr m4 m8 d48)) (* 1 (fre m4 m8 d48)) (* 1 (fel d48)) (* 1 (fmo d48)) ))
  (setq f58 (+ (* 1 (fgr m5 m8 d58)) (* 1 (fre m5 m8 d58)) (* 1 (fel d58)) (* 1 (fmo d58)) ))
  (setq f68 (+ (* 1 (fgr m6 m8 d68)) (* 1 (fre m6 m8 d68)) (* 1 (fel d68)) (* 1 (fmo d68)) ))
  (setq f78 (+ (* 1 (fgr m7 m8 d78)) (* 1 (fre m7 m8 d78)) (* 1 (fel d78)) (* 1 (fmo d78)) ))

  (setq a12 (/ f12 m1))  (setq a21 (* -1 (/ f12 m2)))
  (setq a13 (/ f13 m1))  (setq a31 (* -1 (/ f13 m3)))
  (setq a23 (/ f23 m2))  (setq a32 (* -1 (/ f23 m3)))
  (setq a14 (/ f14 m1))  (setq a41 (* -1 (/ f14 m4)))
  (setq a24 (/ f24 m2))  (setq a42 (* -1 (/ f24 m4)))
  (setq a34 (/ f34 m3))  (setq a43 (* -1 (/ f34 m4)))
  (setq a15 (/ f15 m1))  (setq a51 (* -1 (/ f15 m5)))
  (setq a25 (/ f25 m2))  (setq a52 (* -1 (/ f25 m5)))
  (setq a35 (/ f35 m3))  (setq a53 (* -1 (/ f35 m5)))
  (setq a45 (/ f45 m4))  (setq a54 (* -1 (/ f45 m5)))
  (setq a16 (/ f16 m1))  (setq a61 (* -1 (/ f16 m6)))
  (setq a26 (/ f26 m2))  (setq a62 (* -1 (/ f26 m6)))
  (setq a36 (/ f36 m3))  (setq a63 (* -1 (/ f36 m6)))
  (setq a46 (/ f46 m4))  (setq a64 (* -1 (/ f46 m6)))
  (setq a56 (/ f56 m5))  (setq a65 (* -1 (/ f56 m6)))
  (setq a17 (/ f17 m1))  (setq a71 (* -1 (/ f17 m7)))
  (setq a27 (/ f27 m2))  (setq a72 (* -1 (/ f27 m7)))
  (setq a37 (/ f37 m3))  (setq a73 (* -1 (/ f37 m7)))
  (setq a47 (/ f47 m4))  (setq a74 (* -1 (/ f47 m7)))
  (setq a57 (/ f57 m5))  (setq a75 (* -1 (/ f57 m7)))
  (setq a67 (/ f67 m6))  (setq a76 (* -1 (/ f67 m7)))
  (setq a18 (/ f18 m1))  (setq a81 (* -1 (/ f18 m8)))
  (setq a28 (/ f28 m2))  (setq a82 (* -1 (/ f28 m8)))
  (setq a38 (/ f38 m3))  (setq a83 (* -1 (/ f38 m8)))
  (setq a48 (/ f48 m4))  (setq a84 (* -1 (/ f48 m8)))
  (setq a58 (/ f58 m5))  (setq a85 (* -1 (/ f58 m8)))
  (setq a68 (/ f68 m6))  (setq a86 (* -1 (/ f68 m8)))
  (setq a78 (/ f78 m7))  (setq a87 (* -1 (/ f78 m8)))
 
  (setq a1x (+ (* 1 (/ (fsx x1 y1 z1) m1)) (* 1 (/ (fwx r1) m1)) (* 1 v1x (/ (fvi m1 r1 v1) m1)) (/ (* a12 dx12) d12) (/ (* a13 dx13) d13) (/ (* a14 dx14) d14) (/ (* a15 dx15) d15) (/ (* a16 dx16) d16) (/ (* a17 dx17) d17) (/ (* a18 dx18) d18) ))
  (setq a1y (+ (* 1 (/ (fsy x1 y1 z1) m1)) (* 1 (/ (fwy r1) m1)) (* 1 v1y (/ (fvi m1 r1 v1) m1)) (/ (* a12 dy12) d12) (/ (* a13 dy13) d13) (/ (* a14 dy14) d14) (/ (* a15 dy15) d15) (/ (* a16 dy16) d16) (/ (* a17 dy17) d17) (/ (* a18 dy18) d18) ))
  (setq a1z (+ (* 1 (/ (fsz x1 y1 z1) m1)) (* 1 (/ (fwz r1) m1)) (* 1 v1z (/ (fvi m1 r1 v1) m1)) (/ (* a12 dz12) d12) (/ (* a13 dz13) d13) (/ (* a14 dz14) d14) (/ (* a15 dz15) d15) (/ (* a16 dz16) d16) (/ (* a17 dz17) d17) (/ (* a18 dz18) d18) ))
  (setq a2x (+ (* 1 (/ (fsx x2 y2 z2) m2)) (* 1 (/ (fwx r2) m2)) (* 1 v2x (/ (fvi m2 r2 v2) m2)) (/ (* a21 dx12) d12) (/ (* a23 dx23) d23) (/ (* a24 dx24) d24) (/ (* a25 dx25) d25) (/ (* a26 dx26) d26) (/ (* a27 dx27) d27) (/ (* a28 dx28) d28) ))
  (setq a2y (+ (* 1 (/ (fsy x2 y2 z2) m2)) (* 1 (/ (fwy r2) m2)) (* 1 v2y (/ (fvi m2 r2 v2) m2)) (/ (* a21 dy12) d12) (/ (* a23 dy23) d23) (/ (* a24 dy24) d24) (/ (* a25 dy25) d25) (/ (* a26 dy26) d26) (/ (* a27 dy27) d27) (/ (* a28 dy28) d28) ))
  (setq a2z (+ (* 1 (/ (fsz x2 y2 z2) m2)) (* 1 (/ (fwz r2) m2)) (* 1 v2z (/ (fvi m2 r2 v2) m2)) (/ (* a21 dz12) d12) (/ (* a23 dz23) d23) (/ (* a24 dz24) d24) (/ (* a25 dz25) d25) (/ (* a26 dz26) d26) (/ (* a27 dz27) d27) (/ (* a28 dz28) d28) ))
  (setq a3x (+ (* 1 (/ (fsx x3 y3 z3) m3)) (* 1 (/ (fwx r3) m3)) (* 1 v3x (/ (fvi m3 r3 v3) m3)) (/ (* a31 dx13) d13) (/ (* a32 dx23) d23) (/ (* a34 dx34) d34) (/ (* a35 dx35) d35) (/ (* a36 dx36) d36) (/ (* a37 dx37) d37) (/ (* a38 dx38) d38) ))
  (setq a3y (+ (* 1 (/ (fsy x3 y3 z3) m3)) (* 1 (/ (fwy r3) m3)) (* 1 v3y (/ (fvi m3 r3 v3) m3)) (/ (* a31 dy13) d13) (/ (* a32 dy23) d23) (/ (* a34 dy34) d34) (/ (* a35 dy35) d35) (/ (* a36 dy36) d36) (/ (* a37 dy37) d37) (/ (* a38 dy38) d38) ))
  (setq a3z (+ (* 1 (/ (fsz x3 y3 z3) m3)) (* 1 (/ (fwz r3) m3)) (* 1 v3z (/ (fvi m3 r3 v3) m3)) (/ (* a31 dz13) d13) (/ (* a32 dz23) d23) (/ (* a34 dz34) d34) (/ (* a35 dz35) d35) (/ (* a36 dz36) d36) (/ (* a37 dz37) d37) (/ (* a38 dz38) d38) ))
  (setq a4x (+ (* 1 (/ (fsx x4 y4 z4) m4)) (* 1 (/ (fwx r4) m4)) (* 1 v4x (/ (fvi m4 r4 v4) m4)) (/ (* a41 dx14) d14) (/ (* a42 dx24) d24) (/ (* a43 dx34) d34) (/ (* a45 dx45) d45) (/ (* a46 dx46) d46) (/ (* a47 dx47) d47) (/ (* a48 dx48) d48) ))
  (setq a4y (+ (* 1 (/ (fsy x4 y4 z4) m4)) (* 1 (/ (fwy r4) m4)) (* 1 v4y (/ (fvi m4 r4 v4) m4)) (/ (* a41 dy14) d14) (/ (* a42 dy24) d24) (/ (* a43 dy34) d34) (/ (* a45 dy45) d45) (/ (* a46 dy46) d46) (/ (* a47 dy47) d47) (/ (* a48 dy48) d48) ))
  (setq a4z (+ (* 1 (/ (fsz x4 y4 z4) m4)) (* 1 (/ (fwz r4) m4)) (* 1 v4z (/ (fvi m4 r4 v4) m4)) (/ (* a41 dz14) d14) (/ (* a42 dz24) d24) (/ (* a43 dz34) d34) (/ (* a45 dz45) d45) (/ (* a46 dz46) d46) (/ (* a47 dz47) d47) (/ (* a48 dz48) d48) ))
  (setq a5x (+ (* 1 (/ (fsx x5 y5 z5) m5)) (* 1 (/ (fwx r5) m5)) (* 1 v5x (/ (fvi m5 r5 v5) m5)) (/ (* a51 dx15) d15) (/ (* a52 dx25) d25) (/ (* a53 dx35) d35) (/ (* a54 dx45) d45) (/ (* a56 dx56) d56) (/ (* a57 dx57) d57) (/ (* a58 dx58) d58) ))
  (setq a5y (+ (* 1 (/ (fsy x5 y5 z5) m5)) (* 1 (/ (fwy r5) m5)) (* 1 v5y (/ (fvi m5 r5 v5) m5)) (/ (* a51 dy15) d15) (/ (* a52 dy25) d25) (/ (* a53 dy35) d35) (/ (* a54 dy45) d45) (/ (* a56 dy56) d56) (/ (* a57 dy57) d57) (/ (* a58 dy58) d58) ))
  (setq a5z (+ (* 1 (/ (fsz x5 y5 z5) m5)) (* 1 (/ (fwz r5) m5)) (* 1 v5z (/ (fvi m5 r5 v5) m5)) (/ (* a51 dz15) d15) (/ (* a52 dz25) d25) (/ (* a53 dz35) d35) (/ (* a54 dz45) d45) (/ (* a56 dz56) d56) (/ (* a57 dz57) d57) (/ (* a58 dz58) d58) ))
  (setq a6x (+ (* 1 (/ (fsx x6 y6 z6) m6)) (* 1 (/ (fwx r6) m6)) (* 1 v6x (/ (fvi m6 r6 v6) m6)) (/ (* a61 dx16) d16) (/ (* a62 dx26) d26) (/ (* a63 dx36) d36) (/ (* a64 dx46) d46) (/ (* a65 dx56) d56) (/ (* a67 dx67) d67) (/ (* a68 dx68) d68) ))
  (setq a6y (+ (* 1 (/ (fsy x6 y6 z6) m6)) (* 1 (/ (fwy r6) m6)) (* 1 v6y (/ (fvi m6 r6 v6) m6)) (/ (* a61 dy16) d16) (/ (* a62 dy26) d26) (/ (* a63 dy36) d36) (/ (* a64 dy46) d46) (/ (* a65 dy56) d56) (/ (* a67 dy67) d67) (/ (* a68 dy68) d68) ))
  (setq a6z (+ (* 1 (/ (fsz x6 y6 z6) m6)) (* 1 (/ (fwz r6) m6)) (* 1 v6z (/ (fvi m6 r6 v6) m6)) (/ (* a61 dz16) d16) (/ (* a62 dz26) d26) (/ (* a63 dz36) d36) (/ (* a64 dz46) d46) (/ (* a65 dz56) d56) (/ (* a67 dz67) d67) (/ (* a68 dz68) d68) ))
  (setq a7x (+ (* 1 (/ (fsx x7 y7 z7) m7)) (* 1 (/ (fwx r7) m7)) (* 1 v7x (/ (fvi m7 r7 v7) m7)) (/ (* a71 dx17) d17) (/ (* a72 dx27) d27) (/ (* a73 dx37) d37) (/ (* a74 dx47) d47) (/ (* a75 dx57) d57) (/ (* a76 dx67) d67) (/ (* a78 dx78) d78) ))
  (setq a7y (+ (* 1 (/ (fsy x7 y7 z7) m7)) (* 1 (/ (fwy r7) m7)) (* 1 v7y (/ (fvi m7 r7 v7) m7)) (/ (* a71 dy17) d17) (/ (* a72 dy27) d27) (/ (* a73 dy37) d37) (/ (* a74 dy47) d47) (/ (* a75 dy57) d57) (/ (* a76 dy67) d67) (/ (* a78 dy78) d78) ))
  (setq a7z (+ (* 1 (/ (fsz x7 y7 z7) m7)) (* 1 (/ (fwz r7) m7)) (* 1 v7z (/ (fvi m7 r7 v7) m7)) (/ (* a71 dz17) d17) (/ (* a72 dz27) d27) (/ (* a73 dz37) d37) (/ (* a74 dz47) d47) (/ (* a75 dz57) d57) (/ (* a76 dz67) d67) (/ (* a78 dz78) d78) ))
  (setq a8x (+ (* 1 (/ (fsx x8 y8 z8) m8)) (* 1 (/ (fwx r8) m8)) (* 1 v8x (/ (fvi m8 r8 v8) m8)) (/ (* a81 dx18) d18) (/ (* a82 dx28) d28) (/ (* a83 dx38) d38) (/ (* a84 dx48) d48) (/ (* a85 dx58) d58) (/ (* a86 dx68) d68) (/ (* a87 dx78) d78) ))
  (setq a8y (+ (* 1 (/ (fsy x8 y8 z8) m8)) (* 1 (/ (fwy r8) m8)) (* 1 v8y (/ (fvi m8 r8 v8) m8)) (/ (* a81 dy18) d18) (/ (* a82 dy28) d28) (/ (* a83 dy38) d38) (/ (* a84 dy48) d48) (/ (* a85 dy58) d58) (/ (* a86 dy68) d68) (/ (* a87 dy78) d78) ))
  (setq a8z (+ (* 1 (/ (fsz x8 y8 z8) m8)) (* 1 (/ (fwz r8) m8)) (* 1 v8z (/ (fvi m8 r8 v8) m8)) (/ (* a81 dz18) d18) (/ (* a82 dz28) d28) (/ (* a83 dz38) d38) (/ (* a84 dz48) d48) (/ (* a85 dz58) d58) (/ (* a86 dz68) d68) (/ (* a87 dz78) d78) ))

  (if (> d12 r12)
   (progn 
    (setq v1x (+ v1x (* a1x t)))  (setq v1y (+ v1y (* a1y t)))  (setq v1z (+ v1z (* a1z t)))
    (setq v2x (+ v2x (* a2x t)))  (setq v2y (+ v2y (* a2y t)))  (setq v2z (+ v2z (* a2z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v1i (list v1x v1y v1z)) ;velocita 1 prima dello scontro
     (setq v2i (list v2x v2y v2z)) ;velocita 2 prima dello scontro
     (setq v1i* (trans v1i 0 (list dx12 dy12 dz12)))
     (setq v2i* (trans v2i 0 (list dx12 dy12 dz12)))
     (setq v1i*x (car v1i*) v1i*y (cadr v1i*) v1i*z (caddr v1i*))
     (setq v2i*x (car v2i*) v2i*y (cadr v2i*) v2i*z (caddr v2i*))
     (setq v1f*z (* kur (/ (+ (* (- m1 m2) v1i*z) (* 2 m2 v2i*z)) (+ m1 m2))))
     (setq v2f*z (* kur (/ (+ (* (- m2 m1) v2i*z) (* 2 m1 v1i*z)) (+ m1 m2))))
     (setq v1f* (list v1i*x v1i*y v1f*z))
     (setq v2f* (list v2i*x v2i*y v2f*z))
     (setq v1f (trans v1f* (list dx12 dy12 dz12) 0))
     (setq v2f (trans v2f* (list dx12 dy12 dz12) 0))
     (setq v1x (car v1f) v1y (cadr v1f) v1z (caddr v1f))
     (setq v2x (car v2f) v2y (cadr v2f) v2z (caddr v2f))
    )
   )
  )
  (if (> d13 r13)
   (progn 
    (setq v1x (+ v1x (* a1x t)))  (setq v1y (+ v1y (* a1y t)))  (setq v1z (+ v1z (* a1z t)))
    (setq v3x (+ v3x (* a3x t)))  (setq v3y (+ v3y (* a3y t)))  (setq v3z (+ v3z (* a3z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v1i (list v1x v1y v1z)) ;velocita 1 prima dello scontro
     (setq v3i (list v3x v3y v3z)) ;velocita 3 prima dello scontro
     (setq v1i* (trans v1i 0 (list dx13 dy13 dz13)))
     (setq v3i* (trans v3i 0 (list dx13 dy13 dz13)))
     (setq v1i*x (car v1i*) v1i*y (cadr v1i*) v1i*z (caddr v1i*))
     (setq v3i*x (car v3i*) v3i*y (cadr v3i*) v3i*z (caddr v3i*))
     (setq v1f*z (* kur (/ (+ (* (- m1 m3) v1i*z) (* 2 m3 v3i*z)) (+ m1 m3))))
     (setq v3f*z (* kur (/ (+ (* (- m3 m1) v3i*z) (* 2 m1 v1i*z)) (+ m1 m3))))
     (setq v1f* (list v1i*x v1i*y v1f*z))
     (setq v3f* (list v3i*x v3i*y v3f*z))
     (setq v1f (trans v1f* (list dx13 dy13 dz13) 0))
     (setq v3f (trans v3f* (list dx13 dy13 dz13) 0))
     (setq v1x (car v1f) v1y (cadr v1f) v1z (caddr v1f))
     (setq v3x (car v3f) v3y (cadr v3f) v3z (caddr v3f))
    )
   )
  )
  (if (> d23 r23)
   (progn 
    (setq v2x (+ v2x (* a2x t)))  (setq v2y (+ v2y (* a2y t)))  (setq v2z (+ v2z (* a2z t)))
    (setq v3x (+ v3x (* a3x t)))  (setq v3y (+ v3y (* a3y t)))  (setq v3z (+ v3z (* a3z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v2i (list v2x v2y v2z)) ;velocita 2 prima dello scontro
     (setq v3i (list v3x v3y v3z)) ;velocita 3 prima dello scontro
     (setq v2i* (trans v2i 0 (list dx23 dy23 dz23)))
     (setq v3i* (trans v3i 0 (list dx23 dy23 dz23)))
     (setq v2i*x (car v2i*) v2i*y (cadr v2i*) v2i*z (caddr v2i*))
     (setq v3i*x (car v3i*) v3i*y (cadr v3i*) v3i*z (caddr v3i*))
     (setq v2f*z (* kur (/ (+ (* (- m2 m3) v2i*z) (* 2 m3 v3i*z)) (+ m2 m3))))
     (setq v3f*z (* kur (/ (+ (* (- m3 m2) v3i*z) (* 2 m2 v2i*z)) (+ m2 m3))))
     (setq v2f* (list v2i*x v2i*y v2f*z))
     (setq v3f* (list v3i*x v3i*y v3f*z))
     (setq v2f (trans v2f* (list dx23 dy23 dz23) 0))
     (setq v3f (trans v3f* (list dx23 dy23 dz23) 0))
     (setq v2x (car v2f) v2y (cadr v2f) v2z (caddr v2f))
     (setq v3x (car v3f) v3y (cadr v3f) v3z (caddr v3f))
    )
   )
  )
  (if (> d14 r14)
   (progn 
    (setq v1x (+ v1x (* a1x t)))  (setq v1y (+ v1y (* a1y t)))  (setq v1z (+ v1z (* a1z t)))
    (setq v4x (+ v4x (* a4x t)))  (setq v4y (+ v4y (* a4y t)))  (setq v4z (+ v4z (* a4z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v1i (list v1x v1y v1z)) ;velocita 1 prima dello scontro
     (setq v4i (list v4x v4y v4z)) ;velocita 4 prima dello scontro
     (setq v1i* (trans v1i 0 (list dx14 dy14 dz14)))
     (setq v4i* (trans v4i 0 (list dx14 dy14 dz14)))
     (setq v1i*x (car v1i*) v1i*y (cadr v1i*) v1i*z (caddr v1i*))
     (setq v4i*x (car v4i*) v4i*y (cadr v4i*) v4i*z (caddr v4i*))
     (setq v1f*z (* kur (/ (+ (* (- m1 m4) v1i*z) (* 2 m4 v4i*z)) (+ m1 m4))))
     (setq v4f*z (* kur (/ (+ (* (- m4 m1) v4i*z) (* 2 m1 v1i*z)) (+ m1 m4))))
     (setq v1f* (list v1i*x v1i*y v1f*z))
     (setq v4f* (list v4i*x v4i*y v4f*z))
     (setq v1f (trans v1f* (list dx14 dy14 dz14) 0))
     (setq v4f (trans v4f* (list dx14 dy14 dz14) 0))
     (setq v1x (car v1f) v1y (cadr v1f) v1z (caddr v1f))
     (setq v4x (car v4f) v4y (cadr v4f) v4z (caddr v4f))
    )
   )
  )
  (if (> d24 r24)
   (progn 
    (setq v2x (+ v2x (* a2x t)))  (setq v2y (+ v2y (* a2y t)))  (setq v2z (+ v2z (* a2z t)))
    (setq v4x (+ v4x (* a4x t)))  (setq v4y (+ v4y (* a4y t)))  (setq v4z (+ v4z (* a4z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v2i (list v2x v2y v2z)) ;velocita 2 prima dello scontro
     (setq v4i (list v4x v4y v4z)) ;velocita 4 prima dello scontro
     (setq v2i* (trans v2i 0 (list dx24 dy24 dz24)))
     (setq v4i* (trans v4i 0 (list dx24 dy24 dz24)))
     (setq v2i*x (car v2i*) v2i*y (cadr v2i*) v2i*z (caddr v2i*))
     (setq v4i*x (car v4i*) v4i*y (cadr v4i*) v4i*z (caddr v4i*))
     (setq v2f*z (* kur (/ (+ (* (- m2 m4) v2i*z) (* 2 m4 v4i*z)) (+ m2 m4))))
     (setq v4f*z (* kur (/ (+ (* (- m4 m2) v4i*z) (* 2 m2 v2i*z)) (+ m2 m4))))
     (setq v2f* (list v2i*x v2i*y v2f*z))
     (setq v4f* (list v4i*x v4i*y v4f*z))
     (setq v2f (trans v2f* (list dx24 dy24 dz24) 0))
     (setq v4f (trans v4f* (list dx24 dy24 dz24) 0))
     (setq v2x (car v2f) v2y (cadr v2f) v2z (caddr v2f))
     (setq v4x (car v4f) v4y (cadr v4f) v4z (caddr v4f))
    )
   )
  )
  (if (> d34 r34)
   (progn 
    (setq v3x (+ v3x (* a3x t)))  (setq v3y (+ v3y (* a3y t)))  (setq v3z (+ v3z (* a3z t)))
    (setq v4x (+ v4x (* a4x t)))  (setq v4y (+ v4y (* a4y t)))  (setq v4z (+ v4z (* a4z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v3i (list v3x v3y v3z)) ;velocita 3 prima dello scontro
     (setq v4i (list v4x v4y v4z)) ;velocita 4 prima dello scontro
     (setq v3i* (trans v3i 0 (list dx34 dy34 dz34)))
     (setq v4i* (trans v4i 0 (list dx34 dy34 dz34)))
     (setq v3i*x (car v3i*) v3i*y (cadr v3i*) v3i*z (caddr v3i*))
     (setq v4i*x (car v4i*) v4i*y (cadr v4i*) v4i*z (caddr v4i*))
     (setq v3f*z (* kur (/ (+ (* (- m3 m4) v3i*z) (* 2 m4 v4i*z)) (+ m3 m4))))
     (setq v4f*z (* kur (/ (+ (* (- m4 m3) v4i*z) (* 2 m3 v3i*z)) (+ m3 m4))))
     (setq v3f* (list v3i*x v3i*y v3f*z))
     (setq v4f* (list v4i*x v4i*y v4f*z))
     (setq v3f (trans v3f* (list dx34 dy34 dz34) 0))
     (setq v4f (trans v4f* (list dx34 dy34 dz34) 0))
     (setq v3x (car v3f) v3y (cadr v3f) v3z (caddr v3f))
     (setq v4x (car v4f) v4y (cadr v4f) v4z (caddr v4f))
    )
   )
  )
  (if (> d15 r15)
   (progn 
    (setq v1x (+ v1x (* a1x t)))  (setq v1y (+ v1y (* a1y t)))  (setq v1z (+ v1z (* a1z t)))
    (setq v5x (+ v5x (* a5x t)))  (setq v5y (+ v5y (* a5y t)))  (setq v5z (+ v5z (* a5z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v1i (list v1x v1y v1z)) ;velocita 1 prima dello scontro
     (setq v5i (list v5x v5y v5z)) ;velocita 5 prima dello scontro
     (setq v1i* (trans v1i 0 (list dx15 dy15 dz15)))
     (setq v5i* (trans v5i 0 (list dx15 dy15 dz15)))
     (setq v1i*x (car v1i*) v1i*y (cadr v1i*) v1i*z (caddr v1i*))
     (setq v5i*x (car v5i*) v5i*y (cadr v5i*) v5i*z (caddr v5i*))
     (setq v1f*z (* kur (/ (+ (* (- m1 m5) v1i*z) (* 2 m5 v5i*z)) (+ m1 m5))))
     (setq v5f*z (* kur (/ (+ (* (- m5 m1) v5i*z) (* 2 m1 v1i*z)) (+ m1 m5))))
     (setq v1f* (list v1i*x v1i*y v1f*z))
     (setq v5f* (list v5i*x v5i*y v5f*z))
     (setq v1f (trans v1f* (list dx15 dy15 dz15) 0))
     (setq v5f (trans v5f* (list dx15 dy15 dz15) 0))
     (setq v1x (car v1f) v1y (cadr v1f) v1z (caddr v1f))
     (setq v5x (car v5f) v5y (cadr v5f) v5z (caddr v5f))
    )
   )
  )
  (if (> d25 r25)
   (progn 
    (setq v2x (+ v2x (* a2x t)))  (setq v2y (+ v2y (* a2y t)))  (setq v2z (+ v2z (* a2z t)))
    (setq v5x (+ v5x (* a5x t)))  (setq v5y (+ v5y (* a5y t)))  (setq v5z (+ v5z (* a5z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v2i (list v2x v2y v2z)) ;velocita 2 prima dello scontro
     (setq v5i (list v5x v5y v5z)) ;velocita 5 prima dello scontro
     (setq v2i* (trans v2i 0 (list dx25 dy25 dz25)))
     (setq v5i* (trans v5i 0 (list dx25 dy25 dz25)))
     (setq v2i*x (car v2i*) v2i*y (cadr v2i*) v2i*z (caddr v2i*))
     (setq v5i*x (car v5i*) v5i*y (cadr v5i*) v5i*z (caddr v5i*))
     (setq v2f*z (* kur (/ (+ (* (- m2 m5) v2i*z) (* 2 m5 v5i*z)) (+ m2 m5))))
     (setq v5f*z (* kur (/ (+ (* (- m5 m2) v5i*z) (* 2 m2 v2i*z)) (+ m2 m5))))
     (setq v2f* (list v2i*x v2i*y v2f*z))
     (setq v5f* (list v5i*x v5i*y v5f*z))
     (setq v2f (trans v2f* (list dx25 dy25 dz25) 0))
     (setq v5f (trans v5f* (list dx25 dy25 dz25) 0))
     (setq v2x (car v2f) v2y (cadr v2f) v2z (caddr v2f))
     (setq v5x (car v5f) v5y (cadr v5f) v5z (caddr v5f))
    )
   )
  )
  (if (> d35 r35)
   (progn 
    (setq v3x (+ v3x (* a3x t)))  (setq v3y (+ v3y (* a3y t)))  (setq v3z (+ v3z (* a3z t)))
    (setq v5x (+ v5x (* a5x t)))  (setq v5y (+ v5y (* a5y t)))  (setq v5z (+ v5z (* a5z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v3i (list v3x v3y v3z)) ;velocita 3 prima dello scontro
     (setq v5i (list v5x v5y v5z)) ;velocita 5 prima dello scontro
     (setq v3i* (trans v3i 0 (list dx35 dy35 dz35)))
     (setq v5i* (trans v5i 0 (list dx35 dy35 dz35)))
     (setq v3i*x (car v3i*) v3i*y (cadr v3i*) v3i*z (caddr v3i*))
     (setq v5i*x (car v5i*) v5i*y (cadr v5i*) v5i*z (caddr v5i*))
     (setq v3f*z (* kur (/ (+ (* (- m3 m5) v3i*z) (* 2 m5 v5i*z)) (+ m3 m5))))
     (setq v5f*z (* kur (/ (+ (* (- m5 m3) v5i*z) (* 2 m3 v3i*z)) (+ m3 m5))))
     (setq v3f* (list v3i*x v3i*y v3f*z))
     (setq v5f* (list v5i*x v5i*y v5f*z))
     (setq v3f (trans v3f* (list dx35 dy35 dz35) 0))
     (setq v5f (trans v5f* (list dx35 dy35 dz35) 0))
     (setq v3x (car v3f) v3y (cadr v3f) v3z (caddr v3f))
     (setq v5x (car v5f) v5y (cadr v5f) v5z (caddr v5f))
    )
   )
  )
  (if (> d45 r45)
   (progn 
    (setq v4x (+ v4x (* a4x t)))  (setq v4y (+ v4y (* a4y t)))  (setq v4z (+ v4z (* a4z t)))
    (setq v5x (+ v5x (* a5x t)))  (setq v5y (+ v5y (* a5y t)))  (setq v5z (+ v5z (* a5z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v4i (list v4x v4y v4z)) ;velocita 4 prima dello scontro
     (setq v5i (list v5x v5y v5z)) ;velocita 5 prima dello scontro
     (setq v4i* (trans v4i 0 (list dx45 dy45 dz45)))
     (setq v5i* (trans v5i 0 (list dx45 dy45 dz45)))
     (setq v4i*x (car v4i*) v4i*y (cadr v4i*) v4i*z (caddr v4i*))
     (setq v5i*x (car v5i*) v5i*y (cadr v5i*) v5i*z (caddr v5i*))
     (setq v4f*z (* kur (/ (+ (* (- m4 m5) v4i*z) (* 2 m5 v5i*z)) (+ m4 m5))))
     (setq v5f*z (* kur (/ (+ (* (- m5 m4) v5i*z) (* 2 m4 v4i*z)) (+ m4 m5))))
     (setq v4f* (list v4i*x v4i*y v4f*z))
     (setq v5f* (list v5i*x v5i*y v5f*z))
     (setq v4f (trans v4f* (list dx45 dy45 dz45) 0))
     (setq v5f (trans v5f* (list dx45 dy45 dz45) 0))
     (setq v4x (car v4f) v4y (cadr v4f) v4z (caddr v4f))
     (setq v5x (car v5f) v5y (cadr v5f) v5z (caddr v5f))
    )
   )
  )
  (if (> d16 r16)
   (progn 
    (setq v1x (+ v1x (* a1x t)))  (setq v1y (+ v1y (* a1y t)))  (setq v1z (+ v1z (* a1z t)))
    (setq v6x (+ v6x (* a6x t)))  (setq v6y (+ v6y (* a6y t)))  (setq v6z (+ v6z (* a6z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v1i (list v1x v1y v1z)) ;velocita 1 prima dello scontro
     (setq v6i (list v6x v6y v6z)) ;velocita 6 prima dello scontro
     (setq v1i* (trans v1i 0 (list dx16 dy16 dz16)))
     (setq v6i* (trans v6i 0 (list dx16 dy16 dz16)))
     (setq v1i*x (car v1i*) v1i*y (cadr v1i*) v1i*z (caddr v1i*))
     (setq v6i*x (car v6i*) v6i*y (cadr v6i*) v6i*z (caddr v6i*))
     (setq v1f*z (* kur (/ (+ (* (- m1 m6) v1i*z) (* 2 m6 v6i*z)) (+ m1 m6))))
     (setq v6f*z (* kur (/ (+ (* (- m6 m1) v6i*z) (* 2 m1 v1i*z)) (+ m1 m6))))
     (setq v1f* (list v1i*x v1i*y v1f*z))
     (setq v6f* (list v6i*x v6i*y v6f*z))
     (setq v1f (trans v1f* (list dx16 dy16 dz16) 0))
     (setq v6f (trans v6f* (list dx16 dy16 dz16) 0))
     (setq v1x (car v1f) v1y (cadr v1f) v1z (caddr v1f))
     (setq v6x (car v6f) v6y (cadr v6f) v6z (caddr v6f))
    )
   )
  )
  (if (> d26 r26)
   (progn 
    (setq v2x (+ v2x (* a2x t)))  (setq v2y (+ v2y (* a2y t)))  (setq v2z (+ v2z (* a2z t)))
    (setq v6x (+ v6x (* a6x t)))  (setq v6y (+ v6y (* a6y t)))  (setq v6z (+ v6z (* a6z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v2i (list v2x v2y v2z)) ;velocita 2 prima dello scontro
     (setq v6i (list v6x v6y v6z)) ;velocita 6 prima dello scontro
     (setq v2i* (trans v2i 0 (list dx26 dy26 dz26)))
     (setq v6i* (trans v6i 0 (list dx26 dy26 dz26)))
     (setq v2i*x (car v2i*) v2i*y (cadr v2i*) v2i*z (caddr v2i*))
     (setq v6i*x (car v6i*) v6i*y (cadr v6i*) v6i*z (caddr v6i*))
     (setq v2f*z (* kur (/ (+ (* (- m2 m6) v2i*z) (* 2 m6 v6i*z)) (+ m2 m6))))
     (setq v6f*z (* kur (/ (+ (* (- m6 m2) v6i*z) (* 2 m2 v2i*z)) (+ m2 m6))))
     (setq v2f* (list v2i*x v2i*y v2f*z))
     (setq v6f* (list v6i*x v6i*y v6f*z))
     (setq v2f (trans v2f* (list dx26 dy26 dz26) 0))
     (setq v6f (trans v6f* (list dx26 dy26 dz26) 0))
     (setq v2x (car v2f) v2y (cadr v2f) v2z (caddr v2f))
     (setq v6x (car v6f) v6y (cadr v6f) v6z (caddr v6f))
    )
   )
  )
  (if (> d36 r36)
   (progn 
    (setq v3x (+ v3x (* a3x t)))  (setq v3y (+ v3y (* a3y t)))  (setq v3z (+ v3z (* a3z t)))
    (setq v6x (+ v6x (* a6x t)))  (setq v6y (+ v6y (* a6y t)))  (setq v6z (+ v6z (* a6z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v3i (list v3x v3y v3z)) ;velocita 3 prima dello scontro
     (setq v6i (list v6x v6y v6z)) ;velocita 6 prima dello scontro
     (setq v3i* (trans v3i 0 (list dx36 dy36 dz36)))
     (setq v6i* (trans v6i 0 (list dx36 dy36 dz36)))
     (setq v3i*x (car v3i*) v3i*y (cadr v3i*) v3i*z (caddr v3i*))
     (setq v6i*x (car v6i*) v6i*y (cadr v6i*) v6i*z (caddr v6i*))
     (setq v3f*z (* kur (/ (+ (* (- m3 m6) v3i*z) (* 2 m6 v6i*z)) (+ m3 m6))))
     (setq v6f*z (* kur (/ (+ (* (- m6 m3) v6i*z) (* 2 m3 v3i*z)) (+ m3 m6))))
     (setq v3f* (list v3i*x v3i*y v3f*z))
     (setq v6f* (list v6i*x v6i*y v6f*z))
     (setq v3f (trans v3f* (list dx36 dy36 dz36) 0))
     (setq v6f (trans v6f* (list dx36 dy36 dz36) 0))
     (setq v3x (car v3f) v3y (cadr v3f) v3z (caddr v3f))
     (setq v6x (car v6f) v6y (cadr v6f) v6z (caddr v6f))
    )
   )
  )
  (if (> d46 r46)
   (progn 
    (setq v4x (+ v4x (* a4x t)))  (setq v4y (+ v4y (* a4y t)))  (setq v4z (+ v4z (* a4z t)))
    (setq v6x (+ v6x (* a6x t)))  (setq v6y (+ v6y (* a6y t)))  (setq v6z (+ v6z (* a6z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v4i (list v4x v4y v4z)) ;velocita 4 prima dello scontro
     (setq v6i (list v6x v6y v6z)) ;velocita 6 prima dello scontro
     (setq v4i* (trans v4i 0 (list dx46 dy46 dz46)))
     (setq v6i* (trans v6i 0 (list dx46 dy46 dz46)))
     (setq v4i*x (car v4i*) v4i*y (cadr v4i*) v4i*z (caddr v4i*))
     (setq v6i*x (car v6i*) v6i*y (cadr v6i*) v6i*z (caddr v6i*))
     (setq v4f*z (* kur (/ (+ (* (- m4 m6) v4i*z) (* 2 m6 v6i*z)) (+ m4 m6))))
     (setq v6f*z (* kur (/ (+ (* (- m6 m4) v6i*z) (* 2 m4 v4i*z)) (+ m4 m6))))
     (setq v4f* (list v4i*x v4i*y v4f*z))
     (setq v6f* (list v6i*x v6i*y v6f*z))
     (setq v4f (trans v4f* (list dx46 dy46 dz46) 0))
     (setq v6f (trans v6f* (list dx46 dy46 dz46) 0))
     (setq v4x (car v4f) v4y (cadr v4f) v4z (caddr v4f))
     (setq v6x (car v6f) v6y (cadr v6f) v6z (caddr v6f))
    )
   )
  )
  (if (> d56 r56)
   (progn 
    (setq v5x (+ v5x (* a5x t)))  (setq v5y (+ v5y (* a5y t)))  (setq v5z (+ v5z (* a5z t)))
    (setq v6x (+ v6x (* a6x t)))  (setq v6y (+ v6y (* a6y t)))  (setq v6z (+ v6z (* a6z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v5i (list v5x v5y v5z)) ;velocita 5 prima dello scontro
     (setq v6i (list v6x v6y v6z)) ;velocita 6 prima dello scontro
     (setq v5i* (trans v5i 0 (list dx56 dy56 dz56)))
     (setq v6i* (trans v6i 0 (list dx56 dy56 dz56)))
     (setq v5i*x (car v5i*) v5i*y (cadr v5i*) v5i*z (caddr v5i*))
     (setq v6i*x (car v6i*) v6i*y (cadr v6i*) v6i*z (caddr v6i*))
     (setq v5f*z (* kur (/ (+ (* (- m5 m6) v5i*z) (* 2 m6 v6i*z)) (+ m5 m6))))
     (setq v6f*z (* kur (/ (+ (* (- m6 m5) v6i*z) (* 2 m5 v5i*z)) (+ m5 m6))))
     (setq v5f* (list v5i*x v5i*y v5f*z))
     (setq v6f* (list v6i*x v6i*y v6f*z))
     (setq v5f (trans v5f* (list dx56 dy56 dz56) 0))
     (setq v6f (trans v6f* (list dx56 dy56 dz56) 0))
     (setq v5x (car v5f) v5y (cadr v5f) v5z (caddr v5f))
     (setq v6x (car v6f) v6y (cadr v6f) v6z (caddr v6f))
    )
   )
  )
  (if (> d17 r17)
   (progn 
    (setq v1x (+ v1x (* a1x t)))  (setq v1y (+ v1y (* a1y t)))  (setq v1z (+ v1z (* a1z t)))
    (setq v7x (+ v7x (* a7x t)))  (setq v7y (+ v7y (* a7y t)))  (setq v7z (+ v7z (* a7z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v1i (list v1x v1y v1z)) ;velocita 1 prima dello scontro
     (setq v7i (list v7x v7y v7z)) ;velocita 7 prima dello scontro
     (setq v1i* (trans v1i 0 (list dx17 dy17 dz17)))
     (setq v7i* (trans v7i 0 (list dx17 dy17 dz17)))
     (setq v1i*x (car v1i*) v1i*y (cadr v1i*) v1i*z (caddr v1i*))
     (setq v7i*x (car v7i*) v7i*y (cadr v7i*) v7i*z (caddr v7i*))
     (setq v1f*z (* kur (/ (+ (* (- m1 m7) v1i*z) (* 2 m7 v7i*z)) (+ m1 m7))))
     (setq v7f*z (* kur (/ (+ (* (- m7 m1) v7i*z) (* 2 m1 v1i*z)) (+ m1 m7))))
     (setq v1f* (list v1i*x v1i*y v1f*z))
     (setq v7f* (list v7i*x v7i*y v7f*z))
     (setq v1f (trans v1f* (list dx17 dy17 dz17) 0))
     (setq v7f (trans v7f* (list dx17 dy17 dz17) 0))
     (setq v1x (car v1f) v1y (cadr v1f) v1z (caddr v1f))
     (setq v7x (car v7f) v7y (cadr v7f) v7z (caddr v7f))
    )
   )
  )
  (if (> d27 r27)
   (progn 
    (setq v2x (+ v2x (* a2x t)))  (setq v2y (+ v2y (* a2y t)))  (setq v2z (+ v2z (* a2z t)))
    (setq v7x (+ v7x (* a7x t)))  (setq v7y (+ v7y (* a7y t)))  (setq v7z (+ v7z (* a7z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v2i (list v2x v2y v2z)) ;velocita 2 prima dello scontro
     (setq v7i (list v7x v7y v7z)) ;velocita 7 prima dello scontro
     (setq v2i* (trans v2i 0 (list dx27 dy27 dz27)))
     (setq v7i* (trans v7i 0 (list dx27 dy27 dz27)))
     (setq v2i*x (car v2i*) v2i*y (cadr v2i*) v2i*z (caddr v2i*))
     (setq v7i*x (car v7i*) v7i*y (cadr v7i*) v7i*z (caddr v7i*))
     (setq v2f*z (* kur (/ (+ (* (- m2 m7) v2i*z) (* 2 m7 v7i*z)) (+ m2 m7))))
     (setq v7f*z (* kur (/ (+ (* (- m7 m2) v7i*z) (* 2 m2 v2i*z)) (+ m2 m7))))
     (setq v2f* (list v2i*x v2i*y v2f*z))
     (setq v7f* (list v7i*x v7i*y v7f*z))
     (setq v2f (trans v2f* (list dx27 dy27 dz27) 0))
     (setq v7f (trans v7f* (list dx27 dy27 dz27) 0))
     (setq v2x (car v2f) v2y (cadr v2f) v2z (caddr v2f))
     (setq v7x (car v7f) v7y (cadr v7f) v7z (caddr v7f))
    )
   )
  )
  (if (> d37 r37)
   (progn 
    (setq v3x (+ v3x (* a3x t)))  (setq v3y (+ v3y (* a3y t)))  (setq v3z (+ v3z (* a3z t)))
    (setq v7x (+ v7x (* a7x t)))  (setq v7y (+ v7y (* a7y t)))  (setq v7z (+ v7z (* a7z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v3i (list v3x v3y v3z)) ;velocita 3 prima dello scontro
     (setq v7i (list v7x v7y v7z)) ;velocita 7 prima dello scontro
     (setq v3i* (trans v3i 0 (list dx37 dy37 dz37)))
     (setq v7i* (trans v7i 0 (list dx37 dy37 dz37)))
     (setq v3i*x (car v3i*) v3i*y (cadr v3i*) v3i*z (caddr v3i*))
     (setq v7i*x (car v7i*) v7i*y (cadr v7i*) v7i*z (caddr v7i*))
     (setq v3f*z (* kur (/ (+ (* (- m3 m7) v3i*z) (* 2 m7 v7i*z)) (+ m3 m7))))
     (setq v7f*z (* kur (/ (+ (* (- m7 m3) v7i*z) (* 2 m3 v3i*z)) (+ m3 m7))))
     (setq v3f* (list v3i*x v3i*y v3f*z))
     (setq v7f* (list v7i*x v7i*y v7f*z))
     (setq v3f (trans v3f* (list dx37 dy37 dz37) 0))
     (setq v7f (trans v7f* (list dx37 dy37 dz37) 0))
     (setq v3x (car v3f) v3y (cadr v3f) v3z (caddr v3f))
     (setq v7x (car v7f) v7y (cadr v7f) v7z (caddr v7f))
    )
   )
  )
  (if (> d47 r47)
   (progn 
    (setq v4x (+ v4x (* a4x t)))  (setq v4y (+ v4y (* a4y t)))  (setq v4z (+ v4z (* a4z t)))
    (setq v7x (+ v7x (* a7x t)))  (setq v7y (+ v7y (* a7y t)))  (setq v7z (+ v7z (* a7z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v4i (list v4x v4y v4z)) ;velocita 4 prima dello scontro
     (setq v7i (list v7x v7y v7z)) ;velocita 7 prima dello scontro
     (setq v4i* (trans v4i 0 (list dx47 dy47 dz47)))
     (setq v7i* (trans v7i 0 (list dx47 dy47 dz47)))
     (setq v4i*x (car v4i*) v4i*y (cadr v4i*) v4i*z (caddr v4i*))
     (setq v7i*x (car v7i*) v7i*y (cadr v7i*) v7i*z (caddr v7i*))
     (setq v4f*z (* kur (/ (+ (* (- m4 m7) v4i*z) (* 2 m7 v7i*z)) (+ m4 m7))))
     (setq v7f*z (* kur (/ (+ (* (- m7 m4) v7i*z) (* 2 m4 v4i*z)) (+ m4 m7))))
     (setq v4f* (list v4i*x v4i*y v4f*z))
     (setq v7f* (list v7i*x v7i*y v7f*z))
     (setq v4f (trans v4f* (list dx47 dy47 dz47) 0))
     (setq v7f (trans v7f* (list dx47 dy47 dz47) 0))
     (setq v4x (car v4f) v4y (cadr v4f) v4z (caddr v4f))
     (setq v7x (car v7f) v7y (cadr v7f) v7z (caddr v7f))
    )
   )
  )
  (if (> d57 r57)
   (progn 
    (setq v5x (+ v5x (* a5x t)))  (setq v5y (+ v5y (* a5y t)))  (setq v5z (+ v5z (* a5z t)))
    (setq v7x (+ v7x (* a7x t)))  (setq v7y (+ v7y (* a7y t)))  (setq v7z (+ v7z (* a7z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v5i (list v5x v5y v5z)) ;velocita 5 prima dello scontro
     (setq v7i (list v7x v7y v7z)) ;velocita 7 prima dello scontro
     (setq v5i* (trans v5i 0 (list dx57 dy57 dz57)))
     (setq v7i* (trans v7i 0 (list dx57 dy57 dz57)))
     (setq v5i*x (car v5i*) v5i*y (cadr v5i*) v5i*z (caddr v5i*))
     (setq v7i*x (car v7i*) v7i*y (cadr v7i*) v7i*z (caddr v7i*))
     (setq v5f*z (* kur (/ (+ (* (- m5 m7) v5i*z) (* 2 m7 v7i*z)) (+ m5 m7))))
     (setq v7f*z (* kur (/ (+ (* (- m7 m5) v7i*z) (* 2 m5 v5i*z)) (+ m5 m7))))
     (setq v5f* (list v5i*x v5i*y v5f*z))
     (setq v7f* (list v7i*x v7i*y v7f*z))
     (setq v5f (trans v5f* (list dx57 dy57 dz57) 0))
     (setq v7f (trans v7f* (list dx57 dy57 dz57) 0))
     (setq v5x (car v5f) v5y (cadr v5f) v5z (caddr v5f))
     (setq v7x (car v7f) v7y (cadr v7f) v7z (caddr v7f))
    )
   )
  )
  (if (> d67 r67)
   (progn 
    (setq v6x (+ v6x (* a6x t)))  (setq v6y (+ v6y (* a6y t)))  (setq v6z (+ v6z (* a6z t)))
    (setq v7x (+ v7x (* a7x t)))  (setq v7y (+ v7y (* a7y t)))  (setq v7z (+ v7z (* a7z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v6i (list v6x v6y v6z)) ;velocita 6 prima dello scontro
     (setq v7i (list v7x v7y v7z)) ;velocita 7 prima dello scontro
     (setq v6i* (trans v6i 0 (list dx67 dy67 dz67)))
     (setq v7i* (trans v7i 0 (list dx67 dy67 dz67)))
     (setq v6i*x (car v6i*) v6i*y (cadr v6i*) v6i*z (caddr v6i*))
     (setq v7i*x (car v7i*) v7i*y (cadr v7i*) v7i*z (caddr v7i*))
     (setq v6f*z (* kur (/ (+ (* (- m6 m7) v6i*z) (* 2 m7 v7i*z)) (+ m6 m7))))
     (setq v7f*z (* kur (/ (+ (* (- m7 m6) v7i*z) (* 2 m6 v6i*z)) (+ m6 m7))))
     (setq v6f* (list v6i*x v6i*y v6f*z))
     (setq v7f* (list v7i*x v7i*y v7f*z))
     (setq v6f (trans v6f* (list dx67 dy67 dz67) 0))
     (setq v7f (trans v7f* (list dx67 dy67 dz67) 0))
     (setq v6x (car v6f) v6y (cadr v6f) v6z (caddr v6f))
     (setq v7x (car v7f) v7y (cadr v7f) v7z (caddr v7f))
    )
   )
  )
  (if (> d18 r18)
   (progn 
    (setq v1x (+ v1x (* a1x t)))  (setq v1y (+ v1y (* a1y t)))  (setq v1z (+ v1z (* a1z t)))
    (setq v8x (+ v8x (* a8x t)))  (setq v8y (+ v8y (* a8y t)))  (setq v8z (+ v8z (* a8z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v1i (list v1x v1y v1z)) ;velocita 1 prima dello scontro
     (setq v8i (list v8x v8y v8z)) ;velocita 8 prima dello scontro
     (setq v1i* (trans v1i 0 (list dx18 dy18 dz18)))
     (setq v8i* (trans v8i 0 (list dx18 dy18 dz18)))
     (setq v1i*x (car v1i*) v1i*y (cadr v1i*) v1i*z (caddr v1i*))
     (setq v8i*x (car v8i*) v8i*y (cadr v8i*) v8i*z (caddr v8i*))
     (setq v1f*z (* kur (/ (+ (* (- m1 m8) v1i*z) (* 2 m8 v8i*z)) (+ m1 m8))))
     (setq v8f*z (* kur (/ (+ (* (- m8 m1) v8i*z) (* 2 m1 v1i*z)) (+ m1 m8))))
     (setq v1f* (list v1i*x v1i*y v1f*z))
     (setq v8f* (list v8i*x v8i*y v8f*z))
     (setq v1f (trans v1f* (list dx18 dy18 dz18) 0))
     (setq v8f (trans v8f* (list dx18 dy18 dz18) 0))
     (setq v1x (car v1f) v1y (cadr v1f) v1z (caddr v1f))
     (setq v8x (car v8f) v8y (cadr v8f) v8z (caddr v8f))
    )
   )
  )
  (if (> d28 r28)
   (progn 
    (setq v2x (+ v2x (* a2x t)))  (setq v2y (+ v2y (* a2y t)))  (setq v2z (+ v2z (* a2z t)))
    (setq v8x (+ v8x (* a8x t)))  (setq v8y (+ v8y (* a8y t)))  (setq v8z (+ v8z (* a8z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v2i (list v2x v2y v2z)) ;velocita 2 prima dello scontro
     (setq v8i (list v8x v8y v8z)) ;velocita 8 prima dello scontro
     (setq v2i* (trans v2i 0 (list dx28 dy28 dz28)))
     (setq v8i* (trans v8i 0 (list dx28 dy28 dz28)))
     (setq v2i*x (car v2i*) v2i*y (cadr v2i*) v2i*z (caddr v2i*))
     (setq v8i*x (car v8i*) v8i*y (cadr v8i*) v8i*z (caddr v8i*))
     (setq v2f*z (* kur (/ (+ (* (- m2 m8) v2i*z) (* 2 m8 v8i*z)) (+ m2 m8))))
     (setq v8f*z (* kur (/ (+ (* (- m8 m2) v8i*z) (* 2 m2 v2i*z)) (+ m2 m8))))
     (setq v2f* (list v2i*x v2i*y v2f*z))
     (setq v8f* (list v8i*x v8i*y v8f*z))
     (setq v2f (trans v2f* (list dx28 dy28 dz28) 0))
     (setq v8f (trans v8f* (list dx28 dy28 dz28) 0))
     (setq v2x (car v2f) v2y (cadr v2f) v2z (caddr v2f))
     (setq v8x (car v8f) v8y (cadr v8f) v8z (caddr v8f))
    )
   )
  )
  (if (> d38 r38)
   (progn 
    (setq v3x (+ v3x (* a3x t)))  (setq v3y (+ v3y (* a3y t)))  (setq v3z (+ v3z (* a3z t)))
    (setq v8x (+ v8x (* a8x t)))  (setq v8y (+ v8y (* a8y t)))  (setq v8z (+ v8z (* a8z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v3i (list v3x v3y v3z)) ;velocita 3 prima dello scontro
     (setq v8i (list v8x v8y v8z)) ;velocita 8 prima dello scontro
     (setq v3i* (trans v3i 0 (list dx38 dy38 dz38)))
     (setq v8i* (trans v8i 0 (list dx38 dy38 dz38)))
     (setq v3i*x (car v3i*) v3i*y (cadr v3i*) v3i*z (caddr v3i*))
     (setq v8i*x (car v8i*) v8i*y (cadr v8i*) v8i*z (caddr v8i*))
     (setq v3f*z (* kur (/ (+ (* (- m3 m8) v3i*z) (* 2 m8 v8i*z)) (+ m3 m8))))
     (setq v8f*z (* kur (/ (+ (* (- m8 m3) v8i*z) (* 2 m3 v3i*z)) (+ m3 m8))))
     (setq v3f* (list v3i*x v3i*y v3f*z))
     (setq v8f* (list v8i*x v8i*y v8f*z))
     (setq v3f (trans v3f* (list dx38 dy38 dz38) 0))
     (setq v8f (trans v8f* (list dx38 dy38 dz38) 0))
     (setq v3x (car v3f) v3y (cadr v3f) v3z (caddr v3f))
     (setq v8x (car v8f) v8y (cadr v8f) v8z (caddr v8f))
    )
   )
  )
  (if (> d48 r48)
   (progn 
    (setq v4x (+ v4x (* a4x t)))  (setq v4y (+ v4y (* a4y t)))  (setq v4z (+ v4z (* a4z t)))
    (setq v8x (+ v8x (* a8x t)))  (setq v8y (+ v8y (* a8y t)))  (setq v8z (+ v8z (* a8z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v4i (list v4x v4y v4z)) ;velocita 4 prima dello scontro
     (setq v8i (list v8x v8y v8z)) ;velocita 8 prima dello scontro
     (setq v4i* (trans v4i 0 (list dx48 dy48 dz48)))
     (setq v8i* (trans v8i 0 (list dx48 dy48 dz48)))
     (setq v4i*x (car v4i*) v4i*y (cadr v4i*) v4i*z (caddr v4i*))
     (setq v8i*x (car v8i*) v8i*y (cadr v8i*) v8i*z (caddr v8i*))
     (setq v4f*z (* kur (/ (+ (* (- m4 m8) v4i*z) (* 2 m8 v8i*z)) (+ m4 m8))))
     (setq v8f*z (* kur (/ (+ (* (- m8 m4) v8i*z) (* 2 m4 v4i*z)) (+ m4 m8))))
     (setq v4f* (list v4i*x v4i*y v4f*z))
     (setq v8f* (list v8i*x v8i*y v8f*z))
     (setq v4f (trans v4f* (list dx48 dy48 dz48) 0))
     (setq v8f (trans v8f* (list dx48 dy48 dz48) 0))
     (setq v4x (car v4f) v4y (cadr v4f) v4z (caddr v4f))
     (setq v8x (car v8f) v8y (cadr v8f) v8z (caddr v8f))
    )
   )
  )
  (if (> d58 r58)
   (progn 
    (setq v5x (+ v5x (* a5x t)))  (setq v5y (+ v5y (* a5y t)))  (setq v5z (+ v5z (* a5z t)))
    (setq v8x (+ v8x (* a8x t)))  (setq v8y (+ v8y (* a8y t)))  (setq v8z (+ v8z (* a8z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v5i (list v5x v5y v5z)) ;velocita 5 prima dello scontro
     (setq v8i (list v8x v8y v8z)) ;velocita 8 prima dello scontro
     (setq v5i* (trans v5i 0 (list dx58 dy58 dz58)))
     (setq v8i* (trans v8i 0 (list dx58 dy58 dz58)))
     (setq v5i*x (car v5i*) v5i*y (cadr v5i*) v5i*z (caddr v5i*))
     (setq v8i*x (car v8i*) v8i*y (cadr v8i*) v8i*z (caddr v8i*))
     (setq v5f*z (* kur (/ (+ (* (- m5 m8) v5i*z) (* 2 m8 v8i*z)) (+ m5 m8))))
     (setq v8f*z (* kur (/ (+ (* (- m8 m5) v8i*z) (* 2 m5 v5i*z)) (+ m5 m8))))
     (setq v5f* (list v5i*x v5i*y v5f*z))
     (setq v8f* (list v8i*x v8i*y v8f*z))
     (setq v5f (trans v5f* (list dx58 dy58 dz58) 0))
     (setq v8f (trans v8f* (list dx58 dy58 dz58) 0))
     (setq v5x (car v5f) v5y (cadr v5f) v5z (caddr v5f))
     (setq v8x (car v8f) v8y (cadr v8f) v8z (caddr v8f))
    )
   )
  )
  (if (> d68 r68)
   (progn 
    (setq v6x (+ v6x (* a6x t)))  (setq v6y (+ v6y (* a6y t)))  (setq v6z (+ v6z (* a6z t)))
    (setq v8x (+ v8x (* a8x t)))  (setq v8y (+ v8y (* a8y t)))  (setq v8z (+ v8z (* a8z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v6i (list v6x v6y v6z)) ;velocita 6 prima dello scontro
     (setq v8i (list v8x v8y v8z)) ;velocita 8 prima dello scontro
     (setq v6i* (trans v6i 0 (list dx68 dy68 dz68)))
     (setq v8i* (trans v8i 0 (list dx68 dy68 dz68)))
     (setq v6i*x (car v6i*) v6i*y (cadr v6i*) v6i*z (caddr v6i*))
     (setq v8i*x (car v8i*) v8i*y (cadr v8i*) v8i*z (caddr v8i*))
     (setq v6f*z (* kur (/ (+ (* (- m6 m8) v6i*z) (* 2 m8 v8i*z)) (+ m6 m8))))
     (setq v8f*z (* kur (/ (+ (* (- m8 m6) v8i*z) (* 2 m6 v6i*z)) (+ m6 m8))))
     (setq v6f* (list v6i*x v6i*y v6f*z))
     (setq v8f* (list v8i*x v8i*y v8f*z))
     (setq v6f (trans v6f* (list dx68 dy68 dz68) 0))
     (setq v8f (trans v8f* (list dx68 dy68 dz68) 0))
     (setq v6x (car v6f) v6y (cadr v6f) v6z (caddr v6f))
     (setq v8x (car v8f) v8y (cadr v8f) v8z (caddr v8f))
    )
   )
  )
  (if (> d78 r78)
   (progn 
    (setq v7x (+ v7x (* a7x t)))  (setq v7y (+ v7y (* a7y t)))  (setq v7z (+ v7z (* a7z t)))
    (setq v8x (+ v8x (* a8x t)))  (setq v8y (+ v8y (* a8y t)))  (setq v8z (+ v8z (* a8z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v7i (list v7x v7y v7z)) ;velocita 7 prima dello scontro
     (setq v8i (list v8x v8y v8z)) ;velocita 8 prima dello scontro
     (setq v7i* (trans v7i 0 (list dx78 dy78 dz78)))
     (setq v8i* (trans v8i 0 (list dx78 dy78 dz78)))
     (setq v7i*x (car v7i*) v7i*y (cadr v7i*) v7i*z (caddr v7i*))
     (setq v8i*x (car v8i*) v8i*y (cadr v8i*) v8i*z (caddr v8i*))
     (setq v7f*z (* kur (/ (+ (* (- m7 m8) v7i*z) (* 2 m8 v8i*z)) (+ m7 m8))))
     (setq v8f*z (* kur (/ (+ (* (- m8 m7) v8i*z) (* 2 m7 v7i*z)) (+ m7 m8))))
     (setq v7f* (list v7i*x v7i*y v7f*z))
     (setq v8f* (list v8i*x v8i*y v8f*z))
     (setq v7f (trans v7f* (list dx78 dy78 dz78) 0))
     (setq v8f (trans v8f* (list dx78 dy78 dz78) 0))
     (setq v7x (car v7f) v7y (cadr v7f) v7z (caddr v7f))
     (setq v8x (car v8f) v8y (cadr v8f) v8z (caddr v8f))
    )
   )
  )

  (if (< (- x1 r1) xsa) (setq v1x (* (+ (* -2 kbi) 1) v1x) ) )
  (if (< (- y1 r1) ysa) (setq v1y (* (+ (* -2 kbi) 1) v1y) ) )   
  (if (< (- z1 r1) zsa) (setq v1z (* (+ (* -2 kbi) 1) v1z) ) )   
  (if (> (+ x1 r1) xsb) (setq v1x (* (+ (* -2 kbi) 1) v1x) ) )   
  (if (> (+ y1 r1) ysb) (setq v1y (* (+ (* -2 kbi) 1) v1y) ) )   
  (if (> (+ z1 r1) zsb) (setq v1z (* (+ (* -2 kbi) 1) v1z) ) )   
  (if (< (- x2 r2) xsa) (setq v2x (* (+ (* -2 kbi) 1) v2x) ) )   
  (if (< (- y2 r2) ysa) (setq v2y (* (+ (* -2 kbi) 1) v2y) ) )   
  (if (< (- z2 r2) zsa) (setq v2z (* (+ (* -2 kbi) 1) v2z) ) )   
  (if (> (+ x2 r2) xsb) (setq v2x (* (+ (* -2 kbi) 1) v2x) ) )   
  (if (> (+ y2 r2) ysb) (setq v2y (* (+ (* -2 kbi) 1) v2y) ) )   
  (if (> (+ z2 r2) zsb) (setq v2z (* (+ (* -2 kbi) 1) v2z) ) )   
  (if (< (- x3 r3) xsa) (setq v3x (* (+ (* -2 kbi) 1) v3x) ) )   
  (if (< (- y3 r3) ysa) (setq v3y (* (+ (* -2 kbi) 1) v3y) ) )   
  (if (< (- z3 r3) zsa) (setq v3z (* (+ (* -2 kbi) 1) v3z) ) )   
  (if (> (+ x3 r3) xsb) (setq v3x (* (+ (* -2 kbi) 1) v3x) ) )   
  (if (> (+ y3 r3) ysb) (setq v3y (* (+ (* -2 kbi) 1) v3y) ) )   
  (if (> (+ z3 r3) zsb) (setq v3z (* (+ (* -2 kbi) 1) v3z) ) )   
  (if (< (- x4 r4) xsa) (setq v4x (* (+ (* -2 kbi) 1) v4x) ) )   
  (if (< (- y4 r4) ysa) (setq v4y (* (+ (* -2 kbi) 1) v4y) ) )   
  (if (< (- z4 r4) zsa) (setq v4z (* (+ (* -2 kbi) 1) v4z) ) )   
  (if (> (+ x4 r4) xsb) (setq v4x (* (+ (* -2 kbi) 1) v4x) ) )   
  (if (> (+ y4 r4) ysb) (setq v4y (* (+ (* -2 kbi) 1) v4y) ) )   
  (if (> (+ z4 r4) zsb) (setq v4z (* (+ (* -2 kbi) 1) v4z) ) )   
  (if (< (- x5 r5) xsa) (setq v5x (* (+ (* -2 kbi) 1) v5x) ) )   
  (if (< (- y5 r5) ysa) (setq v5y (* (+ (* -2 kbi) 1) v5y) ) )   
  (if (< (- z5 r5) zsa) (setq v5z (* (+ (* -2 kbi) 1) v5z) ) )   
  (if (> (+ x5 r5) xsb) (setq v5x (* (+ (* -2 kbi) 1) v5x) ) )   
  (if (> (+ y5 r5) ysb) (setq v5y (* (+ (* -2 kbi) 1) v5y) ) )   
  (if (> (+ z5 r5) zsb) (setq v5z (* (+ (* -2 kbi) 1) v5z) ) )   
  (if (< (- x6 r6) xsa) (setq v6x (* (+ (* -2 kbi) 1) v6x) ) )   
  (if (< (- y6 r6) ysa) (setq v6y (* (+ (* -2 kbi) 1) v6y) ) )   
  (if (< (- z6 r6) zsa) (setq v6z (* (+ (* -2 kbi) 1) v6z) ) )   
  (if (> (+ x6 r6) xsb) (setq v6x (* (+ (* -2 kbi) 1) v6x) ) )   
  (if (> (+ y6 r6) ysb) (setq v6y (* (+ (* -2 kbi) 1) v6y) ) )   
  (if (> (+ z6 r6) zsb) (setq v6z (* (+ (* -2 kbi) 1) v6z) ) )   
  (if (< (- x7 r7) xsa) (setq v7x (* (+ (* -2 kbi) 1) v7x) ) )   
  (if (< (- y7 r7) ysa) (setq v7y (* (+ (* -2 kbi) 1) v7y) ) )   
  (if (< (- z7 r7) zsa) (setq v7z (* (+ (* -2 kbi) 1) v7z) ) )   
  (if (> (+ x7 r7) xsb) (setq v7x (* (+ (* -2 kbi) 1) v7x) ) )   
  (if (> (+ y7 r7) ysb) (setq v7y (* (+ (* -2 kbi) 1) v7y) ) )   
  (if (> (+ z7 r7) zsb) (setq v7z (* (+ (* -2 kbi) 1) v7z) ) )   
  (if (< (- x8 r8) xsa) (setq v8x (* (+ (* -2 kbi) 1) v8x) ) )   
  (if (< (- y8 r8) ysa) (setq v8y (* (+ (* -2 kbi) 1) v8y) ) )   
  (if (< (- z8 r8) zsa) (setq v8z (* (+ (* -2 kbi) 1) v8z) ) )   
  (if (> (+ x8 r8) xsb) (setq v8x (* (+ (* -2 kbi) 1) v8x) ) )   
  (if (> (+ y8 r8) ysb) (setq v8y (* (+ (* -2 kbi) 1) v8y) ) )   
  (if (> (+ z8 r8) zsb) (setq v8z (* (+ (* -2 kbi) 1) v8z) ) )   

  (setq s1x (+ (* v1x t) (* 0.5 a1x t t)))  (setq s1y (+ (* v1y t) (* 0.5 a1y t t)))  (setq s1z (+ (* v1z t) (* 0.5 a1z t t)))
  (setq s2x (+ (* v2x t) (* 0.5 a2x t t)))  (setq s2y (+ (* v2y t) (* 0.5 a2y t t)))  (setq s2z (+ (* v2z t) (* 0.5 a2z t t)))
  (setq s3x (+ (* v3x t) (* 0.5 a3x t t)))  (setq s3y (+ (* v3y t) (* 0.5 a3y t t)))  (setq s3z (+ (* v3z t) (* 0.5 a3z t t)))
  (setq s4x (+ (* v4x t) (* 0.5 a4x t t)))  (setq s4y (+ (* v4y t) (* 0.5 a4y t t)))  (setq s4z (+ (* v4z t) (* 0.5 a4z t t)))
  (setq s5x (+ (* v5x t) (* 0.5 a5x t t)))  (setq s5y (+ (* v5y t) (* 0.5 a5y t t)))  (setq s5z (+ (* v5z t) (* 0.5 a5z t t)))
  (setq s6x (+ (* v6x t) (* 0.5 a6x t t)))  (setq s6y (+ (* v6y t) (* 0.5 a6y t t)))  (setq s6z (+ (* v6z t) (* 0.5 a6z t t)))
  (setq s7x (+ (* v7x t) (* 0.5 a7x t t)))  (setq s7y (+ (* v7y t) (* 0.5 a7y t t)))  (setq s7z (+ (* v7z t) (* 0.5 a7z t t)))
  (setq s8x (+ (* v8x t) (* 0.5 a8x t t)))  (setq s8y (+ (* v8y t) (* 0.5 a8y t t)))  (setq s8z (+ (* v8z t) (* 0.5 a8z t t)))

  (setq x1 (+ x1 (* k1 s1x)))  (setq y1 (+ y1 (* k1 s1y)))  (setq z1 (+ z1 (* k1 s1z)))
  (setq x2 (+ x2 (* k2 s2x)))  (setq y2 (+ y2 (* k2 s2y)))  (setq z2 (+ z2 (* k2 s2z)))
  (setq x3 (+ x3 (* k3 s3x)))  (setq y3 (+ y3 (* k3 s3y)))  (setq z3 (+ z3 (* k3 s3z)))
  (setq x4 (+ x4 (* k4 s4x)))  (setq y4 (+ y4 (* k4 s4y)))  (setq z4 (+ z4 (* k4 s4z)))
  (setq x5 (+ x5 (* k5 s5x)))  (setq y5 (+ y5 (* k5 s5y)))  (setq z5 (+ z5 (* k5 s5z)))
  (setq x6 (+ x6 (* k6 s6x)))  (setq y6 (+ y6 (* k6 s6y)))  (setq z6 (+ z6 (* k6 s6z)))
  (setq x7 (+ x7 (* k7 s7x)))  (setq y7 (+ y7 (* k7 s7y)))  (setq z7 (+ z7 (* k7 s7z)))
  (setq x8 (+ x8 (* k8 s8x)))  (setq y8 (+ y8 (* k8 s8y)))  (setq z8 (+ z8 (* k8 s8z)))

  (setq a1 (sqrt (+ (* a1x a1x) (* a1y a1y) (* a1z a1z))))
  (setq a2 (sqrt (+ (* a2x a2x) (* a2y a2y) (* a2z a2z))))
  (setq a3 (sqrt (+ (* a3x a3x) (* a3y a3y) (* a3z a3z))))
  (setq a4 (sqrt (+ (* a4x a4x) (* a4y a4y) (* a4z a4z))))
  (setq a5 (sqrt (+ (* a5x a5x) (* a5y a5y) (* a5z a5z))))
  (setq a6 (sqrt (+ (* a6x a6x) (* a6y a6y) (* a6z a6z))))
  (setq a7 (sqrt (+ (* a7x a7x) (* a7y a7y) (* a7z a7z))))
  (setq a8 (sqrt (+ (* a8x a8x) (* a8y a8y) (* a8z a8z))))

  (setq va (+ (abs a1) (abs a2) (abs a3) (abs a4) (abs a5) (abs a6) (abs a7) (abs a8)
              (abs v1) (abs v2) (abs v3) (abs v4) (abs v5) (abs v6) (abs v7) (abs v8)
           )
  )
  (princ "\n")
  (princ va)
  (princ)

  (setq q1 (list x1 y1 z1))
  (setq q2 (list x2 y2 z2))
  (setq q3 (list x3 y3 z3))
  (setq q4 (list x4 y4 z4))
  (setq q5 (list x5 y5 z5))
  (setq q6 (list x6 y6 z6))
  (setq q7 (list x7 y7 z7))
  (setq q8 (list x8 y8 z8))

  (if (= iscan 0)
   (progn
 
   (if (= ker 0)
    (progn
    (if (= pc "p")
        (progn
         (setvar "clayer" "m1") (command "_point" p1)
         (setvar "clayer" "m2") (command "_point" p2)
         (setvar "clayer" "m3") (command "_point" p3)
         (setvar "clayer" "m4") (command "_point" p4)
         (setvar "clayer" "m5") (command "_point" p5)
         (setvar "clayer" "m6") (command "_point" p6)
         (setvar "clayer" "m7") (command "_point" p7)
         (setvar "clayer" "m8") (command "_point" p8)
        )
        (if (= pc "c")
            (progn
             (setvar "clayer" "m1") (command "_circle" p1 r1)
             (setvar "clayer" "m2") (command "_circle" p2 r2)
             (setvar "clayer" "m3") (command "_circle" p3 r3)
             (setvar "clayer" "m4") (command "_circle" p4 r4)
             (setvar "clayer" "m5") (command "_circle" p5 r5)
             (setvar "clayer" "m6") (command "_circle" p6 r6)
             (setvar "clayer" "m7") (command "_circle" p7 r7)
             (setvar "clayer" "m8") (command "_circle" p8 r8)
            )
            (if (= pc "s")
                (progn
                 (setvar "clayer" "m1") (command "_sphere" p1 r1)
                 (setvar "clayer" "m2") (command "_sphere" p2 r2)
                 (setvar "clayer" "m3") (command "_sphere" p3 r3)
                 (setvar "clayer" "m4") (command "_sphere" p4 r4)
                 (setvar "clayer" "m5") (command "_sphere" p5 r5)
                 (setvar "clayer" "m6") (command "_sphere" p6 r6)
                 (setvar "clayer" "m7") (command "_sphere" p7 r7)
                 (setvar "clayer" "m8") (command "_sphere" p8 r8)
                )
            )
        )
    )
    )
    (progn
             (command "_move" o1 "" p1 q1)
             (command "_move" o2 "" p2 q2)
             (command "_move" o3 "" p3 q3)
             (command "_move" o4 "" p4 q4)
             (command "_move" o5 "" p5 q5)
             (command "_move" o6 "" p6 q6)
             (command "_move" o7 "" p7 q7)
             (command "_move" o8 "" p8 q8)
    )    
   )
    
   )

  )
 
  (setq p1 q1)
  (setq p2 q2)  
  (setq p3 q3)  
  (setq p4 q4)  
  (setq p5 q5)  
  (setq p6 q6)  
  (setq p7 q7)  
  (setq p8 q8)  

  (setq iscan (+ 1 iscan))
  (if (= iscan scan) (setq iscan 0))

 )
 (setvar "clayer" "0")
 (command "_pline" p1 p2 p3 p4 p5 p6 p7 p8 p1 "")
)

;;;*****************************************************************
;simula il moto di 10 oggetti sottoposti a forza gravitazionale
;gravita9 ver 1.5 23/07/2010
;Dott. Ing. Emanuele Ballasina
;cell 349-1813748
;mail ballacr75@libero.it

(defun c:gravita9 ()
(setvar "osmode" 0)
(setvar "dimzin" 0)
(setvar "cmdecho" 0)

(command "_-layer" "n" "m1" "_c" 10 "m1" "_s" "m1" "")
(command "_-layer" "n" "m2" "_c" 30 "m2" "_s" "m2" "")
(command "_-layer" "n" "m3" "_c" 50 "m3" "_s" "m3" "")
(command "_-layer" "n" "m4" "_c" 70 "m4" "_s" "m4" "")
(command "_-layer" "n" "m5" "_c" 100 "m5" "_s" "m5" "")
(command "_-layer" "n" "m6" "_c" 130 "m6" "_s" "m6" "")
(command "_-layer" "n" "m7" "_c" 170 "m7" "_s" "m7" "")
(command "_-layer" "n" "m8" "_c" 200 "m8" "_s" "m8" "")
(command "_-layer" "n" "m9" "_c" 230 "m9" "_s" "m9" "")

(setq t 1) ;scansione tempo
(setq kdi 1) ;riduzione diametro cilindri
(setq scan 1) ;scansione posizione (non funziona >1 se ker=1)

(setq m1 100.0) ;massa
(setq m2 100.0)
(setq m3 100.0)
(setq m4 100.0)
(setq m5 100.0)
(setq m6 100.0)
(setq m7 100.0)
(setq m8 100.0)
(setq m9 100.0)
(setq d1 0.1) ;densita
(setq d2 0.1)
(setq d3 0.1) 
(setq d4 0.1)
(setq d5 0.1)
(setq d6 0.1)
(setq d7 0.1)
(setq d8 0.1)
(setq d9 0.1)
(setq r1 (expt (/ m1 d1) 0.3333)) ;raggio
(setq r2 (expt (/ m2 d2) 0.3333))
(setq r3 (expt (/ m3 d3) 0.3333))
(setq r4 (expt (/ m4 d4) 0.3333))
(setq r5 (expt (/ m5 d5) 0.3333))
(setq r6 (expt (/ m6 d6) 0.3333))
(setq r7 (expt (/ m7 d7) 0.3333))
(setq r8 (expt (/ m8 d8) 0.3333))
(setq r9 (expt (/ m9 d9) 0.3333))
(setq r12 (+ r1 r2)) ;distanza di sfioro
(setq r13 (+ r1 r3))
(setq r23 (+ r2 r3))
(setq r14 (+ r1 r4))
(setq r24 (+ r2 r4))
(setq r34 (+ r3 r4))
(setq r15 (+ r1 r5))
(setq r25 (+ r2 r5))
(setq r35 (+ r3 r5))
(setq r45 (+ r4 r5))
(setq r16 (+ r1 r6))
(setq r26 (+ r2 r6))
(setq r36 (+ r3 r6))
(setq r46 (+ r4 r6))
(setq r56 (+ r5 r6))
(setq r17 (+ r1 r7))
(setq r27 (+ r2 r7))
(setq r37 (+ r3 r7))
(setq r47 (+ r4 r7))
(setq r57 (+ r5 r7))
(setq r67 (+ r6 r7))
(setq r18 (+ r1 r8))
(setq r28 (+ r2 r8))
(setq r38 (+ r3 r8))
(setq r48 (+ r4 r8))
(setq r58 (+ r5 r8))
(setq r68 (+ r6 r8))
(setq r78 (+ r7 r8))
(setq r19 (+ r1 r9))
(setq r29 (+ r2 r9))
(setq r39 (+ r3 r9))
(setq r49 (+ r4 r9))
(setq r59 (+ r5 r9))
(setq r69 (+ r6 r9))
(setq r79 (+ r7 r9))
(setq r89 (+ r8 r9))

(setq k1 1) ;abilita movimento pianeta
(setq k2 1)
(setq k3 1)
(setq k4 1)
(setq k5 1)
(setq k6 1)
(setq k7 1)
(setq k8 1)
(setq k9 1)
(setq kur 1) ;abilita urti, con coefficente di rimbalzo, <1 smorza
(setq kbi 1) ;abilita rimbalzo tipo biliardo contro pareti dello schermo, <1 smorza
(setq ker 1) ;1=cancella pianeti vecchi, 0=mantiene tutti i pianeti
(setq c (getvar "VIEWCTR"))
(setq xsc (car c))
(setq ysc (cadr c))
(setq zsc (caddr c))
(setq currh (getvar "viewsize"))
(setq sizex (nth 0 (getvar "screensize")))
(setq sizey (nth 1 (getvar "screensize")))
(setq j (/ sizex sizey))
(setq currw (* j currh))
(setq h2 (/ currh 2.0))
(setq w2 (/ currw 2.0))
(setq xsa (- xsc w2))
(setq ysa (- ysc h2))
(setq zsa (- zsc h2))
(setq xsb (+ xsc w2))
(setq ysb (+ ysc h2))
(setq zsb (+ zsc h2))
(if (/= kbi 0) (command "_rectangle" (list xsa ysa) (list xsb ysb)))

(setq pc "c") ;punti,cerchi,sfere
(setq lc "n") ;abilita disegno linee tra un pianeta e gli altri
(setq tc "n") ;abilita disegno linee traiettoria

(setq x1 0) ;posizione
(setq y1 0)
(setq z1 0)
(setq x2 100)
(setq y2 0)
(setq z2 0)
(setq x3 200)
(setq y3 0)
(setq z3 0)
(setq x4 300)
(setq y4 0)
(setq z4 0)
(setq x5 400)
(setq y5 0)
(setq z5 0)
(setq x6 500)
(setq y6 0)
(setq z6 0)
(setq x7 600)
(setq y7 0) 
(setq z7 0) 
(setq x8 700) 
(setq y8 0) 
(setq z8 0) 
(setq x9 800) 
(setq y9 0) 
(setq z9 0) 

(setq v1x 0.0) ;velocita
(setq v1y 0.0)
(setq v1z 0.0)
(setq v2x 0.0)
(setq v2y 0.0)
(setq v2z 0.0)
(setq v3x 0.0)
(setq v3y 0.0)
(setq v3z 0.0)
(setq v4x 0.0)
(setq v4y 0.0)
(setq v4z 0.0)
(setq v5x 0.0)
(setq v5y 0.0)
(setq v5z 0.0) 
(setq v6x 0.0)
(setq v6y 0.0)
(setq v6z 0.0)
(setq v7x 0.0)
(setq v7y 0.0)
(setq v7z 0.0)
(setq v8x 0.0)
(setq v8y 0.0)
(setq v8z 0.0)
(setq v9x 0.0)
(setq v9y 0.0)
(setq v9z 0.0)

(setq p1 (list x1 y1 z1))
(setq p2 (list x2 y2 z2))
(setq p3 (list x3 y3 z3))
(setq p4 (list x4 y4 z4))
(setq p5 (list x5 y5 z5))
(setq p6 (list x6 y6 z6))
(setq p7 (list x7 y7 z7))
(setq p8 (list x8 y8 z8))
(setq p9 (list x9 y9 z9))

(if (= pc "p")
    (progn
     (setvar "clayer" "m1") (command "_point" p1) (setq o1 (cdr (car (entget (entlast)))))
     (setvar "clayer" "m2") (command "_point" p2) (setq o2 (cdr (car (entget (entlast)))))
     (setvar "clayer" "m3") (command "_point" p3) (setq o3 (cdr (car (entget (entlast)))))
     (setvar "clayer" "m4") (command "_point" p4) (setq o4 (cdr (car (entget (entlast)))))
     (setvar "clayer" "m5") (command "_point" p5) (setq o5 (cdr (car (entget (entlast)))))
     (setvar "clayer" "m6") (command "_point" p6) (setq o6 (cdr (car (entget (entlast)))))
     (setvar "clayer" "m7") (command "_point" p7) (setq o7 (cdr (car (entget (entlast)))))
     (setvar "clayer" "m8") (command "_point" p8) (setq o8 (cdr (car (entget (entlast)))))
     (setvar "clayer" "m9") (command "_point" p9) (setq o9 (cdr (car (entget (entlast)))))
    )
    (if (= pc "c")
        (progn
         (setvar "clayer" "m1") (command "_circle" p1 r1) (setq o1 (cdr (car (entget (entlast)))))
         (setvar "clayer" "m2") (command "_circle" p2 r2) (setq o2 (cdr (car (entget (entlast)))))
         (setvar "clayer" "m3") (command "_circle" p3 r3) (setq o3 (cdr (car (entget (entlast)))))
         (setvar "clayer" "m4") (command "_circle" p4 r4) (setq o4 (cdr (car (entget (entlast)))))
         (setvar "clayer" "m5") (command "_circle" p5 r5) (setq o5 (cdr (car (entget (entlast)))))
         (setvar "clayer" "m6") (command "_circle" p6 r6) (setq o6 (cdr (car (entget (entlast)))))
         (setvar "clayer" "m7") (command "_circle" p7 r7) (setq o7 (cdr (car (entget (entlast)))))
         (setvar "clayer" "m8") (command "_circle" p8 r8) (setq o8 (cdr (car (entget (entlast)))))
         (setvar "clayer" "m9") (command "_circle" p9 r9) (setq o9 (cdr (car (entget (entlast)))))
        )
        (if (= pc "s")
            (progn
             (setvar "clayer" "m1") (command "_sphere" p1 r1) (setq o1 (cdr (car (entget (entlast)))))
             (setvar "clayer" "m2") (command "_sphere" p2 r2) (setq o2 (cdr (car (entget (entlast)))))
             (setvar "clayer" "m3") (command "_sphere" p3 r3) (setq o3 (cdr (car (entget (entlast)))))
             (setvar "clayer" "m4") (command "_sphere" p4 r4) (setq o4 (cdr (car (entget (entlast)))))
             (setvar "clayer" "m5") (command "_sphere" p5 r5) (setq o5 (cdr (car (entget (entlast)))))
             (setvar "clayer" "m6") (command "_sphere" p6 r6) (setq o6 (cdr (car (entget (entlast)))))
             (setvar "clayer" "m7") (command "_sphere" p7 r7) (setq o7 (cdr (car (entget (entlast)))))
             (setvar "clayer" "m8") (command "_sphere" p8 r8) (setq o8 (cdr (car (entget (entlast)))))
             (setvar "clayer" "m9") (command "_sphere" p9 r9) (setq o9 (cdr (car (entget (entlast)))))
            )
        )
    )
)

(setq va 1000)
(setq iscan 0)
 (while (> va 0.0001) ;scansione velocit ed accelerazione, se = 0 si ferma il lisp

  (setq v1 (sqrt (+ (* v1x v1x) (* v1y v1y) (* v1z v1z))))
  (setq v2 (sqrt (+ (* v2x v2x) (* v2y v2y) (* v2z v2z))))
  (setq v3 (sqrt (+ (* v3x v3x) (* v3y v3y) (* v3z v3z))))
  (setq v4 (sqrt (+ (* v4x v4x) (* v4y v4y) (* v4z v4z))))
  (setq v5 (sqrt (+ (* v5x v5x) (* v5y v5y) (* v5z v5z))))
  (setq v6 (sqrt (+ (* v6x v6x) (* v6y v6y) (* v6z v6z))))
  (setq v7 (sqrt (+ (* v7x v7x) (* v7y v7y) (* v7z v7z))))
  (setq v8 (sqrt (+ (* v8x v8x) (* v8y v8y) (* v8z v8z))))
  (setq v9 (sqrt (+ (* v9x v9x) (* v9y v9y) (* v9z v9z))))
  
  (setq d12 (distance p1 p2))
  (setq d13 (distance p1 p3))
  (setq d23 (distance p2 p3))
  (setq d14 (distance p1 p4))
  (setq d24 (distance p2 p4))
  (setq d34 (distance p3 p4))
  (setq d15 (distance p1 p5))
  (setq d25 (distance p2 p5))
  (setq d35 (distance p3 p5))
  (setq d45 (distance p4 p5))
  (setq d16 (distance p1 p6))
  (setq d26 (distance p2 p6))
  (setq d36 (distance p3 p6))
  (setq d46 (distance p4 p6))
  (setq d56 (distance p5 p6))
  (setq d17 (distance p1 p7))
  (setq d27 (distance p2 p7))
  (setq d37 (distance p3 p7))
  (setq d47 (distance p4 p7))
  (setq d57 (distance p5 p7))
  (setq d67 (distance p6 p7))
  (setq d18 (distance p1 p8))
  (setq d28 (distance p2 p8))
  (setq d38 (distance p3 p8))
  (setq d48 (distance p4 p8))
  (setq d58 (distance p5 p8))
  (setq d68 (distance p6 p8))
  (setq d78 (distance p7 p8))
  (setq d19 (distance p1 p9))
  (setq d29 (distance p2 p9))
  (setq d39 (distance p3 p9))
  (setq d49 (distance p4 p9))
  (setq d59 (distance p5 p9))
  (setq d69 (distance p6 p9))
  (setq d79 (distance p7 p9))
  (setq d89 (distance p8 p9))

  (setq dx12 (- x2 x1))  (setq dy12 (- y2 y1))  (setq dz12 (- z2 z1))
  (setq dx13 (- x3 x1))  (setq dy13 (- y3 y1))  (setq dz13 (- z3 z1))
  (setq dx23 (- x3 x2))  (setq dy23 (- y3 y2))  (setq dz23 (- z3 z2))
  (setq dx14 (- x4 x1))  (setq dy14 (- y4 y1))  (setq dz14 (- z4 z1))
  (setq dx24 (- x4 x2))  (setq dy24 (- y4 y2))  (setq dz24 (- z4 z2))
  (setq dx34 (- x4 x3))  (setq dy34 (- y4 y3))  (setq dz34 (- z4 z3))
  (setq dx15 (- x5 x1))  (setq dy15 (- y5 y1))  (setq dz15 (- z5 z1))
  (setq dx25 (- x5 x2))  (setq dy25 (- y5 y2))  (setq dz25 (- z5 z2))
  (setq dx35 (- x5 x3))  (setq dy35 (- y5 y3))  (setq dz35 (- z5 z3))
  (setq dx45 (- x5 x4))  (setq dy45 (- y5 y4))  (setq dz45 (- z5 z4))
  (setq dx16 (- x6 x1))  (setq dy16 (- y6 y1))  (setq dz16 (- z6 z1))
  (setq dx26 (- x6 x2))  (setq dy26 (- y6 y2))  (setq dz26 (- z6 z2))
  (setq dx36 (- x6 x3))  (setq dy36 (- y6 y3))  (setq dz36 (- z6 z3))
  (setq dx46 (- x6 x4))  (setq dy46 (- y6 y4))  (setq dz46 (- z6 z4))
  (setq dx56 (- x6 x5))  (setq dy56 (- y6 y5))  (setq dz56 (- z6 z5))
  (setq dx17 (- x7 x1))  (setq dy17 (- y7 y1))  (setq dz17 (- z7 z1))
  (setq dx27 (- x7 x2))  (setq dy27 (- y7 y2))  (setq dz27 (- z7 z2))
  (setq dx37 (- x7 x3))  (setq dy37 (- y7 y3))  (setq dz37 (- z7 z3))
  (setq dx47 (- x7 x4))  (setq dy47 (- y7 y4))  (setq dz47 (- z7 z4))
  (setq dx57 (- x7 x5))  (setq dy57 (- y7 y5))  (setq dz57 (- z7 z5))
  (setq dx67 (- x7 x6))  (setq dy67 (- y7 y6))  (setq dz67 (- z7 z6))
  (setq dx18 (- x8 x1))  (setq dy18 (- y8 y1))  (setq dz18 (- z8 z1))
  (setq dx28 (- x8 x2))  (setq dy28 (- y8 y2))  (setq dz28 (- z8 z2))
  (setq dx38 (- x8 x3))  (setq dy38 (- y8 y3))  (setq dz38 (- z8 z3))
  (setq dx48 (- x8 x4))  (setq dy48 (- y8 y4))  (setq dz48 (- z8 z4))
  (setq dx58 (- x8 x5))  (setq dy58 (- y8 y5))  (setq dz58 (- z8 z5))
  (setq dx68 (- x8 x6))  (setq dy68 (- y8 y6))  (setq dz68 (- z8 z6))
  (setq dx78 (- x8 x7))  (setq dy78 (- y8 y7))  (setq dz78 (- z8 z7))
  (setq dx19 (- x9 x1))  (setq dy19 (- y9 y1))  (setq dz19 (- z9 z1))
  (setq dx29 (- x9 x2))  (setq dy29 (- y9 y2))  (setq dz29 (- z9 z2))
  (setq dx39 (- x9 x3))  (setq dy39 (- y9 y3))  (setq dz39 (- z9 z3))
  (setq dx49 (- x9 x4))  (setq dy49 (- y9 y4))  (setq dz49 (- z9 z4))
  (setq dx59 (- x9 x5))  (setq dy59 (- y9 y5))  (setq dz59 (- z9 z5))
  (setq dx69 (- x9 x6))  (setq dy69 (- y9 y6))  (setq dz69 (- z9 z6))
  (setq dx79 (- x9 x7))  (setq dy79 (- y9 y7))  (setq dz79 (- z9 z7))
  (setq dx89 (- x9 x8))  (setq dy89 (- y9 y8))  (setq dz89 (- z9 z8))

;                   GRAVITA              REPULSIONE           ELASTICO       MOLLA
  (if (<= d12 r12) (setq d12 r12))
  (if (<= d13 r13) (setq d13 r13))
  (if (<= d23 r23) (setq d23 r23))
  (if (<= d14 r14) (setq d14 r14))
  (if (<= d24 r24) (setq d24 r24))
  (if (<= d34 r34) (setq d34 r34))
  (if (<= d15 r15) (setq d15 r15))
  (if (<= d25 r25) (setq d25 r25))
  (if (<= d35 r35) (setq d35 r35))
  (if (<= d45 r45) (setq d45 r45))
  (if (<= d16 r16) (setq d16 r16))
  (if (<= d26 r26) (setq d26 r26))
  (if (<= d36 r36) (setq d36 r36))
  (if (<= d46 r46) (setq d46 r46))
  (if (<= d56 r56) (setq d56 r56))
  (if (<= d17 r17) (setq d17 r17))
  (if (<= d27 r27) (setq d27 r27))
  (if (<= d37 r37) (setq d37 r37))
  (if (<= d47 r47) (setq d47 r47))
  (if (<= d57 r57) (setq d57 r57))
  (if (<= d67 r67) (setq d67 r67))
  (if (<= d18 r18) (setq d18 r18))
  (if (<= d28 r28) (setq d28 r28))
  (if (<= d38 r38) (setq d38 r38))
  (if (<= d48 r48) (setq d48 r48))
  (if (<= d58 r58) (setq d58 r58))
  (if (<= d68 r68) (setq d68 r68))
  (if (<= d78 r78) (setq d78 r78))
  (if (<= d19 r19) (setq d19 r19))
  (if (<= d29 r29) (setq d29 r29))
  (if (<= d39 r39) (setq d39 r39))
  (if (<= d49 r49) (setq d49 r49))
  (if (<= d59 r59) (setq d59 r59))
  (if (<= d69 r69) (setq d69 r69))
  (if (<= d79 r79) (setq d79 r79))
  (if (<= d89 r89) (setq d89 r89))
  (setq f12 (+ (* 1 (fgr m1 m2 d12)) (* 1 (fre m1 m2 d12)) (* 1 (fel d12)) (* 1 (fmo d12)) ))
  (setq f13 (+ (* 1 (fgr m1 m3 d13)) (* 1 (fre m1 m3 d13)) (* 1 (fel d13)) (* 1 (fmo d13)) ))
  (setq f23 (+ (* 1 (fgr m2 m3 d23)) (* 1 (fre m2 m3 d23)) (* 1 (fel d23)) (* 1 (fmo d23)) ))
  (setq f14 (+ (* 1 (fgr m1 m4 d14)) (* 1 (fre m1 m4 d14)) (* 1 (fel d14)) (* 1 (fmo d14)) ))
  (setq f24 (+ (* 1 (fgr m2 m4 d24)) (* 1 (fre m2 m4 d24)) (* 1 (fel d24)) (* 1 (fmo d24)) ))
  (setq f34 (+ (* 1 (fgr m3 m4 d34)) (* 1 (fre m3 m4 d34)) (* 1 (fel d34)) (* 1 (fmo d34)) ))
  (setq f15 (+ (* 1 (fgr m1 m5 d15)) (* 1 (fre m1 m5 d15)) (* 1 (fel d15)) (* 1 (fmo d15)) ))
  (setq f25 (+ (* 1 (fgr m2 m5 d25)) (* 1 (fre m2 m5 d25)) (* 1 (fel d25)) (* 1 (fmo d25)) ))
  (setq f35 (+ (* 1 (fgr m3 m5 d35)) (* 1 (fre m3 m5 d35)) (* 1 (fel d35)) (* 1 (fmo d35)) ))
  (setq f45 (+ (* 1 (fgr m4 m5 d45)) (* 1 (fre m4 m5 d45)) (* 1 (fel d45)) (* 1 (fmo d45)) ))
  (setq f16 (+ (* 1 (fgr m1 m6 d16)) (* 1 (fre m1 m6 d16)) (* 1 (fel d16)) (* 1 (fmo d16)) ))
  (setq f26 (+ (* 1 (fgr m2 m6 d26)) (* 1 (fre m2 m6 d26)) (* 1 (fel d26)) (* 1 (fmo d26)) ))
  (setq f36 (+ (* 1 (fgr m3 m6 d36)) (* 1 (fre m3 m6 d36)) (* 1 (fel d36)) (* 1 (fmo d36)) ))
  (setq f46 (+ (* 1 (fgr m4 m6 d46)) (* 1 (fre m4 m6 d46)) (* 1 (fel d46)) (* 1 (fmo d46)) ))
  (setq f56 (+ (* 1 (fgr m5 m6 d56)) (* 1 (fre m5 m6 d56)) (* 1 (fel d56)) (* 1 (fmo d56)) ))
  (setq f17 (+ (* 1 (fgr m1 m7 d17)) (* 1 (fre m1 m7 d17)) (* 1 (fel d17)) (* 1 (fmo d17)) ))
  (setq f27 (+ (* 1 (fgr m2 m7 d27)) (* 1 (fre m2 m7 d27)) (* 1 (fel d27)) (* 1 (fmo d27)) ))
  (setq f37 (+ (* 1 (fgr m3 m7 d37)) (* 1 (fre m3 m7 d37)) (* 1 (fel d37)) (* 1 (fmo d37)) ))
  (setq f47 (+ (* 1 (fgr m4 m7 d47)) (* 1 (fre m4 m7 d47)) (* 1 (fel d47)) (* 1 (fmo d47)) ))
  (setq f57 (+ (* 1 (fgr m5 m7 d57)) (* 1 (fre m5 m7 d57)) (* 1 (fel d57)) (* 1 (fmo d57)) ))
  (setq f67 (+ (* 1 (fgr m6 m7 d67)) (* 1 (fre m6 m7 d67)) (* 1 (fel d67)) (* 1 (fmo d67)) ))
  (setq f18 (+ (* 1 (fgr m1 m8 d18)) (* 1 (fre m1 m8 d18)) (* 1 (fel d18)) (* 1 (fmo d18)) ))
  (setq f28 (+ (* 1 (fgr m2 m8 d28)) (* 1 (fre m2 m8 d28)) (* 1 (fel d28)) (* 1 (fmo d28)) ))
  (setq f38 (+ (* 1 (fgr m3 m8 d38)) (* 1 (fre m3 m8 d38)) (* 1 (fel d38)) (* 1 (fmo d38)) ))
  (setq f48 (+ (* 1 (fgr m4 m8 d48)) (* 1 (fre m4 m8 d48)) (* 1 (fel d48)) (* 1 (fmo d48)) ))
  (setq f58 (+ (* 1 (fgr m5 m8 d58)) (* 1 (fre m5 m8 d58)) (* 1 (fel d58)) (* 1 (fmo d58)) ))
  (setq f68 (+ (* 1 (fgr m6 m8 d68)) (* 1 (fre m6 m8 d68)) (* 1 (fel d68)) (* 1 (fmo d68)) ))
  (setq f78 (+ (* 1 (fgr m7 m8 d78)) (* 1 (fre m7 m8 d78)) (* 1 (fel d78)) (* 1 (fmo d78)) ))
  (setq f19 (+ (* 1 (fgr m1 m9 d19)) (* 1 (fre m1 m9 d19)) (* 1 (fel d19)) (* 1 (fmo d19)) ))
  (setq f29 (+ (* 1 (fgr m2 m9 d29)) (* 1 (fre m2 m9 d29)) (* 1 (fel d29)) (* 1 (fmo d29)) ))
  (setq f39 (+ (* 1 (fgr m3 m9 d39)) (* 1 (fre m3 m9 d39)) (* 1 (fel d39)) (* 1 (fmo d39)) ))
  (setq f49 (+ (* 1 (fgr m4 m9 d49)) (* 1 (fre m4 m9 d49)) (* 1 (fel d49)) (* 1 (fmo d49)) ))
  (setq f59 (+ (* 1 (fgr m5 m9 d59)) (* 1 (fre m5 m9 d59)) (* 1 (fel d59)) (* 1 (fmo d59)) ))
  (setq f69 (+ (* 1 (fgr m6 m9 d69)) (* 1 (fre m6 m9 d69)) (* 1 (fel d69)) (* 1 (fmo d69)) ))
  (setq f79 (+ (* 1 (fgr m7 m9 d79)) (* 1 (fre m7 m9 d79)) (* 1 (fel d79)) (* 1 (fmo d79)) ))
  (setq f89 (+ (* 1 (fgr m8 m9 d89)) (* 1 (fre m8 m9 d89)) (* 1 (fel d89)) (* 1 (fmo d89)) ))

  (setq a12 (/ f12 m1))  (setq a21 (* -1 (/ f12 m2)))
  (setq a13 (/ f13 m1))  (setq a31 (* -1 (/ f13 m3)))
  (setq a23 (/ f23 m2))  (setq a32 (* -1 (/ f23 m3)))
  (setq a14 (/ f14 m1))  (setq a41 (* -1 (/ f14 m4)))
  (setq a24 (/ f24 m2))  (setq a42 (* -1 (/ f24 m4)))
  (setq a34 (/ f34 m3))  (setq a43 (* -1 (/ f34 m4)))
  (setq a15 (/ f15 m1))  (setq a51 (* -1 (/ f15 m5)))
  (setq a25 (/ f25 m2))  (setq a52 (* -1 (/ f25 m5)))
  (setq a35 (/ f35 m3))  (setq a53 (* -1 (/ f35 m5)))
  (setq a45 (/ f45 m4))  (setq a54 (* -1 (/ f45 m5)))
  (setq a16 (/ f16 m1))  (setq a61 (* -1 (/ f16 m6)))
  (setq a26 (/ f26 m2))  (setq a62 (* -1 (/ f26 m6)))
  (setq a36 (/ f36 m3))  (setq a63 (* -1 (/ f36 m6)))
  (setq a46 (/ f46 m4))  (setq a64 (* -1 (/ f46 m6)))
  (setq a56 (/ f56 m5))  (setq a65 (* -1 (/ f56 m6)))
  (setq a17 (/ f17 m1))  (setq a71 (* -1 (/ f17 m7)))
  (setq a27 (/ f27 m2))  (setq a72 (* -1 (/ f27 m7)))
  (setq a37 (/ f37 m3))  (setq a73 (* -1 (/ f37 m7)))
  (setq a47 (/ f47 m4))  (setq a74 (* -1 (/ f47 m7)))
  (setq a57 (/ f57 m5))  (setq a75 (* -1 (/ f57 m7)))
  (setq a67 (/ f67 m6))  (setq a76 (* -1 (/ f67 m7)))
  (setq a18 (/ f18 m1))  (setq a81 (* -1 (/ f18 m8)))
  (setq a28 (/ f28 m2))  (setq a82 (* -1 (/ f28 m8)))
  (setq a38 (/ f38 m3))  (setq a83 (* -1 (/ f38 m8)))
  (setq a48 (/ f48 m4))  (setq a84 (* -1 (/ f48 m8)))
  (setq a58 (/ f58 m5))  (setq a85 (* -1 (/ f58 m8)))
  (setq a68 (/ f68 m6))  (setq a86 (* -1 (/ f68 m8)))
  (setq a78 (/ f78 m7))  (setq a87 (* -1 (/ f78 m8)))
  (setq a19 (/ f19 m1))  (setq a91 (* -1 (/ f19 m9)))
  (setq a29 (/ f29 m2))  (setq a92 (* -1 (/ f29 m9)))
  (setq a39 (/ f39 m3))  (setq a93 (* -1 (/ f39 m9)))
  (setq a49 (/ f49 m4))  (setq a94 (* -1 (/ f49 m9)))
  (setq a59 (/ f59 m5))  (setq a95 (* -1 (/ f59 m9)))
  (setq a69 (/ f69 m6))  (setq a96 (* -1 (/ f69 m9)))
  (setq a79 (/ f79 m7))  (setq a97 (* -1 (/ f79 m9)))
  (setq a89 (/ f89 m8))  (setq a98 (* -1 (/ f89 m9)))
 
  (setq a1x (+ (* 1 (/ (fsx x1 y1 z1) m1)) (* 1 (/ (fwx r1) m1)) (* 1 v1x (/ (fvi m1 r1 v1) m1)) (/ (* a12 dx12) d12) (/ (* a13 dx13) d13) (/ (* a14 dx14) d14) (/ (* a15 dx15) d15) (/ (* a16 dx16) d16) (/ (* a17 dx17) d17) (/ (* a18 dx18) d18) (/ (* a19 dx19) d19) ))
  (setq a1y (+ (* 1 (/ (fsy x1 y1 z1) m1)) (* 1 (/ (fwy r1) m1)) (* 1 v1y (/ (fvi m1 r1 v1) m1)) (/ (* a12 dy12) d12) (/ (* a13 dy13) d13) (/ (* a14 dy14) d14) (/ (* a15 dy15) d15) (/ (* a16 dy16) d16) (/ (* a17 dy17) d17) (/ (* a18 dy18) d18) (/ (* a19 dy19) d19) ))
  (setq a1z (+ (* 1 (/ (fsz x1 y1 z1) m1)) (* 1 (/ (fwz r1) m1)) (* 1 v1z (/ (fvi m1 r1 v1) m1)) (/ (* a12 dz12) d12) (/ (* a13 dz13) d13) (/ (* a14 dz14) d14) (/ (* a15 dz15) d15) (/ (* a16 dz16) d16) (/ (* a17 dz17) d17) (/ (* a18 dz18) d18) (/ (* a19 dz19) d19) ))
  (setq a2x (+ (* 1 (/ (fsx x2 y2 z2) m2)) (* 1 (/ (fwx r2) m2)) (* 1 v2x (/ (fvi m2 r2 v2) m2)) (/ (* a21 dx12) d12) (/ (* a23 dx23) d23) (/ (* a24 dx24) d24) (/ (* a25 dx25) d25) (/ (* a26 dx26) d26) (/ (* a27 dx27) d27) (/ (* a28 dx28) d28) (/ (* a29 dx29) d29) ))
  (setq a2y (+ (* 1 (/ (fsy x2 y2 z2) m2)) (* 1 (/ (fwy r2) m2)) (* 1 v2y (/ (fvi m2 r2 v2) m2)) (/ (* a21 dy12) d12) (/ (* a23 dy23) d23) (/ (* a24 dy24) d24) (/ (* a25 dy25) d25) (/ (* a26 dy26) d26) (/ (* a27 dy27) d27) (/ (* a28 dy28) d28) (/ (* a29 dy29) d29) ))
  (setq a2z (+ (* 1 (/ (fsz x2 y2 z2) m2)) (* 1 (/ (fwz r2) m2)) (* 1 v2z (/ (fvi m2 r2 v2) m2)) (/ (* a21 dz12) d12) (/ (* a23 dz23) d23) (/ (* a24 dz24) d24) (/ (* a25 dz25) d25) (/ (* a26 dz26) d26) (/ (* a27 dz27) d27) (/ (* a28 dz28) d28) (/ (* a29 dz29) d29) ))
  (setq a3x (+ (* 1 (/ (fsx x3 y3 z3) m3)) (* 1 (/ (fwx r3) m3)) (* 1 v3x (/ (fvi m3 r3 v3) m3)) (/ (* a31 dx13) d13) (/ (* a32 dx23) d23) (/ (* a34 dx34) d34) (/ (* a35 dx35) d35) (/ (* a36 dx36) d36) (/ (* a37 dx37) d37) (/ (* a38 dx38) d38) (/ (* a39 dx39) d39) ))
  (setq a3y (+ (* 1 (/ (fsy x3 y3 z3) m3)) (* 1 (/ (fwy r3) m3)) (* 1 v3y (/ (fvi m3 r3 v3) m3)) (/ (* a31 dy13) d13) (/ (* a32 dy23) d23) (/ (* a34 dy34) d34) (/ (* a35 dy35) d35) (/ (* a36 dy36) d36) (/ (* a37 dy37) d37) (/ (* a38 dy38) d38) (/ (* a39 dy39) d39) ))
  (setq a3z (+ (* 1 (/ (fsz x3 y3 z3) m3)) (* 1 (/ (fwz r3) m3)) (* 1 v3z (/ (fvi m3 r3 v3) m3)) (/ (* a31 dz13) d13) (/ (* a32 dz23) d23) (/ (* a34 dz34) d34) (/ (* a35 dz35) d35) (/ (* a36 dz36) d36) (/ (* a37 dz37) d37) (/ (* a38 dz38) d38) (/ (* a39 dz39) d39) ))
  (setq a4x (+ (* 1 (/ (fsx x4 y4 z4) m4)) (* 1 (/ (fwx r4) m4)) (* 1 v4x (/ (fvi m4 r4 v4) m4)) (/ (* a41 dx14) d14) (/ (* a42 dx24) d24) (/ (* a43 dx34) d34) (/ (* a45 dx45) d45) (/ (* a46 dx46) d46) (/ (* a47 dx47) d47) (/ (* a48 dx48) d48) (/ (* a49 dx49) d49) ))
  (setq a4y (+ (* 1 (/ (fsy x4 y4 z4) m4)) (* 1 (/ (fwy r4) m4)) (* 1 v4y (/ (fvi m4 r4 v4) m4)) (/ (* a41 dy14) d14) (/ (* a42 dy24) d24) (/ (* a43 dy34) d34) (/ (* a45 dy45) d45) (/ (* a46 dy46) d46) (/ (* a47 dy47) d47) (/ (* a48 dy48) d48) (/ (* a49 dy49) d49) ))
  (setq a4z (+ (* 1 (/ (fsz x4 y4 z4) m4)) (* 1 (/ (fwz r4) m4)) (* 1 v4z (/ (fvi m4 r4 v4) m4)) (/ (* a41 dz14) d14) (/ (* a42 dz24) d24) (/ (* a43 dz34) d34) (/ (* a45 dz45) d45) (/ (* a46 dz46) d46) (/ (* a47 dz47) d47) (/ (* a48 dz48) d48) (/ (* a49 dz49) d49) ))
  (setq a5x (+ (* 1 (/ (fsx x5 y5 z5) m5)) (* 1 (/ (fwx r5) m5)) (* 1 v5x (/ (fvi m5 r5 v5) m5)) (/ (* a51 dx15) d15) (/ (* a52 dx25) d25) (/ (* a53 dx35) d35) (/ (* a54 dx45) d45) (/ (* a56 dx56) d56) (/ (* a57 dx57) d57) (/ (* a58 dx58) d58) (/ (* a59 dx59) d59) ))
  (setq a5y (+ (* 1 (/ (fsy x5 y5 z5) m5)) (* 1 (/ (fwy r5) m5)) (* 1 v5y (/ (fvi m5 r5 v5) m5)) (/ (* a51 dy15) d15) (/ (* a52 dy25) d25) (/ (* a53 dy35) d35) (/ (* a54 dy45) d45) (/ (* a56 dy56) d56) (/ (* a57 dy57) d57) (/ (* a58 dy58) d58) (/ (* a59 dy59) d59) ))
  (setq a5z (+ (* 1 (/ (fsz x5 y5 z5) m5)) (* 1 (/ (fwz r5) m5)) (* 1 v5z (/ (fvi m5 r5 v5) m5)) (/ (* a51 dz15) d15) (/ (* a52 dz25) d25) (/ (* a53 dz35) d35) (/ (* a54 dz45) d45) (/ (* a56 dz56) d56) (/ (* a57 dz57) d57) (/ (* a58 dz58) d58) (/ (* a59 dz59) d59) ))
  (setq a6x (+ (* 1 (/ (fsx x6 y6 z6) m6)) (* 1 (/ (fwx r6) m6)) (* 1 v6x (/ (fvi m6 r6 v6) m6)) (/ (* a61 dx16) d16) (/ (* a62 dx26) d26) (/ (* a63 dx36) d36) (/ (* a64 dx46) d46) (/ (* a65 dx56) d56) (/ (* a67 dx67) d67) (/ (* a68 dx68) d68) (/ (* a69 dx69) d69) ))
  (setq a6y (+ (* 1 (/ (fsy x6 y6 z6) m6)) (* 1 (/ (fwy r6) m6)) (* 1 v6y (/ (fvi m6 r6 v6) m6)) (/ (* a61 dy16) d16) (/ (* a62 dy26) d26) (/ (* a63 dy36) d36) (/ (* a64 dy46) d46) (/ (* a65 dy56) d56) (/ (* a67 dy67) d67) (/ (* a68 dy68) d68) (/ (* a69 dy69) d69) ))
  (setq a6z (+ (* 1 (/ (fsz x6 y6 z6) m6)) (* 1 (/ (fwz r6) m6)) (* 1 v6z (/ (fvi m6 r6 v6) m6)) (/ (* a61 dz16) d16) (/ (* a62 dz26) d26) (/ (* a63 dz36) d36) (/ (* a64 dz46) d46) (/ (* a65 dz56) d56) (/ (* a67 dz67) d67) (/ (* a68 dz68) d68) (/ (* a69 dz69) d69) ))
  (setq a7x (+ (* 1 (/ (fsx x7 y7 z7) m7)) (* 1 (/ (fwx r7) m7)) (* 1 v7x (/ (fvi m7 r7 v7) m7)) (/ (* a71 dx17) d17) (/ (* a72 dx27) d27) (/ (* a73 dx37) d37) (/ (* a74 dx47) d47) (/ (* a75 dx57) d57) (/ (* a76 dx67) d67) (/ (* a78 dx78) d78) (/ (* a79 dx79) d79) ))
  (setq a7y (+ (* 1 (/ (fsy x7 y7 z7) m7)) (* 1 (/ (fwy r7) m7)) (* 1 v7y (/ (fvi m7 r7 v7) m7)) (/ (* a71 dy17) d17) (/ (* a72 dy27) d27) (/ (* a73 dy37) d37) (/ (* a74 dy47) d47) (/ (* a75 dy57) d57) (/ (* a76 dy67) d67) (/ (* a78 dy78) d78) (/ (* a79 dy79) d79) ))
  (setq a7z (+ (* 1 (/ (fsz x7 y7 z7) m7)) (* 1 (/ (fwz r7) m7)) (* 1 v7z (/ (fvi m7 r7 v7) m7)) (/ (* a71 dz17) d17) (/ (* a72 dz27) d27) (/ (* a73 dz37) d37) (/ (* a74 dz47) d47) (/ (* a75 dz57) d57) (/ (* a76 dz67) d67) (/ (* a78 dz78) d78) (/ (* a79 dz79) d79) ))
  (setq a8x (+ (* 1 (/ (fsx x8 y8 z8) m8)) (* 1 (/ (fwx r8) m8)) (* 1 v8x (/ (fvi m8 r8 v8) m8)) (/ (* a81 dx18) d18) (/ (* a82 dx28) d28) (/ (* a83 dx38) d38) (/ (* a84 dx48) d48) (/ (* a85 dx58) d58) (/ (* a86 dx68) d68) (/ (* a87 dx78) d78) (/ (* a89 dx89) d89) ))
  (setq a8y (+ (* 1 (/ (fsy x8 y8 z8) m8)) (* 1 (/ (fwy r8) m8)) (* 1 v8y (/ (fvi m8 r8 v8) m8)) (/ (* a81 dy18) d18) (/ (* a82 dy28) d28) (/ (* a83 dy38) d38) (/ (* a84 dy48) d48) (/ (* a85 dy58) d58) (/ (* a86 dy68) d68) (/ (* a87 dy78) d78) (/ (* a89 dy89) d89) ))
  (setq a8z (+ (* 1 (/ (fsz x8 y8 z8) m8)) (* 1 (/ (fwz r8) m8)) (* 1 v8z (/ (fvi m8 r8 v8) m8)) (/ (* a81 dz18) d18) (/ (* a82 dz28) d28) (/ (* a83 dz38) d38) (/ (* a84 dz48) d48) (/ (* a85 dz58) d58) (/ (* a86 dz68) d68) (/ (* a87 dz78) d78) (/ (* a89 dz89) d89) ))
  (setq a9x (+ (* 1 (/ (fsx x9 y9 z9) m9)) (* 1 (/ (fwx r9) m9)) (* 1 v9x (/ (fvi m9 r9 v9) m9)) (/ (* a91 dx19) d19) (/ (* a92 dx29) d29) (/ (* a93 dx39) d39) (/ (* a94 dx49) d49) (/ (* a95 dx59) d59) (/ (* a96 dx69) d69) (/ (* a97 dx79) d79) (/ (* a98 dx89) d89) ))
  (setq a9y (+ (* 1 (/ (fsy x9 y9 z9) m9)) (* 1 (/ (fwy r9) m9)) (* 1 v9y (/ (fvi m9 r9 v9) m9)) (/ (* a91 dy19) d19) (/ (* a92 dy29) d29) (/ (* a93 dy39) d39) (/ (* a94 dy49) d49) (/ (* a95 dy59) d59) (/ (* a96 dy69) d69) (/ (* a97 dy79) d79) (/ (* a98 dy89) d89) ))
  (setq a9z (+ (* 1 (/ (fsz x9 y9 z9) m9)) (* 1 (/ (fwz r9) m9)) (* 1 v9z (/ (fvi m9 r9 v9) m9)) (/ (* a91 dz19) d19) (/ (* a92 dz29) d29) (/ (* a93 dz39) d39) (/ (* a94 dz49) d49) (/ (* a95 dz59) d59) (/ (* a96 dz69) d69) (/ (* a97 dz79) d79) (/ (* a98 dz89) d89) ))

  (if (> d12 r12)
   (progn 
    (setq v1x (+ v1x (* a1x t)))  (setq v1y (+ v1y (* a1y t)))  (setq v1z (+ v1z (* a1z t)))
    (setq v2x (+ v2x (* a2x t)))  (setq v2y (+ v2y (* a2y t)))  (setq v2z (+ v2z (* a2z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v1i (list v1x v1y v1z)) ;velocita 1 prima dello scontro
     (setq v2i (list v2x v2y v2z)) ;velocita 2 prima dello scontro
     (setq v1i* (trans v1i 0 (list dx12 dy12 dz12)))
     (setq v2i* (trans v2i 0 (list dx12 dy12 dz12)))
     (setq v1i*x (car v1i*) v1i*y (cadr v1i*) v1i*z (caddr v1i*))
     (setq v2i*x (car v2i*) v2i*y (cadr v2i*) v2i*z (caddr v2i*))
     (setq v1f*z (* kur (/ (+ (* (- m1 m2) v1i*z) (* 2 m2 v2i*z)) (+ m1 m2))))
     (setq v2f*z (* kur (/ (+ (* (- m2 m1) v2i*z) (* 2 m1 v1i*z)) (+ m1 m2))))
     (setq v1f* (list v1i*x v1i*y v1f*z))
     (setq v2f* (list v2i*x v2i*y v2f*z))
     (setq v1f (trans v1f* (list dx12 dy12 dz12) 0))
     (setq v2f (trans v2f* (list dx12 dy12 dz12) 0))
     (setq v1x (car v1f) v1y (cadr v1f) v1z (caddr v1f))
     (setq v2x (car v2f) v2y (cadr v2f) v2z (caddr v2f))
    )
   )
  )
  (if (> d13 r13)
   (progn 
    (setq v1x (+ v1x (* a1x t)))  (setq v1y (+ v1y (* a1y t)))  (setq v1z (+ v1z (* a1z t)))
    (setq v3x (+ v3x (* a3x t)))  (setq v3y (+ v3y (* a3y t)))  (setq v3z (+ v3z (* a3z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v1i (list v1x v1y v1z)) ;velocita 1 prima dello scontro
     (setq v3i (list v3x v3y v3z)) ;velocita 3 prima dello scontro
     (setq v1i* (trans v1i 0 (list dx13 dy13 dz13)))
     (setq v3i* (trans v3i 0 (list dx13 dy13 dz13)))
     (setq v1i*x (car v1i*) v1i*y (cadr v1i*) v1i*z (caddr v1i*))
     (setq v3i*x (car v3i*) v3i*y (cadr v3i*) v3i*z (caddr v3i*))
     (setq v1f*z (* kur (/ (+ (* (- m1 m3) v1i*z) (* 2 m3 v3i*z)) (+ m1 m3))))
     (setq v3f*z (* kur (/ (+ (* (- m3 m1) v3i*z) (* 2 m1 v1i*z)) (+ m1 m3))))
     (setq v1f* (list v1i*x v1i*y v1f*z))
     (setq v3f* (list v3i*x v3i*y v3f*z))
     (setq v1f (trans v1f* (list dx13 dy13 dz13) 0))
     (setq v3f (trans v3f* (list dx13 dy13 dz13) 0))
     (setq v1x (car v1f) v1y (cadr v1f) v1z (caddr v1f))
     (setq v3x (car v3f) v3y (cadr v3f) v3z (caddr v3f))
    )
   )
  )
  (if (> d23 r23)
   (progn 
    (setq v2x (+ v2x (* a2x t)))  (setq v2y (+ v2y (* a2y t)))  (setq v2z (+ v2z (* a2z t)))
    (setq v3x (+ v3x (* a3x t)))  (setq v3y (+ v3y (* a3y t)))  (setq v3z (+ v3z (* a3z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v2i (list v2x v2y v2z)) ;velocita 2 prima dello scontro
     (setq v3i (list v3x v3y v3z)) ;velocita 3 prima dello scontro
     (setq v2i* (trans v2i 0 (list dx23 dy23 dz23)))
     (setq v3i* (trans v3i 0 (list dx23 dy23 dz23)))
     (setq v2i*x (car v2i*) v2i*y (cadr v2i*) v2i*z (caddr v2i*))
     (setq v3i*x (car v3i*) v3i*y (cadr v3i*) v3i*z (caddr v3i*))
     (setq v2f*z (* kur (/ (+ (* (- m2 m3) v2i*z) (* 2 m3 v3i*z)) (+ m2 m3))))
     (setq v3f*z (* kur (/ (+ (* (- m3 m2) v3i*z) (* 2 m2 v2i*z)) (+ m2 m3))))
     (setq v2f* (list v2i*x v2i*y v2f*z))
     (setq v3f* (list v3i*x v3i*y v3f*z))
     (setq v2f (trans v2f* (list dx23 dy23 dz23) 0))
     (setq v3f (trans v3f* (list dx23 dy23 dz23) 0))
     (setq v2x (car v2f) v2y (cadr v2f) v2z (caddr v2f))
     (setq v3x (car v3f) v3y (cadr v3f) v3z (caddr v3f))
    )
   )
  )
  (if (> d14 r14)
   (progn 
    (setq v1x (+ v1x (* a1x t)))  (setq v1y (+ v1y (* a1y t)))  (setq v1z (+ v1z (* a1z t)))
    (setq v4x (+ v4x (* a4x t)))  (setq v4y (+ v4y (* a4y t)))  (setq v4z (+ v4z (* a4z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v1i (list v1x v1y v1z)) ;velocita 1 prima dello scontro
     (setq v4i (list v4x v4y v4z)) ;velocita 4 prima dello scontro
     (setq v1i* (trans v1i 0 (list dx14 dy14 dz14)))
     (setq v4i* (trans v4i 0 (list dx14 dy14 dz14)))
     (setq v1i*x (car v1i*) v1i*y (cadr v1i*) v1i*z (caddr v1i*))
     (setq v4i*x (car v4i*) v4i*y (cadr v4i*) v4i*z (caddr v4i*))
     (setq v1f*z (* kur (/ (+ (* (- m1 m4) v1i*z) (* 2 m4 v4i*z)) (+ m1 m4))))
     (setq v4f*z (* kur (/ (+ (* (- m4 m1) v4i*z) (* 2 m1 v1i*z)) (+ m1 m4))))
     (setq v1f* (list v1i*x v1i*y v1f*z))
     (setq v4f* (list v4i*x v4i*y v4f*z))
     (setq v1f (trans v1f* (list dx14 dy14 dz14) 0))
     (setq v4f (trans v4f* (list dx14 dy14 dz14) 0))
     (setq v1x (car v1f) v1y (cadr v1f) v1z (caddr v1f))
     (setq v4x (car v4f) v4y (cadr v4f) v4z (caddr v4f))
    )
   )
  )
  (if (> d24 r24)
   (progn 
    (setq v2x (+ v2x (* a2x t)))  (setq v2y (+ v2y (* a2y t)))  (setq v2z (+ v2z (* a2z t)))
    (setq v4x (+ v4x (* a4x t)))  (setq v4y (+ v4y (* a4y t)))  (setq v4z (+ v4z (* a4z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v2i (list v2x v2y v2z)) ;velocita 2 prima dello scontro
     (setq v4i (list v4x v4y v4z)) ;velocita 4 prima dello scontro
     (setq v2i* (trans v2i 0 (list dx24 dy24 dz24)))
     (setq v4i* (trans v4i 0 (list dx24 dy24 dz24)))
     (setq v2i*x (car v2i*) v2i*y (cadr v2i*) v2i*z (caddr v2i*))
     (setq v4i*x (car v4i*) v4i*y (cadr v4i*) v4i*z (caddr v4i*))
     (setq v2f*z (* kur (/ (+ (* (- m2 m4) v2i*z) (* 2 m4 v4i*z)) (+ m2 m4))))
     (setq v4f*z (* kur (/ (+ (* (- m4 m2) v4i*z) (* 2 m2 v2i*z)) (+ m2 m4))))
     (setq v2f* (list v2i*x v2i*y v2f*z))
     (setq v4f* (list v4i*x v4i*y v4f*z))
     (setq v2f (trans v2f* (list dx24 dy24 dz24) 0))
     (setq v4f (trans v4f* (list dx24 dy24 dz24) 0))
     (setq v2x (car v2f) v2y (cadr v2f) v2z (caddr v2f))
     (setq v4x (car v4f) v4y (cadr v4f) v4z (caddr v4f))
    )
   )
  )
  (if (> d34 r34)
   (progn 
    (setq v3x (+ v3x (* a3x t)))  (setq v3y (+ v3y (* a3y t)))  (setq v3z (+ v3z (* a3z t)))
    (setq v4x (+ v4x (* a4x t)))  (setq v4y (+ v4y (* a4y t)))  (setq v4z (+ v4z (* a4z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v3i (list v3x v3y v3z)) ;velocita 3 prima dello scontro
     (setq v4i (list v4x v4y v4z)) ;velocita 4 prima dello scontro
     (setq v3i* (trans v3i 0 (list dx34 dy34 dz34)))
     (setq v4i* (trans v4i 0 (list dx34 dy34 dz34)))
     (setq v3i*x (car v3i*) v3i*y (cadr v3i*) v3i*z (caddr v3i*))
     (setq v4i*x (car v4i*) v4i*y (cadr v4i*) v4i*z (caddr v4i*))
     (setq v3f*z (* kur (/ (+ (* (- m3 m4) v3i*z) (* 2 m4 v4i*z)) (+ m3 m4))))
     (setq v4f*z (* kur (/ (+ (* (- m4 m3) v4i*z) (* 2 m3 v3i*z)) (+ m3 m4))))
     (setq v3f* (list v3i*x v3i*y v3f*z))
     (setq v4f* (list v4i*x v4i*y v4f*z))
     (setq v3f (trans v3f* (list dx34 dy34 dz34) 0))
     (setq v4f (trans v4f* (list dx34 dy34 dz34) 0))
     (setq v3x (car v3f) v3y (cadr v3f) v3z (caddr v3f))
     (setq v4x (car v4f) v4y (cadr v4f) v4z (caddr v4f))
    )
   )
  )
  (if (> d15 r15)
   (progn 
    (setq v1x (+ v1x (* a1x t)))  (setq v1y (+ v1y (* a1y t)))  (setq v1z (+ v1z (* a1z t)))
    (setq v5x (+ v5x (* a5x t)))  (setq v5y (+ v5y (* a5y t)))  (setq v5z (+ v5z (* a5z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v1i (list v1x v1y v1z)) ;velocita 1 prima dello scontro
     (setq v5i (list v5x v5y v5z)) ;velocita 5 prima dello scontro
     (setq v1i* (trans v1i 0 (list dx15 dy15 dz15)))
     (setq v5i* (trans v5i 0 (list dx15 dy15 dz15)))
     (setq v1i*x (car v1i*) v1i*y (cadr v1i*) v1i*z (caddr v1i*))
     (setq v5i*x (car v5i*) v5i*y (cadr v5i*) v5i*z (caddr v5i*))
     (setq v1f*z (* kur (/ (+ (* (- m1 m5) v1i*z) (* 2 m5 v5i*z)) (+ m1 m5))))
     (setq v5f*z (* kur (/ (+ (* (- m5 m1) v5i*z) (* 2 m1 v1i*z)) (+ m1 m5))))
     (setq v1f* (list v1i*x v1i*y v1f*z))
     (setq v5f* (list v5i*x v5i*y v5f*z))
     (setq v1f (trans v1f* (list dx15 dy15 dz15) 0))
     (setq v5f (trans v5f* (list dx15 dy15 dz15) 0))
     (setq v1x (car v1f) v1y (cadr v1f) v1z (caddr v1f))
     (setq v5x (car v5f) v5y (cadr v5f) v5z (caddr v5f))
    )
   )
  )
  (if (> d25 r25)
   (progn 
    (setq v2x (+ v2x (* a2x t)))  (setq v2y (+ v2y (* a2y t)))  (setq v2z (+ v2z (* a2z t)))
    (setq v5x (+ v5x (* a5x t)))  (setq v5y (+ v5y (* a5y t)))  (setq v5z (+ v5z (* a5z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v2i (list v2x v2y v2z)) ;velocita 2 prima dello scontro
     (setq v5i (list v5x v5y v5z)) ;velocita 5 prima dello scontro
     (setq v2i* (trans v2i 0 (list dx25 dy25 dz25)))
     (setq v5i* (trans v5i 0 (list dx25 dy25 dz25)))
     (setq v2i*x (car v2i*) v2i*y (cadr v2i*) v2i*z (caddr v2i*))
     (setq v5i*x (car v5i*) v5i*y (cadr v5i*) v5i*z (caddr v5i*))
     (setq v2f*z (* kur (/ (+ (* (- m2 m5) v2i*z) (* 2 m5 v5i*z)) (+ m2 m5))))
     (setq v5f*z (* kur (/ (+ (* (- m5 m2) v5i*z) (* 2 m2 v2i*z)) (+ m2 m5))))
     (setq v2f* (list v2i*x v2i*y v2f*z))
     (setq v5f* (list v5i*x v5i*y v5f*z))
     (setq v2f (trans v2f* (list dx25 dy25 dz25) 0))
     (setq v5f (trans v5f* (list dx25 dy25 dz25) 0))
     (setq v2x (car v2f) v2y (cadr v2f) v2z (caddr v2f))
     (setq v5x (car v5f) v5y (cadr v5f) v5z (caddr v5f))
    )
   )
  )
  (if (> d35 r35)
   (progn 
    (setq v3x (+ v3x (* a3x t)))  (setq v3y (+ v3y (* a3y t)))  (setq v3z (+ v3z (* a3z t)))
    (setq v5x (+ v5x (* a5x t)))  (setq v5y (+ v5y (* a5y t)))  (setq v5z (+ v5z (* a5z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v3i (list v3x v3y v3z)) ;velocita 3 prima dello scontro
     (setq v5i (list v5x v5y v5z)) ;velocita 5 prima dello scontro
     (setq v3i* (trans v3i 0 (list dx35 dy35 dz35)))
     (setq v5i* (trans v5i 0 (list dx35 dy35 dz35)))
     (setq v3i*x (car v3i*) v3i*y (cadr v3i*) v3i*z (caddr v3i*))
     (setq v5i*x (car v5i*) v5i*y (cadr v5i*) v5i*z (caddr v5i*))
     (setq v3f*z (* kur (/ (+ (* (- m3 m5) v3i*z) (* 2 m5 v5i*z)) (+ m3 m5))))
     (setq v5f*z (* kur (/ (+ (* (- m5 m3) v5i*z) (* 2 m3 v3i*z)) (+ m3 m5))))
     (setq v3f* (list v3i*x v3i*y v3f*z))
     (setq v5f* (list v5i*x v5i*y v5f*z))
     (setq v3f (trans v3f* (list dx35 dy35 dz35) 0))
     (setq v5f (trans v5f* (list dx35 dy35 dz35) 0))
     (setq v3x (car v3f) v3y (cadr v3f) v3z (caddr v3f))
     (setq v5x (car v5f) v5y (cadr v5f) v5z (caddr v5f))
    )
   )
  )
  (if (> d45 r45)
   (progn 
    (setq v4x (+ v4x (* a4x t)))  (setq v4y (+ v4y (* a4y t)))  (setq v4z (+ v4z (* a4z t)))
    (setq v5x (+ v5x (* a5x t)))  (setq v5y (+ v5y (* a5y t)))  (setq v5z (+ v5z (* a5z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v4i (list v4x v4y v4z)) ;velocita 4 prima dello scontro
     (setq v5i (list v5x v5y v5z)) ;velocita 5 prima dello scontro
     (setq v4i* (trans v4i 0 (list dx45 dy45 dz45)))
     (setq v5i* (trans v5i 0 (list dx45 dy45 dz45)))
     (setq v4i*x (car v4i*) v4i*y (cadr v4i*) v4i*z (caddr v4i*))
     (setq v5i*x (car v5i*) v5i*y (cadr v5i*) v5i*z (caddr v5i*))
     (setq v4f*z (* kur (/ (+ (* (- m4 m5) v4i*z) (* 2 m5 v5i*z)) (+ m4 m5))))
     (setq v5f*z (* kur (/ (+ (* (- m5 m4) v5i*z) (* 2 m4 v4i*z)) (+ m4 m5))))
     (setq v4f* (list v4i*x v4i*y v4f*z))
     (setq v5f* (list v5i*x v5i*y v5f*z))
     (setq v4f (trans v4f* (list dx45 dy45 dz45) 0))
     (setq v5f (trans v5f* (list dx45 dy45 dz45) 0))
     (setq v4x (car v4f) v4y (cadr v4f) v4z (caddr v4f))
     (setq v5x (car v5f) v5y (cadr v5f) v5z (caddr v5f))
    )
   )
  )
  (if (> d16 r16)
   (progn 
    (setq v1x (+ v1x (* a1x t)))  (setq v1y (+ v1y (* a1y t)))  (setq v1z (+ v1z (* a1z t)))
    (setq v6x (+ v6x (* a6x t)))  (setq v6y (+ v6y (* a6y t)))  (setq v6z (+ v6z (* a6z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v1i (list v1x v1y v1z)) ;velocita 1 prima dello scontro
     (setq v6i (list v6x v6y v6z)) ;velocita 6 prima dello scontro
     (setq v1i* (trans v1i 0 (list dx16 dy16 dz16)))
     (setq v6i* (trans v6i 0 (list dx16 dy16 dz16)))
     (setq v1i*x (car v1i*) v1i*y (cadr v1i*) v1i*z (caddr v1i*))
     (setq v6i*x (car v6i*) v6i*y (cadr v6i*) v6i*z (caddr v6i*))
     (setq v1f*z (* kur (/ (+ (* (- m1 m6) v1i*z) (* 2 m6 v6i*z)) (+ m1 m6))))
     (setq v6f*z (* kur (/ (+ (* (- m6 m1) v6i*z) (* 2 m1 v1i*z)) (+ m1 m6))))
     (setq v1f* (list v1i*x v1i*y v1f*z))
     (setq v6f* (list v6i*x v6i*y v6f*z))
     (setq v1f (trans v1f* (list dx16 dy16 dz16) 0))
     (setq v6f (trans v6f* (list dx16 dy16 dz16) 0))
     (setq v1x (car v1f) v1y (cadr v1f) v1z (caddr v1f))
     (setq v6x (car v6f) v6y (cadr v6f) v6z (caddr v6f))
    )
   )
  )
  (if (> d26 r26)
   (progn 
    (setq v2x (+ v2x (* a2x t)))  (setq v2y (+ v2y (* a2y t)))  (setq v2z (+ v2z (* a2z t)))
    (setq v6x (+ v6x (* a6x t)))  (setq v6y (+ v6y (* a6y t)))  (setq v6z (+ v6z (* a6z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v2i (list v2x v2y v2z)) ;velocita 2 prima dello scontro
     (setq v6i (list v6x v6y v6z)) ;velocita 6 prima dello scontro
     (setq v2i* (trans v2i 0 (list dx26 dy26 dz26)))
     (setq v6i* (trans v6i 0 (list dx26 dy26 dz26)))
     (setq v2i*x (car v2i*) v2i*y (cadr v2i*) v2i*z (caddr v2i*))
     (setq v6i*x (car v6i*) v6i*y (cadr v6i*) v6i*z (caddr v6i*))
     (setq v2f*z (* kur (/ (+ (* (- m2 m6) v2i*z) (* 2 m6 v6i*z)) (+ m2 m6))))
     (setq v6f*z (* kur (/ (+ (* (- m6 m2) v6i*z) (* 2 m2 v2i*z)) (+ m2 m6))))
     (setq v2f* (list v2i*x v2i*y v2f*z))
     (setq v6f* (list v6i*x v6i*y v6f*z))
     (setq v2f (trans v2f* (list dx26 dy26 dz26) 0))
     (setq v6f (trans v6f* (list dx26 dy26 dz26) 0))
     (setq v2x (car v2f) v2y (cadr v2f) v2z (caddr v2f))
     (setq v6x (car v6f) v6y (cadr v6f) v6z (caddr v6f))
    )
   )
  )
  (if (> d36 r36)
   (progn 
    (setq v3x (+ v3x (* a3x t)))  (setq v3y (+ v3y (* a3y t)))  (setq v3z (+ v3z (* a3z t)))
    (setq v6x (+ v6x (* a6x t)))  (setq v6y (+ v6y (* a6y t)))  (setq v6z (+ v6z (* a6z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v3i (list v3x v3y v3z)) ;velocita 3 prima dello scontro
     (setq v6i (list v6x v6y v6z)) ;velocita 6 prima dello scontro
     (setq v3i* (trans v3i 0 (list dx36 dy36 dz36)))
     (setq v6i* (trans v6i 0 (list dx36 dy36 dz36)))
     (setq v3i*x (car v3i*) v3i*y (cadr v3i*) v3i*z (caddr v3i*))
     (setq v6i*x (car v6i*) v6i*y (cadr v6i*) v6i*z (caddr v6i*))
     (setq v3f*z (* kur (/ (+ (* (- m3 m6) v3i*z) (* 2 m6 v6i*z)) (+ m3 m6))))
     (setq v6f*z (* kur (/ (+ (* (- m6 m3) v6i*z) (* 2 m3 v3i*z)) (+ m3 m6))))
     (setq v3f* (list v3i*x v3i*y v3f*z))
     (setq v6f* (list v6i*x v6i*y v6f*z))
     (setq v3f (trans v3f* (list dx36 dy36 dz36) 0))
     (setq v6f (trans v6f* (list dx36 dy36 dz36) 0))
     (setq v3x (car v3f) v3y (cadr v3f) v3z (caddr v3f))
     (setq v6x (car v6f) v6y (cadr v6f) v6z (caddr v6f))
    )
   )
  )
  (if (> d46 r46)
   (progn 
    (setq v4x (+ v4x (* a4x t)))  (setq v4y (+ v4y (* a4y t)))  (setq v4z (+ v4z (* a4z t)))
    (setq v6x (+ v6x (* a6x t)))  (setq v6y (+ v6y (* a6y t)))  (setq v6z (+ v6z (* a6z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v4i (list v4x v4y v4z)) ;velocita 4 prima dello scontro
     (setq v6i (list v6x v6y v6z)) ;velocita 6 prima dello scontro
     (setq v4i* (trans v4i 0 (list dx46 dy46 dz46)))
     (setq v6i* (trans v6i 0 (list dx46 dy46 dz46)))
     (setq v4i*x (car v4i*) v4i*y (cadr v4i*) v4i*z (caddr v4i*))
     (setq v6i*x (car v6i*) v6i*y (cadr v6i*) v6i*z (caddr v6i*))
     (setq v4f*z (* kur (/ (+ (* (- m4 m6) v4i*z) (* 2 m6 v6i*z)) (+ m4 m6))))
     (setq v6f*z (* kur (/ (+ (* (- m6 m4) v6i*z) (* 2 m4 v4i*z)) (+ m4 m6))))
     (setq v4f* (list v4i*x v4i*y v4f*z))
     (setq v6f* (list v6i*x v6i*y v6f*z))
     (setq v4f (trans v4f* (list dx46 dy46 dz46) 0))
     (setq v6f (trans v6f* (list dx46 dy46 dz46) 0))
     (setq v4x (car v4f) v4y (cadr v4f) v4z (caddr v4f))
     (setq v6x (car v6f) v6y (cadr v6f) v6z (caddr v6f))
    )
   )
  )
  (if (> d56 r56)
   (progn 
    (setq v5x (+ v5x (* a5x t)))  (setq v5y (+ v5y (* a5y t)))  (setq v5z (+ v5z (* a5z t)))
    (setq v6x (+ v6x (* a6x t)))  (setq v6y (+ v6y (* a6y t)))  (setq v6z (+ v6z (* a6z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v5i (list v5x v5y v5z)) ;velocita 5 prima dello scontro
     (setq v6i (list v6x v6y v6z)) ;velocita 6 prima dello scontro
     (setq v5i* (trans v5i 0 (list dx56 dy56 dz56)))
     (setq v6i* (trans v6i 0 (list dx56 dy56 dz56)))
     (setq v5i*x (car v5i*) v5i*y (cadr v5i*) v5i*z (caddr v5i*))
     (setq v6i*x (car v6i*) v6i*y (cadr v6i*) v6i*z (caddr v6i*))
     (setq v5f*z (* kur (/ (+ (* (- m5 m6) v5i*z) (* 2 m6 v6i*z)) (+ m5 m6))))
     (setq v6f*z (* kur (/ (+ (* (- m6 m5) v6i*z) (* 2 m5 v5i*z)) (+ m5 m6))))
     (setq v5f* (list v5i*x v5i*y v5f*z))
     (setq v6f* (list v6i*x v6i*y v6f*z))
     (setq v5f (trans v5f* (list dx56 dy56 dz56) 0))
     (setq v6f (trans v6f* (list dx56 dy56 dz56) 0))
     (setq v5x (car v5f) v5y (cadr v5f) v5z (caddr v5f))
     (setq v6x (car v6f) v6y (cadr v6f) v6z (caddr v6f))
    )
   )
  )
  (if (> d17 r17)
   (progn 
    (setq v1x (+ v1x (* a1x t)))  (setq v1y (+ v1y (* a1y t)))  (setq v1z (+ v1z (* a1z t)))
    (setq v7x (+ v7x (* a7x t)))  (setq v7y (+ v7y (* a7y t)))  (setq v7z (+ v7z (* a7z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v1i (list v1x v1y v1z)) ;velocita 1 prima dello scontro
     (setq v7i (list v7x v7y v7z)) ;velocita 7 prima dello scontro
     (setq v1i* (trans v1i 0 (list dx17 dy17 dz17)))
     (setq v7i* (trans v7i 0 (list dx17 dy17 dz17)))
     (setq v1i*x (car v1i*) v1i*y (cadr v1i*) v1i*z (caddr v1i*))
     (setq v7i*x (car v7i*) v7i*y (cadr v7i*) v7i*z (caddr v7i*))
     (setq v1f*z (* kur (/ (+ (* (- m1 m7) v1i*z) (* 2 m7 v7i*z)) (+ m1 m7))))
     (setq v7f*z (* kur (/ (+ (* (- m7 m1) v7i*z) (* 2 m1 v1i*z)) (+ m1 m7))))
     (setq v1f* (list v1i*x v1i*y v1f*z))
     (setq v7f* (list v7i*x v7i*y v7f*z))
     (setq v1f (trans v1f* (list dx17 dy17 dz17) 0))
     (setq v7f (trans v7f* (list dx17 dy17 dz17) 0))
     (setq v1x (car v1f) v1y (cadr v1f) v1z (caddr v1f))
     (setq v7x (car v7f) v7y (cadr v7f) v7z (caddr v7f))
    )
   )
  )
  (if (> d27 r27)
   (progn 
    (setq v2x (+ v2x (* a2x t)))  (setq v2y (+ v2y (* a2y t)))  (setq v2z (+ v2z (* a2z t)))
    (setq v7x (+ v7x (* a7x t)))  (setq v7y (+ v7y (* a7y t)))  (setq v7z (+ v7z (* a7z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v2i (list v2x v2y v2z)) ;velocita 2 prima dello scontro
     (setq v7i (list v7x v7y v7z)) ;velocita 7 prima dello scontro
     (setq v2i* (trans v2i 0 (list dx27 dy27 dz27)))
     (setq v7i* (trans v7i 0 (list dx27 dy27 dz27)))
     (setq v2i*x (car v2i*) v2i*y (cadr v2i*) v2i*z (caddr v2i*))
     (setq v7i*x (car v7i*) v7i*y (cadr v7i*) v7i*z (caddr v7i*))
     (setq v2f*z (* kur (/ (+ (* (- m2 m7) v2i*z) (* 2 m7 v7i*z)) (+ m2 m7))))
     (setq v7f*z (* kur (/ (+ (* (- m7 m2) v7i*z) (* 2 m2 v2i*z)) (+ m2 m7))))
     (setq v2f* (list v2i*x v2i*y v2f*z))
     (setq v7f* (list v7i*x v7i*y v7f*z))
     (setq v2f (trans v2f* (list dx27 dy27 dz27) 0))
     (setq v7f (trans v7f* (list dx27 dy27 dz27) 0))
     (setq v2x (car v2f) v2y (cadr v2f) v2z (caddr v2f))
     (setq v7x (car v7f) v7y (cadr v7f) v7z (caddr v7f))
    )
   )
  )
  (if (> d37 r37)
   (progn 
    (setq v3x (+ v3x (* a3x t)))  (setq v3y (+ v3y (* a3y t)))  (setq v3z (+ v3z (* a3z t)))
    (setq v7x (+ v7x (* a7x t)))  (setq v7y (+ v7y (* a7y t)))  (setq v7z (+ v7z (* a7z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v3i (list v3x v3y v3z)) ;velocita 3 prima dello scontro
     (setq v7i (list v7x v7y v7z)) ;velocita 7 prima dello scontro
     (setq v3i* (trans v3i 0 (list dx37 dy37 dz37)))
     (setq v7i* (trans v7i 0 (list dx37 dy37 dz37)))
     (setq v3i*x (car v3i*) v3i*y (cadr v3i*) v3i*z (caddr v3i*))
     (setq v7i*x (car v7i*) v7i*y (cadr v7i*) v7i*z (caddr v7i*))
     (setq v3f*z (* kur (/ (+ (* (- m3 m7) v3i*z) (* 2 m7 v7i*z)) (+ m3 m7))))
     (setq v7f*z (* kur (/ (+ (* (- m7 m3) v7i*z) (* 2 m3 v3i*z)) (+ m3 m7))))
     (setq v3f* (list v3i*x v3i*y v3f*z))
     (setq v7f* (list v7i*x v7i*y v7f*z))
     (setq v3f (trans v3f* (list dx37 dy37 dz37) 0))
     (setq v7f (trans v7f* (list dx37 dy37 dz37) 0))
     (setq v3x (car v3f) v3y (cadr v3f) v3z (caddr v3f))
     (setq v7x (car v7f) v7y (cadr v7f) v7z (caddr v7f))
    )
   )
  )
  (if (> d47 r47)
   (progn 
    (setq v4x (+ v4x (* a4x t)))  (setq v4y (+ v4y (* a4y t)))  (setq v4z (+ v4z (* a4z t)))
    (setq v7x (+ v7x (* a7x t)))  (setq v7y (+ v7y (* a7y t)))  (setq v7z (+ v7z (* a7z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v4i (list v4x v4y v4z)) ;velocita 4 prima dello scontro
     (setq v7i (list v7x v7y v7z)) ;velocita 7 prima dello scontro
     (setq v4i* (trans v4i 0 (list dx47 dy47 dz47)))
     (setq v7i* (trans v7i 0 (list dx47 dy47 dz47)))
     (setq v4i*x (car v4i*) v4i*y (cadr v4i*) v4i*z (caddr v4i*))
     (setq v7i*x (car v7i*) v7i*y (cadr v7i*) v7i*z (caddr v7i*))
     (setq v4f*z (* kur (/ (+ (* (- m4 m7) v4i*z) (* 2 m7 v7i*z)) (+ m4 m7))))
     (setq v7f*z (* kur (/ (+ (* (- m7 m4) v7i*z) (* 2 m4 v4i*z)) (+ m4 m7))))
     (setq v4f* (list v4i*x v4i*y v4f*z))
     (setq v7f* (list v7i*x v7i*y v7f*z))
     (setq v4f (trans v4f* (list dx47 dy47 dz47) 0))
     (setq v7f (trans v7f* (list dx47 dy47 dz47) 0))
     (setq v4x (car v4f) v4y (cadr v4f) v4z (caddr v4f))
     (setq v7x (car v7f) v7y (cadr v7f) v7z (caddr v7f))
    )
   )
  )
  (if (> d57 r57)
   (progn 
    (setq v5x (+ v5x (* a5x t)))  (setq v5y (+ v5y (* a5y t)))  (setq v5z (+ v5z (* a5z t)))
    (setq v7x (+ v7x (* a7x t)))  (setq v7y (+ v7y (* a7y t)))  (setq v7z (+ v7z (* a7z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v5i (list v5x v5y v5z)) ;velocita 5 prima dello scontro
     (setq v7i (list v7x v7y v7z)) ;velocita 7 prima dello scontro
     (setq v5i* (trans v5i 0 (list dx57 dy57 dz57)))
     (setq v7i* (trans v7i 0 (list dx57 dy57 dz57)))
     (setq v5i*x (car v5i*) v5i*y (cadr v5i*) v5i*z (caddr v5i*))
     (setq v7i*x (car v7i*) v7i*y (cadr v7i*) v7i*z (caddr v7i*))
     (setq v5f*z (* kur (/ (+ (* (- m5 m7) v5i*z) (* 2 m7 v7i*z)) (+ m5 m7))))
     (setq v7f*z (* kur (/ (+ (* (- m7 m5) v7i*z) (* 2 m5 v5i*z)) (+ m5 m7))))
     (setq v5f* (list v5i*x v5i*y v5f*z))
     (setq v7f* (list v7i*x v7i*y v7f*z))
     (setq v5f (trans v5f* (list dx57 dy57 dz57) 0))
     (setq v7f (trans v7f* (list dx57 dy57 dz57) 0))
     (setq v5x (car v5f) v5y (cadr v5f) v5z (caddr v5f))
     (setq v7x (car v7f) v7y (cadr v7f) v7z (caddr v7f))
    )
   )
  )
  (if (> d67 r67)
   (progn 
    (setq v6x (+ v6x (* a6x t)))  (setq v6y (+ v6y (* a6y t)))  (setq v6z (+ v6z (* a6z t)))
    (setq v7x (+ v7x (* a7x t)))  (setq v7y (+ v7y (* a7y t)))  (setq v7z (+ v7z (* a7z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v6i (list v6x v6y v6z)) ;velocita 6 prima dello scontro
     (setq v7i (list v7x v7y v7z)) ;velocita 7 prima dello scontro
     (setq v6i* (trans v6i 0 (list dx67 dy67 dz67)))
     (setq v7i* (trans v7i 0 (list dx67 dy67 dz67)))
     (setq v6i*x (car v6i*) v6i*y (cadr v6i*) v6i*z (caddr v6i*))
     (setq v7i*x (car v7i*) v7i*y (cadr v7i*) v7i*z (caddr v7i*))
     (setq v6f*z (* kur (/ (+ (* (- m6 m7) v6i*z) (* 2 m7 v7i*z)) (+ m6 m7))))
     (setq v7f*z (* kur (/ (+ (* (- m7 m6) v7i*z) (* 2 m6 v6i*z)) (+ m6 m7))))
     (setq v6f* (list v6i*x v6i*y v6f*z))
     (setq v7f* (list v7i*x v7i*y v7f*z))
     (setq v6f (trans v6f* (list dx67 dy67 dz67) 0))
     (setq v7f (trans v7f* (list dx67 dy67 dz67) 0))
     (setq v6x (car v6f) v6y (cadr v6f) v6z (caddr v6f))
     (setq v7x (car v7f) v7y (cadr v7f) v7z (caddr v7f))
    )
   )
  )
  (if (> d18 r18)
   (progn 
    (setq v1x (+ v1x (* a1x t)))  (setq v1y (+ v1y (* a1y t)))  (setq v1z (+ v1z (* a1z t)))
    (setq v8x (+ v8x (* a8x t)))  (setq v8y (+ v8y (* a8y t)))  (setq v8z (+ v8z (* a8z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v1i (list v1x v1y v1z)) ;velocita 1 prima dello scontro
     (setq v8i (list v8x v8y v8z)) ;velocita 8 prima dello scontro
     (setq v1i* (trans v1i 0 (list dx18 dy18 dz18)))
     (setq v8i* (trans v8i 0 (list dx18 dy18 dz18)))
     (setq v1i*x (car v1i*) v1i*y (cadr v1i*) v1i*z (caddr v1i*))
     (setq v8i*x (car v8i*) v8i*y (cadr v8i*) v8i*z (caddr v8i*))
     (setq v1f*z (* kur (/ (+ (* (- m1 m8) v1i*z) (* 2 m8 v8i*z)) (+ m1 m8))))
     (setq v8f*z (* kur (/ (+ (* (- m8 m1) v8i*z) (* 2 m1 v1i*z)) (+ m1 m8))))
     (setq v1f* (list v1i*x v1i*y v1f*z))
     (setq v8f* (list v8i*x v8i*y v8f*z))
     (setq v1f (trans v1f* (list dx18 dy18 dz18) 0))
     (setq v8f (trans v8f* (list dx18 dy18 dz18) 0))
     (setq v1x (car v1f) v1y (cadr v1f) v1z (caddr v1f))
     (setq v8x (car v8f) v8y (cadr v8f) v8z (caddr v8f))
    )
   )
  )
  (if (> d28 r28)
   (progn 
    (setq v2x (+ v2x (* a2x t)))  (setq v2y (+ v2y (* a2y t)))  (setq v2z (+ v2z (* a2z t)))
    (setq v8x (+ v8x (* a8x t)))  (setq v8y (+ v8y (* a8y t)))  (setq v8z (+ v8z (* a8z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v2i (list v2x v2y v2z)) ;velocita 2 prima dello scontro
     (setq v8i (list v8x v8y v8z)) ;velocita 8 prima dello scontro
     (setq v2i* (trans v2i 0 (list dx28 dy28 dz28)))
     (setq v8i* (trans v8i 0 (list dx28 dy28 dz28)))
     (setq v2i*x (car v2i*) v2i*y (cadr v2i*) v2i*z (caddr v2i*))
     (setq v8i*x (car v8i*) v8i*y (cadr v8i*) v8i*z (caddr v8i*))
     (setq v2f*z (* kur (/ (+ (* (- m2 m8) v2i*z) (* 2 m8 v8i*z)) (+ m2 m8))))
     (setq v8f*z (* kur (/ (+ (* (- m8 m2) v8i*z) (* 2 m2 v2i*z)) (+ m2 m8))))
     (setq v2f* (list v2i*x v2i*y v2f*z))
     (setq v8f* (list v8i*x v8i*y v8f*z))
     (setq v2f (trans v2f* (list dx28 dy28 dz28) 0))
     (setq v8f (trans v8f* (list dx28 dy28 dz28) 0))
     (setq v2x (car v2f) v2y (cadr v2f) v2z (caddr v2f))
     (setq v8x (car v8f) v8y (cadr v8f) v8z (caddr v8f))
    )
   )
  )
  (if (> d38 r38)
   (progn 
    (setq v3x (+ v3x (* a3x t)))  (setq v3y (+ v3y (* a3y t)))  (setq v3z (+ v3z (* a3z t)))
    (setq v8x (+ v8x (* a8x t)))  (setq v8y (+ v8y (* a8y t)))  (setq v8z (+ v8z (* a8z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v3i (list v3x v3y v3z)) ;velocita 3 prima dello scontro
     (setq v8i (list v8x v8y v8z)) ;velocita 8 prima dello scontro
     (setq v3i* (trans v3i 0 (list dx38 dy38 dz38)))
     (setq v8i* (trans v8i 0 (list dx38 dy38 dz38)))
     (setq v3i*x (car v3i*) v3i*y (cadr v3i*) v3i*z (caddr v3i*))
     (setq v8i*x (car v8i*) v8i*y (cadr v8i*) v8i*z (caddr v8i*))
     (setq v3f*z (* kur (/ (+ (* (- m3 m8) v3i*z) (* 2 m8 v8i*z)) (+ m3 m8))))
     (setq v8f*z (* kur (/ (+ (* (- m8 m3) v8i*z) (* 2 m3 v3i*z)) (+ m3 m8))))
     (setq v3f* (list v3i*x v3i*y v3f*z))
     (setq v8f* (list v8i*x v8i*y v8f*z))
     (setq v3f (trans v3f* (list dx38 dy38 dz38) 0))
     (setq v8f (trans v8f* (list dx38 dy38 dz38) 0))
     (setq v3x (car v3f) v3y (cadr v3f) v3z (caddr v3f))
     (setq v8x (car v8f) v8y (cadr v8f) v8z (caddr v8f))
    )
   )
  )
  (if (> d48 r48)
   (progn 
    (setq v4x (+ v4x (* a4x t)))  (setq v4y (+ v4y (* a4y t)))  (setq v4z (+ v4z (* a4z t)))
    (setq v8x (+ v8x (* a8x t)))  (setq v8y (+ v8y (* a8y t)))  (setq v8z (+ v8z (* a8z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v4i (list v4x v4y v4z)) ;velocita 4 prima dello scontro
     (setq v8i (list v8x v8y v8z)) ;velocita 8 prima dello scontro
     (setq v4i* (trans v4i 0 (list dx48 dy48 dz48)))
     (setq v8i* (trans v8i 0 (list dx48 dy48 dz48)))
     (setq v4i*x (car v4i*) v4i*y (cadr v4i*) v4i*z (caddr v4i*))
     (setq v8i*x (car v8i*) v8i*y (cadr v8i*) v8i*z (caddr v8i*))
     (setq v4f*z (* kur (/ (+ (* (- m4 m8) v4i*z) (* 2 m8 v8i*z)) (+ m4 m8))))
     (setq v8f*z (* kur (/ (+ (* (- m8 m4) v8i*z) (* 2 m4 v4i*z)) (+ m4 m8))))
     (setq v4f* (list v4i*x v4i*y v4f*z))
     (setq v8f* (list v8i*x v8i*y v8f*z))
     (setq v4f (trans v4f* (list dx48 dy48 dz48) 0))
     (setq v8f (trans v8f* (list dx48 dy48 dz48) 0))
     (setq v4x (car v4f) v4y (cadr v4f) v4z (caddr v4f))
     (setq v8x (car v8f) v8y (cadr v8f) v8z (caddr v8f))
    )
   )
  )
  (if (> d58 r58)
   (progn 
    (setq v5x (+ v5x (* a5x t)))  (setq v5y (+ v5y (* a5y t)))  (setq v5z (+ v5z (* a5z t)))
    (setq v8x (+ v8x (* a8x t)))  (setq v8y (+ v8y (* a8y t)))  (setq v8z (+ v8z (* a8z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v5i (list v5x v5y v5z)) ;velocita 5 prima dello scontro
     (setq v8i (list v8x v8y v8z)) ;velocita 8 prima dello scontro
     (setq v5i* (trans v5i 0 (list dx58 dy58 dz58)))
     (setq v8i* (trans v8i 0 (list dx58 dy58 dz58)))
     (setq v5i*x (car v5i*) v5i*y (cadr v5i*) v5i*z (caddr v5i*))
     (setq v8i*x (car v8i*) v8i*y (cadr v8i*) v8i*z (caddr v8i*))
     (setq v5f*z (* kur (/ (+ (* (- m5 m8) v5i*z) (* 2 m8 v8i*z)) (+ m5 m8))))
     (setq v8f*z (* kur (/ (+ (* (- m8 m5) v8i*z) (* 2 m5 v5i*z)) (+ m5 m8))))
     (setq v5f* (list v5i*x v5i*y v5f*z))
     (setq v8f* (list v8i*x v8i*y v8f*z))
     (setq v5f (trans v5f* (list dx58 dy58 dz58) 0))
     (setq v8f (trans v8f* (list dx58 dy58 dz58) 0))
     (setq v5x (car v5f) v5y (cadr v5f) v5z (caddr v5f))
     (setq v8x (car v8f) v8y (cadr v8f) v8z (caddr v8f))
    )
   )
  )
  (if (> d68 r68)
   (progn 
    (setq v6x (+ v6x (* a6x t)))  (setq v6y (+ v6y (* a6y t)))  (setq v6z (+ v6z (* a6z t)))
    (setq v8x (+ v8x (* a8x t)))  (setq v8y (+ v8y (* a8y t)))  (setq v8z (+ v8z (* a8z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v6i (list v6x v6y v6z)) ;velocita 6 prima dello scontro
     (setq v8i (list v8x v8y v8z)) ;velocita 8 prima dello scontro
     (setq v6i* (trans v6i 0 (list dx68 dy68 dz68)))
     (setq v8i* (trans v8i 0 (list dx68 dy68 dz68)))
     (setq v6i*x (car v6i*) v6i*y (cadr v6i*) v6i*z (caddr v6i*))
     (setq v8i*x (car v8i*) v8i*y (cadr v8i*) v8i*z (caddr v8i*))
     (setq v6f*z (* kur (/ (+ (* (- m6 m8) v6i*z) (* 2 m8 v8i*z)) (+ m6 m8))))
     (setq v8f*z (* kur (/ (+ (* (- m8 m6) v8i*z) (* 2 m6 v6i*z)) (+ m6 m8))))
     (setq v6f* (list v6i*x v6i*y v6f*z))
     (setq v8f* (list v8i*x v8i*y v8f*z))
     (setq v6f (trans v6f* (list dx68 dy68 dz68) 0))
     (setq v8f (trans v8f* (list dx68 dy68 dz68) 0))
     (setq v6x (car v6f) v6y (cadr v6f) v6z (caddr v6f))
     (setq v8x (car v8f) v8y (cadr v8f) v8z (caddr v8f))
    )
   )
  )
  (if (> d78 r78)
   (progn 
    (setq v7x (+ v7x (* a7x t)))  (setq v7y (+ v7y (* a7y t)))  (setq v7z (+ v7z (* a7z t)))
    (setq v8x (+ v8x (* a8x t)))  (setq v8y (+ v8y (* a8y t)))  (setq v8z (+ v8z (* a8z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v7i (list v7x v7y v7z)) ;velocita 7 prima dello scontro
     (setq v8i (list v8x v8y v8z)) ;velocita 8 prima dello scontro
     (setq v7i* (trans v7i 0 (list dx78 dy78 dz78)))
     (setq v8i* (trans v8i 0 (list dx78 dy78 dz78)))
     (setq v7i*x (car v7i*) v7i*y (cadr v7i*) v7i*z (caddr v7i*))
     (setq v8i*x (car v8i*) v8i*y (cadr v8i*) v8i*z (caddr v8i*))
     (setq v7f*z (* kur (/ (+ (* (- m7 m8) v7i*z) (* 2 m8 v8i*z)) (+ m7 m8))))
     (setq v8f*z (* kur (/ (+ (* (- m8 m7) v8i*z) (* 2 m7 v7i*z)) (+ m7 m8))))
     (setq v7f* (list v7i*x v7i*y v7f*z))
     (setq v8f* (list v8i*x v8i*y v8f*z))
     (setq v7f (trans v7f* (list dx78 dy78 dz78) 0))
     (setq v8f (trans v8f* (list dx78 dy78 dz78) 0))
     (setq v7x (car v7f) v7y (cadr v7f) v7z (caddr v7f))
     (setq v8x (car v8f) v8y (cadr v8f) v8z (caddr v8f))
    )
   )
  )
  (if (> d19 r19)
   (progn 
    (setq v1x (+ v1x (* a1x t)))  (setq v1y (+ v1y (* a1y t)))  (setq v1z (+ v1z (* a1z t)))
    (setq v9x (+ v9x (* a9x t)))  (setq v9y (+ v9y (* a9y t)))  (setq v9z (+ v9z (* a9z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v1i (list v1x v1y v1z)) ;velocita 1 prima dello scontro
     (setq v9i (list v9x v9y v9z)) ;velocita 9 prima dello scontro
     (setq v1i* (trans v1i 0 (list dx19 dy19 dz19)))
     (setq v9i* (trans v9i 0 (list dx19 dy19 dz19)))
     (setq v1i*x (car v1i*) v1i*y (cadr v1i*) v1i*z (caddr v1i*))
     (setq v9i*x (car v9i*) v9i*y (cadr v9i*) v9i*z (caddr v9i*))
     (setq v1f*z (* kur (/ (+ (* (- m1 m9) v1i*z) (* 2 m9 v9i*z)) (+ m1 m9))))
     (setq v9f*z (* kur (/ (+ (* (- m9 m1) v9i*z) (* 2 m1 v1i*z)) (+ m1 m9))))
     (setq v1f* (list v1i*x v1i*y v1f*z))
     (setq v9f* (list v9i*x v9i*y v9f*z))
     (setq v1f (trans v1f* (list dx19 dy19 dz19) 0))
     (setq v9f (trans v9f* (list dx19 dy19 dz19) 0))
     (setq v1x (car v1f) v1y (cadr v1f) v1z (caddr v1f))
     (setq v9x (car v9f) v9y (cadr v9f) v9z (caddr v9f))
    )
   )
  )
  (if (> d29 r29)
   (progn 
    (setq v2x (+ v2x (* a2x t)))  (setq v2y (+ v2y (* a2y t)))  (setq v2z (+ v2z (* a2z t)))
    (setq v9x (+ v9x (* a9x t)))  (setq v9y (+ v9y (* a9y t)))  (setq v9z (+ v9z (* a9z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v2i (list v2x v2y v2z)) ;velocita 2 prima dello scontro
     (setq v9i (list v9x v9y v9z)) ;velocita 9 prima dello scontro
     (setq v2i* (trans v2i 0 (list dx29 dy29 dz29)))
     (setq v9i* (trans v9i 0 (list dx29 dy29 dz29)))
     (setq v2i*x (car v2i*) v2i*y (cadr v2i*) v2i*z (caddr v2i*))
     (setq v9i*x (car v9i*) v9i*y (cadr v9i*) v9i*z (caddr v9i*))
     (setq v2f*z (* kur (/ (+ (* (- m2 m9) v2i*z) (* 2 m9 v9i*z)) (+ m2 m9))))
     (setq v9f*z (* kur (/ (+ (* (- m9 m2) v9i*z) (* 2 m2 v2i*z)) (+ m2 m9))))
     (setq v2f* (list v2i*x v2i*y v2f*z))
     (setq v9f* (list v9i*x v9i*y v9f*z))
     (setq v2f (trans v2f* (list dx29 dy29 dz29) 0))
     (setq v9f (trans v9f* (list dx29 dy29 dz29) 0))
     (setq v2x (car v2f) v2y (cadr v2f) v2z (caddr v2f))
     (setq v9x (car v9f) v9y (cadr v9f) v9z (caddr v9f))
    )
   )
  )
  (if (> d39 r39)
   (progn 
    (setq v3x (+ v3x (* a3x t)))  (setq v3y (+ v3y (* a3y t)))  (setq v3z (+ v3z (* a3z t)))
    (setq v9x (+ v9x (* a9x t)))  (setq v9y (+ v9y (* a9y t)))  (setq v9z (+ v9z (* a9z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v3i (list v3x v3y v3z)) ;velocita 3 prima dello scontro
     (setq v9i (list v9x v9y v9z)) ;velocita 9 prima dello scontro
     (setq v3i* (trans v3i 0 (list dx39 dy39 dz39)))
     (setq v9i* (trans v9i 0 (list dx39 dy39 dz39)))
     (setq v3i*x (car v3i*) v3i*y (cadr v3i*) v3i*z (caddr v3i*))
     (setq v9i*x (car v9i*) v9i*y (cadr v9i*) v9i*z (caddr v9i*))
     (setq v3f*z (* kur (/ (+ (* (- m3 m9) v3i*z) (* 2 m9 v9i*z)) (+ m3 m9))))
     (setq v9f*z (* kur (/ (+ (* (- m9 m3) v9i*z) (* 2 m3 v3i*z)) (+ m3 m9))))
     (setq v3f* (list v3i*x v3i*y v3f*z))
     (setq v9f* (list v9i*x v9i*y v9f*z))
     (setq v3f (trans v3f* (list dx39 dy39 dz39) 0))
     (setq v9f (trans v9f* (list dx39 dy39 dz39) 0))
     (setq v3x (car v3f) v3y (cadr v3f) v3z (caddr v3f))
     (setq v9x (car v9f) v9y (cadr v9f) v9z (caddr v9f))
    )
   )
  )
  (if (> d49 r49)
   (progn 
    (setq v4x (+ v4x (* a4x t)))  (setq v4y (+ v4y (* a4y t)))  (setq v4z (+ v4z (* a4z t)))
    (setq v9x (+ v9x (* a9x t)))  (setq v9y (+ v9y (* a9y t)))  (setq v9z (+ v9z (* a9z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v4i (list v4x v4y v4z)) ;velocita 4 prima dello scontro
     (setq v9i (list v9x v9y v9z)) ;velocita 9 prima dello scontro
     (setq v4i* (trans v4i 0 (list dx49 dy49 dz49)))
     (setq v9i* (trans v9i 0 (list dx49 dy49 dz49)))
     (setq v4i*x (car v4i*) v4i*y (cadr v4i*) v4i*z (caddr v4i*))
     (setq v9i*x (car v9i*) v9i*y (cadr v9i*) v9i*z (caddr v9i*))
     (setq v4f*z (* kur (/ (+ (* (- m4 m9) v4i*z) (* 2 m9 v9i*z)) (+ m4 m9))))
     (setq v9f*z (* kur (/ (+ (* (- m9 m4) v9i*z) (* 2 m4 v4i*z)) (+ m4 m9))))
     (setq v4f* (list v4i*x v4i*y v4f*z))
     (setq v9f* (list v9i*x v9i*y v9f*z))
     (setq v4f (trans v4f* (list dx49 dy49 dz49) 0))
     (setq v9f (trans v9f* (list dx49 dy49 dz49) 0))
     (setq v4x (car v4f) v4y (cadr v4f) v4z (caddr v4f))
     (setq v9x (car v9f) v9y (cadr v9f) v9z (caddr v9f))
    )
   )
  )
  (if (> d59 r59)
   (progn 
    (setq v5x (+ v5x (* a5x t)))  (setq v5y (+ v5y (* a5y t)))  (setq v5z (+ v5z (* a5z t)))
    (setq v9x (+ v9x (* a9x t)))  (setq v9y (+ v9y (* a9y t)))  (setq v9z (+ v9z (* a9z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v5i (list v5x v5y v5z)) ;velocita 5 prima dello scontro
     (setq v9i (list v9x v9y v9z)) ;velocita 9 prima dello scontro
     (setq v5i* (trans v5i 0 (list dx59 dy59 dz59)))
     (setq v9i* (trans v9i 0 (list dx59 dy59 dz59)))
     (setq v5i*x (car v5i*) v5i*y (cadr v5i*) v5i*z (caddr v5i*))
     (setq v9i*x (car v9i*) v9i*y (cadr v9i*) v9i*z (caddr v9i*))
     (setq v5f*z (* kur (/ (+ (* (- m5 m9) v5i*z) (* 2 m9 v9i*z)) (+ m5 m9))))
     (setq v9f*z (* kur (/ (+ (* (- m9 m5) v9i*z) (* 2 m5 v5i*z)) (+ m5 m9))))
     (setq v5f* (list v5i*x v5i*y v5f*z))
     (setq v9f* (list v9i*x v9i*y v9f*z))
     (setq v5f (trans v5f* (list dx59 dy59 dz59) 0))
     (setq v9f (trans v9f* (list dx59 dy59 dz59) 0))
     (setq v5x (car v5f) v5y (cadr v5f) v5z (caddr v5f))
     (setq v9x (car v9f) v9y (cadr v9f) v9z (caddr v9f))
    )
   )
  )
  (if (> d69 r69)
   (progn 
    (setq v6x (+ v6x (* a6x t)))  (setq v6y (+ v6y (* a6y t)))  (setq v6z (+ v6z (* a6z t)))
    (setq v9x (+ v9x (* a9x t)))  (setq v9y (+ v9y (* a9y t)))  (setq v9z (+ v9z (* a9z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v6i (list v6x v6y v6z)) ;velocita 6 prima dello scontro
     (setq v9i (list v9x v9y v9z)) ;velocita 9 prima dello scontro
     (setq v6i* (trans v6i 0 (list dx69 dy69 dz69)))
     (setq v9i* (trans v9i 0 (list dx69 dy69 dz69)))
     (setq v6i*x (car v6i*) v6i*y (cadr v6i*) v6i*z (caddr v6i*))
     (setq v9i*x (car v9i*) v9i*y (cadr v9i*) v9i*z (caddr v9i*))
     (setq v6f*z (* kur (/ (+ (* (- m6 m9) v6i*z) (* 2 m9 v9i*z)) (+ m6 m9))))
     (setq v9f*z (* kur (/ (+ (* (- m9 m6) v9i*z) (* 2 m6 v6i*z)) (+ m6 m9))))
     (setq v6f* (list v6i*x v6i*y v6f*z))
     (setq v9f* (list v9i*x v9i*y v9f*z))
     (setq v6f (trans v6f* (list dx69 dy69 dz69) 0))
     (setq v9f (trans v9f* (list dx69 dy69 dz69) 0))
     (setq v6x (car v6f) v6y (cadr v6f) v6z (caddr v6f))
     (setq v9x (car v9f) v9y (cadr v9f) v9z (caddr v9f))
    )
   )
  )
  (if (> d79 r79)
   (progn 
    (setq v7x (+ v7x (* a7x t)))  (setq v7y (+ v7y (* a7y t)))  (setq v7z (+ v7z (* a7z t)))
    (setq v9x (+ v9x (* a9x t)))  (setq v9y (+ v9y (* a9y t)))  (setq v9z (+ v9z (* a9z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v7i (list v7x v7y v7z)) ;velocita 7 prima dello scontro
     (setq v9i (list v9x v9y v9z)) ;velocita 9 prima dello scontro
     (setq v7i* (trans v7i 0 (list dx79 dy79 dz79)))
     (setq v9i* (trans v9i 0 (list dx79 dy79 dz79)))
     (setq v7i*x (car v7i*) v7i*y (cadr v7i*) v7i*z (caddr v7i*))
     (setq v9i*x (car v9i*) v9i*y (cadr v9i*) v9i*z (caddr v9i*))
     (setq v7f*z (* kur (/ (+ (* (- m7 m9) v7i*z) (* 2 m9 v9i*z)) (+ m7 m9))))
     (setq v9f*z (* kur (/ (+ (* (- m9 m7) v9i*z) (* 2 m7 v7i*z)) (+ m7 m9))))
     (setq v7f* (list v7i*x v7i*y v7f*z))
     (setq v9f* (list v9i*x v9i*y v9f*z))
     (setq v7f (trans v7f* (list dx79 dy79 dz79) 0))
     (setq v9f (trans v9f* (list dx79 dy79 dz79) 0))
     (setq v7x (car v7f) v7y (cadr v7f) v7z (caddr v7f))
     (setq v9x (car v9f) v9y (cadr v9f) v9z (caddr v9f))
    )
   )
  )
  (if (> d89 r89)
   (progn 
    (setq v8x (+ v8x (* a8x t)))  (setq v8y (+ v8y (* a8y t)))  (setq v8z (+ v8z (* a8z t)))
    (setq v9x (+ v9x (* a9x t)))  (setq v9y (+ v9y (* a9y t)))  (setq v9z (+ v9z (* a9z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v8i (list v8x v8y v8z)) ;velocita 8 prima dello scontro
     (setq v9i (list v9x v9y v9z)) ;velocita 9 prima dello scontro
     (setq v8i* (trans v8i 0 (list dx89 dy89 dz89)))
     (setq v9i* (trans v9i 0 (list dx89 dy89 dz89)))
     (setq v8i*x (car v8i*) v8i*y (cadr v8i*) v8i*z (caddr v8i*))
     (setq v9i*x (car v9i*) v9i*y (cadr v9i*) v9i*z (caddr v9i*))
     (setq v8f*z (* kur (/ (+ (* (- m8 m9) v8i*z) (* 2 m9 v9i*z)) (+ m8 m9))))
     (setq v9f*z (* kur (/ (+ (* (- m9 m8) v9i*z) (* 2 m8 v8i*z)) (+ m8 m9))))
     (setq v8f* (list v8i*x v8i*y v8f*z))
     (setq v9f* (list v9i*x v9i*y v9f*z))
     (setq v8f (trans v8f* (list dx89 dy89 dz89) 0))
     (setq v9f (trans v9f* (list dx89 dy89 dz89) 0))
     (setq v8x (car v8f) v8y (cadr v8f) v8z (caddr v8f))
     (setq v9x (car v9f) v9y (cadr v9f) v9z (caddr v9f))
    )
   )
  )

  (if (< (- x1 r1) xsa) (setq v1x (* (+ (* -2 kbi) 1) v1x) ) )
  (if (< (- y1 r1) ysa) (setq v1y (* (+ (* -2 kbi) 1) v1y) ) )   
  (if (< (- z1 r1) zsa) (setq v1z (* (+ (* -2 kbi) 1) v1z) ) )   
  (if (> (+ x1 r1) xsb) (setq v1x (* (+ (* -2 kbi) 1) v1x) ) )   
  (if (> (+ y1 r1) ysb) (setq v1y (* (+ (* -2 kbi) 1) v1y) ) )   
  (if (> (+ z1 r1) zsb) (setq v1z (* (+ (* -2 kbi) 1) v1z) ) )   
  (if (< (- x2 r2) xsa) (setq v2x (* (+ (* -2 kbi) 1) v2x) ) )   
  (if (< (- y2 r2) ysa) (setq v2y (* (+ (* -2 kbi) 1) v2y) ) )   
  (if (< (- z2 r2) zsa) (setq v2z (* (+ (* -2 kbi) 1) v2z) ) )   
  (if (> (+ x2 r2) xsb) (setq v2x (* (+ (* -2 kbi) 1) v2x) ) )   
  (if (> (+ y2 r2) ysb) (setq v2y (* (+ (* -2 kbi) 1) v2y) ) )   
  (if (> (+ z2 r2) zsb) (setq v2z (* (+ (* -2 kbi) 1) v2z) ) )   
  (if (< (- x3 r3) xsa) (setq v3x (* (+ (* -2 kbi) 1) v3x) ) )   
  (if (< (- y3 r3) ysa) (setq v3y (* (+ (* -2 kbi) 1) v3y) ) )   
  (if (< (- z3 r3) zsa) (setq v3z (* (+ (* -2 kbi) 1) v3z) ) )   
  (if (> (+ x3 r3) xsb) (setq v3x (* (+ (* -2 kbi) 1) v3x) ) )   
  (if (> (+ y3 r3) ysb) (setq v3y (* (+ (* -2 kbi) 1) v3y) ) )   
  (if (> (+ z3 r3) zsb) (setq v3z (* (+ (* -2 kbi) 1) v3z) ) )   
  (if (< (- x4 r4) xsa) (setq v4x (* (+ (* -2 kbi) 1) v4x) ) )   
  (if (< (- y4 r4) ysa) (setq v4y (* (+ (* -2 kbi) 1) v4y) ) )   
  (if (< (- z4 r4) zsa) (setq v4z (* (+ (* -2 kbi) 1) v4z) ) )   
  (if (> (+ x4 r4) xsb) (setq v4x (* (+ (* -2 kbi) 1) v4x) ) )   
  (if (> (+ y4 r4) ysb) (setq v4y (* (+ (* -2 kbi) 1) v4y) ) )   
  (if (> (+ z4 r4) zsb) (setq v4z (* (+ (* -2 kbi) 1) v4z) ) )   
  (if (< (- x5 r5) xsa) (setq v5x (* (+ (* -2 kbi) 1) v5x) ) )   
  (if (< (- y5 r5) ysa) (setq v5y (* (+ (* -2 kbi) 1) v5y) ) )   
  (if (< (- z5 r5) zsa) (setq v5z (* (+ (* -2 kbi) 1) v5z) ) )   
  (if (> (+ x5 r5) xsb) (setq v5x (* (+ (* -2 kbi) 1) v5x) ) )   
  (if (> (+ y5 r5) ysb) (setq v5y (* (+ (* -2 kbi) 1) v5y) ) )   
  (if (> (+ z5 r5) zsb) (setq v5z (* (+ (* -2 kbi) 1) v5z) ) )   
  (if (< (- x6 r6) xsa) (setq v6x (* (+ (* -2 kbi) 1) v6x) ) )   
  (if (< (- y6 r6) ysa) (setq v6y (* (+ (* -2 kbi) 1) v6y) ) )   
  (if (< (- z6 r6) zsa) (setq v6z (* (+ (* -2 kbi) 1) v6z) ) )   
  (if (> (+ x6 r6) xsb) (setq v6x (* (+ (* -2 kbi) 1) v6x) ) )   
  (if (> (+ y6 r6) ysb) (setq v6y (* (+ (* -2 kbi) 1) v6y) ) )   
  (if (> (+ z6 r6) zsb) (setq v6z (* (+ (* -2 kbi) 1) v6z) ) )   
  (if (< (- x7 r7) xsa) (setq v7x (* (+ (* -2 kbi) 1) v7x) ) )   
  (if (< (- y7 r7) ysa) (setq v7y (* (+ (* -2 kbi) 1) v7y) ) )   
  (if (< (- z7 r7) zsa) (setq v7z (* (+ (* -2 kbi) 1) v7z) ) )   
  (if (> (+ x7 r7) xsb) (setq v7x (* (+ (* -2 kbi) 1) v7x) ) )   
  (if (> (+ y7 r7) ysb) (setq v7y (* (+ (* -2 kbi) 1) v7y) ) )   
  (if (> (+ z7 r7) zsb) (setq v7z (* (+ (* -2 kbi) 1) v7z) ) )   
  (if (< (- x8 r8) xsa) (setq v8x (* (+ (* -2 kbi) 1) v8x) ) )   
  (if (< (- y8 r8) ysa) (setq v8y (* (+ (* -2 kbi) 1) v8y) ) )   
  (if (< (- z8 r8) zsa) (setq v8z (* (+ (* -2 kbi) 1) v8z) ) )   
  (if (> (+ x8 r8) xsb) (setq v8x (* (+ (* -2 kbi) 1) v8x) ) )   
  (if (> (+ y8 r8) ysb) (setq v8y (* (+ (* -2 kbi) 1) v8y) ) )   
  (if (> (+ z8 r8) zsb) (setq v8z (* (+ (* -2 kbi) 1) v8z) ) )   
  (if (< (- x9 r9) xsa) (setq v9x (* (+ (* -2 kbi) 1) v9x) ) )   
  (if (< (- y9 r9) ysa) (setq v9y (* (+ (* -2 kbi) 1) v9y) ) )   
  (if (< (- z9 r9) zsa) (setq v9z (* (+ (* -2 kbi) 1) v9z) ) )   
  (if (> (+ x9 r9) xsb) (setq v9x (* (+ (* -2 kbi) 1) v9x) ) )   
  (if (> (+ y9 r9) ysb) (setq v9y (* (+ (* -2 kbi) 1) v9y) ) )   
  (if (> (+ z9 r9) zsb) (setq v9z (* (+ (* -2 kbi) 1) v9z) ) )   

  (setq s1x (+ (* v1x t) (* 0.5 a1x t t)))  (setq s1y (+ (* v1y t) (* 0.5 a1y t t)))  (setq s1z (+ (* v1z t) (* 0.5 a1z t t)))
  (setq s2x (+ (* v2x t) (* 0.5 a2x t t)))  (setq s2y (+ (* v2y t) (* 0.5 a2y t t)))  (setq s2z (+ (* v2z t) (* 0.5 a2z t t)))
  (setq s3x (+ (* v3x t) (* 0.5 a3x t t)))  (setq s3y (+ (* v3y t) (* 0.5 a3y t t)))  (setq s3z (+ (* v3z t) (* 0.5 a3z t t)))
  (setq s4x (+ (* v4x t) (* 0.5 a4x t t)))  (setq s4y (+ (* v4y t) (* 0.5 a4y t t)))  (setq s4z (+ (* v4z t) (* 0.5 a4z t t)))
  (setq s5x (+ (* v5x t) (* 0.5 a5x t t)))  (setq s5y (+ (* v5y t) (* 0.5 a5y t t)))  (setq s5z (+ (* v5z t) (* 0.5 a5z t t)))
  (setq s6x (+ (* v6x t) (* 0.5 a6x t t)))  (setq s6y (+ (* v6y t) (* 0.5 a6y t t)))  (setq s6z (+ (* v6z t) (* 0.5 a6z t t)))
  (setq s7x (+ (* v7x t) (* 0.5 a7x t t)))  (setq s7y (+ (* v7y t) (* 0.5 a7y t t)))  (setq s7z (+ (* v7z t) (* 0.5 a7z t t)))
  (setq s8x (+ (* v8x t) (* 0.5 a8x t t)))  (setq s8y (+ (* v8y t) (* 0.5 a8y t t)))  (setq s8z (+ (* v8z t) (* 0.5 a8z t t)))
  (setq s9x (+ (* v9x t) (* 0.5 a9x t t)))  (setq s9y (+ (* v9y t) (* 0.5 a9y t t)))  (setq s9z (+ (* v9z t) (* 0.5 a9z t t)))

  (setq x1 (+ x1 (* k1 s1x)))  (setq y1 (+ y1 (* k1 s1y)))  (setq z1 (+ z1 (* k1 s1z)))
  (setq x2 (+ x2 (* k2 s2x)))  (setq y2 (+ y2 (* k2 s2y)))  (setq z2 (+ z2 (* k2 s2z)))
  (setq x3 (+ x3 (* k3 s3x)))  (setq y3 (+ y3 (* k3 s3y)))  (setq z3 (+ z3 (* k3 s3z)))
  (setq x4 (+ x4 (* k4 s4x)))  (setq y4 (+ y4 (* k4 s4y)))  (setq z4 (+ z4 (* k4 s4z)))
  (setq x5 (+ x5 (* k5 s5x)))  (setq y5 (+ y5 (* k5 s5y)))  (setq z5 (+ z5 (* k5 s5z)))
  (setq x6 (+ x6 (* k6 s6x)))  (setq y6 (+ y6 (* k6 s6y)))  (setq z6 (+ z6 (* k6 s6z)))
  (setq x7 (+ x7 (* k7 s7x)))  (setq y7 (+ y7 (* k7 s7y)))  (setq z7 (+ z7 (* k7 s7z)))
  (setq x8 (+ x8 (* k8 s8x)))  (setq y8 (+ y8 (* k8 s8y)))  (setq z8 (+ z8 (* k8 s8z)))
  (setq x9 (+ x9 (* k9 s9x)))  (setq y9 (+ y9 (* k9 s9y)))  (setq z9 (+ z9 (* k9 s9z)))

  (setq a1 (sqrt (+ (* a1x a1x) (* a1y a1y) (* a1z a1z))))
  (setq a2 (sqrt (+ (* a2x a2x) (* a2y a2y) (* a2z a2z))))
  (setq a3 (sqrt (+ (* a3x a3x) (* a3y a3y) (* a3z a3z))))
  (setq a4 (sqrt (+ (* a4x a4x) (* a4y a4y) (* a4z a4z))))
  (setq a5 (sqrt (+ (* a5x a5x) (* a5y a5y) (* a5z a5z))))
  (setq a6 (sqrt (+ (* a6x a6x) (* a6y a6y) (* a6z a6z))))
  (setq a7 (sqrt (+ (* a7x a7x) (* a7y a7y) (* a7z a7z))))
  (setq a8 (sqrt (+ (* a8x a8x) (* a8y a8y) (* a8z a8z))))
  (setq a9 (sqrt (+ (* a9x a9x) (* a9y a9y) (* a9z a9z))))

  (setq va (+ (abs a1) (abs a2) (abs a3) (abs a4) (abs a5) (abs a6) (abs a7) (abs a8) (abs a9)
              (abs v1) (abs v2) (abs v3) (abs v4) (abs v5) (abs v6) (abs v7) (abs v8) (abs v9)
           )
  )
  (princ "\n")
  (princ va)
  (princ)

  (setq q1 (list x1 y1 z1))
  (setq q2 (list x2 y2 z2))
  (setq q3 (list x3 y3 z3))
  (setq q4 (list x4 y4 z4))
  (setq q5 (list x5 y5 z5))
  (setq q6 (list x6 y6 z6))
  (setq q7 (list x7 y7 z7))
  (setq q8 (list x8 y8 z8))
  (setq q9 (list x9 y9 z9))

  (if (= iscan 0)
   (progn
 
   (if (= ker 0)
    (progn
    (if (= pc "p")
        (progn
         (setvar "clayer" "m1") (command "_point" p1)
         (setvar "clayer" "m2") (command "_point" p2)
         (setvar "clayer" "m3") (command "_point" p3)
         (setvar "clayer" "m4") (command "_point" p4)
         (setvar "clayer" "m5") (command "_point" p5)
         (setvar "clayer" "m6") (command "_point" p6)
         (setvar "clayer" "m7") (command "_point" p7)
         (setvar "clayer" "m8") (command "_point" p8)
         (setvar "clayer" "m9") (command "_point" p9)
        )
        (if (= pc "c")
            (progn
             (setvar "clayer" "m1") (command "_circle" p1 r1)
             (setvar "clayer" "m2") (command "_circle" p2 r2)
             (setvar "clayer" "m3") (command "_circle" p3 r3)
             (setvar "clayer" "m4") (command "_circle" p4 r4)
             (setvar "clayer" "m5") (command "_circle" p5 r5)
             (setvar "clayer" "m6") (command "_circle" p6 r6)
             (setvar "clayer" "m7") (command "_circle" p7 r7)
             (setvar "clayer" "m8") (command "_circle" p8 r8)
             (setvar "clayer" "m9") (command "_circle" p9 r9)
            )
            (if (= pc "s")
                (progn
                 (setvar "clayer" "m1") (command "_sphere" p1 r1)
                 (setvar "clayer" "m2") (command "_sphere" p2 r2)
                 (setvar "clayer" "m3") (command "_sphere" p3 r3)
                 (setvar "clayer" "m4") (command "_sphere" p4 r4)
                 (setvar "clayer" "m5") (command "_sphere" p5 r5)
                 (setvar "clayer" "m6") (command "_sphere" p6 r6)
                 (setvar "clayer" "m7") (command "_sphere" p7 r7)
                 (setvar "clayer" "m8") (command "_sphere" p8 r8)
                 (setvar "clayer" "m9") (command "_sphere" p9 r9)
                )
            )
        )
    )
    )
    (progn
             (command "_move" o1 "" p1 q1)
             (command "_move" o2 "" p2 q2)
             (command "_move" o3 "" p3 q3)
             (command "_move" o4 "" p4 q4)
             (command "_move" o5 "" p5 q5)
             (command "_move" o6 "" p6 q6)
             (command "_move" o7 "" p7 q7)
             (command "_move" o8 "" p8 q8)
             (command "_move" o9 "" p9 q9)
    )    
   )
    
   )

  )
 
  (setq p1 q1)
  (setq p2 q2)  
  (setq p3 q3)  
  (setq p4 q4)  
  (setq p5 q5)  
  (setq p6 q6)  
  (setq p7 q7)  
  (setq p8 q8)  
  (setq p9 q9)  

  (setq iscan (+ 1 iscan))
  (if (= iscan scan) (setq iscan 0))

 )
 (setvar "clayer" "0")
 (command "_pline" p1 p2 p3 p4 p5 p6 p7 p8 p9 p1 "")
)

;;;*****************************************************************
;simula il moto di 10 oggetti sottoposti a forza gravitazionale
;gravita10 ver 1.5 23/07/2010
;Dott. Ing. Emanuele Ballasina
;cell 349-1813748
;mail ballacr75@libero.it

(defun c:gravita10 ()
(setvar "osmode" 0)
(setvar "dimzin" 0)
(setvar "cmdecho" 0)

(command "_-layer" "n" "m1" "_c" 10 "m1" "_s" "m1" "")
(command "_-layer" "n" "m2" "_c" 30 "m2" "_s" "m2" "")
(command "_-layer" "n" "m3" "_c" 50 "m3" "_s" "m3" "")
(command "_-layer" "n" "m4" "_c" 70 "m4" "_s" "m4" "")
(command "_-layer" "n" "m5" "_c" 90 "m5" "_s" "m5" "")
(command "_-layer" "n" "m6" "_c" 120 "m6" "_s" "m6" "")
(command "_-layer" "n" "m7" "_c" 140 "m7" "_s" "m7" "")
(command "_-layer" "n" "m8" "_c" 170 "m8" "_s" "m8" "")
(command "_-layer" "n" "m9" "_c" 190 "m9" "_s" "m9" "")
(command "_-layer" "n" "m0" "_c" 230 "m0" "_s" "m0" "")

(setq t 100) ;scansione tempo
(setq kdi 10) ;riduzione diametro cilindri
(setq scan 10) ;scansione posizione (non funziona >1 se ker=1)

(setq m1 332800.0) ;massa
(setq m2 0.05)
(setq m3 0.89)
(setq m4 1.0)
(setq m5 0.11)
(setq m6 318.0)
(setq m7 95.0)
(setq m8 15.0)
(setq m9 17.0)
(setq m0 0.002)
(setq d1 0.14100) ;densita
(setq d2 0.000543)
(setq d3 0.000525) 
(setq d4 0.000552)
(setq d5 0.000395)
(setq d6 0.000133)
(setq d7 0.000069)
(setq d8 0.000129)
(setq d9 0.000164)
(setq d0 0.000203)
(setq r1 (expt (/ m1 d1) 0.3333)) ;raggio
(setq r2 (expt (/ m2 d2) 0.3333))
(setq r3 (expt (/ m3 d3) 0.3333))
(setq r4 (expt (/ m4 d4) 0.3333))
(setq r5 (expt (/ m5 d5) 0.3333))
(setq r6 (expt (/ m6 d6) 0.3333))
(setq r7 (expt (/ m7 d7) 0.3333))
(setq r8 (expt (/ m8 d8) 0.3333))
(setq r9 (expt (/ m9 d9) 0.3333))
(setq r0 (expt (/ m0 d0) 0.3333))
(setq r12 (+ r1 r2)) ;distanza di sfioro
(setq r13 (+ r1 r3))
(setq r23 (+ r2 r3))
(setq r14 (+ r1 r4))
(setq r24 (+ r2 r4))
(setq r34 (+ r3 r4))
(setq r15 (+ r1 r5))
(setq r25 (+ r2 r5))
(setq r35 (+ r3 r5))
(setq r45 (+ r4 r5))
(setq r16 (+ r1 r6))
(setq r26 (+ r2 r6))
(setq r36 (+ r3 r6))
(setq r46 (+ r4 r6))
(setq r56 (+ r5 r6))
(setq r17 (+ r1 r7))
(setq r27 (+ r2 r7))
(setq r37 (+ r3 r7))
(setq r47 (+ r4 r7))
(setq r57 (+ r5 r7))
(setq r67 (+ r6 r7))
(setq r18 (+ r1 r8))
(setq r28 (+ r2 r8))
(setq r38 (+ r3 r8))
(setq r48 (+ r4 r8))
(setq r58 (+ r5 r8))
(setq r68 (+ r6 r8))
(setq r78 (+ r7 r8))
(setq r19 (+ r1 r9))
(setq r29 (+ r2 r9))
(setq r39 (+ r3 r9))
(setq r49 (+ r4 r9))
(setq r59 (+ r5 r9))
(setq r69 (+ r6 r9))
(setq r79 (+ r7 r9))
(setq r89 (+ r8 r9))
(setq r10 (+ r1 r0))
(setq r20 (+ r2 r0))
(setq r30 (+ r3 r0))
(setq r40 (+ r4 r0))
(setq r50 (+ r5 r0))
(setq r60 (+ r6 r0))
(setq r70 (+ r7 r0))
(setq r80 (+ r8 r0))
(setq r90 (+ r9 r0))

(setq k1 1) ;abilita movimento pianeta
(setq k2 1)
(setq k3 1)
(setq k4 1)
(setq k5 1)
(setq k6 1)
(setq k7 1)
(setq k8 1)
(setq k9 1)
(setq k0 1)
(setq kur 0) ;abilita urti, con coefficente di rimbalzo, <1 smorza
(setq kbi 0) ;abilita rimbalzo tipo biliardo contro pareti dello schermo, <1 smorza
(setq ker 0) ;1=cancella pianeti vecchi, 0=mantiene tutti i pianeti
(setq c (getvar "VIEWCTR"))
(setq xsc (car c))
(setq ysc (cadr c))
(setq zsc (caddr c))
(setq currh (getvar "viewsize"))
(setq sizex (nth 0 (getvar "screensize")))
(setq sizey (nth 1 (getvar "screensize")))
(setq j (/ sizex sizey))
(setq currw (* j currh))
(setq h2 (/ currh 2.0))
(setq w2 (/ currw 2.0))
(setq xsa (- xsc w2))
(setq ysa (- ysc h2))
(setq zsa (- zsc h2))
(setq xsb (+ xsc w2))
(setq ysb (+ ysc h2))
(setq zsb (+ zsc h2))
(if (/= kbi 0) (command "_rectangle" (list xsa ysa) (list xsb ysb)))

(setq pc "c") ;punti,cerchi,sfere
(setq lc "n") ;abilita disegno linee tra un pianeta e gli altri
(setq tc "n") ;abilita disegno linee traiettoria

(setq x1 0) ;posizione
(setq y1 0)
(setq z1 0)
(setq x2 39000)
(setq y2 0)
(setq z2 0)
(setq x3 72000)
(setq y3 0)
(setq z3 0)
(setq x4 100000)
(setq y4 0)
(setq z4 0)
(setq x5 150000)
(setq y5 0)
(setq z5 0)
(setq x6 520000)
(setq y6 0)
(setq z6 0)
(setq x7 950000)
(setq y7 0) 
(setq z7 0) 
(setq x8 1920000) 
(setq y8 0) 
(setq z8 0) 
(setq x9 3010000) 
(setq y9 0) 
(setq z9 0) 
(setq x0 3950000) 
(setq y0 0) 
(setq z0 0) 

(setq v1x 0.0) ;velocita
(setq v1y 0.0)
(setq v1z 0.0)
(setq v2x 0.0)
(setq v2y 0.9169)
(setq v2z 0.1126)
(setq v3x 0.0)
(setq v3y 0.6789)
(setq v3z 0.0402)
(setq v4x 0.0)
(setq v4y 0.5768)
(setq v4z 0.0)
(setq v5x 0.0)
(setq v5y 0.4708)
(setq v5z 0.0152) 
(setq v6x 0.0)
(setq v6y 0.2528)
(setq v6z 0.0058)
(setq v7x 0.0)
(setq v7y 0.1870)
(setq v7z 0.0081)
(setq v8x 0.0)
(setq v8y 0.1316)
(setq v8z 0.0018)
(setq v9x 0.0)
(setq v9y 0.1051)
(setq v9z 0.0033)
(setq v0x 0.0)
(setq v0y 0.0877)
(setq v0z 0.0271)

(setq p1 (list x1 y1 z1))
(setq p2 (list x2 y2 z2))
(setq p3 (list x3 y3 z3))
(setq p4 (list x4 y4 z4))
(setq p5 (list x5 y5 z5))
(setq p6 (list x6 y6 z6))
(setq p7 (list x7 y7 z7))
(setq p8 (list x8 y8 z8))
(setq p9 (list x9 y9 z9))
(setq p0 (list x0 y0 z0))

(if (= pc "p")
    (progn
     (setvar "clayer" "m1") (command "_point" p1) (setq o1 (cdr (car (entget (entlast)))))
     (setvar "clayer" "m2") (command "_point" p2) (setq o2 (cdr (car (entget (entlast)))))
     (setvar "clayer" "m3") (command "_point" p3) (setq o3 (cdr (car (entget (entlast)))))
     (setvar "clayer" "m4") (command "_point" p4) (setq o4 (cdr (car (entget (entlast)))))
     (setvar "clayer" "m5") (command "_point" p5) (setq o5 (cdr (car (entget (entlast)))))
     (setvar "clayer" "m6") (command "_point" p6) (setq o6 (cdr (car (entget (entlast)))))
     (setvar "clayer" "m7") (command "_point" p7) (setq o7 (cdr (car (entget (entlast)))))
     (setvar "clayer" "m8") (command "_point" p8) (setq o8 (cdr (car (entget (entlast)))))
     (setvar "clayer" "m9") (command "_point" p9) (setq o9 (cdr (car (entget (entlast)))))
     (setvar "clayer" "m0") (command "_point" p0) (setq o0 (cdr (car (entget (entlast)))))
    )
    (if (= pc "c")
        (progn
         (setvar "clayer" "m1") (command "_circle" p1 (* kdi r1)) (setq o1 (cdr (car (entget (entlast)))))
         (setvar "clayer" "m2") (command "_circle" p2 (* kdi r2)) (setq o2 (cdr (car (entget (entlast)))))
         (setvar "clayer" "m3") (command "_circle" p3 (* kdi r3)) (setq o3 (cdr (car (entget (entlast)))))
         (setvar "clayer" "m4") (command "_circle" p4 (* kdi r4)) (setq o4 (cdr (car (entget (entlast)))))
         (setvar "clayer" "m5") (command "_circle" p5 (* kdi r5)) (setq o5 (cdr (car (entget (entlast)))))
         (setvar "clayer" "m6") (command "_circle" p6 (* kdi r6)) (setq o6 (cdr (car (entget (entlast)))))
         (setvar "clayer" "m7") (command "_circle" p7 (* kdi r7)) (setq o7 (cdr (car (entget (entlast)))))
         (setvar "clayer" "m8") (command "_circle" p8 (* kdi r8)) (setq o8 (cdr (car (entget (entlast)))))
         (setvar "clayer" "m9") (command "_circle" p9 (* kdi r9)) (setq o9 (cdr (car (entget (entlast)))))
         (setvar "clayer" "m0") (command "_circle" p0 (* kdi r0)) (setq o0 (cdr (car (entget (entlast)))))
        )
        (if (= pc "s")
            (progn
             (setvar "clayer" "m1") (command "_sphere" p1 r1) (setq o1 (cdr (car (entget (entlast)))))
             (setvar "clayer" "m2") (command "_sphere" p2 r2) (setq o2 (cdr (car (entget (entlast)))))
             (setvar "clayer" "m3") (command "_sphere" p3 r3) (setq o3 (cdr (car (entget (entlast)))))
             (setvar "clayer" "m4") (command "_sphere" p4 r4) (setq o4 (cdr (car (entget (entlast)))))
             (setvar "clayer" "m5") (command "_sphere" p5 r5) (setq o5 (cdr (car (entget (entlast)))))
             (setvar "clayer" "m6") (command "_sphere" p6 r6) (setq o6 (cdr (car (entget (entlast)))))
             (setvar "clayer" "m7") (command "_sphere" p7 r7) (setq o7 (cdr (car (entget (entlast)))))
             (setvar "clayer" "m8") (command "_sphere" p8 r8) (setq o8 (cdr (car (entget (entlast)))))
             (setvar "clayer" "m9") (command "_sphere" p9 r9) (setq o9 (cdr (car (entget (entlast)))))
             (setvar "clayer" "m0") (command "_sphere" p0 r0) (setq o0 (cdr (car (entget (entlast)))))
            )
        )
    )
)

(setq va 1000)
(setq iscan 0)
 (while (> va 0.0001) ;scansione velocit ed accelerazione, se = 0 si ferma il lisp

  (setq v1 (sqrt (+ (* v1x v1x) (* v1y v1y) (* v1z v1z))))
  (setq v2 (sqrt (+ (* v2x v2x) (* v2y v2y) (* v2z v2z))))
  (setq v3 (sqrt (+ (* v3x v3x) (* v3y v3y) (* v3z v3z))))
  (setq v4 (sqrt (+ (* v4x v4x) (* v4y v4y) (* v4z v4z))))
  (setq v5 (sqrt (+ (* v5x v5x) (* v5y v5y) (* v5z v5z))))
  (setq v6 (sqrt (+ (* v6x v6x) (* v6y v6y) (* v6z v6z))))
  (setq v7 (sqrt (+ (* v7x v7x) (* v7y v7y) (* v7z v7z))))
  (setq v8 (sqrt (+ (* v8x v8x) (* v8y v8y) (* v8z v8z))))
  (setq v9 (sqrt (+ (* v9x v9x) (* v9y v9y) (* v9z v9z))))
  (setq v0 (sqrt (+ (* v0x v0x) (* v0y v0y) (* v0z v0z))))
  
  (setq d12 (distance p1 p2))
  (setq d13 (distance p1 p3))
  (setq d23 (distance p2 p3))
  (setq d14 (distance p1 p4))
  (setq d24 (distance p2 p4))
  (setq d34 (distance p3 p4))
  (setq d15 (distance p1 p5))
  (setq d25 (distance p2 p5))
  (setq d35 (distance p3 p5))
  (setq d45 (distance p4 p5))
  (setq d16 (distance p1 p6))
  (setq d26 (distance p2 p6))
  (setq d36 (distance p3 p6))
  (setq d46 (distance p4 p6))
  (setq d56 (distance p5 p6))
  (setq d17 (distance p1 p7))
  (setq d27 (distance p2 p7))
  (setq d37 (distance p3 p7))
  (setq d47 (distance p4 p7))
  (setq d57 (distance p5 p7))
  (setq d67 (distance p6 p7))
  (setq d18 (distance p1 p8))
  (setq d28 (distance p2 p8))
  (setq d38 (distance p3 p8))
  (setq d48 (distance p4 p8))
  (setq d58 (distance p5 p8))
  (setq d68 (distance p6 p8))
  (setq d78 (distance p7 p8))
  (setq d19 (distance p1 p9))
  (setq d29 (distance p2 p9))
  (setq d39 (distance p3 p9))
  (setq d49 (distance p4 p9))
  (setq d59 (distance p5 p9))
  (setq d69 (distance p6 p9))
  (setq d79 (distance p7 p9))
  (setq d89 (distance p8 p9))
  (setq d10 (distance p1 p0))
  (setq d20 (distance p2 p0))
  (setq d30 (distance p3 p0))
  (setq d40 (distance p4 p0))
  (setq d50 (distance p5 p0))
  (setq d60 (distance p6 p0))
  (setq d70 (distance p7 p0))
  (setq d80 (distance p8 p0))
  (setq d90 (distance p9 p0))

  (setq dx12 (- x2 x1))  (setq dy12 (- y2 y1))  (setq dz12 (- z2 z1))
  (setq dx13 (- x3 x1))  (setq dy13 (- y3 y1))  (setq dz13 (- z3 z1))
  (setq dx23 (- x3 x2))  (setq dy23 (- y3 y2))  (setq dz23 (- z3 z2))
  (setq dx14 (- x4 x1))  (setq dy14 (- y4 y1))  (setq dz14 (- z4 z1))
  (setq dx24 (- x4 x2))  (setq dy24 (- y4 y2))  (setq dz24 (- z4 z2))
  (setq dx34 (- x4 x3))  (setq dy34 (- y4 y3))  (setq dz34 (- z4 z3))
  (setq dx15 (- x5 x1))  (setq dy15 (- y5 y1))  (setq dz15 (- z5 z1))
  (setq dx25 (- x5 x2))  (setq dy25 (- y5 y2))  (setq dz25 (- z5 z2))
  (setq dx35 (- x5 x3))  (setq dy35 (- y5 y3))  (setq dz35 (- z5 z3))
  (setq dx45 (- x5 x4))  (setq dy45 (- y5 y4))  (setq dz45 (- z5 z4))
  (setq dx16 (- x6 x1))  (setq dy16 (- y6 y1))  (setq dz16 (- z6 z1))
  (setq dx26 (- x6 x2))  (setq dy26 (- y6 y2))  (setq dz26 (- z6 z2))
  (setq dx36 (- x6 x3))  (setq dy36 (- y6 y3))  (setq dz36 (- z6 z3))
  (setq dx46 (- x6 x4))  (setq dy46 (- y6 y4))  (setq dz46 (- z6 z4))
  (setq dx56 (- x6 x5))  (setq dy56 (- y6 y5))  (setq dz56 (- z6 z5))
  (setq dx17 (- x7 x1))  (setq dy17 (- y7 y1))  (setq dz17 (- z7 z1))
  (setq dx27 (- x7 x2))  (setq dy27 (- y7 y2))  (setq dz27 (- z7 z2))
  (setq dx37 (- x7 x3))  (setq dy37 (- y7 y3))  (setq dz37 (- z7 z3))
  (setq dx47 (- x7 x4))  (setq dy47 (- y7 y4))  (setq dz47 (- z7 z4))
  (setq dx57 (- x7 x5))  (setq dy57 (- y7 y5))  (setq dz57 (- z7 z5))
  (setq dx67 (- x7 x6))  (setq dy67 (- y7 y6))  (setq dz67 (- z7 z6))
  (setq dx18 (- x8 x1))  (setq dy18 (- y8 y1))  (setq dz18 (- z8 z1))
  (setq dx28 (- x8 x2))  (setq dy28 (- y8 y2))  (setq dz28 (- z8 z2))
  (setq dx38 (- x8 x3))  (setq dy38 (- y8 y3))  (setq dz38 (- z8 z3))
  (setq dx48 (- x8 x4))  (setq dy48 (- y8 y4))  (setq dz48 (- z8 z4))
  (setq dx58 (- x8 x5))  (setq dy58 (- y8 y5))  (setq dz58 (- z8 z5))
  (setq dx68 (- x8 x6))  (setq dy68 (- y8 y6))  (setq dz68 (- z8 z6))
  (setq dx78 (- x8 x7))  (setq dy78 (- y8 y7))  (setq dz78 (- z8 z7))
  (setq dx19 (- x9 x1))  (setq dy19 (- y9 y1))  (setq dz19 (- z9 z1))
  (setq dx29 (- x9 x2))  (setq dy29 (- y9 y2))  (setq dz29 (- z9 z2))
  (setq dx39 (- x9 x3))  (setq dy39 (- y9 y3))  (setq dz39 (- z9 z3))
  (setq dx49 (- x9 x4))  (setq dy49 (- y9 y4))  (setq dz49 (- z9 z4))
  (setq dx59 (- x9 x5))  (setq dy59 (- y9 y5))  (setq dz59 (- z9 z5))
  (setq dx69 (- x9 x6))  (setq dy69 (- y9 y6))  (setq dz69 (- z9 z6))
  (setq dx79 (- x9 x7))  (setq dy79 (- y9 y7))  (setq dz79 (- z9 z7))
  (setq dx89 (- x9 x8))  (setq dy89 (- y9 y8))  (setq dz89 (- z9 z8))
  (setq dx10 (- x0 x1))  (setq dy10 (- y0 y1))  (setq dz10 (- z0 z1))
  (setq dx20 (- x0 x2))  (setq dy20 (- y0 y2))  (setq dz20 (- z0 z2))
  (setq dx30 (- x0 x3))  (setq dy30 (- y0 y3))  (setq dz30 (- z0 z3))
  (setq dx40 (- x0 x4))  (setq dy40 (- y0 y4))  (setq dz40 (- z0 z4))
  (setq dx50 (- x0 x5))  (setq dy50 (- y0 y5))  (setq dz50 (- z0 z5))
  (setq dx60 (- x0 x6))  (setq dy60 (- y0 y6))  (setq dz60 (- z0 z6))
  (setq dx70 (- x0 x7))  (setq dy70 (- y0 y7))  (setq dz70 (- z0 z7))
  (setq dx80 (- x0 x8))  (setq dy80 (- y0 y8))  (setq dz80 (- z0 z8))
  (setq dx90 (- x0 x9))  (setq dy90 (- y0 y9))  (setq dz90 (- z0 z9))

;                   GRAVITA              REPULSIONE           ELASTICO       MOLLA
  (if (<= d12 r12) (setq d12 r12))
  (if (<= d13 r13) (setq d13 r13))
  (if (<= d23 r23) (setq d23 r23))
  (if (<= d14 r14) (setq d14 r14))
  (if (<= d24 r24) (setq d24 r24))
  (if (<= d34 r34) (setq d34 r34))
  (if (<= d15 r15) (setq d15 r15))
  (if (<= d25 r25) (setq d25 r25))
  (if (<= d35 r35) (setq d35 r35))
  (if (<= d45 r45) (setq d45 r45))
  (if (<= d16 r16) (setq d16 r16))
  (if (<= d26 r26) (setq d26 r26))
  (if (<= d36 r36) (setq d36 r36))
  (if (<= d46 r46) (setq d46 r46))
  (if (<= d56 r56) (setq d56 r56))
  (if (<= d17 r17) (setq d17 r17))
  (if (<= d27 r27) (setq d27 r27))
  (if (<= d37 r37) (setq d37 r37))
  (if (<= d47 r47) (setq d47 r47))
  (if (<= d57 r57) (setq d57 r57))
  (if (<= d67 r67) (setq d67 r67))
  (if (<= d18 r18) (setq d18 r18))
  (if (<= d28 r28) (setq d28 r28))
  (if (<= d38 r38) (setq d38 r38))
  (if (<= d48 r48) (setq d48 r48))
  (if (<= d58 r58) (setq d58 r58))
  (if (<= d68 r68) (setq d68 r68))
  (if (<= d78 r78) (setq d78 r78))
  (if (<= d19 r19) (setq d19 r19))
  (if (<= d29 r29) (setq d29 r29))
  (if (<= d39 r39) (setq d39 r39))
  (if (<= d49 r49) (setq d49 r49))
  (if (<= d59 r59) (setq d59 r59))
  (if (<= d69 r69) (setq d69 r69))
  (if (<= d79 r79) (setq d79 r79))
  (if (<= d89 r89) (setq d89 r89))
  (if (<= d10 r10) (setq d10 r10))
  (if (<= d20 r20) (setq d20 r20))
  (if (<= d30 r30) (setq d30 r30))
  (if (<= d40 r40) (setq d40 r40))
  (if (<= d50 r50) (setq d50 r50))
  (if (<= d60 r60) (setq d60 r60))
  (if (<= d70 r70) (setq d70 r70))
  (if (<= d80 r80) (setq d80 r80))
  (if (<= d90 r90) (setq d90 r90))
  (setq f12 (+ (* 1 (fgr m1 m2 d12)) (* 1 (fre m1 m2 d12)) (* 1 (fel d12)) (* 1 (fmo d12)) ))
  (setq f13 (+ (* 1 (fgr m1 m3 d13)) (* 1 (fre m1 m3 d13)) (* 1 (fel d13)) (* 1 (fmo d13)) ))
  (setq f23 (+ (* 1 (fgr m2 m3 d23)) (* 1 (fre m2 m3 d23)) (* 1 (fel d23)) (* 1 (fmo d23)) ))
  (setq f14 (+ (* 1 (fgr m1 m4 d14)) (* 1 (fre m1 m4 d14)) (* 1 (fel d14)) (* 1 (fmo d14)) ))
  (setq f24 (+ (* 1 (fgr m2 m4 d24)) (* 1 (fre m2 m4 d24)) (* 1 (fel d24)) (* 1 (fmo d24)) ))
  (setq f34 (+ (* 1 (fgr m3 m4 d34)) (* 1 (fre m3 m4 d34)) (* 1 (fel d34)) (* 1 (fmo d34)) ))
  (setq f15 (+ (* 1 (fgr m1 m5 d15)) (* 1 (fre m1 m5 d15)) (* 1 (fel d15)) (* 1 (fmo d15)) ))
  (setq f25 (+ (* 1 (fgr m2 m5 d25)) (* 1 (fre m2 m5 d25)) (* 1 (fel d25)) (* 1 (fmo d25)) ))
  (setq f35 (+ (* 1 (fgr m3 m5 d35)) (* 1 (fre m3 m5 d35)) (* 1 (fel d35)) (* 1 (fmo d35)) ))
  (setq f45 (+ (* 1 (fgr m4 m5 d45)) (* 1 (fre m4 m5 d45)) (* 1 (fel d45)) (* 1 (fmo d45)) ))
  (setq f16 (+ (* 1 (fgr m1 m6 d16)) (* 1 (fre m1 m6 d16)) (* 1 (fel d16)) (* 1 (fmo d16)) ))
  (setq f26 (+ (* 1 (fgr m2 m6 d26)) (* 1 (fre m2 m6 d26)) (* 1 (fel d26)) (* 1 (fmo d26)) ))
  (setq f36 (+ (* 1 (fgr m3 m6 d36)) (* 1 (fre m3 m6 d36)) (* 1 (fel d36)) (* 1 (fmo d36)) ))
  (setq f46 (+ (* 1 (fgr m4 m6 d46)) (* 1 (fre m4 m6 d46)) (* 1 (fel d46)) (* 1 (fmo d46)) ))
  (setq f56 (+ (* 1 (fgr m5 m6 d56)) (* 1 (fre m5 m6 d56)) (* 1 (fel d56)) (* 1 (fmo d56)) ))
  (setq f17 (+ (* 1 (fgr m1 m7 d17)) (* 1 (fre m1 m7 d17)) (* 1 (fel d17)) (* 1 (fmo d17)) ))
  (setq f27 (+ (* 1 (fgr m2 m7 d27)) (* 1 (fre m2 m7 d27)) (* 1 (fel d27)) (* 1 (fmo d27)) ))
  (setq f37 (+ (* 1 (fgr m3 m7 d37)) (* 1 (fre m3 m7 d37)) (* 1 (fel d37)) (* 1 (fmo d37)) ))
  (setq f47 (+ (* 1 (fgr m4 m7 d47)) (* 1 (fre m4 m7 d47)) (* 1 (fel d47)) (* 1 (fmo d47)) ))
  (setq f57 (+ (* 1 (fgr m5 m7 d57)) (* 1 (fre m5 m7 d57)) (* 1 (fel d57)) (* 1 (fmo d57)) ))
  (setq f67 (+ (* 1 (fgr m6 m7 d67)) (* 1 (fre m6 m7 d67)) (* 1 (fel d67)) (* 1 (fmo d67)) ))
  (setq f18 (+ (* 1 (fgr m1 m8 d18)) (* 1 (fre m1 m8 d18)) (* 1 (fel d18)) (* 1 (fmo d18)) ))
  (setq f28 (+ (* 1 (fgr m2 m8 d28)) (* 1 (fre m2 m8 d28)) (* 1 (fel d28)) (* 1 (fmo d28)) ))
  (setq f38 (+ (* 1 (fgr m3 m8 d38)) (* 1 (fre m3 m8 d38)) (* 1 (fel d38)) (* 1 (fmo d38)) ))
  (setq f48 (+ (* 1 (fgr m4 m8 d48)) (* 1 (fre m4 m8 d48)) (* 1 (fel d48)) (* 1 (fmo d48)) ))
  (setq f58 (+ (* 1 (fgr m5 m8 d58)) (* 1 (fre m5 m8 d58)) (* 1 (fel d58)) (* 1 (fmo d58)) ))
  (setq f68 (+ (* 1 (fgr m6 m8 d68)) (* 1 (fre m6 m8 d68)) (* 1 (fel d68)) (* 1 (fmo d68)) ))
  (setq f78 (+ (* 1 (fgr m7 m8 d78)) (* 1 (fre m7 m8 d78)) (* 1 (fel d78)) (* 1 (fmo d78)) ))
  (setq f19 (+ (* 1 (fgr m1 m9 d19)) (* 1 (fre m1 m9 d19)) (* 1 (fel d19)) (* 1 (fmo d19)) ))
  (setq f29 (+ (* 1 (fgr m2 m9 d29)) (* 1 (fre m2 m9 d29)) (* 1 (fel d29)) (* 1 (fmo d29)) ))
  (setq f39 (+ (* 1 (fgr m3 m9 d39)) (* 1 (fre m3 m9 d39)) (* 1 (fel d39)) (* 1 (fmo d39)) ))
  (setq f49 (+ (* 1 (fgr m4 m9 d49)) (* 1 (fre m4 m9 d49)) (* 1 (fel d49)) (* 1 (fmo d49)) ))
  (setq f59 (+ (* 1 (fgr m5 m9 d59)) (* 1 (fre m5 m9 d59)) (* 1 (fel d59)) (* 1 (fmo d59)) ))
  (setq f69 (+ (* 1 (fgr m6 m9 d69)) (* 1 (fre m6 m9 d69)) (* 1 (fel d69)) (* 1 (fmo d69)) ))
  (setq f79 (+ (* 1 (fgr m7 m9 d79)) (* 1 (fre m7 m9 d79)) (* 1 (fel d79)) (* 1 (fmo d79)) ))
  (setq f89 (+ (* 1 (fgr m8 m9 d89)) (* 1 (fre m8 m9 d89)) (* 1 (fel d89)) (* 1 (fmo d89)) ))
  (setq f10 (+ (* 1 (fgr m1 m0 d10)) (* 1 (fre m1 m0 d10)) (* 1 (fel d10)) (* 1 (fmo d10)) ))
  (setq f20 (+ (* 1 (fgr m2 m0 d20)) (* 1 (fre m2 m0 d20)) (* 1 (fel d20)) (* 1 (fmo d20)) ))
  (setq f30 (+ (* 1 (fgr m3 m0 d30)) (* 1 (fre m3 m0 d30)) (* 1 (fel d30)) (* 1 (fmo d30)) ))
  (setq f40 (+ (* 1 (fgr m4 m0 d40)) (* 1 (fre m4 m0 d40)) (* 1 (fel d40)) (* 1 (fmo d40)) ))
  (setq f50 (+ (* 1 (fgr m5 m0 d50)) (* 1 (fre m5 m0 d50)) (* 1 (fel d50)) (* 1 (fmo d50)) ))
  (setq f60 (+ (* 1 (fgr m6 m0 d60)) (* 1 (fre m6 m0 d60)) (* 1 (fel d60)) (* 1 (fmo d60)) ))
  (setq f70 (+ (* 1 (fgr m7 m0 d70)) (* 1 (fre m7 m0 d70)) (* 1 (fel d70)) (* 1 (fmo d70)) ))
  (setq f80 (+ (* 1 (fgr m8 m0 d80)) (* 1 (fre m8 m0 d80)) (* 1 (fel d80)) (* 1 (fmo d80)) ))
  (setq f90 (+ (* 1 (fgr m9 m0 d90)) (* 1 (fre m9 m0 d90)) (* 1 (fel d90)) (* 1 (fmo d90)) ))

  (setq a12 (/ f12 m1))  (setq a21 (* -1 (/ f12 m2)))
  (setq a13 (/ f13 m1))  (setq a31 (* -1 (/ f13 m3)))
  (setq a23 (/ f23 m2))  (setq a32 (* -1 (/ f23 m3)))
  (setq a14 (/ f14 m1))  (setq a41 (* -1 (/ f14 m4)))
  (setq a24 (/ f24 m2))  (setq a42 (* -1 (/ f24 m4)))
  (setq a34 (/ f34 m3))  (setq a43 (* -1 (/ f34 m4)))
  (setq a15 (/ f15 m1))  (setq a51 (* -1 (/ f15 m5)))
  (setq a25 (/ f25 m2))  (setq a52 (* -1 (/ f25 m5)))
  (setq a35 (/ f35 m3))  (setq a53 (* -1 (/ f35 m5)))
  (setq a45 (/ f45 m4))  (setq a54 (* -1 (/ f45 m5)))
  (setq a16 (/ f16 m1))  (setq a61 (* -1 (/ f16 m6)))
  (setq a26 (/ f26 m2))  (setq a62 (* -1 (/ f26 m6)))
  (setq a36 (/ f36 m3))  (setq a63 (* -1 (/ f36 m6)))
  (setq a46 (/ f46 m4))  (setq a64 (* -1 (/ f46 m6)))
  (setq a56 (/ f56 m5))  (setq a65 (* -1 (/ f56 m6)))
  (setq a17 (/ f17 m1))  (setq a71 (* -1 (/ f17 m7)))
  (setq a27 (/ f27 m2))  (setq a72 (* -1 (/ f27 m7)))
  (setq a37 (/ f37 m3))  (setq a73 (* -1 (/ f37 m7)))
  (setq a47 (/ f47 m4))  (setq a74 (* -1 (/ f47 m7)))
  (setq a57 (/ f57 m5))  (setq a75 (* -1 (/ f57 m7)))
  (setq a67 (/ f67 m6))  (setq a76 (* -1 (/ f67 m7)))
  (setq a18 (/ f18 m1))  (setq a81 (* -1 (/ f18 m8)))
  (setq a28 (/ f28 m2))  (setq a82 (* -1 (/ f28 m8)))
  (setq a38 (/ f38 m3))  (setq a83 (* -1 (/ f38 m8)))
  (setq a48 (/ f48 m4))  (setq a84 (* -1 (/ f48 m8)))
  (setq a58 (/ f58 m5))  (setq a85 (* -1 (/ f58 m8)))
  (setq a68 (/ f68 m6))  (setq a86 (* -1 (/ f68 m8)))
  (setq a78 (/ f78 m7))  (setq a87 (* -1 (/ f78 m8)))
  (setq a19 (/ f19 m1))  (setq a91 (* -1 (/ f19 m9)))
  (setq a29 (/ f29 m2))  (setq a92 (* -1 (/ f29 m9)))
  (setq a39 (/ f39 m3))  (setq a93 (* -1 (/ f39 m9)))
  (setq a49 (/ f49 m4))  (setq a94 (* -1 (/ f49 m9)))
  (setq a59 (/ f59 m5))  (setq a95 (* -1 (/ f59 m9)))
  (setq a69 (/ f69 m6))  (setq a96 (* -1 (/ f69 m9)))
  (setq a79 (/ f79 m7))  (setq a97 (* -1 (/ f79 m9)))
  (setq a89 (/ f89 m8))  (setq a98 (* -1 (/ f89 m9)))
  (setq a10 (/ f10 m1))  (setq a01 (* -1 (/ f10 m0)))
  (setq a20 (/ f20 m2))  (setq a02 (* -1 (/ f20 m0)))
  (setq a30 (/ f30 m3))  (setq a03 (* -1 (/ f30 m0)))
  (setq a40 (/ f40 m4))  (setq a04 (* -1 (/ f40 m0)))
  (setq a50 (/ f50 m5))  (setq a05 (* -1 (/ f50 m0)))
  (setq a60 (/ f60 m6))  (setq a06 (* -1 (/ f60 m0)))
  (setq a70 (/ f70 m7))  (setq a07 (* -1 (/ f70 m0)))
  (setq a80 (/ f80 m8))  (setq a08 (* -1 (/ f80 m0)))
  (setq a90 (/ f90 m9))  (setq a09 (* -1 (/ f90 m0)))
 
  (setq a1x (+ (* 1 (/ (fsx x1 y1 z1) m1)) (* 1 (/ (fwx r1) m1)) (* 1 v1x (/ (fvi m1 r1 v1) m1)) (/ (* a12 dx12) d12) (/ (* a13 dx13) d13) (/ (* a14 dx14) d14) (/ (* a15 dx15) d15) (/ (* a16 dx16) d16) (/ (* a17 dx17) d17) (/ (* a18 dx18) d18) (/ (* a19 dx19) d19) (/ (* a10 dx10) d10) ))
  (setq a1y (+ (* 1 (/ (fsy x1 y1 z1) m1)) (* 1 (/ (fwy r1) m1)) (* 1 v1y (/ (fvi m1 r1 v1) m1)) (/ (* a12 dy12) d12) (/ (* a13 dy13) d13) (/ (* a14 dy14) d14) (/ (* a15 dy15) d15) (/ (* a16 dy16) d16) (/ (* a17 dy17) d17) (/ (* a18 dy18) d18) (/ (* a19 dy19) d19) (/ (* a10 dy10) d10) ))
  (setq a1z (+ (* 1 (/ (fsz x1 y1 z1) m1)) (* 1 (/ (fwz r1) m1)) (* 1 v1z (/ (fvi m1 r1 v1) m1)) (/ (* a12 dz12) d12) (/ (* a13 dz13) d13) (/ (* a14 dz14) d14) (/ (* a15 dz15) d15) (/ (* a16 dz16) d16) (/ (* a17 dz17) d17) (/ (* a18 dz18) d18) (/ (* a19 dz19) d19) (/ (* a10 dz10) d10) ))
  (setq a2x (+ (* 1 (/ (fsx x2 y2 z2) m2)) (* 1 (/ (fwx r2) m2)) (* 1 v2x (/ (fvi m2 r2 v2) m2)) (/ (* a21 dx12) d12) (/ (* a23 dx23) d23) (/ (* a24 dx24) d24) (/ (* a25 dx25) d25) (/ (* a26 dx26) d26) (/ (* a27 dx27) d27) (/ (* a28 dx28) d28) (/ (* a29 dx29) d29) (/ (* a20 dx20) d20) ))
  (setq a2y (+ (* 1 (/ (fsy x2 y2 z2) m2)) (* 1 (/ (fwy r2) m2)) (* 1 v2y (/ (fvi m2 r2 v2) m2)) (/ (* a21 dy12) d12) (/ (* a23 dy23) d23) (/ (* a24 dy24) d24) (/ (* a25 dy25) d25) (/ (* a26 dy26) d26) (/ (* a27 dy27) d27) (/ (* a28 dy28) d28) (/ (* a29 dy29) d29) (/ (* a20 dy20) d20) ))
  (setq a2z (+ (* 1 (/ (fsz x2 y2 z2) m2)) (* 1 (/ (fwz r2) m2)) (* 1 v2z (/ (fvi m2 r2 v2) m2)) (/ (* a21 dz12) d12) (/ (* a23 dz23) d23) (/ (* a24 dz24) d24) (/ (* a25 dz25) d25) (/ (* a26 dz26) d26) (/ (* a27 dz27) d27) (/ (* a28 dz28) d28) (/ (* a29 dz29) d29) (/ (* a20 dz20) d20) ))
  (setq a3x (+ (* 1 (/ (fsx x3 y3 z3) m3)) (* 1 (/ (fwx r3) m3)) (* 1 v3x (/ (fvi m3 r3 v3) m3)) (/ (* a31 dx13) d13) (/ (* a32 dx23) d23) (/ (* a34 dx34) d34) (/ (* a35 dx35) d35) (/ (* a36 dx36) d36) (/ (* a37 dx37) d37) (/ (* a38 dx38) d38) (/ (* a39 dx39) d39) (/ (* a30 dx30) d30) ))
  (setq a3y (+ (* 1 (/ (fsy x3 y3 z3) m3)) (* 1 (/ (fwy r3) m3)) (* 1 v3y (/ (fvi m3 r3 v3) m3)) (/ (* a31 dy13) d13) (/ (* a32 dy23) d23) (/ (* a34 dy34) d34) (/ (* a35 dy35) d35) (/ (* a36 dy36) d36) (/ (* a37 dy37) d37) (/ (* a38 dy38) d38) (/ (* a39 dy39) d39) (/ (* a30 dy30) d30) ))
  (setq a3z (+ (* 1 (/ (fsz x3 y3 z3) m3)) (* 1 (/ (fwz r3) m3)) (* 1 v3z (/ (fvi m3 r3 v3) m3)) (/ (* a31 dz13) d13) (/ (* a32 dz23) d23) (/ (* a34 dz34) d34) (/ (* a35 dz35) d35) (/ (* a36 dz36) d36) (/ (* a37 dz37) d37) (/ (* a38 dz38) d38) (/ (* a39 dz39) d39) (/ (* a30 dz30) d30) ))
  (setq a4x (+ (* 1 (/ (fsx x4 y4 z4) m4)) (* 1 (/ (fwx r4) m4)) (* 1 v4x (/ (fvi m4 r4 v4) m4)) (/ (* a41 dx14) d14) (/ (* a42 dx24) d24) (/ (* a43 dx34) d34) (/ (* a45 dx45) d45) (/ (* a46 dx46) d46) (/ (* a47 dx47) d47) (/ (* a48 dx48) d48) (/ (* a49 dx49) d49) (/ (* a40 dx40) d40) ))
  (setq a4y (+ (* 1 (/ (fsy x4 y4 z4) m4)) (* 1 (/ (fwy r4) m4)) (* 1 v4y (/ (fvi m4 r4 v4) m4)) (/ (* a41 dy14) d14) (/ (* a42 dy24) d24) (/ (* a43 dy34) d34) (/ (* a45 dy45) d45) (/ (* a46 dy46) d46) (/ (* a47 dy47) d47) (/ (* a48 dy48) d48) (/ (* a49 dy49) d49) (/ (* a40 dy40) d40) ))
  (setq a4z (+ (* 1 (/ (fsz x4 y4 z4) m4)) (* 1 (/ (fwz r4) m4)) (* 1 v4z (/ (fvi m4 r4 v4) m4)) (/ (* a41 dz14) d14) (/ (* a42 dz24) d24) (/ (* a43 dz34) d34) (/ (* a45 dz45) d45) (/ (* a46 dz46) d46) (/ (* a47 dz47) d47) (/ (* a48 dz48) d48) (/ (* a49 dz49) d49) (/ (* a40 dz40) d40) ))
  (setq a5x (+ (* 1 (/ (fsx x5 y5 z5) m5)) (* 1 (/ (fwx r5) m5)) (* 1 v5x (/ (fvi m5 r5 v5) m5)) (/ (* a51 dx15) d15) (/ (* a52 dx25) d25) (/ (* a53 dx35) d35) (/ (* a54 dx45) d45) (/ (* a56 dx56) d56) (/ (* a57 dx57) d57) (/ (* a58 dx58) d58) (/ (* a59 dx59) d59) (/ (* a50 dx50) d50) ))
  (setq a5y (+ (* 1 (/ (fsy x5 y5 z5) m5)) (* 1 (/ (fwy r5) m5)) (* 1 v5y (/ (fvi m5 r5 v5) m5)) (/ (* a51 dy15) d15) (/ (* a52 dy25) d25) (/ (* a53 dy35) d35) (/ (* a54 dy45) d45) (/ (* a56 dy56) d56) (/ (* a57 dy57) d57) (/ (* a58 dy58) d58) (/ (* a59 dy59) d59) (/ (* a50 dy50) d50) ))
  (setq a5z (+ (* 1 (/ (fsz x5 y5 z5) m5)) (* 1 (/ (fwz r5) m5)) (* 1 v5z (/ (fvi m5 r5 v5) m5)) (/ (* a51 dz15) d15) (/ (* a52 dz25) d25) (/ (* a53 dz35) d35) (/ (* a54 dz45) d45) (/ (* a56 dz56) d56) (/ (* a57 dz57) d57) (/ (* a58 dz58) d58) (/ (* a59 dz59) d59) (/ (* a50 dz50) d50) ))
  (setq a6x (+ (* 1 (/ (fsx x6 y6 z6) m6)) (* 1 (/ (fwx r6) m6)) (* 1 v6x (/ (fvi m6 r6 v6) m6)) (/ (* a61 dx16) d16) (/ (* a62 dx26) d26) (/ (* a63 dx36) d36) (/ (* a64 dx46) d46) (/ (* a65 dx56) d56) (/ (* a67 dx67) d67) (/ (* a68 dx68) d68) (/ (* a69 dx69) d69) (/ (* a60 dx60) d60) ))
  (setq a6y (+ (* 1 (/ (fsy x6 y6 z6) m6)) (* 1 (/ (fwy r6) m6)) (* 1 v6y (/ (fvi m6 r6 v6) m6)) (/ (* a61 dy16) d16) (/ (* a62 dy26) d26) (/ (* a63 dy36) d36) (/ (* a64 dy46) d46) (/ (* a65 dy56) d56) (/ (* a67 dy67) d67) (/ (* a68 dy68) d68) (/ (* a69 dy69) d69) (/ (* a60 dy60) d60) ))
  (setq a6z (+ (* 1 (/ (fsz x6 y6 z6) m6)) (* 1 (/ (fwz r6) m6)) (* 1 v6z (/ (fvi m6 r6 v6) m6)) (/ (* a61 dz16) d16) (/ (* a62 dz26) d26) (/ (* a63 dz36) d36) (/ (* a64 dz46) d46) (/ (* a65 dz56) d56) (/ (* a67 dz67) d67) (/ (* a68 dz68) d68) (/ (* a69 dz69) d69) (/ (* a60 dz60) d60) ))
  (setq a7x (+ (* 1 (/ (fsx x7 y7 z7) m7)) (* 1 (/ (fwx r7) m7)) (* 1 v7x (/ (fvi m7 r7 v7) m7)) (/ (* a71 dx17) d17) (/ (* a72 dx27) d27) (/ (* a73 dx37) d37) (/ (* a74 dx47) d47) (/ (* a75 dx57) d57) (/ (* a76 dx67) d67) (/ (* a78 dx78) d78) (/ (* a79 dx79) d79) (/ (* a70 dx70) d70) ))
  (setq a7y (+ (* 1 (/ (fsy x7 y7 z7) m7)) (* 1 (/ (fwy r7) m7)) (* 1 v7y (/ (fvi m7 r7 v7) m7)) (/ (* a71 dy17) d17) (/ (* a72 dy27) d27) (/ (* a73 dy37) d37) (/ (* a74 dy47) d47) (/ (* a75 dy57) d57) (/ (* a76 dy67) d67) (/ (* a78 dy78) d78) (/ (* a79 dy79) d79) (/ (* a70 dy70) d70) ))
  (setq a7z (+ (* 1 (/ (fsz x7 y7 z7) m7)) (* 1 (/ (fwz r7) m7)) (* 1 v7z (/ (fvi m7 r7 v7) m7)) (/ (* a71 dz17) d17) (/ (* a72 dz27) d27) (/ (* a73 dz37) d37) (/ (* a74 dz47) d47) (/ (* a75 dz57) d57) (/ (* a76 dz67) d67) (/ (* a78 dz78) d78) (/ (* a79 dz79) d79) (/ (* a70 dz70) d70) ))
  (setq a8x (+ (* 1 (/ (fsx x8 y8 z8) m8)) (* 1 (/ (fwx r8) m8)) (* 1 v8x (/ (fvi m8 r8 v8) m8)) (/ (* a81 dx18) d18) (/ (* a82 dx28) d28) (/ (* a83 dx38) d38) (/ (* a84 dx48) d48) (/ (* a85 dx58) d58) (/ (* a86 dx68) d68) (/ (* a87 dx78) d78) (/ (* a89 dx89) d89) (/ (* a80 dx80) d80) ))
  (setq a8y (+ (* 1 (/ (fsy x8 y8 z8) m8)) (* 1 (/ (fwy r8) m8)) (* 1 v8y (/ (fvi m8 r8 v8) m8)) (/ (* a81 dy18) d18) (/ (* a82 dy28) d28) (/ (* a83 dy38) d38) (/ (* a84 dy48) d48) (/ (* a85 dy58) d58) (/ (* a86 dy68) d68) (/ (* a87 dy78) d78) (/ (* a89 dy89) d89) (/ (* a80 dy80) d80) ))
  (setq a8z (+ (* 1 (/ (fsz x8 y8 z8) m8)) (* 1 (/ (fwz r8) m8)) (* 1 v8z (/ (fvi m8 r8 v8) m8)) (/ (* a81 dz18) d18) (/ (* a82 dz28) d28) (/ (* a83 dz38) d38) (/ (* a84 dz48) d48) (/ (* a85 dz58) d58) (/ (* a86 dz68) d68) (/ (* a87 dz78) d78) (/ (* a89 dz89) d89) (/ (* a80 dz80) d80) ))
  (setq a9x (+ (* 1 (/ (fsx x9 y9 z9) m9)) (* 1 (/ (fwx r9) m9)) (* 1 v9x (/ (fvi m9 r9 v9) m9)) (/ (* a91 dx19) d19) (/ (* a92 dx29) d29) (/ (* a93 dx39) d39) (/ (* a94 dx49) d49) (/ (* a95 dx59) d59) (/ (* a96 dx69) d69) (/ (* a97 dx79) d79) (/ (* a98 dx89) d89) (/ (* a90 dx90) d90) ))
  (setq a9y (+ (* 1 (/ (fsy x9 y9 z9) m9)) (* 1 (/ (fwy r9) m9)) (* 1 v9y (/ (fvi m9 r9 v9) m9)) (/ (* a91 dy19) d19) (/ (* a92 dy29) d29) (/ (* a93 dy39) d39) (/ (* a94 dy49) d49) (/ (* a95 dy59) d59) (/ (* a96 dy69) d69) (/ (* a97 dy79) d79) (/ (* a98 dy89) d89) (/ (* a90 dy90) d90) ))
  (setq a9z (+ (* 1 (/ (fsz x9 y9 z9) m9)) (* 1 (/ (fwz r9) m9)) (* 1 v9z (/ (fvi m9 r9 v9) m9)) (/ (* a91 dz19) d19) (/ (* a92 dz29) d29) (/ (* a93 dz39) d39) (/ (* a94 dz49) d49) (/ (* a95 dz59) d59) (/ (* a96 dz69) d69) (/ (* a97 dz79) d79) (/ (* a98 dz89) d89) (/ (* a90 dz90) d90) ))
  (setq a0x (+ (* 1 (/ (fsx x0 y0 z0) m0)) (* 1 (/ (fwx r0) m0)) (* 1 v0x (/ (fvi m0 r0 v0) m0)) (/ (* a01 dx10) d10) (/ (* a02 dx20) d20) (/ (* a03 dx30) d30) (/ (* a04 dx40) d40) (/ (* a05 dx50) d50) (/ (* a06 dx60) d60) (/ (* a07 dx70) d70) (/ (* a08 dx80) d80) (/ (* a09 dx90) d90) ))
  (setq a0y (+ (* 1 (/ (fsy x0 y0 z0) m0)) (* 1 (/ (fwy r0) m0)) (* 1 v0y (/ (fvi m0 r0 v0) m0)) (/ (* a01 dy10) d10) (/ (* a02 dy20) d20) (/ (* a03 dy30) d30) (/ (* a04 dy40) d40) (/ (* a05 dy50) d50) (/ (* a06 dy60) d60) (/ (* a07 dy70) d70) (/ (* a08 dy80) d80) (/ (* a09 dy90) d90) ))
  (setq a0z (+ (* 1 (/ (fsz x0 y0 z0) m0)) (* 1 (/ (fwz r0) m0)) (* 1 v0z (/ (fvi m0 r0 v0) m0)) (/ (* a01 dz10) d10) (/ (* a02 dz20) d20) (/ (* a03 dz30) d30) (/ (* a04 dz40) d40) (/ (* a05 dz50) d50) (/ (* a06 dz60) d60) (/ (* a07 dz70) d70) (/ (* a08 dz80) d80) (/ (* a09 dz90) d90) ))

  (if (> d12 r12)
   (progn 
    (setq v1x (+ v1x (* a1x t)))  (setq v1y (+ v1y (* a1y t)))  (setq v1z (+ v1z (* a1z t)))
    (setq v2x (+ v2x (* a2x t)))  (setq v2y (+ v2y (* a2y t)))  (setq v2z (+ v2z (* a2z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v1i (list v1x v1y v1z)) ;velocita 1 prima dello scontro
     (setq v2i (list v2x v2y v2z)) ;velocita 2 prima dello scontro
     (setq v1i* (trans v1i 0 (list dx12 dy12 dz12)))
     (setq v2i* (trans v2i 0 (list dx12 dy12 dz12)))
     (setq v1i*x (car v1i*) v1i*y (cadr v1i*) v1i*z (caddr v1i*))
     (setq v2i*x (car v2i*) v2i*y (cadr v2i*) v2i*z (caddr v2i*))
     (setq v1f*z (* kur (/ (+ (* (- m1 m2) v1i*z) (* 2 m2 v2i*z)) (+ m1 m2))))
     (setq v2f*z (* kur (/ (+ (* (- m2 m1) v2i*z) (* 2 m1 v1i*z)) (+ m1 m2))))
     (setq v1f* (list v1i*x v1i*y v1f*z))
     (setq v2f* (list v2i*x v2i*y v2f*z))
     (setq v1f (trans v1f* (list dx12 dy12 dz12) 0))
     (setq v2f (trans v2f* (list dx12 dy12 dz12) 0))
     (setq v1x (car v1f) v1y (cadr v1f) v1z (caddr v1f))
     (setq v2x (car v2f) v2y (cadr v2f) v2z (caddr v2f))
    )
   )
  )
  (if (> d13 r13)
   (progn 
    (setq v1x (+ v1x (* a1x t)))  (setq v1y (+ v1y (* a1y t)))  (setq v1z (+ v1z (* a1z t)))
    (setq v3x (+ v3x (* a3x t)))  (setq v3y (+ v3y (* a3y t)))  (setq v3z (+ v3z (* a3z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v1i (list v1x v1y v1z)) ;velocita 1 prima dello scontro
     (setq v3i (list v3x v3y v3z)) ;velocita 3 prima dello scontro
     (setq v1i* (trans v1i 0 (list dx13 dy13 dz13)))
     (setq v3i* (trans v3i 0 (list dx13 dy13 dz13)))
     (setq v1i*x (car v1i*) v1i*y (cadr v1i*) v1i*z (caddr v1i*))
     (setq v3i*x (car v3i*) v3i*y (cadr v3i*) v3i*z (caddr v3i*))
     (setq v1f*z (* kur (/ (+ (* (- m1 m3) v1i*z) (* 2 m3 v3i*z)) (+ m1 m3))))
     (setq v3f*z (* kur (/ (+ (* (- m3 m1) v3i*z) (* 2 m1 v1i*z)) (+ m1 m3))))
     (setq v1f* (list v1i*x v1i*y v1f*z))
     (setq v3f* (list v3i*x v3i*y v3f*z))
     (setq v1f (trans v1f* (list dx13 dy13 dz13) 0))
     (setq v3f (trans v3f* (list dx13 dy13 dz13) 0))
     (setq v1x (car v1f) v1y (cadr v1f) v1z (caddr v1f))
     (setq v3x (car v3f) v3y (cadr v3f) v3z (caddr v3f))
    )
   )
  )
  (if (> d23 r23)
   (progn 
    (setq v2x (+ v2x (* a2x t)))  (setq v2y (+ v2y (* a2y t)))  (setq v2z (+ v2z (* a2z t)))
    (setq v3x (+ v3x (* a3x t)))  (setq v3y (+ v3y (* a3y t)))  (setq v3z (+ v3z (* a3z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v2i (list v2x v2y v2z)) ;velocita 2 prima dello scontro
     (setq v3i (list v3x v3y v3z)) ;velocita 3 prima dello scontro
     (setq v2i* (trans v2i 0 (list dx23 dy23 dz23)))
     (setq v3i* (trans v3i 0 (list dx23 dy23 dz23)))
     (setq v2i*x (car v2i*) v2i*y (cadr v2i*) v2i*z (caddr v2i*))
     (setq v3i*x (car v3i*) v3i*y (cadr v3i*) v3i*z (caddr v3i*))
     (setq v2f*z (* kur (/ (+ (* (- m2 m3) v2i*z) (* 2 m3 v3i*z)) (+ m2 m3))))
     (setq v3f*z (* kur (/ (+ (* (- m3 m2) v3i*z) (* 2 m2 v2i*z)) (+ m2 m3))))
     (setq v2f* (list v2i*x v2i*y v2f*z))
     (setq v3f* (list v3i*x v3i*y v3f*z))
     (setq v2f (trans v2f* (list dx23 dy23 dz23) 0))
     (setq v3f (trans v3f* (list dx23 dy23 dz23) 0))
     (setq v2x (car v2f) v2y (cadr v2f) v2z (caddr v2f))
     (setq v3x (car v3f) v3y (cadr v3f) v3z (caddr v3f))
    )
   )
  )
  (if (> d14 r14)
   (progn 
    (setq v1x (+ v1x (* a1x t)))  (setq v1y (+ v1y (* a1y t)))  (setq v1z (+ v1z (* a1z t)))
    (setq v4x (+ v4x (* a4x t)))  (setq v4y (+ v4y (* a4y t)))  (setq v4z (+ v4z (* a4z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v1i (list v1x v1y v1z)) ;velocita 1 prima dello scontro
     (setq v4i (list v4x v4y v4z)) ;velocita 4 prima dello scontro
     (setq v1i* (trans v1i 0 (list dx14 dy14 dz14)))
     (setq v4i* (trans v4i 0 (list dx14 dy14 dz14)))
     (setq v1i*x (car v1i*) v1i*y (cadr v1i*) v1i*z (caddr v1i*))
     (setq v4i*x (car v4i*) v4i*y (cadr v4i*) v4i*z (caddr v4i*))
     (setq v1f*z (* kur (/ (+ (* (- m1 m4) v1i*z) (* 2 m4 v4i*z)) (+ m1 m4))))
     (setq v4f*z (* kur (/ (+ (* (- m4 m1) v4i*z) (* 2 m1 v1i*z)) (+ m1 m4))))
     (setq v1f* (list v1i*x v1i*y v1f*z))
     (setq v4f* (list v4i*x v4i*y v4f*z))
     (setq v1f (trans v1f* (list dx14 dy14 dz14) 0))
     (setq v4f (trans v4f* (list dx14 dy14 dz14) 0))
     (setq v1x (car v1f) v1y (cadr v1f) v1z (caddr v1f))
     (setq v4x (car v4f) v4y (cadr v4f) v4z (caddr v4f))
    )
   )
  )
  (if (> d24 r24)
   (progn 
    (setq v2x (+ v2x (* a2x t)))  (setq v2y (+ v2y (* a2y t)))  (setq v2z (+ v2z (* a2z t)))
    (setq v4x (+ v4x (* a4x t)))  (setq v4y (+ v4y (* a4y t)))  (setq v4z (+ v4z (* a4z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v2i (list v2x v2y v2z)) ;velocita 2 prima dello scontro
     (setq v4i (list v4x v4y v4z)) ;velocita 4 prima dello scontro
     (setq v2i* (trans v2i 0 (list dx24 dy24 dz24)))
     (setq v4i* (trans v4i 0 (list dx24 dy24 dz24)))
     (setq v2i*x (car v2i*) v2i*y (cadr v2i*) v2i*z (caddr v2i*))
     (setq v4i*x (car v4i*) v4i*y (cadr v4i*) v4i*z (caddr v4i*))
     (setq v2f*z (* kur (/ (+ (* (- m2 m4) v2i*z) (* 2 m4 v4i*z)) (+ m2 m4))))
     (setq v4f*z (* kur (/ (+ (* (- m4 m2) v4i*z) (* 2 m2 v2i*z)) (+ m2 m4))))
     (setq v2f* (list v2i*x v2i*y v2f*z))
     (setq v4f* (list v4i*x v4i*y v4f*z))
     (setq v2f (trans v2f* (list dx24 dy24 dz24) 0))
     (setq v4f (trans v4f* (list dx24 dy24 dz24) 0))
     (setq v2x (car v2f) v2y (cadr v2f) v2z (caddr v2f))
     (setq v4x (car v4f) v4y (cadr v4f) v4z (caddr v4f))
    )
   )
  )
  (if (> d34 r34)
   (progn 
    (setq v3x (+ v3x (* a3x t)))  (setq v3y (+ v3y (* a3y t)))  (setq v3z (+ v3z (* a3z t)))
    (setq v4x (+ v4x (* a4x t)))  (setq v4y (+ v4y (* a4y t)))  (setq v4z (+ v4z (* a4z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v3i (list v3x v3y v3z)) ;velocita 3 prima dello scontro
     (setq v4i (list v4x v4y v4z)) ;velocita 4 prima dello scontro
     (setq v3i* (trans v3i 0 (list dx34 dy34 dz34)))
     (setq v4i* (trans v4i 0 (list dx34 dy34 dz34)))
     (setq v3i*x (car v3i*) v3i*y (cadr v3i*) v3i*z (caddr v3i*))
     (setq v4i*x (car v4i*) v4i*y (cadr v4i*) v4i*z (caddr v4i*))
     (setq v3f*z (* kur (/ (+ (* (- m3 m4) v3i*z) (* 2 m4 v4i*z)) (+ m3 m4))))
     (setq v4f*z (* kur (/ (+ (* (- m4 m3) v4i*z) (* 2 m3 v3i*z)) (+ m3 m4))))
     (setq v3f* (list v3i*x v3i*y v3f*z))
     (setq v4f* (list v4i*x v4i*y v4f*z))
     (setq v3f (trans v3f* (list dx34 dy34 dz34) 0))
     (setq v4f (trans v4f* (list dx34 dy34 dz34) 0))
     (setq v3x (car v3f) v3y (cadr v3f) v3z (caddr v3f))
     (setq v4x (car v4f) v4y (cadr v4f) v4z (caddr v4f))
    )
   )
  )
  (if (> d15 r15)
   (progn 
    (setq v1x (+ v1x (* a1x t)))  (setq v1y (+ v1y (* a1y t)))  (setq v1z (+ v1z (* a1z t)))
    (setq v5x (+ v5x (* a5x t)))  (setq v5y (+ v5y (* a5y t)))  (setq v5z (+ v5z (* a5z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v1i (list v1x v1y v1z)) ;velocita 1 prima dello scontro
     (setq v5i (list v5x v5y v5z)) ;velocita 5 prima dello scontro
     (setq v1i* (trans v1i 0 (list dx15 dy15 dz15)))
     (setq v5i* (trans v5i 0 (list dx15 dy15 dz15)))
     (setq v1i*x (car v1i*) v1i*y (cadr v1i*) v1i*z (caddr v1i*))
     (setq v5i*x (car v5i*) v5i*y (cadr v5i*) v5i*z (caddr v5i*))
     (setq v1f*z (* kur (/ (+ (* (- m1 m5) v1i*z) (* 2 m5 v5i*z)) (+ m1 m5))))
     (setq v5f*z (* kur (/ (+ (* (- m5 m1) v5i*z) (* 2 m1 v1i*z)) (+ m1 m5))))
     (setq v1f* (list v1i*x v1i*y v1f*z))
     (setq v5f* (list v5i*x v5i*y v5f*z))
     (setq v1f (trans v1f* (list dx15 dy15 dz15) 0))
     (setq v5f (trans v5f* (list dx15 dy15 dz15) 0))
     (setq v1x (car v1f) v1y (cadr v1f) v1z (caddr v1f))
     (setq v5x (car v5f) v5y (cadr v5f) v5z (caddr v5f))
    )
   )
  )
  (if (> d25 r25)
   (progn 
    (setq v2x (+ v2x (* a2x t)))  (setq v2y (+ v2y (* a2y t)))  (setq v2z (+ v2z (* a2z t)))
    (setq v5x (+ v5x (* a5x t)))  (setq v5y (+ v5y (* a5y t)))  (setq v5z (+ v5z (* a5z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v2i (list v2x v2y v2z)) ;velocita 2 prima dello scontro
     (setq v5i (list v5x v5y v5z)) ;velocita 5 prima dello scontro
     (setq v2i* (trans v2i 0 (list dx25 dy25 dz25)))
     (setq v5i* (trans v5i 0 (list dx25 dy25 dz25)))
     (setq v2i*x (car v2i*) v2i*y (cadr v2i*) v2i*z (caddr v2i*))
     (setq v5i*x (car v5i*) v5i*y (cadr v5i*) v5i*z (caddr v5i*))
     (setq v2f*z (* kur (/ (+ (* (- m2 m5) v2i*z) (* 2 m5 v5i*z)) (+ m2 m5))))
     (setq v5f*z (* kur (/ (+ (* (- m5 m2) v5i*z) (* 2 m2 v2i*z)) (+ m2 m5))))
     (setq v2f* (list v2i*x v2i*y v2f*z))
     (setq v5f* (list v5i*x v5i*y v5f*z))
     (setq v2f (trans v2f* (list dx25 dy25 dz25) 0))
     (setq v5f (trans v5f* (list dx25 dy25 dz25) 0))
     (setq v2x (car v2f) v2y (cadr v2f) v2z (caddr v2f))
     (setq v5x (car v5f) v5y (cadr v5f) v5z (caddr v5f))
    )
   )
  )
  (if (> d35 r35)
   (progn 
    (setq v3x (+ v3x (* a3x t)))  (setq v3y (+ v3y (* a3y t)))  (setq v3z (+ v3z (* a3z t)))
    (setq v5x (+ v5x (* a5x t)))  (setq v5y (+ v5y (* a5y t)))  (setq v5z (+ v5z (* a5z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v3i (list v3x v3y v3z)) ;velocita 3 prima dello scontro
     (setq v5i (list v5x v5y v5z)) ;velocita 5 prima dello scontro
     (setq v3i* (trans v3i 0 (list dx35 dy35 dz35)))
     (setq v5i* (trans v5i 0 (list dx35 dy35 dz35)))
     (setq v3i*x (car v3i*) v3i*y (cadr v3i*) v3i*z (caddr v3i*))
     (setq v5i*x (car v5i*) v5i*y (cadr v5i*) v5i*z (caddr v5i*))
     (setq v3f*z (* kur (/ (+ (* (- m3 m5) v3i*z) (* 2 m5 v5i*z)) (+ m3 m5))))
     (setq v5f*z (* kur (/ (+ (* (- m5 m3) v5i*z) (* 2 m3 v3i*z)) (+ m3 m5))))
     (setq v3f* (list v3i*x v3i*y v3f*z))
     (setq v5f* (list v5i*x v5i*y v5f*z))
     (setq v3f (trans v3f* (list dx35 dy35 dz35) 0))
     (setq v5f (trans v5f* (list dx35 dy35 dz35) 0))
     (setq v3x (car v3f) v3y (cadr v3f) v3z (caddr v3f))
     (setq v5x (car v5f) v5y (cadr v5f) v5z (caddr v5f))
    )
   )
  )
  (if (> d45 r45)
   (progn 
    (setq v4x (+ v4x (* a4x t)))  (setq v4y (+ v4y (* a4y t)))  (setq v4z (+ v4z (* a4z t)))
    (setq v5x (+ v5x (* a5x t)))  (setq v5y (+ v5y (* a5y t)))  (setq v5z (+ v5z (* a5z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v4i (list v4x v4y v4z)) ;velocita 4 prima dello scontro
     (setq v5i (list v5x v5y v5z)) ;velocita 5 prima dello scontro
     (setq v4i* (trans v4i 0 (list dx45 dy45 dz45)))
     (setq v5i* (trans v5i 0 (list dx45 dy45 dz45)))
     (setq v4i*x (car v4i*) v4i*y (cadr v4i*) v4i*z (caddr v4i*))
     (setq v5i*x (car v5i*) v5i*y (cadr v5i*) v5i*z (caddr v5i*))
     (setq v4f*z (* kur (/ (+ (* (- m4 m5) v4i*z) (* 2 m5 v5i*z)) (+ m4 m5))))
     (setq v5f*z (* kur (/ (+ (* (- m5 m4) v5i*z) (* 2 m4 v4i*z)) (+ m4 m5))))
     (setq v4f* (list v4i*x v4i*y v4f*z))
     (setq v5f* (list v5i*x v5i*y v5f*z))
     (setq v4f (trans v4f* (list dx45 dy45 dz45) 0))
     (setq v5f (trans v5f* (list dx45 dy45 dz45) 0))
     (setq v4x (car v4f) v4y (cadr v4f) v4z (caddr v4f))
     (setq v5x (car v5f) v5y (cadr v5f) v5z (caddr v5f))
    )
   )
  )
  (if (> d16 r16)
   (progn 
    (setq v1x (+ v1x (* a1x t)))  (setq v1y (+ v1y (* a1y t)))  (setq v1z (+ v1z (* a1z t)))
    (setq v6x (+ v6x (* a6x t)))  (setq v6y (+ v6y (* a6y t)))  (setq v6z (+ v6z (* a6z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v1i (list v1x v1y v1z)) ;velocita 1 prima dello scontro
     (setq v6i (list v6x v6y v6z)) ;velocita 6 prima dello scontro
     (setq v1i* (trans v1i 0 (list dx16 dy16 dz16)))
     (setq v6i* (trans v6i 0 (list dx16 dy16 dz16)))
     (setq v1i*x (car v1i*) v1i*y (cadr v1i*) v1i*z (caddr v1i*))
     (setq v6i*x (car v6i*) v6i*y (cadr v6i*) v6i*z (caddr v6i*))
     (setq v1f*z (* kur (/ (+ (* (- m1 m6) v1i*z) (* 2 m6 v6i*z)) (+ m1 m6))))
     (setq v6f*z (* kur (/ (+ (* (- m6 m1) v6i*z) (* 2 m1 v1i*z)) (+ m1 m6))))
     (setq v1f* (list v1i*x v1i*y v1f*z))
     (setq v6f* (list v6i*x v6i*y v6f*z))
     (setq v1f (trans v1f* (list dx16 dy16 dz16) 0))
     (setq v6f (trans v6f* (list dx16 dy16 dz16) 0))
     (setq v1x (car v1f) v1y (cadr v1f) v1z (caddr v1f))
     (setq v6x (car v6f) v6y (cadr v6f) v6z (caddr v6f))
    )
   )
  )
  (if (> d26 r26)
   (progn 
    (setq v2x (+ v2x (* a2x t)))  (setq v2y (+ v2y (* a2y t)))  (setq v2z (+ v2z (* a2z t)))
    (setq v6x (+ v6x (* a6x t)))  (setq v6y (+ v6y (* a6y t)))  (setq v6z (+ v6z (* a6z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v2i (list v2x v2y v2z)) ;velocita 2 prima dello scontro
     (setq v6i (list v6x v6y v6z)) ;velocita 6 prima dello scontro
     (setq v2i* (trans v2i 0 (list dx26 dy26 dz26)))
     (setq v6i* (trans v6i 0 (list dx26 dy26 dz26)))
     (setq v2i*x (car v2i*) v2i*y (cadr v2i*) v2i*z (caddr v2i*))
     (setq v6i*x (car v6i*) v6i*y (cadr v6i*) v6i*z (caddr v6i*))
     (setq v2f*z (* kur (/ (+ (* (- m2 m6) v2i*z) (* 2 m6 v6i*z)) (+ m2 m6))))
     (setq v6f*z (* kur (/ (+ (* (- m6 m2) v6i*z) (* 2 m2 v2i*z)) (+ m2 m6))))
     (setq v2f* (list v2i*x v2i*y v2f*z))
     (setq v6f* (list v6i*x v6i*y v6f*z))
     (setq v2f (trans v2f* (list dx26 dy26 dz26) 0))
     (setq v6f (trans v6f* (list dx26 dy26 dz26) 0))
     (setq v2x (car v2f) v2y (cadr v2f) v2z (caddr v2f))
     (setq v6x (car v6f) v6y (cadr v6f) v6z (caddr v6f))
    )
   )
  )
  (if (> d36 r36)
   (progn 
    (setq v3x (+ v3x (* a3x t)))  (setq v3y (+ v3y (* a3y t)))  (setq v3z (+ v3z (* a3z t)))
    (setq v6x (+ v6x (* a6x t)))  (setq v6y (+ v6y (* a6y t)))  (setq v6z (+ v6z (* a6z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v3i (list v3x v3y v3z)) ;velocita 3 prima dello scontro
     (setq v6i (list v6x v6y v6z)) ;velocita 6 prima dello scontro
     (setq v3i* (trans v3i 0 (list dx36 dy36 dz36)))
     (setq v6i* (trans v6i 0 (list dx36 dy36 dz36)))
     (setq v3i*x (car v3i*) v3i*y (cadr v3i*) v3i*z (caddr v3i*))
     (setq v6i*x (car v6i*) v6i*y (cadr v6i*) v6i*z (caddr v6i*))
     (setq v3f*z (* kur (/ (+ (* (- m3 m6) v3i*z) (* 2 m6 v6i*z)) (+ m3 m6))))
     (setq v6f*z (* kur (/ (+ (* (- m6 m3) v6i*z) (* 2 m3 v3i*z)) (+ m3 m6))))
     (setq v3f* (list v3i*x v3i*y v3f*z))
     (setq v6f* (list v6i*x v6i*y v6f*z))
     (setq v3f (trans v3f* (list dx36 dy36 dz36) 0))
     (setq v6f (trans v6f* (list dx36 dy36 dz36) 0))
     (setq v3x (car v3f) v3y (cadr v3f) v3z (caddr v3f))
     (setq v6x (car v6f) v6y (cadr v6f) v6z (caddr v6f))
    )
   )
  )
  (if (> d46 r46)
   (progn 
    (setq v4x (+ v4x (* a4x t)))  (setq v4y (+ v4y (* a4y t)))  (setq v4z (+ v4z (* a4z t)))
    (setq v6x (+ v6x (* a6x t)))  (setq v6y (+ v6y (* a6y t)))  (setq v6z (+ v6z (* a6z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v4i (list v4x v4y v4z)) ;velocita 4 prima dello scontro
     (setq v6i (list v6x v6y v6z)) ;velocita 6 prima dello scontro
     (setq v4i* (trans v4i 0 (list dx46 dy46 dz46)))
     (setq v6i* (trans v6i 0 (list dx46 dy46 dz46)))
     (setq v4i*x (car v4i*) v4i*y (cadr v4i*) v4i*z (caddr v4i*))
     (setq v6i*x (car v6i*) v6i*y (cadr v6i*) v6i*z (caddr v6i*))
     (setq v4f*z (* kur (/ (+ (* (- m4 m6) v4i*z) (* 2 m6 v6i*z)) (+ m4 m6))))
     (setq v6f*z (* kur (/ (+ (* (- m6 m4) v6i*z) (* 2 m4 v4i*z)) (+ m4 m6))))
     (setq v4f* (list v4i*x v4i*y v4f*z))
     (setq v6f* (list v6i*x v6i*y v6f*z))
     (setq v4f (trans v4f* (list dx46 dy46 dz46) 0))
     (setq v6f (trans v6f* (list dx46 dy46 dz46) 0))
     (setq v4x (car v4f) v4y (cadr v4f) v4z (caddr v4f))
     (setq v6x (car v6f) v6y (cadr v6f) v6z (caddr v6f))
    )
   )
  )
  (if (> d56 r56)
   (progn 
    (setq v5x (+ v5x (* a5x t)))  (setq v5y (+ v5y (* a5y t)))  (setq v5z (+ v5z (* a5z t)))
    (setq v6x (+ v6x (* a6x t)))  (setq v6y (+ v6y (* a6y t)))  (setq v6z (+ v6z (* a6z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v5i (list v5x v5y v5z)) ;velocita 5 prima dello scontro
     (setq v6i (list v6x v6y v6z)) ;velocita 6 prima dello scontro
     (setq v5i* (trans v5i 0 (list dx56 dy56 dz56)))
     (setq v6i* (trans v6i 0 (list dx56 dy56 dz56)))
     (setq v5i*x (car v5i*) v5i*y (cadr v5i*) v5i*z (caddr v5i*))
     (setq v6i*x (car v6i*) v6i*y (cadr v6i*) v6i*z (caddr v6i*))
     (setq v5f*z (* kur (/ (+ (* (- m5 m6) v5i*z) (* 2 m6 v6i*z)) (+ m5 m6))))
     (setq v6f*z (* kur (/ (+ (* (- m6 m5) v6i*z) (* 2 m5 v5i*z)) (+ m5 m6))))
     (setq v5f* (list v5i*x v5i*y v5f*z))
     (setq v6f* (list v6i*x v6i*y v6f*z))
     (setq v5f (trans v5f* (list dx56 dy56 dz56) 0))
     (setq v6f (trans v6f* (list dx56 dy56 dz56) 0))
     (setq v5x (car v5f) v5y (cadr v5f) v5z (caddr v5f))
     (setq v6x (car v6f) v6y (cadr v6f) v6z (caddr v6f))
    )
   )
  )
  (if (> d17 r17)
   (progn 
    (setq v1x (+ v1x (* a1x t)))  (setq v1y (+ v1y (* a1y t)))  (setq v1z (+ v1z (* a1z t)))
    (setq v7x (+ v7x (* a7x t)))  (setq v7y (+ v7y (* a7y t)))  (setq v7z (+ v7z (* a7z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v1i (list v1x v1y v1z)) ;velocita 1 prima dello scontro
     (setq v7i (list v7x v7y v7z)) ;velocita 7 prima dello scontro
     (setq v1i* (trans v1i 0 (list dx17 dy17 dz17)))
     (setq v7i* (trans v7i 0 (list dx17 dy17 dz17)))
     (setq v1i*x (car v1i*) v1i*y (cadr v1i*) v1i*z (caddr v1i*))
     (setq v7i*x (car v7i*) v7i*y (cadr v7i*) v7i*z (caddr v7i*))
     (setq v1f*z (* kur (/ (+ (* (- m1 m7) v1i*z) (* 2 m7 v7i*z)) (+ m1 m7))))
     (setq v7f*z (* kur (/ (+ (* (- m7 m1) v7i*z) (* 2 m1 v1i*z)) (+ m1 m7))))
     (setq v1f* (list v1i*x v1i*y v1f*z))
     (setq v7f* (list v7i*x v7i*y v7f*z))
     (setq v1f (trans v1f* (list dx17 dy17 dz17) 0))
     (setq v7f (trans v7f* (list dx17 dy17 dz17) 0))
     (setq v1x (car v1f) v1y (cadr v1f) v1z (caddr v1f))
     (setq v7x (car v7f) v7y (cadr v7f) v7z (caddr v7f))
    )
   )
  )
  (if (> d27 r27)
   (progn 
    (setq v2x (+ v2x (* a2x t)))  (setq v2y (+ v2y (* a2y t)))  (setq v2z (+ v2z (* a2z t)))
    (setq v7x (+ v7x (* a7x t)))  (setq v7y (+ v7y (* a7y t)))  (setq v7z (+ v7z (* a7z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v2i (list v2x v2y v2z)) ;velocita 2 prima dello scontro
     (setq v7i (list v7x v7y v7z)) ;velocita 7 prima dello scontro
     (setq v2i* (trans v2i 0 (list dx27 dy27 dz27)))
     (setq v7i* (trans v7i 0 (list dx27 dy27 dz27)))
     (setq v2i*x (car v2i*) v2i*y (cadr v2i*) v2i*z (caddr v2i*))
     (setq v7i*x (car v7i*) v7i*y (cadr v7i*) v7i*z (caddr v7i*))
     (setq v2f*z (* kur (/ (+ (* (- m2 m7) v2i*z) (* 2 m7 v7i*z)) (+ m2 m7))))
     (setq v7f*z (* kur (/ (+ (* (- m7 m2) v7i*z) (* 2 m2 v2i*z)) (+ m2 m7))))
     (setq v2f* (list v2i*x v2i*y v2f*z))
     (setq v7f* (list v7i*x v7i*y v7f*z))
     (setq v2f (trans v2f* (list dx27 dy27 dz27) 0))
     (setq v7f (trans v7f* (list dx27 dy27 dz27) 0))
     (setq v2x (car v2f) v2y (cadr v2f) v2z (caddr v2f))
     (setq v7x (car v7f) v7y (cadr v7f) v7z (caddr v7f))
    )
   )
  )
  (if (> d37 r37)
   (progn 
    (setq v3x (+ v3x (* a3x t)))  (setq v3y (+ v3y (* a3y t)))  (setq v3z (+ v3z (* a3z t)))
    (setq v7x (+ v7x (* a7x t)))  (setq v7y (+ v7y (* a7y t)))  (setq v7z (+ v7z (* a7z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v3i (list v3x v3y v3z)) ;velocita 3 prima dello scontro
     (setq v7i (list v7x v7y v7z)) ;velocita 7 prima dello scontro
     (setq v3i* (trans v3i 0 (list dx37 dy37 dz37)))
     (setq v7i* (trans v7i 0 (list dx37 dy37 dz37)))
     (setq v3i*x (car v3i*) v3i*y (cadr v3i*) v3i*z (caddr v3i*))
     (setq v7i*x (car v7i*) v7i*y (cadr v7i*) v7i*z (caddr v7i*))
     (setq v3f*z (* kur (/ (+ (* (- m3 m7) v3i*z) (* 2 m7 v7i*z)) (+ m3 m7))))
     (setq v7f*z (* kur (/ (+ (* (- m7 m3) v7i*z) (* 2 m3 v3i*z)) (+ m3 m7))))
     (setq v3f* (list v3i*x v3i*y v3f*z))
     (setq v7f* (list v7i*x v7i*y v7f*z))
     (setq v3f (trans v3f* (list dx37 dy37 dz37) 0))
     (setq v7f (trans v7f* (list dx37 dy37 dz37) 0))
     (setq v3x (car v3f) v3y (cadr v3f) v3z (caddr v3f))
     (setq v7x (car v7f) v7y (cadr v7f) v7z (caddr v7f))
    )
   )
  )
  (if (> d47 r47)
   (progn 
    (setq v4x (+ v4x (* a4x t)))  (setq v4y (+ v4y (* a4y t)))  (setq v4z (+ v4z (* a4z t)))
    (setq v7x (+ v7x (* a7x t)))  (setq v7y (+ v7y (* a7y t)))  (setq v7z (+ v7z (* a7z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v4i (list v4x v4y v4z)) ;velocita 4 prima dello scontro
     (setq v7i (list v7x v7y v7z)) ;velocita 7 prima dello scontro
     (setq v4i* (trans v4i 0 (list dx47 dy47 dz47)))
     (setq v7i* (trans v7i 0 (list dx47 dy47 dz47)))
     (setq v4i*x (car v4i*) v4i*y (cadr v4i*) v4i*z (caddr v4i*))
     (setq v7i*x (car v7i*) v7i*y (cadr v7i*) v7i*z (caddr v7i*))
     (setq v4f*z (* kur (/ (+ (* (- m4 m7) v4i*z) (* 2 m7 v7i*z)) (+ m4 m7))))
     (setq v7f*z (* kur (/ (+ (* (- m7 m4) v7i*z) (* 2 m4 v4i*z)) (+ m4 m7))))
     (setq v4f* (list v4i*x v4i*y v4f*z))
     (setq v7f* (list v7i*x v7i*y v7f*z))
     (setq v4f (trans v4f* (list dx47 dy47 dz47) 0))
     (setq v7f (trans v7f* (list dx47 dy47 dz47) 0))
     (setq v4x (car v4f) v4y (cadr v4f) v4z (caddr v4f))
     (setq v7x (car v7f) v7y (cadr v7f) v7z (caddr v7f))
    )
   )
  )
  (if (> d57 r57)
   (progn 
    (setq v5x (+ v5x (* a5x t)))  (setq v5y (+ v5y (* a5y t)))  (setq v5z (+ v5z (* a5z t)))
    (setq v7x (+ v7x (* a7x t)))  (setq v7y (+ v7y (* a7y t)))  (setq v7z (+ v7z (* a7z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v5i (list v5x v5y v5z)) ;velocita 5 prima dello scontro
     (setq v7i (list v7x v7y v7z)) ;velocita 7 prima dello scontro
     (setq v5i* (trans v5i 0 (list dx57 dy57 dz57)))
     (setq v7i* (trans v7i 0 (list dx57 dy57 dz57)))
     (setq v5i*x (car v5i*) v5i*y (cadr v5i*) v5i*z (caddr v5i*))
     (setq v7i*x (car v7i*) v7i*y (cadr v7i*) v7i*z (caddr v7i*))
     (setq v5f*z (* kur (/ (+ (* (- m5 m7) v5i*z) (* 2 m7 v7i*z)) (+ m5 m7))))
     (setq v7f*z (* kur (/ (+ (* (- m7 m5) v7i*z) (* 2 m5 v5i*z)) (+ m5 m7))))
     (setq v5f* (list v5i*x v5i*y v5f*z))
     (setq v7f* (list v7i*x v7i*y v7f*z))
     (setq v5f (trans v5f* (list dx57 dy57 dz57) 0))
     (setq v7f (trans v7f* (list dx57 dy57 dz57) 0))
     (setq v5x (car v5f) v5y (cadr v5f) v5z (caddr v5f))
     (setq v7x (car v7f) v7y (cadr v7f) v7z (caddr v7f))
    )
   )
  )
  (if (> d67 r67)
   (progn 
    (setq v6x (+ v6x (* a6x t)))  (setq v6y (+ v6y (* a6y t)))  (setq v6z (+ v6z (* a6z t)))
    (setq v7x (+ v7x (* a7x t)))  (setq v7y (+ v7y (* a7y t)))  (setq v7z (+ v7z (* a7z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v6i (list v6x v6y v6z)) ;velocita 6 prima dello scontro
     (setq v7i (list v7x v7y v7z)) ;velocita 7 prima dello scontro
     (setq v6i* (trans v6i 0 (list dx67 dy67 dz67)))
     (setq v7i* (trans v7i 0 (list dx67 dy67 dz67)))
     (setq v6i*x (car v6i*) v6i*y (cadr v6i*) v6i*z (caddr v6i*))
     (setq v7i*x (car v7i*) v7i*y (cadr v7i*) v7i*z (caddr v7i*))
     (setq v6f*z (* kur (/ (+ (* (- m6 m7) v6i*z) (* 2 m7 v7i*z)) (+ m6 m7))))
     (setq v7f*z (* kur (/ (+ (* (- m7 m6) v7i*z) (* 2 m6 v6i*z)) (+ m6 m7))))
     (setq v6f* (list v6i*x v6i*y v6f*z))
     (setq v7f* (list v7i*x v7i*y v7f*z))
     (setq v6f (trans v6f* (list dx67 dy67 dz67) 0))
     (setq v7f (trans v7f* (list dx67 dy67 dz67) 0))
     (setq v6x (car v6f) v6y (cadr v6f) v6z (caddr v6f))
     (setq v7x (car v7f) v7y (cadr v7f) v7z (caddr v7f))
    )
   )
  )
  (if (> d18 r18)
   (progn 
    (setq v1x (+ v1x (* a1x t)))  (setq v1y (+ v1y (* a1y t)))  (setq v1z (+ v1z (* a1z t)))
    (setq v8x (+ v8x (* a8x t)))  (setq v8y (+ v8y (* a8y t)))  (setq v8z (+ v8z (* a8z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v1i (list v1x v1y v1z)) ;velocita 1 prima dello scontro
     (setq v8i (list v8x v8y v8z)) ;velocita 8 prima dello scontro
     (setq v1i* (trans v1i 0 (list dx18 dy18 dz18)))
     (setq v8i* (trans v8i 0 (list dx18 dy18 dz18)))
     (setq v1i*x (car v1i*) v1i*y (cadr v1i*) v1i*z (caddr v1i*))
     (setq v8i*x (car v8i*) v8i*y (cadr v8i*) v8i*z (caddr v8i*))
     (setq v1f*z (* kur (/ (+ (* (- m1 m8) v1i*z) (* 2 m8 v8i*z)) (+ m1 m8))))
     (setq v8f*z (* kur (/ (+ (* (- m8 m1) v8i*z) (* 2 m1 v1i*z)) (+ m1 m8))))
     (setq v1f* (list v1i*x v1i*y v1f*z))
     (setq v8f* (list v8i*x v8i*y v8f*z))
     (setq v1f (trans v1f* (list dx18 dy18 dz18) 0))
     (setq v8f (trans v8f* (list dx18 dy18 dz18) 0))
     (setq v1x (car v1f) v1y (cadr v1f) v1z (caddr v1f))
     (setq v8x (car v8f) v8y (cadr v8f) v8z (caddr v8f))
    )
   )
  )
  (if (> d28 r28)
   (progn 
    (setq v2x (+ v2x (* a2x t)))  (setq v2y (+ v2y (* a2y t)))  (setq v2z (+ v2z (* a2z t)))
    (setq v8x (+ v8x (* a8x t)))  (setq v8y (+ v8y (* a8y t)))  (setq v8z (+ v8z (* a8z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v2i (list v2x v2y v2z)) ;velocita 2 prima dello scontro
     (setq v8i (list v8x v8y v8z)) ;velocita 8 prima dello scontro
     (setq v2i* (trans v2i 0 (list dx28 dy28 dz28)))
     (setq v8i* (trans v8i 0 (list dx28 dy28 dz28)))
     (setq v2i*x (car v2i*) v2i*y (cadr v2i*) v2i*z (caddr v2i*))
     (setq v8i*x (car v8i*) v8i*y (cadr v8i*) v8i*z (caddr v8i*))
     (setq v2f*z (* kur (/ (+ (* (- m2 m8) v2i*z) (* 2 m8 v8i*z)) (+ m2 m8))))
     (setq v8f*z (* kur (/ (+ (* (- m8 m2) v8i*z) (* 2 m2 v2i*z)) (+ m2 m8))))
     (setq v2f* (list v2i*x v2i*y v2f*z))
     (setq v8f* (list v8i*x v8i*y v8f*z))
     (setq v2f (trans v2f* (list dx28 dy28 dz28) 0))
     (setq v8f (trans v8f* (list dx28 dy28 dz28) 0))
     (setq v2x (car v2f) v2y (cadr v2f) v2z (caddr v2f))
     (setq v8x (car v8f) v8y (cadr v8f) v8z (caddr v8f))
    )
   )
  )
  (if (> d38 r38)
   (progn 
    (setq v3x (+ v3x (* a3x t)))  (setq v3y (+ v3y (* a3y t)))  (setq v3z (+ v3z (* a3z t)))
    (setq v8x (+ v8x (* a8x t)))  (setq v8y (+ v8y (* a8y t)))  (setq v8z (+ v8z (* a8z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v3i (list v3x v3y v3z)) ;velocita 3 prima dello scontro
     (setq v8i (list v8x v8y v8z)) ;velocita 8 prima dello scontro
     (setq v3i* (trans v3i 0 (list dx38 dy38 dz38)))
     (setq v8i* (trans v8i 0 (list dx38 dy38 dz38)))
     (setq v3i*x (car v3i*) v3i*y (cadr v3i*) v3i*z (caddr v3i*))
     (setq v8i*x (car v8i*) v8i*y (cadr v8i*) v8i*z (caddr v8i*))
     (setq v3f*z (* kur (/ (+ (* (- m3 m8) v3i*z) (* 2 m8 v8i*z)) (+ m3 m8))))
     (setq v8f*z (* kur (/ (+ (* (- m8 m3) v8i*z) (* 2 m3 v3i*z)) (+ m3 m8))))
     (setq v3f* (list v3i*x v3i*y v3f*z))
     (setq v8f* (list v8i*x v8i*y v8f*z))
     (setq v3f (trans v3f* (list dx38 dy38 dz38) 0))
     (setq v8f (trans v8f* (list dx38 dy38 dz38) 0))
     (setq v3x (car v3f) v3y (cadr v3f) v3z (caddr v3f))
     (setq v8x (car v8f) v8y (cadr v8f) v8z (caddr v8f))
    )
   )
  )
  (if (> d48 r48)
   (progn 
    (setq v4x (+ v4x (* a4x t)))  (setq v4y (+ v4y (* a4y t)))  (setq v4z (+ v4z (* a4z t)))
    (setq v8x (+ v8x (* a8x t)))  (setq v8y (+ v8y (* a8y t)))  (setq v8z (+ v8z (* a8z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v4i (list v4x v4y v4z)) ;velocita 4 prima dello scontro
     (setq v8i (list v8x v8y v8z)) ;velocita 8 prima dello scontro
     (setq v4i* (trans v4i 0 (list dx48 dy48 dz48)))
     (setq v8i* (trans v8i 0 (list dx48 dy48 dz48)))
     (setq v4i*x (car v4i*) v4i*y (cadr v4i*) v4i*z (caddr v4i*))
     (setq v8i*x (car v8i*) v8i*y (cadr v8i*) v8i*z (caddr v8i*))
     (setq v4f*z (* kur (/ (+ (* (- m4 m8) v4i*z) (* 2 m8 v8i*z)) (+ m4 m8))))
     (setq v8f*z (* kur (/ (+ (* (- m8 m4) v8i*z) (* 2 m4 v4i*z)) (+ m4 m8))))
     (setq v4f* (list v4i*x v4i*y v4f*z))
     (setq v8f* (list v8i*x v8i*y v8f*z))
     (setq v4f (trans v4f* (list dx48 dy48 dz48) 0))
     (setq v8f (trans v8f* (list dx48 dy48 dz48) 0))
     (setq v4x (car v4f) v4y (cadr v4f) v4z (caddr v4f))
     (setq v8x (car v8f) v8y (cadr v8f) v8z (caddr v8f))
    )
   )
  )
  (if (> d58 r58)
   (progn 
    (setq v5x (+ v5x (* a5x t)))  (setq v5y (+ v5y (* a5y t)))  (setq v5z (+ v5z (* a5z t)))
    (setq v8x (+ v8x (* a8x t)))  (setq v8y (+ v8y (* a8y t)))  (setq v8z (+ v8z (* a8z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v5i (list v5x v5y v5z)) ;velocita 5 prima dello scontro
     (setq v8i (list v8x v8y v8z)) ;velocita 8 prima dello scontro
     (setq v5i* (trans v5i 0 (list dx58 dy58 dz58)))
     (setq v8i* (trans v8i 0 (list dx58 dy58 dz58)))
     (setq v5i*x (car v5i*) v5i*y (cadr v5i*) v5i*z (caddr v5i*))
     (setq v8i*x (car v8i*) v8i*y (cadr v8i*) v8i*z (caddr v8i*))
     (setq v5f*z (* kur (/ (+ (* (- m5 m8) v5i*z) (* 2 m8 v8i*z)) (+ m5 m8))))
     (setq v8f*z (* kur (/ (+ (* (- m8 m5) v8i*z) (* 2 m5 v5i*z)) (+ m5 m8))))
     (setq v5f* (list v5i*x v5i*y v5f*z))
     (setq v8f* (list v8i*x v8i*y v8f*z))
     (setq v5f (trans v5f* (list dx58 dy58 dz58) 0))
     (setq v8f (trans v8f* (list dx58 dy58 dz58) 0))
     (setq v5x (car v5f) v5y (cadr v5f) v5z (caddr v5f))
     (setq v8x (car v8f) v8y (cadr v8f) v8z (caddr v8f))
    )
   )
  )
  (if (> d68 r68)
   (progn 
    (setq v6x (+ v6x (* a6x t)))  (setq v6y (+ v6y (* a6y t)))  (setq v6z (+ v6z (* a6z t)))
    (setq v8x (+ v8x (* a8x t)))  (setq v8y (+ v8y (* a8y t)))  (setq v8z (+ v8z (* a8z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v6i (list v6x v6y v6z)) ;velocita 6 prima dello scontro
     (setq v8i (list v8x v8y v8z)) ;velocita 8 prima dello scontro
     (setq v6i* (trans v6i 0 (list dx68 dy68 dz68)))
     (setq v8i* (trans v8i 0 (list dx68 dy68 dz68)))
     (setq v6i*x (car v6i*) v6i*y (cadr v6i*) v6i*z (caddr v6i*))
     (setq v8i*x (car v8i*) v8i*y (cadr v8i*) v8i*z (caddr v8i*))
     (setq v6f*z (* kur (/ (+ (* (- m6 m8) v6i*z) (* 2 m8 v8i*z)) (+ m6 m8))))
     (setq v8f*z (* kur (/ (+ (* (- m8 m6) v8i*z) (* 2 m6 v6i*z)) (+ m6 m8))))
     (setq v6f* (list v6i*x v6i*y v6f*z))
     (setq v8f* (list v8i*x v8i*y v8f*z))
     (setq v6f (trans v6f* (list dx68 dy68 dz68) 0))
     (setq v8f (trans v8f* (list dx68 dy68 dz68) 0))
     (setq v6x (car v6f) v6y (cadr v6f) v6z (caddr v6f))
     (setq v8x (car v8f) v8y (cadr v8f) v8z (caddr v8f))
    )
   )
  )
  (if (> d78 r78)
   (progn 
    (setq v7x (+ v7x (* a7x t)))  (setq v7y (+ v7y (* a7y t)))  (setq v7z (+ v7z (* a7z t)))
    (setq v8x (+ v8x (* a8x t)))  (setq v8y (+ v8y (* a8y t)))  (setq v8z (+ v8z (* a8z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v7i (list v7x v7y v7z)) ;velocita 7 prima dello scontro
     (setq v8i (list v8x v8y v8z)) ;velocita 8 prima dello scontro
     (setq v7i* (trans v7i 0 (list dx78 dy78 dz78)))
     (setq v8i* (trans v8i 0 (list dx78 dy78 dz78)))
     (setq v7i*x (car v7i*) v7i*y (cadr v7i*) v7i*z (caddr v7i*))
     (setq v8i*x (car v8i*) v8i*y (cadr v8i*) v8i*z (caddr v8i*))
     (setq v7f*z (* kur (/ (+ (* (- m7 m8) v7i*z) (* 2 m8 v8i*z)) (+ m7 m8))))
     (setq v8f*z (* kur (/ (+ (* (- m8 m7) v8i*z) (* 2 m7 v7i*z)) (+ m7 m8))))
     (setq v7f* (list v7i*x v7i*y v7f*z))
     (setq v8f* (list v8i*x v8i*y v8f*z))
     (setq v7f (trans v7f* (list dx78 dy78 dz78) 0))
     (setq v8f (trans v8f* (list dx78 dy78 dz78) 0))
     (setq v7x (car v7f) v7y (cadr v7f) v7z (caddr v7f))
     (setq v8x (car v8f) v8y (cadr v8f) v8z (caddr v8f))
    )
   )
  )
  (if (> d19 r19)
   (progn 
    (setq v1x (+ v1x (* a1x t)))  (setq v1y (+ v1y (* a1y t)))  (setq v1z (+ v1z (* a1z t)))
    (setq v9x (+ v9x (* a9x t)))  (setq v9y (+ v9y (* a9y t)))  (setq v9z (+ v9z (* a9z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v1i (list v1x v1y v1z)) ;velocita 1 prima dello scontro
     (setq v9i (list v9x v9y v9z)) ;velocita 9 prima dello scontro
     (setq v1i* (trans v1i 0 (list dx19 dy19 dz19)))
     (setq v9i* (trans v9i 0 (list dx19 dy19 dz19)))
     (setq v1i*x (car v1i*) v1i*y (cadr v1i*) v1i*z (caddr v1i*))
     (setq v9i*x (car v9i*) v9i*y (cadr v9i*) v9i*z (caddr v9i*))
     (setq v1f*z (* kur (/ (+ (* (- m1 m9) v1i*z) (* 2 m9 v9i*z)) (+ m1 m9))))
     (setq v9f*z (* kur (/ (+ (* (- m9 m1) v9i*z) (* 2 m1 v1i*z)) (+ m1 m9))))
     (setq v1f* (list v1i*x v1i*y v1f*z))
     (setq v9f* (list v9i*x v9i*y v9f*z))
     (setq v1f (trans v1f* (list dx19 dy19 dz19) 0))
     (setq v9f (trans v9f* (list dx19 dy19 dz19) 0))
     (setq v1x (car v1f) v1y (cadr v1f) v1z (caddr v1f))
     (setq v9x (car v9f) v9y (cadr v9f) v9z (caddr v9f))
    )
   )
  )
  (if (> d29 r29)
   (progn 
    (setq v2x (+ v2x (* a2x t)))  (setq v2y (+ v2y (* a2y t)))  (setq v2z (+ v2z (* a2z t)))
    (setq v9x (+ v9x (* a9x t)))  (setq v9y (+ v9y (* a9y t)))  (setq v9z (+ v9z (* a9z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v2i (list v2x v2y v2z)) ;velocita 2 prima dello scontro
     (setq v9i (list v9x v9y v9z)) ;velocita 9 prima dello scontro
     (setq v2i* (trans v2i 0 (list dx29 dy29 dz29)))
     (setq v9i* (trans v9i 0 (list dx29 dy29 dz29)))
     (setq v2i*x (car v2i*) v2i*y (cadr v2i*) v2i*z (caddr v2i*))
     (setq v9i*x (car v9i*) v9i*y (cadr v9i*) v9i*z (caddr v9i*))
     (setq v2f*z (* kur (/ (+ (* (- m2 m9) v2i*z) (* 2 m9 v9i*z)) (+ m2 m9))))
     (setq v9f*z (* kur (/ (+ (* (- m9 m2) v9i*z) (* 2 m2 v2i*z)) (+ m2 m9))))
     (setq v2f* (list v2i*x v2i*y v2f*z))
     (setq v9f* (list v9i*x v9i*y v9f*z))
     (setq v2f (trans v2f* (list dx29 dy29 dz29) 0))
     (setq v9f (trans v9f* (list dx29 dy29 dz29) 0))
     (setq v2x (car v2f) v2y (cadr v2f) v2z (caddr v2f))
     (setq v9x (car v9f) v9y (cadr v9f) v9z (caddr v9f))
    )
   )
  )
  (if (> d39 r39)
   (progn 
    (setq v3x (+ v3x (* a3x t)))  (setq v3y (+ v3y (* a3y t)))  (setq v3z (+ v3z (* a3z t)))
    (setq v9x (+ v9x (* a9x t)))  (setq v9y (+ v9y (* a9y t)))  (setq v9z (+ v9z (* a9z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v3i (list v3x v3y v3z)) ;velocita 3 prima dello scontro
     (setq v9i (list v9x v9y v9z)) ;velocita 9 prima dello scontro
     (setq v3i* (trans v3i 0 (list dx39 dy39 dz39)))
     (setq v9i* (trans v9i 0 (list dx39 dy39 dz39)))
     (setq v3i*x (car v3i*) v3i*y (cadr v3i*) v3i*z (caddr v3i*))
     (setq v9i*x (car v9i*) v9i*y (cadr v9i*) v9i*z (caddr v9i*))
     (setq v3f*z (* kur (/ (+ (* (- m3 m9) v3i*z) (* 2 m9 v9i*z)) (+ m3 m9))))
     (setq v9f*z (* kur (/ (+ (* (- m9 m3) v9i*z) (* 2 m3 v3i*z)) (+ m3 m9))))
     (setq v3f* (list v3i*x v3i*y v3f*z))
     (setq v9f* (list v9i*x v9i*y v9f*z))
     (setq v3f (trans v3f* (list dx39 dy39 dz39) 0))
     (setq v9f (trans v9f* (list dx39 dy39 dz39) 0))
     (setq v3x (car v3f) v3y (cadr v3f) v3z (caddr v3f))
     (setq v9x (car v9f) v9y (cadr v9f) v9z (caddr v9f))
    )
   )
  )
  (if (> d49 r49)
   (progn 
    (setq v4x (+ v4x (* a4x t)))  (setq v4y (+ v4y (* a4y t)))  (setq v4z (+ v4z (* a4z t)))
    (setq v9x (+ v9x (* a9x t)))  (setq v9y (+ v9y (* a9y t)))  (setq v9z (+ v9z (* a9z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v4i (list v4x v4y v4z)) ;velocita 4 prima dello scontro
     (setq v9i (list v9x v9y v9z)) ;velocita 9 prima dello scontro
     (setq v4i* (trans v4i 0 (list dx49 dy49 dz49)))
     (setq v9i* (trans v9i 0 (list dx49 dy49 dz49)))
     (setq v4i*x (car v4i*) v4i*y (cadr v4i*) v4i*z (caddr v4i*))
     (setq v9i*x (car v9i*) v9i*y (cadr v9i*) v9i*z (caddr v9i*))
     (setq v4f*z (* kur (/ (+ (* (- m4 m9) v4i*z) (* 2 m9 v9i*z)) (+ m4 m9))))
     (setq v9f*z (* kur (/ (+ (* (- m9 m4) v9i*z) (* 2 m4 v4i*z)) (+ m4 m9))))
     (setq v4f* (list v4i*x v4i*y v4f*z))
     (setq v9f* (list v9i*x v9i*y v9f*z))
     (setq v4f (trans v4f* (list dx49 dy49 dz49) 0))
     (setq v9f (trans v9f* (list dx49 dy49 dz49) 0))
     (setq v4x (car v4f) v4y (cadr v4f) v4z (caddr v4f))
     (setq v9x (car v9f) v9y (cadr v9f) v9z (caddr v9f))
    )
   )
  )
  (if (> d59 r59)
   (progn 
    (setq v5x (+ v5x (* a5x t)))  (setq v5y (+ v5y (* a5y t)))  (setq v5z (+ v5z (* a5z t)))
    (setq v9x (+ v9x (* a9x t)))  (setq v9y (+ v9y (* a9y t)))  (setq v9z (+ v9z (* a9z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v5i (list v5x v5y v5z)) ;velocita 5 prima dello scontro
     (setq v9i (list v9x v9y v9z)) ;velocita 9 prima dello scontro
     (setq v5i* (trans v5i 0 (list dx59 dy59 dz59)))
     (setq v9i* (trans v9i 0 (list dx59 dy59 dz59)))
     (setq v5i*x (car v5i*) v5i*y (cadr v5i*) v5i*z (caddr v5i*))
     (setq v9i*x (car v9i*) v9i*y (cadr v9i*) v9i*z (caddr v9i*))
     (setq v5f*z (* kur (/ (+ (* (- m5 m9) v5i*z) (* 2 m9 v9i*z)) (+ m5 m9))))
     (setq v9f*z (* kur (/ (+ (* (- m9 m5) v9i*z) (* 2 m5 v5i*z)) (+ m5 m9))))
     (setq v5f* (list v5i*x v5i*y v5f*z))
     (setq v9f* (list v9i*x v9i*y v9f*z))
     (setq v5f (trans v5f* (list dx59 dy59 dz59) 0))
     (setq v9f (trans v9f* (list dx59 dy59 dz59) 0))
     (setq v5x (car v5f) v5y (cadr v5f) v5z (caddr v5f))
     (setq v9x (car v9f) v9y (cadr v9f) v9z (caddr v9f))
    )
   )
  )
  (if (> d69 r69)
   (progn 
    (setq v6x (+ v6x (* a6x t)))  (setq v6y (+ v6y (* a6y t)))  (setq v6z (+ v6z (* a6z t)))
    (setq v9x (+ v9x (* a9x t)))  (setq v9y (+ v9y (* a9y t)))  (setq v9z (+ v9z (* a9z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v6i (list v6x v6y v6z)) ;velocita 6 prima dello scontro
     (setq v9i (list v9x v9y v9z)) ;velocita 9 prima dello scontro
     (setq v6i* (trans v6i 0 (list dx69 dy69 dz69)))
     (setq v9i* (trans v9i 0 (list dx69 dy69 dz69)))
     (setq v6i*x (car v6i*) v6i*y (cadr v6i*) v6i*z (caddr v6i*))
     (setq v9i*x (car v9i*) v9i*y (cadr v9i*) v9i*z (caddr v9i*))
     (setq v6f*z (* kur (/ (+ (* (- m6 m9) v6i*z) (* 2 m9 v9i*z)) (+ m6 m9))))
     (setq v9f*z (* kur (/ (+ (* (- m9 m6) v9i*z) (* 2 m6 v6i*z)) (+ m6 m9))))
     (setq v6f* (list v6i*x v6i*y v6f*z))
     (setq v9f* (list v9i*x v9i*y v9f*z))
     (setq v6f (trans v6f* (list dx69 dy69 dz69) 0))
     (setq v9f (trans v9f* (list dx69 dy69 dz69) 0))
     (setq v6x (car v6f) v6y (cadr v6f) v6z (caddr v6f))
     (setq v9x (car v9f) v9y (cadr v9f) v9z (caddr v9f))
    )
   )
  )
  (if (> d79 r79)
   (progn 
    (setq v7x (+ v7x (* a7x t)))  (setq v7y (+ v7y (* a7y t)))  (setq v7z (+ v7z (* a7z t)))
    (setq v9x (+ v9x (* a9x t)))  (setq v9y (+ v9y (* a9y t)))  (setq v9z (+ v9z (* a9z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v7i (list v7x v7y v7z)) ;velocita 7 prima dello scontro
     (setq v9i (list v9x v9y v9z)) ;velocita 9 prima dello scontro
     (setq v7i* (trans v7i 0 (list dx79 dy79 dz79)))
     (setq v9i* (trans v9i 0 (list dx79 dy79 dz79)))
     (setq v7i*x (car v7i*) v7i*y (cadr v7i*) v7i*z (caddr v7i*))
     (setq v9i*x (car v9i*) v9i*y (cadr v9i*) v9i*z (caddr v9i*))
     (setq v7f*z (* kur (/ (+ (* (- m7 m9) v7i*z) (* 2 m9 v9i*z)) (+ m7 m9))))
     (setq v9f*z (* kur (/ (+ (* (- m9 m7) v9i*z) (* 2 m7 v7i*z)) (+ m7 m9))))
     (setq v7f* (list v7i*x v7i*y v7f*z))
     (setq v9f* (list v9i*x v9i*y v9f*z))
     (setq v7f (trans v7f* (list dx79 dy79 dz79) 0))
     (setq v9f (trans v9f* (list dx79 dy79 dz79) 0))
     (setq v7x (car v7f) v7y (cadr v7f) v7z (caddr v7f))
     (setq v9x (car v9f) v9y (cadr v9f) v9z (caddr v9f))
    )
   )
  )
  (if (> d89 r89)
   (progn 
    (setq v8x (+ v8x (* a8x t)))  (setq v8y (+ v8y (* a8y t)))  (setq v8z (+ v8z (* a8z t)))
    (setq v9x (+ v9x (* a9x t)))  (setq v9y (+ v9y (* a9y t)))  (setq v9z (+ v9z (* a9z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v8i (list v8x v8y v8z)) ;velocita 8 prima dello scontro
     (setq v9i (list v9x v9y v9z)) ;velocita 9 prima dello scontro
     (setq v8i* (trans v8i 0 (list dx89 dy89 dz89)))
     (setq v9i* (trans v9i 0 (list dx89 dy89 dz89)))
     (setq v8i*x (car v8i*) v8i*y (cadr v8i*) v8i*z (caddr v8i*))
     (setq v9i*x (car v9i*) v9i*y (cadr v9i*) v9i*z (caddr v9i*))
     (setq v8f*z (* kur (/ (+ (* (- m8 m9) v8i*z) (* 2 m9 v9i*z)) (+ m8 m9))))
     (setq v9f*z (* kur (/ (+ (* (- m9 m8) v9i*z) (* 2 m8 v8i*z)) (+ m8 m9))))
     (setq v8f* (list v8i*x v8i*y v8f*z))
     (setq v9f* (list v9i*x v9i*y v9f*z))
     (setq v8f (trans v8f* (list dx89 dy89 dz89) 0))
     (setq v9f (trans v9f* (list dx89 dy89 dz89) 0))
     (setq v8x (car v8f) v8y (cadr v8f) v8z (caddr v8f))
     (setq v9x (car v9f) v9y (cadr v9f) v9z (caddr v9f))
    )
   )
  )
  (if (> d10 r10)
   (progn 
    (setq v1x (+ v1x (* a1x t)))  (setq v1y (+ v1y (* a1y t)))  (setq v1z (+ v1z (* a1z t)))
    (setq v0x (+ v0x (* a0x t)))  (setq v0y (+ v0y (* a0y t)))  (setq v0z (+ v0z (* a0z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v1i (list v1x v1y v1z)) ;velocita 1 prima dello scontro
     (setq v0i (list v0x v0y v0z)) ;velocita 0 prima dello scontro
     (setq v1i* (trans v1i 0 (list dx10 dy10 dz10)))
     (setq v0i* (trans v0i 0 (list dx10 dy10 dz10)))
     (setq v1i*x (car v1i*) v1i*y (cadr v1i*) v1i*z (caddr v1i*))
     (setq v0i*x (car v0i*) v0i*y (cadr v0i*) v0i*z (caddr v0i*))
     (setq v1f*z (* kur (/ (+ (* (- m1 m0) v1i*z) (* 2 m0 v0i*z)) (+ m1 m0))))
     (setq v0f*z (* kur (/ (+ (* (- m0 m1) v0i*z) (* 2 m1 v1i*z)) (+ m1 m0))))
     (setq v1f* (list v1i*x v1i*y v1f*z))
     (setq v0f* (list v0i*x v0i*y v0f*z))
     (setq v1f (trans v1f* (list dx10 dy10 dz10) 0))
     (setq v0f (trans v0f* (list dx10 dy10 dz10) 0))
     (setq v1x (car v1f) v1y (cadr v1f) v1z (caddr v1f))
     (setq v0x (car v0f) v0y (cadr v0f) v0z (caddr v0f))
    )
   )
  )
  (if (> d20 r20)
   (progn 
    (setq v2x (+ v2x (* a2x t)))  (setq v2y (+ v2y (* a2y t)))  (setq v2z (+ v2z (* a2z t)))
    (setq v0x (+ v0x (* a0x t)))  (setq v0y (+ v0y (* a0y t)))  (setq v0z (+ v0z (* a0z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v2i (list v2x v2y v2z)) ;velocita 2 prima dello scontro
     (setq v0i (list v0x v0y v0z)) ;velocita 0 prima dello scontro
     (setq v2i* (trans v2i 0 (list dx20 dy20 dz20)))
     (setq v0i* (trans v0i 0 (list dx20 dy20 dz20)))
     (setq v2i*x (car v2i*) v2i*y (cadr v2i*) v2i*z (caddr v2i*))
     (setq v0i*x (car v0i*) v0i*y (cadr v0i*) v0i*z (caddr v0i*))
     (setq v2f*z (* kur (/ (+ (* (- m2 m0) v2i*z) (* 2 m0 v0i*z)) (+ m2 m0))))
     (setq v0f*z (* kur (/ (+ (* (- m0 m2) v0i*z) (* 2 m2 v2i*z)) (+ m2 m0))))
     (setq v2f* (list v2i*x v2i*y v2f*z))
     (setq v0f* (list v0i*x v0i*y v0f*z))
     (setq v2f (trans v2f* (list dx20 dy20 dz20) 0))
     (setq v0f (trans v0f* (list dx20 dy20 dz20) 0))
     (setq v2x (car v2f) v2y (cadr v2f) v2z (caddr v2f))
     (setq v0x (car v0f) v0y (cadr v0f) v0z (caddr v0f))
    )
   )
  )
  (if (> d30 r30)
   (progn 
    (setq v3x (+ v3x (* a3x t)))  (setq v3y (+ v3y (* a3y t)))  (setq v3z (+ v3z (* a3z t)))
    (setq v0x (+ v0x (* a0x t)))  (setq v0y (+ v0y (* a0y t)))  (setq v0z (+ v0z (* a0z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v3i (list v3x v3y v3z)) ;velocita 3 prima dello scontro
     (setq v0i (list v0x v0y v0z)) ;velocita 0 prima dello scontro
     (setq v3i* (trans v3i 0 (list dx30 dy30 dz30)))
     (setq v0i* (trans v0i 0 (list dx30 dy30 dz30)))
     (setq v3i*x (car v3i*) v3i*y (cadr v3i*) v3i*z (caddr v3i*))
     (setq v0i*x (car v0i*) v0i*y (cadr v0i*) v0i*z (caddr v0i*))
     (setq v3f*z (* kur (/ (+ (* (- m3 m0) v3i*z) (* 2 m0 v0i*z)) (+ m3 m0))))
     (setq v0f*z (* kur (/ (+ (* (- m0 m3) v0i*z) (* 2 m3 v3i*z)) (+ m3 m0))))
     (setq v3f* (list v3i*x v3i*y v3f*z))
     (setq v0f* (list v0i*x v0i*y v0f*z))
     (setq v3f (trans v3f* (list dx30 dy30 dz30) 0))
     (setq v0f (trans v0f* (list dx30 dy30 dz30) 0))
     (setq v3x (car v3f) v3y (cadr v3f) v3z (caddr v3f))
     (setq v0x (car v0f) v0y (cadr v0f) v0z (caddr v0f))
    )
   )
  )
  (if (> d40 r40)
   (progn 
    (setq v4x (+ v4x (* a4x t)))  (setq v4y (+ v4y (* a4y t)))  (setq v4z (+ v4z (* a4z t)))
    (setq v0x (+ v0x (* a0x t)))  (setq v0y (+ v0y (* a0y t)))  (setq v0z (+ v0z (* a0z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v4i (list v4x v4y v4z)) ;velocita 4 prima dello scontro
     (setq v0i (list v0x v0y v0z)) ;velocita 0 prima dello scontro
     (setq v4i* (trans v4i 0 (list dx40 dy40 dz40)))
     (setq v0i* (trans v0i 0 (list dx40 dy40 dz40)))
     (setq v4i*x (car v4i*) v4i*y (cadr v4i*) v4i*z (caddr v4i*))
     (setq v0i*x (car v0i*) v0i*y (cadr v0i*) v0i*z (caddr v0i*))
     (setq v4f*z (* kur (/ (+ (* (- m4 m0) v4i*z) (* 2 m0 v0i*z)) (+ m4 m0))))
     (setq v0f*z (* kur (/ (+ (* (- m0 m4) v0i*z) (* 2 m4 v4i*z)) (+ m4 m0))))
     (setq v4f* (list v4i*x v4i*y v4f*z))
     (setq v0f* (list v0i*x v0i*y v0f*z))
     (setq v4f (trans v4f* (list dx40 dy40 dz40) 0))
     (setq v0f (trans v0f* (list dx40 dy40 dz40) 0))
     (setq v4x (car v4f) v4y (cadr v4f) v4z (caddr v4f))
     (setq v0x (car v0f) v0y (cadr v0f) v0z (caddr v0f))
    )
   )
  )
  (if (> d50 r50)
   (progn 
    (setq v5x (+ v5x (* a5x t)))  (setq v5y (+ v5y (* a5y t)))  (setq v5z (+ v5z (* a5z t)))
    (setq v0x (+ v0x (* a0x t)))  (setq v0y (+ v0y (* a0y t)))  (setq v0z (+ v0z (* a0z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v5i (list v5x v5y v5z)) ;velocita 5 prima dello scontro
     (setq v0i (list v0x v0y v0z)) ;velocita 0 prima dello scontro
     (setq v5i* (trans v5i 0 (list dx50 dy50 dz50)))
     (setq v0i* (trans v0i 0 (list dx50 dy50 dz50)))
     (setq v5i*x (car v5i*) v5i*y (cadr v5i*) v5i*z (caddr v5i*))
     (setq v0i*x (car v0i*) v0i*y (cadr v0i*) v0i*z (caddr v0i*))
     (setq v5f*z (* kur (/ (+ (* (- m5 m0) v5i*z) (* 2 m0 v0i*z)) (+ m5 m0))))
     (setq v0f*z (* kur (/ (+ (* (- m0 m5) v0i*z) (* 2 m5 v5i*z)) (+ m5 m0))))
     (setq v5f* (list v5i*x v5i*y v5f*z))
     (setq v0f* (list v0i*x v0i*y v0f*z))
     (setq v5f (trans v5f* (list dx50 dy50 dz50) 0))
     (setq v0f (trans v0f* (list dx50 dy50 dz50) 0))
     (setq v5x (car v5f) v5y (cadr v5f) v5z (caddr v5f))
     (setq v0x (car v0f) v0y (cadr v0f) v0z (caddr v0f))
    )
   )
  )
  (if (> d60 r60)
   (progn 
    (setq v6x (+ v6x (* a6x t)))  (setq v6y (+ v6y (* a6y t)))  (setq v6z (+ v6z (* a6z t)))
    (setq v0x (+ v0x (* a0x t)))  (setq v0y (+ v0y (* a0y t)))  (setq v0z (+ v0z (* a0z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v6i (list v6x v6y v6z)) ;velocita 6 prima dello scontro
     (setq v0i (list v0x v0y v0z)) ;velocita 0 prima dello scontro
     (setq v6i* (trans v6i 0 (list dx60 dy60 dz60)))
     (setq v0i* (trans v0i 0 (list dx60 dy60 dz60)))
     (setq v6i*x (car v6i*) v6i*y (cadr v6i*) v6i*z (caddr v6i*))
     (setq v0i*x (car v0i*) v0i*y (cadr v0i*) v0i*z (caddr v0i*))
     (setq v6f*z (* kur (/ (+ (* (- m6 m0) v6i*z) (* 2 m0 v0i*z)) (+ m6 m0))))
     (setq v0f*z (* kur (/ (+ (* (- m0 m6) v0i*z) (* 2 m6 v6i*z)) (+ m6 m0))))
     (setq v6f* (list v6i*x v6i*y v6f*z))
     (setq v0f* (list v0i*x v0i*y v0f*z))
     (setq v6f (trans v6f* (list dx60 dy60 dz60) 0))
     (setq v0f (trans v0f* (list dx60 dy60 dz60) 0))
     (setq v6x (car v6f) v6y (cadr v6f) v6z (caddr v6f))
     (setq v0x (car v0f) v0y (cadr v0f) v0z (caddr v0f))
    )
   )
  )
  (if (> d70 r70)
   (progn 
    (setq v7x (+ v7x (* a7x t)))  (setq v7y (+ v7y (* a7y t)))  (setq v7z (+ v7z (* a7z t)))
    (setq v0x (+ v0x (* a0x t)))  (setq v0y (+ v0y (* a0y t)))  (setq v0z (+ v0z (* a0z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v7i (list v7x v7y v7z)) ;velocita 7 prima dello scontro
     (setq v0i (list v0x v0y v0z)) ;velocita 0 prima dello scontro
     (setq v7i* (trans v7i 0 (list dx70 dy70 dz70)))
     (setq v0i* (trans v0i 0 (list dx70 dy70 dz70)))
     (setq v7i*x (car v7i*) v7i*y (cadr v7i*) v7i*z (caddr v7i*))
     (setq v0i*x (car v0i*) v0i*y (cadr v0i*) v0i*z (caddr v0i*))
     (setq v7f*z (* kur (/ (+ (* (- m7 m0) v7i*z) (* 2 m0 v0i*z)) (+ m7 m0))))
     (setq v0f*z (* kur (/ (+ (* (- m0 m7) v0i*z) (* 2 m7 v7i*z)) (+ m7 m0))))
     (setq v7f* (list v7i*x v7i*y v7f*z))
     (setq v0f* (list v0i*x v0i*y v0f*z))
     (setq v7f (trans v7f* (list dx70 dy70 dz70) 0))
     (setq v0f (trans v0f* (list dx70 dy70 dz70) 0))
     (setq v7x (car v7f) v7y (cadr v7f) v7z (caddr v7f))
     (setq v0x (car v0f) v0y (cadr v0f) v0z (caddr v0f))
    )
   )
  )
  (if (> d80 r80)
   (progn 
    (setq v8x (+ v8x (* a8x t)))  (setq v8y (+ v8y (* a8y t)))  (setq v8z (+ v8z (* a8z t)))
    (setq v0x (+ v0x (* a0x t)))  (setq v0y (+ v0y (* a0y t)))  (setq v0z (+ v0z (* a0z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v8i (list v8x v8y v8z)) ;velocita 8 prima dello scontro
     (setq v0i (list v0x v0y v0z)) ;velocita 0 prima dello scontro
     (setq v8i* (trans v8i 0 (list dx80 dy80 dz80)))
     (setq v0i* (trans v0i 0 (list dx80 dy80 dz80)))
     (setq v8i*x (car v8i*) v8i*y (cadr v8i*) v8i*z (caddr v8i*))
     (setq v0i*x (car v0i*) v0i*y (cadr v0i*) v0i*z (caddr v0i*))
     (setq v8f*z (* kur (/ (+ (* (- m8 m0) v8i*z) (* 2 m0 v0i*z)) (+ m8 m0))))
     (setq v0f*z (* kur (/ (+ (* (- m0 m8) v0i*z) (* 2 m8 v8i*z)) (+ m8 m0))))
     (setq v8f* (list v8i*x v8i*y v8f*z))
     (setq v0f* (list v0i*x v0i*y v0f*z))
     (setq v8f (trans v8f* (list dx80 dy80 dz80) 0))
     (setq v0f (trans v0f* (list dx80 dy80 dz80) 0))
     (setq v8x (car v8f) v8y (cadr v8f) v8z (caddr v8f))
     (setq v0x (car v0f) v0y (cadr v0f) v0z (caddr v0f))
    )
   )
  )
  (if (> d90 r90)
   (progn 
    (setq v9x (+ v9x (* a9x t)))  (setq v9y (+ v9y (* a9y t)))  (setq v9z (+ v9z (* a9z t)))
    (setq v0x (+ v0x (* a0x t)))  (setq v0y (+ v0y (* a0y t)))  (setq v0z (+ v0z (* a0z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v9i (list v9x v9y v9z)) ;velocita 9 prima dello scontro
     (setq v0i (list v0x v0y v0z)) ;velocita 0 prima dello scontro
     (setq v9i* (trans v9i 0 (list dx90 dy90 dz90)))
     (setq v0i* (trans v0i 0 (list dx90 dy90 dz90)))
     (setq v9i*x (car v9i*) v9i*y (cadr v9i*) v9i*z (caddr v9i*))
     (setq v0i*x (car v0i*) v0i*y (cadr v0i*) v0i*z (caddr v0i*))
     (setq v9f*z (* kur (/ (+ (* (- m9 m0) v9i*z) (* 2 m0 v0i*z)) (+ m9 m0))))
     (setq v0f*z (* kur (/ (+ (* (- m0 m9) v0i*z) (* 2 m9 v9i*z)) (+ m9 m0))))
     (setq v9f* (list v9i*x v9i*y v9f*z))
     (setq v0f* (list v0i*x v0i*y v0f*z))
     (setq v9f (trans v9f* (list dx90 dy90 dz90) 0))
     (setq v0f (trans v0f* (list dx90 dy90 dz90) 0))
     (setq v9x (car v9f) v9y (cadr v9f) v9z (caddr v9f))
     (setq v0x (car v0f) v0y (cadr v0f) v0z (caddr v0f))
    )
   )
  )


  (if (< (- x1 r1) xsa) (setq v1x (* (+ (* -2 kbi) 1) v1x) ) )
  (if (< (- y1 r1) ysa) (setq v1y (* (+ (* -2 kbi) 1) v1y) ) )   
  (if (< (- z1 r1) zsa) (setq v1z (* (+ (* -2 kbi) 1) v1z) ) )   
  (if (> (+ x1 r1) xsb) (setq v1x (* (+ (* -2 kbi) 1) v1x) ) )   
  (if (> (+ y1 r1) ysb) (setq v1y (* (+ (* -2 kbi) 1) v1y) ) )   
  (if (> (+ z1 r1) zsb) (setq v1z (* (+ (* -2 kbi) 1) v1z) ) )   
  (if (< (- x2 r2) xsa) (setq v2x (* (+ (* -2 kbi) 1) v2x) ) )   
  (if (< (- y2 r2) ysa) (setq v2y (* (+ (* -2 kbi) 1) v2y) ) )   
  (if (< (- z2 r2) zsa) (setq v2z (* (+ (* -2 kbi) 1) v2z) ) )   
  (if (> (+ x2 r2) xsb) (setq v2x (* (+ (* -2 kbi) 1) v2x) ) )   
  (if (> (+ y2 r2) ysb) (setq v2y (* (+ (* -2 kbi) 1) v2y) ) )   
  (if (> (+ z2 r2) zsb) (setq v2z (* (+ (* -2 kbi) 1) v2z) ) )   
  (if (< (- x3 r3) xsa) (setq v3x (* (+ (* -2 kbi) 1) v3x) ) )   
  (if (< (- y3 r3) ysa) (setq v3y (* (+ (* -2 kbi) 1) v3y) ) )   
  (if (< (- z3 r3) zsa) (setq v3z (* (+ (* -2 kbi) 1) v3z) ) )   
  (if (> (+ x3 r3) xsb) (setq v3x (* (+ (* -2 kbi) 1) v3x) ) )   
  (if (> (+ y3 r3) ysb) (setq v3y (* (+ (* -2 kbi) 1) v3y) ) )   
  (if (> (+ z3 r3) zsb) (setq v3z (* (+ (* -2 kbi) 1) v3z) ) )   
  (if (< (- x4 r4) xsa) (setq v4x (* (+ (* -2 kbi) 1) v4x) ) )   
  (if (< (- y4 r4) ysa) (setq v4y (* (+ (* -2 kbi) 1) v4y) ) )   
  (if (< (- z4 r4) zsa) (setq v4z (* (+ (* -2 kbi) 1) v4z) ) )   
  (if (> (+ x4 r4) xsb) (setq v4x (* (+ (* -2 kbi) 1) v4x) ) )   
  (if (> (+ y4 r4) ysb) (setq v4y (* (+ (* -2 kbi) 1) v4y) ) )   
  (if (> (+ z4 r4) zsb) (setq v4z (* (+ (* -2 kbi) 1) v4z) ) )   
  (if (< (- x5 r5) xsa) (setq v5x (* (+ (* -2 kbi) 1) v5x) ) )   
  (if (< (- y5 r5) ysa) (setq v5y (* (+ (* -2 kbi) 1) v5y) ) )   
  (if (< (- z5 r5) zsa) (setq v5z (* (+ (* -2 kbi) 1) v5z) ) )   
  (if (> (+ x5 r5) xsb) (setq v5x (* (+ (* -2 kbi) 1) v5x) ) )   
  (if (> (+ y5 r5) ysb) (setq v5y (* (+ (* -2 kbi) 1) v5y) ) )   
  (if (> (+ z5 r5) zsb) (setq v5z (* (+ (* -2 kbi) 1) v5z) ) )   
  (if (< (- x6 r6) xsa) (setq v6x (* (+ (* -2 kbi) 1) v6x) ) )   
  (if (< (- y6 r6) ysa) (setq v6y (* (+ (* -2 kbi) 1) v6y) ) )   
  (if (< (- z6 r6) zsa) (setq v6z (* (+ (* -2 kbi) 1) v6z) ) )   
  (if (> (+ x6 r6) xsb) (setq v6x (* (+ (* -2 kbi) 1) v6x) ) )   
  (if (> (+ y6 r6) ysb) (setq v6y (* (+ (* -2 kbi) 1) v6y) ) )   
  (if (> (+ z6 r6) zsb) (setq v6z (* (+ (* -2 kbi) 1) v6z) ) )   
  (if (< (- x7 r7) xsa) (setq v7x (* (+ (* -2 kbi) 1) v7x) ) )   
  (if (< (- y7 r7) ysa) (setq v7y (* (+ (* -2 kbi) 1) v7y) ) )   
  (if (< (- z7 r7) zsa) (setq v7z (* (+ (* -2 kbi) 1) v7z) ) )   
  (if (> (+ x7 r7) xsb) (setq v7x (* (+ (* -2 kbi) 1) v7x) ) )   
  (if (> (+ y7 r7) ysb) (setq v7y (* (+ (* -2 kbi) 1) v7y) ) )   
  (if (> (+ z7 r7) zsb) (setq v7z (* (+ (* -2 kbi) 1) v7z) ) )   
  (if (< (- x8 r8) xsa) (setq v8x (* (+ (* -2 kbi) 1) v8x) ) )   
  (if (< (- y8 r8) ysa) (setq v8y (* (+ (* -2 kbi) 1) v8y) ) )   
  (if (< (- z8 r8) zsa) (setq v8z (* (+ (* -2 kbi) 1) v8z) ) )   
  (if (> (+ x8 r8) xsb) (setq v8x (* (+ (* -2 kbi) 1) v8x) ) )   
  (if (> (+ y8 r8) ysb) (setq v8y (* (+ (* -2 kbi) 1) v8y) ) )   
  (if (> (+ z8 r8) zsb) (setq v8z (* (+ (* -2 kbi) 1) v8z) ) )   
  (if (< (- x9 r9) xsa) (setq v9x (* (+ (* -2 kbi) 1) v9x) ) )   
  (if (< (- y9 r9) ysa) (setq v9y (* (+ (* -2 kbi) 1) v9y) ) )   
  (if (< (- z9 r9) zsa) (setq v9z (* (+ (* -2 kbi) 1) v9z) ) )   
  (if (> (+ x9 r9) xsb) (setq v9x (* (+ (* -2 kbi) 1) v9x) ) )   
  (if (> (+ y9 r9) ysb) (setq v9y (* (+ (* -2 kbi) 1) v9y) ) )   
  (if (> (+ z9 r9) zsb) (setq v9z (* (+ (* -2 kbi) 1) v9z) ) )   
  (if (< (- x0 r0) xsa) (setq v0x (* (+ (* -2 kbi) 1) v0x) ) )   
  (if (< (- y0 r0) ysa) (setq v0y (* (+ (* -2 kbi) 1) v0y) ) )   
  (if (< (- z0 r0) zsa) (setq v0z (* (+ (* -2 kbi) 1) v0z) ) )   
  (if (> (+ x0 r0) xsb) (setq v0x (* (+ (* -2 kbi) 1) v0x) ) )   
  (if (> (+ y0 r0) ysb) (setq v0y (* (+ (* -2 kbi) 1) v0y) ) )   
  (if (> (+ z0 r0) zsb) (setq v0z (* (+ (* -2 kbi) 1) v0z) ) )   

  (setq s1x (+ (* v1x t) (* 0.5 a1x t t)))  (setq s1y (+ (* v1y t) (* 0.5 a1y t t)))  (setq s1z (+ (* v1z t) (* 0.5 a1z t t)))
  (setq s2x (+ (* v2x t) (* 0.5 a2x t t)))  (setq s2y (+ (* v2y t) (* 0.5 a2y t t)))  (setq s2z (+ (* v2z t) (* 0.5 a2z t t)))
  (setq s3x (+ (* v3x t) (* 0.5 a3x t t)))  (setq s3y (+ (* v3y t) (* 0.5 a3y t t)))  (setq s3z (+ (* v3z t) (* 0.5 a3z t t)))
  (setq s4x (+ (* v4x t) (* 0.5 a4x t t)))  (setq s4y (+ (* v4y t) (* 0.5 a4y t t)))  (setq s4z (+ (* v4z t) (* 0.5 a4z t t)))
  (setq s5x (+ (* v5x t) (* 0.5 a5x t t)))  (setq s5y (+ (* v5y t) (* 0.5 a5y t t)))  (setq s5z (+ (* v5z t) (* 0.5 a5z t t)))
  (setq s6x (+ (* v6x t) (* 0.5 a6x t t)))  (setq s6y (+ (* v6y t) (* 0.5 a6y t t)))  (setq s6z (+ (* v6z t) (* 0.5 a6z t t)))
  (setq s7x (+ (* v7x t) (* 0.5 a7x t t)))  (setq s7y (+ (* v7y t) (* 0.5 a7y t t)))  (setq s7z (+ (* v7z t) (* 0.5 a7z t t)))
  (setq s8x (+ (* v8x t) (* 0.5 a8x t t)))  (setq s8y (+ (* v8y t) (* 0.5 a8y t t)))  (setq s8z (+ (* v8z t) (* 0.5 a8z t t)))
  (setq s9x (+ (* v9x t) (* 0.5 a9x t t)))  (setq s9y (+ (* v9y t) (* 0.5 a9y t t)))  (setq s9z (+ (* v9z t) (* 0.5 a9z t t)))
  (setq s0x (+ (* v0x t) (* 0.5 a0x t t)))  (setq s0y (+ (* v0y t) (* 0.5 a0y t t)))  (setq s0z (+ (* v0z t) (* 0.5 a0z t t)))

  (setq x1 (+ x1 (* k1 s1x)))  (setq y1 (+ y1 (* k1 s1y)))  (setq z1 (+ z1 (* k1 s1z)))
  (setq x2 (+ x2 (* k2 s2x)))  (setq y2 (+ y2 (* k2 s2y)))  (setq z2 (+ z2 (* k2 s2z)))
  (setq x3 (+ x3 (* k3 s3x)))  (setq y3 (+ y3 (* k3 s3y)))  (setq z3 (+ z3 (* k3 s3z)))
  (setq x4 (+ x4 (* k4 s4x)))  (setq y4 (+ y4 (* k4 s4y)))  (setq z4 (+ z4 (* k4 s4z)))
  (setq x5 (+ x5 (* k5 s5x)))  (setq y5 (+ y5 (* k5 s5y)))  (setq z5 (+ z5 (* k5 s5z)))
  (setq x6 (+ x6 (* k6 s6x)))  (setq y6 (+ y6 (* k6 s6y)))  (setq z6 (+ z6 (* k6 s6z)))
  (setq x7 (+ x7 (* k7 s7x)))  (setq y7 (+ y7 (* k7 s7y)))  (setq z7 (+ z7 (* k7 s7z)))
  (setq x8 (+ x8 (* k8 s8x)))  (setq y8 (+ y8 (* k8 s8y)))  (setq z8 (+ z8 (* k8 s8z)))
  (setq x9 (+ x9 (* k9 s9x)))  (setq y9 (+ y9 (* k9 s9y)))  (setq z9 (+ z9 (* k9 s9z)))
  (setq x0 (+ x0 (* k0 s0x)))  (setq y0 (+ y0 (* k0 s0y)))  (setq z0 (+ z0 (* k0 s0z)))

  (setq a1 (sqrt (+ (* a1x a1x) (* a1y a1y) (* a1z a1z))))
  (setq a2 (sqrt (+ (* a2x a2x) (* a2y a2y) (* a2z a2z))))
  (setq a3 (sqrt (+ (* a3x a3x) (* a3y a3y) (* a3z a3z))))
  (setq a4 (sqrt (+ (* a4x a4x) (* a4y a4y) (* a4z a4z))))
  (setq a5 (sqrt (+ (* a5x a5x) (* a5y a5y) (* a5z a5z))))
  (setq a6 (sqrt (+ (* a6x a6x) (* a6y a6y) (* a6z a6z))))
  (setq a7 (sqrt (+ (* a7x a7x) (* a7y a7y) (* a7z a7z))))
  (setq a8 (sqrt (+ (* a8x a8x) (* a8y a8y) (* a8z a8z))))
  (setq a9 (sqrt (+ (* a9x a9x) (* a9y a9y) (* a9z a9z))))
  (setq a0 (sqrt (+ (* a0x a0x) (* a0y a0y) (* a0z a0z))))

  (setq va (+ (abs a1) (abs a2) (abs a3) (abs a4) (abs a5) (abs a6) (abs a7) (abs a8) (abs a9) (abs a0)
              (abs v1) (abs v2) (abs v3) (abs v4) (abs v5) (abs v6) (abs v7) (abs v8) (abs v9) (abs v0)
           )
  )
  (princ "\n")
  (princ va)
  (princ)

  (setq q1 (list x1 y1 z1))
  (setq q2 (list x2 y2 z2))
  (setq q3 (list x3 y3 z3))
  (setq q4 (list x4 y4 z4))
  (setq q5 (list x5 y5 z5))
  (setq q6 (list x6 y6 z6))
  (setq q7 (list x7 y7 z7))
  (setq q8 (list x8 y8 z8))
  (setq q9 (list x9 y9 z9))
  (setq q0 (list x0 y0 z0))

  (if (= iscan 0)
   (progn
 
   (if (= ker 0)
    (progn
    (if (= pc "p")
        (progn
         (setvar "clayer" "m1") (command "_point" p1)
         (setvar "clayer" "m2") (command "_point" p2)
         (setvar "clayer" "m3") (command "_point" p3)
         (setvar "clayer" "m4") (command "_point" p4)
         (setvar "clayer" "m5") (command "_point" p5)
         (setvar "clayer" "m6") (command "_point" p6)
         (setvar "clayer" "m7") (command "_point" p7)
         (setvar "clayer" "m8") (command "_point" p8)
         (setvar "clayer" "m9") (command "_point" p9)
         (setvar "clayer" "m0") (command "_point" p0)
        )
        (if (= pc "c")
            (progn
             (setvar "clayer" "m1") (command "_circle" p1 (* kdi r1))
             (setvar "clayer" "m2") (command "_circle" p2 (* kdi r2))
             (setvar "clayer" "m3") (command "_circle" p3 (* kdi r3))
             (setvar "clayer" "m4") (command "_circle" p4 (* kdi r4))
             (setvar "clayer" "m5") (command "_circle" p5 (* kdi r5))
             (setvar "clayer" "m6") (command "_circle" p6 (* kdi r6))
             (setvar "clayer" "m7") (command "_circle" p7 (* kdi r7))
             (setvar "clayer" "m8") (command "_circle" p8 (* kdi r8))
             (setvar "clayer" "m9") (command "_circle" p9 (* kdi r9))
             (setvar "clayer" "m0") (command "_circle" p0 (* kdi r0))
            )
            (if (= pc "s")
                (progn
                 (setvar "clayer" "m1") (command "_sphere" p1 r1)
                 (setvar "clayer" "m2") (command "_sphere" p2 r2)
                 (setvar "clayer" "m3") (command "_sphere" p3 r3)
                 (setvar "clayer" "m4") (command "_sphere" p4 r4)
                 (setvar "clayer" "m5") (command "_sphere" p5 r5)
                 (setvar "clayer" "m6") (command "_sphere" p6 r6)
                 (setvar "clayer" "m7") (command "_sphere" p7 r7)
                 (setvar "clayer" "m8") (command "_sphere" p8 r8)
                 (setvar "clayer" "m9") (command "_sphere" p9 r9)
                 (setvar "clayer" "m0") (command "_sphere" p0 r0)
                )
            )
        )
    )
    )
    (progn
             (command "_move" o1 "" p1 q1)
             (command "_move" o2 "" p2 q2)
             (command "_move" o3 "" p3 q3)
             (command "_move" o4 "" p4 q4)
             (command "_move" o5 "" p5 q5)
             (command "_move" o6 "" p6 q6)
             (command "_move" o7 "" p7 q7)
             (command "_move" o8 "" p8 q8)
             (command "_move" o9 "" p9 q9)
             (command "_move" o0 "" p0 q0)
    )    
   )
    
   )

  )
 
  (setq p1 q1)
  (setq p2 q2)  
  (setq p3 q3)  
  (setq p4 q4)  
  (setq p5 q5)  
  (setq p6 q6)  
  (setq p7 q7)  
  (setq p8 q8)  
  (setq p9 q9)  
  (setq p0 q0)  

  (setq iscan (+ 1 iscan))
  (if (= iscan scan) (setq iscan 0))

 )
 (setvar "clayer" "0")
 (command "_pline" p1 p2 p3 p4 p5 p6 p7 p8 p9 p0 p1 "")
)

;;;*****************************************************************
;simula il moto di 10 oggetti sottoposti a forza gravitazionale
;gravita11 ver 1.5 23/07/2010
;Dott. Ing. Emanuele Ballasina
;cell 349-1813748
;mail ballacr75@libero.it

(defun c:gravita11 ()
(setvar "osmode" 0)
(setvar "dimzin" 0)
(setvar "cmdecho" 0)

(command "_-layer" "n" "m1" "_c" 10 "m1" "_s" "m1" "")
(command "_-layer" "n" "m2" "_c" 30 "m2" "_s" "m2" "")
(command "_-layer" "n" "m3" "_c" 50 "m3" "_s" "m3" "")
(command "_-layer" "n" "m4" "_c" 70 "m4" "_s" "m4" "")
(command "_-layer" "n" "m5" "_c" 90 "m5" "_s" "m5" "")
(command "_-layer" "n" "m6" "_c" 110 "m6" "_s" "m6" "")
(command "_-layer" "n" "m7" "_c" 130 "m7" "_s" "m7" "")
(command "_-layer" "n" "m8" "_c" 150 "m8" "_s" "m8" "")
(command "_-layer" "n" "m9" "_c" 170 "m9" "_s" "m9" "")
(command "_-layer" "n" "m0" "_c" 190 "m0" "_s" "m0" "")
(command "_-layer" "n" "ma" "_c" 210 "ma" "_s" "ma" "")

(setq t 1) ;scansione tempo
(setq kdi 1) ;riduzione diametro cilindri
(setq scan 1) ;scansione posizione (non funziona >1 se ker=1)

(setq m1 100.0) ;massa
(setq m2 100.0)
(setq m3 100.0)
(setq m4 100.0)
(setq m5 100.0)
(setq m6 100.0)
(setq m7 100.0)
(setq m8 100.0)
(setq m9 100.0)
(setq m0 100.0)
(setq ma 100.0)
(setq d1 0.1) ;densita
(setq d2 0.1)
(setq d3 0.1) 
(setq d4 0.1)
(setq d5 0.1)
(setq d6 0.1)
(setq d7 0.1)
(setq d8 0.1)
(setq d9 0.1)
(setq d0 0.1)
(setq da 0.1)
(setq r1 (expt (/ m1 d1) 0.3333)) ;raggio
(setq r2 (expt (/ m2 d2) 0.3333))
(setq r3 (expt (/ m3 d3) 0.3333))
(setq r4 (expt (/ m4 d4) 0.3333))
(setq r5 (expt (/ m5 d5) 0.3333))
(setq r6 (expt (/ m6 d6) 0.3333))
(setq r7 (expt (/ m7 d7) 0.3333))
(setq r8 (expt (/ m8 d8) 0.3333))
(setq r9 (expt (/ m9 d9) 0.3333))
(setq r0 (expt (/ m0 d0) 0.3333))
(setq ra (expt (/ ma da) 0.3333))
(setq r12 (+ r1 r2)) ;distanza di sfioro
(setq r13 (+ r1 r3))
(setq r23 (+ r2 r3))
(setq r14 (+ r1 r4))
(setq r24 (+ r2 r4))
(setq r34 (+ r3 r4))
(setq r15 (+ r1 r5))
(setq r25 (+ r2 r5))
(setq r35 (+ r3 r5))
(setq r45 (+ r4 r5))
(setq r16 (+ r1 r6))
(setq r26 (+ r2 r6))
(setq r36 (+ r3 r6))
(setq r46 (+ r4 r6))
(setq r56 (+ r5 r6))
(setq r17 (+ r1 r7))
(setq r27 (+ r2 r7))
(setq r37 (+ r3 r7))
(setq r47 (+ r4 r7))
(setq r57 (+ r5 r7))
(setq r67 (+ r6 r7))
(setq r18 (+ r1 r8))
(setq r28 (+ r2 r8))
(setq r38 (+ r3 r8))
(setq r48 (+ r4 r8))
(setq r58 (+ r5 r8))
(setq r68 (+ r6 r8))
(setq r78 (+ r7 r8))
(setq r19 (+ r1 r9))
(setq r29 (+ r2 r9))
(setq r39 (+ r3 r9))
(setq r49 (+ r4 r9))
(setq r59 (+ r5 r9))
(setq r69 (+ r6 r9))
(setq r79 (+ r7 r9))
(setq r89 (+ r8 r9))
(setq r10 (+ r1 r0))
(setq r20 (+ r2 r0))
(setq r30 (+ r3 r0))
(setq r40 (+ r4 r0))
(setq r50 (+ r5 r0))
(setq r60 (+ r6 r0))
(setq r70 (+ r7 r0))
(setq r80 (+ r8 r0))
(setq r90 (+ r9 r0))
(setq r1a (+ r1 ra))
(setq r2a (+ r2 ra))
(setq r3a (+ r3 ra))
(setq r4a (+ r4 ra))
(setq r5a (+ r5 ra))
(setq r6a (+ r6 ra))
(setq r7a (+ r7 ra))
(setq r8a (+ r8 ra))
(setq r9a (+ r9 ra))
(setq r0a (+ r0 ra))

(setq k1 1) ;abilita movimento pianeta
(setq k2 1)
(setq k3 1)
(setq k4 1)
(setq k5 1)
(setq k6 1)
(setq k7 1)
(setq k8 1)
(setq k9 1)
(setq k0 1)
(setq ka 1)
(setq kur 1) ;abilita urti, con coefficente di rimbalzo, <1 smorza
(setq kbi 1) ;abilita rimbalzo tipo biliardo contro pareti dello schermo, <1 smorza
(setq ker 1) ;1=cancella pianeti vecchi, 0=mantiene tutti i pianeti
(setq c (getvar "VIEWCTR"))
(setq xsc (car c))
(setq ysc (cadr c))
(setq zsc (caddr c))
(setq currh (getvar "viewsize"))
(setq sizex (nth 0 (getvar "screensize")))
(setq sizey (nth 1 (getvar "screensize")))
(setq j (/ sizex sizey))
(setq currw (* j currh))
(setq h2 (/ currh 2.0))
(setq w2 (/ currw 2.0))
(setq xsa (- xsc w2))
(setq ysa (- ysc h2))
(setq zsa (- zsc h2))
(setq xsb (+ xsc w2))
(setq ysb (+ ysc h2))
(setq zsb (+ zsc h2))
(if (/= kbi 0) (command "_rectangle" (list xsa ysa) (list xsb ysb)))

(setq pc "c") ;punti,cerchi,sfere
(setq lc "n") ;abilita disegno linee tra un pianeta e gli altri
(setq tc "n") ;abilita disegno linee traiettoria

(setq x1 0) ;posizione
(setq y1 0)
(setq z1 0)
(setq x2 100)
(setq y2 0)
(setq z2 0)
(setq x3 200)
(setq y3 0)
(setq z3 0)
(setq x4 300)
(setq y4 0)
(setq z4 0)
(setq x5 400)
(setq y5 0)
(setq z5 0)
(setq x6 500)
(setq y6 0)
(setq z6 0)
(setq x7 600)
(setq y7 0) 
(setq z7 0) 
(setq x8 700) 
(setq y8 0) 
(setq z8 0) 
(setq x9 800) 
(setq y9 0) 
(setq z9 0) 
(setq x0 900) 
(setq y0 0) 
(setq z0 0) 
(setq xa 1000) 
(setq ya 0) 
(setq za 0) 

(setq v1x 0.0) ;velocita
(setq v1y 0.0)
(setq v1z 0.0)
(setq v2x 0.0)
(setq v2y 0.0)
(setq v2z 0.0)
(setq v3x 0.0)
(setq v3y 0.0)
(setq v3z 0.0)
(setq v4x 0.0)
(setq v4y 0.0)
(setq v4z 0.0)
(setq v5x 0.0)
(setq v5y 0.0)
(setq v5z 0.0) 
(setq v6x 0.0)
(setq v6y 0.0)
(setq v6z 0.0)
(setq v7x 0.0)
(setq v7y 0.0)
(setq v7z 0.0)
(setq v8x 0.0)
(setq v8y 0.0)
(setq v8z 0.0)
(setq v9x 0.0)
(setq v9y 0.0)
(setq v9z 0.0)
(setq v0x 0.0)
(setq v0y 0.0)
(setq v0z 0.0)
(setq vax 0.0)
(setq vay 0.0)
(setq vaz 0.0)

(setq p1 (list x1 y1 z1))
(setq p2 (list x2 y2 z2))
(setq p3 (list x3 y3 z3))
(setq p4 (list x4 y4 z4))
(setq p5 (list x5 y5 z5))
(setq p6 (list x6 y6 z6))
(setq p7 (list x7 y7 z7))
(setq p8 (list x8 y8 z8))
(setq p9 (list x9 y9 z9))
(setq p0 (list x0 y0 z0))
(setq pa (list xa ya za))

(if (= pc "p")
    (progn
     (setvar "clayer" "m1") (command "_point" p1) (setq o1 (cdr (car (entget (entlast)))))
     (setvar "clayer" "m2") (command "_point" p2) (setq o2 (cdr (car (entget (entlast)))))
     (setvar "clayer" "m3") (command "_point" p3) (setq o3 (cdr (car (entget (entlast)))))
     (setvar "clayer" "m4") (command "_point" p4) (setq o4 (cdr (car (entget (entlast)))))
     (setvar "clayer" "m5") (command "_point" p5) (setq o5 (cdr (car (entget (entlast)))))
     (setvar "clayer" "m6") (command "_point" p6) (setq o6 (cdr (car (entget (entlast)))))
     (setvar "clayer" "m7") (command "_point" p7) (setq o7 (cdr (car (entget (entlast)))))
     (setvar "clayer" "m8") (command "_point" p8) (setq o8 (cdr (car (entget (entlast)))))
     (setvar "clayer" "m9") (command "_point" p9) (setq o9 (cdr (car (entget (entlast)))))
     (setvar "clayer" "m0") (command "_point" p0) (setq o0 (cdr (car (entget (entlast)))))
     (setvar "clayer" "ma") (command "_point" pa) (setq oa (cdr (car (entget (entlast)))))
    )
    (if (= pc "c")
        (progn
         (setvar "clayer" "m1") (command "_circle" p1 r1) (setq o1 (cdr (car (entget (entlast)))))
         (setvar "clayer" "m2") (command "_circle" p2 r2) (setq o2 (cdr (car (entget (entlast)))))
         (setvar "clayer" "m3") (command "_circle" p3 r3) (setq o3 (cdr (car (entget (entlast)))))
         (setvar "clayer" "m4") (command "_circle" p4 r4) (setq o4 (cdr (car (entget (entlast)))))
         (setvar "clayer" "m5") (command "_circle" p5 r5) (setq o5 (cdr (car (entget (entlast)))))
         (setvar "clayer" "m6") (command "_circle" p6 r6) (setq o6 (cdr (car (entget (entlast)))))
         (setvar "clayer" "m7") (command "_circle" p7 r7) (setq o7 (cdr (car (entget (entlast)))))
         (setvar "clayer" "m8") (command "_circle" p8 r8) (setq o8 (cdr (car (entget (entlast)))))
         (setvar "clayer" "m9") (command "_circle" p9 r9) (setq o9 (cdr (car (entget (entlast)))))
         (setvar "clayer" "m0") (command "_circle" p0 r0) (setq o0 (cdr (car (entget (entlast)))))
         (setvar "clayer" "ma") (command "_circle" pa ra) (setq oa (cdr (car (entget (entlast)))))
        )
        (if (= pc "s")
            (progn
             (setvar "clayer" "m1") (command "_sphere" p1 r1) (setq o1 (cdr (car (entget (entlast)))))
             (setvar "clayer" "m2") (command "_sphere" p2 r2) (setq o2 (cdr (car (entget (entlast)))))
             (setvar "clayer" "m3") (command "_sphere" p3 r3) (setq o3 (cdr (car (entget (entlast)))))
             (setvar "clayer" "m4") (command "_sphere" p4 r4) (setq o4 (cdr (car (entget (entlast)))))
             (setvar "clayer" "m5") (command "_sphere" p5 r5) (setq o5 (cdr (car (entget (entlast)))))
             (setvar "clayer" "m6") (command "_sphere" p6 r6) (setq o6 (cdr (car (entget (entlast)))))
             (setvar "clayer" "m7") (command "_sphere" p7 r7) (setq o7 (cdr (car (entget (entlast)))))
             (setvar "clayer" "m8") (command "_sphere" p8 r8) (setq o8 (cdr (car (entget (entlast)))))
             (setvar "clayer" "m9") (command "_sphere" p9 r9) (setq o9 (cdr (car (entget (entlast)))))
             (setvar "clayer" "m0") (command "_sphere" p0 r0) (setq o0 (cdr (car (entget (entlast)))))
             (setvar "clayer" "ma") (command "_sphere" pa ra) (setq oa (cdr (car (entget (entlast)))))
            )
        )
    )
)

(setq va 1000)
(setq iscan 0)
 (while (> va 0.0001) ;scansione velocit ed accelerazione, se = 0 si ferma il lisp

  (setq v1 (sqrt (+ (* v1x v1x) (* v1y v1y) (* v1z v1z))))
  (setq v2 (sqrt (+ (* v2x v2x) (* v2y v2y) (* v2z v2z))))
  (setq v3 (sqrt (+ (* v3x v3x) (* v3y v3y) (* v3z v3z))))
  (setq v4 (sqrt (+ (* v4x v4x) (* v4y v4y) (* v4z v4z))))
  (setq v5 (sqrt (+ (* v5x v5x) (* v5y v5y) (* v5z v5z))))
  (setq v6 (sqrt (+ (* v6x v6x) (* v6y v6y) (* v6z v6z))))
  (setq v7 (sqrt (+ (* v7x v7x) (* v7y v7y) (* v7z v7z))))
  (setq v8 (sqrt (+ (* v8x v8x) (* v8y v8y) (* v8z v8z))))
  (setq v9 (sqrt (+ (* v9x v9x) (* v9y v9y) (* v9z v9z))))
  (setq v0 (sqrt (+ (* v0x v0x) (* v0y v0y) (* v0z v0z))))
  (setq va (sqrt (+ (* vax vax) (* vay vay) (* vaz vaz))))
  
  (setq d12 (distance p1 p2))
  (setq d13 (distance p1 p3))
  (setq d23 (distance p2 p3))
  (setq d14 (distance p1 p4))
  (setq d24 (distance p2 p4))
  (setq d34 (distance p3 p4))
  (setq d15 (distance p1 p5))
  (setq d25 (distance p2 p5))
  (setq d35 (distance p3 p5))
  (setq d45 (distance p4 p5))
  (setq d16 (distance p1 p6))
  (setq d26 (distance p2 p6))
  (setq d36 (distance p3 p6))
  (setq d46 (distance p4 p6))
  (setq d56 (distance p5 p6))
  (setq d17 (distance p1 p7))
  (setq d27 (distance p2 p7))
  (setq d37 (distance p3 p7))
  (setq d47 (distance p4 p7))
  (setq d57 (distance p5 p7))
  (setq d67 (distance p6 p7))
  (setq d18 (distance p1 p8))
  (setq d28 (distance p2 p8))
  (setq d38 (distance p3 p8))
  (setq d48 (distance p4 p8))
  (setq d58 (distance p5 p8))
  (setq d68 (distance p6 p8))
  (setq d78 (distance p7 p8))
  (setq d19 (distance p1 p9))
  (setq d29 (distance p2 p9))
  (setq d39 (distance p3 p9))
  (setq d49 (distance p4 p9))
  (setq d59 (distance p5 p9))
  (setq d69 (distance p6 p9))
  (setq d79 (distance p7 p9))
  (setq d89 (distance p8 p9))
  (setq d10 (distance p1 p0))
  (setq d20 (distance p2 p0))
  (setq d30 (distance p3 p0))
  (setq d40 (distance p4 p0))
  (setq d50 (distance p5 p0))
  (setq d60 (distance p6 p0))
  (setq d70 (distance p7 p0))
  (setq d80 (distance p8 p0))
  (setq d90 (distance p9 p0))
  (setq d1a (distance p1 pa))
  (setq d2a (distance p2 pa))
  (setq d3a (distance p3 pa))
  (setq d4a (distance p4 pa))
  (setq d5a (distance p5 pa))
  (setq d6a (distance p6 pa))
  (setq d7a (distance p7 pa))
  (setq d8a (distance p8 pa))
  (setq d9a (distance p9 pa))
  (setq d0a (distance p0 pa))

  (setq dx12 (- x2 x1))  (setq dy12 (- y2 y1))  (setq dz12 (- z2 z1))
  (setq dx13 (- x3 x1))  (setq dy13 (- y3 y1))  (setq dz13 (- z3 z1))
  (setq dx23 (- x3 x2))  (setq dy23 (- y3 y2))  (setq dz23 (- z3 z2))
  (setq dx14 (- x4 x1))  (setq dy14 (- y4 y1))  (setq dz14 (- z4 z1))
  (setq dx24 (- x4 x2))  (setq dy24 (- y4 y2))  (setq dz24 (- z4 z2))
  (setq dx34 (- x4 x3))  (setq dy34 (- y4 y3))  (setq dz34 (- z4 z3))
  (setq dx15 (- x5 x1))  (setq dy15 (- y5 y1))  (setq dz15 (- z5 z1))
  (setq dx25 (- x5 x2))  (setq dy25 (- y5 y2))  (setq dz25 (- z5 z2))
  (setq dx35 (- x5 x3))  (setq dy35 (- y5 y3))  (setq dz35 (- z5 z3))
  (setq dx45 (- x5 x4))  (setq dy45 (- y5 y4))  (setq dz45 (- z5 z4))
  (setq dx16 (- x6 x1))  (setq dy16 (- y6 y1))  (setq dz16 (- z6 z1))
  (setq dx26 (- x6 x2))  (setq dy26 (- y6 y2))  (setq dz26 (- z6 z2))
  (setq dx36 (- x6 x3))  (setq dy36 (- y6 y3))  (setq dz36 (- z6 z3))
  (setq dx46 (- x6 x4))  (setq dy46 (- y6 y4))  (setq dz46 (- z6 z4))
  (setq dx56 (- x6 x5))  (setq dy56 (- y6 y5))  (setq dz56 (- z6 z5))
  (setq dx17 (- x7 x1))  (setq dy17 (- y7 y1))  (setq dz17 (- z7 z1))
  (setq dx27 (- x7 x2))  (setq dy27 (- y7 y2))  (setq dz27 (- z7 z2))
  (setq dx37 (- x7 x3))  (setq dy37 (- y7 y3))  (setq dz37 (- z7 z3))
  (setq dx47 (- x7 x4))  (setq dy47 (- y7 y4))  (setq dz47 (- z7 z4))
  (setq dx57 (- x7 x5))  (setq dy57 (- y7 y5))  (setq dz57 (- z7 z5))
  (setq dx67 (- x7 x6))  (setq dy67 (- y7 y6))  (setq dz67 (- z7 z6))
  (setq dx18 (- x8 x1))  (setq dy18 (- y8 y1))  (setq dz18 (- z8 z1))
  (setq dx28 (- x8 x2))  (setq dy28 (- y8 y2))  (setq dz28 (- z8 z2))
  (setq dx38 (- x8 x3))  (setq dy38 (- y8 y3))  (setq dz38 (- z8 z3))
  (setq dx48 (- x8 x4))  (setq dy48 (- y8 y4))  (setq dz48 (- z8 z4))
  (setq dx58 (- x8 x5))  (setq dy58 (- y8 y5))  (setq dz58 (- z8 z5))
  (setq dx68 (- x8 x6))  (setq dy68 (- y8 y6))  (setq dz68 (- z8 z6))
  (setq dx78 (- x8 x7))  (setq dy78 (- y8 y7))  (setq dz78 (- z8 z7))
  (setq dx19 (- x9 x1))  (setq dy19 (- y9 y1))  (setq dz19 (- z9 z1))
  (setq dx29 (- x9 x2))  (setq dy29 (- y9 y2))  (setq dz29 (- z9 z2))
  (setq dx39 (- x9 x3))  (setq dy39 (- y9 y3))  (setq dz39 (- z9 z3))
  (setq dx49 (- x9 x4))  (setq dy49 (- y9 y4))  (setq dz49 (- z9 z4))
  (setq dx59 (- x9 x5))  (setq dy59 (- y9 y5))  (setq dz59 (- z9 z5))
  (setq dx69 (- x9 x6))  (setq dy69 (- y9 y6))  (setq dz69 (- z9 z6))
  (setq dx79 (- x9 x7))  (setq dy79 (- y9 y7))  (setq dz79 (- z9 z7))
  (setq dx89 (- x9 x8))  (setq dy89 (- y9 y8))  (setq dz89 (- z9 z8))
  (setq dx10 (- x0 x1))  (setq dy10 (- y0 y1))  (setq dz10 (- z0 z1))
  (setq dx20 (- x0 x2))  (setq dy20 (- y0 y2))  (setq dz20 (- z0 z2))
  (setq dx30 (- x0 x3))  (setq dy30 (- y0 y3))  (setq dz30 (- z0 z3))
  (setq dx40 (- x0 x4))  (setq dy40 (- y0 y4))  (setq dz40 (- z0 z4))
  (setq dx50 (- x0 x5))  (setq dy50 (- y0 y5))  (setq dz50 (- z0 z5))
  (setq dx60 (- x0 x6))  (setq dy60 (- y0 y6))  (setq dz60 (- z0 z6))
  (setq dx70 (- x0 x7))  (setq dy70 (- y0 y7))  (setq dz70 (- z0 z7))
  (setq dx80 (- x0 x8))  (setq dy80 (- y0 y8))  (setq dz80 (- z0 z8))
  (setq dx90 (- x0 x9))  (setq dy90 (- y0 y9))  (setq dz90 (- z0 z9))
  (setq dx1a (- xa x1))  (setq dy1a (- ya y1))  (setq dz1a (- za z1))
  (setq dx2a (- xa x2))  (setq dy2a (- ya y2))  (setq dz2a (- za z2))
  (setq dx3a (- xa x3))  (setq dy3a (- ya y3))  (setq dz3a (- za z3))
  (setq dx4a (- xa x4))  (setq dy4a (- ya y4))  (setq dz4a (- za z4))
  (setq dx5a (- xa x5))  (setq dy5a (- ya y5))  (setq dz5a (- za z5))
  (setq dx6a (- xa x6))  (setq dy6a (- ya y6))  (setq dz6a (- za z6))
  (setq dx7a (- xa x7))  (setq dy7a (- ya y7))  (setq dz7a (- za z7))
  (setq dx8a (- xa x8))  (setq dy8a (- ya y8))  (setq dz8a (- za z8))
  (setq dx9a (- xa x9))  (setq dy9a (- ya y9))  (setq dz9a (- za z9))
  (setq dx0a (- xa x0))  (setq dy0a (- ya y0))  (setq dz0a (- za z0))

;                   GRAVITA              REPULSIONE           ELASTICO       MOLLA
  (if (<= d12 r12) (setq d12 r12))
  (if (<= d13 r13) (setq d13 r13))
  (if (<= d23 r23) (setq d23 r23))
  (if (<= d14 r14) (setq d14 r14))
  (if (<= d24 r24) (setq d24 r24))
  (if (<= d34 r34) (setq d34 r34))
  (if (<= d15 r15) (setq d15 r15))
  (if (<= d25 r25) (setq d25 r25))
  (if (<= d35 r35) (setq d35 r35))
  (if (<= d45 r45) (setq d45 r45))
  (if (<= d16 r16) (setq d16 r16))
  (if (<= d26 r26) (setq d26 r26))
  (if (<= d36 r36) (setq d36 r36))
  (if (<= d46 r46) (setq d46 r46))
  (if (<= d56 r56) (setq d56 r56))
  (if (<= d17 r17) (setq d17 r17))
  (if (<= d27 r27) (setq d27 r27))
  (if (<= d37 r37) (setq d37 r37))
  (if (<= d47 r47) (setq d47 r47))
  (if (<= d57 r57) (setq d57 r57))
  (if (<= d67 r67) (setq d67 r67))
  (if (<= d18 r18) (setq d18 r18))
  (if (<= d28 r28) (setq d28 r28))
  (if (<= d38 r38) (setq d38 r38))
  (if (<= d48 r48) (setq d48 r48))
  (if (<= d58 r58) (setq d58 r58))
  (if (<= d68 r68) (setq d68 r68))
  (if (<= d78 r78) (setq d78 r78))
  (if (<= d19 r19) (setq d19 r19))
  (if (<= d29 r29) (setq d29 r29))
  (if (<= d39 r39) (setq d39 r39))
  (if (<= d49 r49) (setq d49 r49))
  (if (<= d59 r59) (setq d59 r59))
  (if (<= d69 r69) (setq d69 r69))
  (if (<= d79 r79) (setq d79 r79))
  (if (<= d89 r89) (setq d89 r89))
  (if (<= d10 r10) (setq d10 r10))
  (if (<= d20 r20) (setq d20 r20))
  (if (<= d30 r30) (setq d30 r30))
  (if (<= d40 r40) (setq d40 r40))
  (if (<= d50 r50) (setq d50 r50))
  (if (<= d60 r60) (setq d60 r60))
  (if (<= d70 r70) (setq d70 r70))
  (if (<= d80 r80) (setq d80 r80))
  (if (<= d90 r90) (setq d90 r90))
  (if (<= d1a r1a) (setq d1a r1a))
  (if (<= d2a r2a) (setq d2a r2a))
  (if (<= d3a r3a) (setq d3a r3a))
  (if (<= d4a r4a) (setq d4a r4a))
  (if (<= d5a r5a) (setq d5a r5a))
  (if (<= d6a r6a) (setq d6a r6a))
  (if (<= d7a r7a) (setq d7a r7a))
  (if (<= d8a r8a) (setq d8a r8a))
  (if (<= d9a r9a) (setq d9a r9a))
  (if (<= d0a r0a) (setq d0a r0a))
  (setq f12 (+ (* 1 (fgr m1 m2 d12)) (* 1 (fre m1 m2 d12)) (* 1 (fel d12)) (* 1 (fmo d12)) ))
  (setq f13 (+ (* 1 (fgr m1 m3 d13)) (* 1 (fre m1 m3 d13)) (* 1 (fel d13)) (* 1 (fmo d13)) ))
  (setq f23 (+ (* 1 (fgr m2 m3 d23)) (* 1 (fre m2 m3 d23)) (* 1 (fel d23)) (* 1 (fmo d23)) ))
  (setq f14 (+ (* 1 (fgr m1 m4 d14)) (* 1 (fre m1 m4 d14)) (* 1 (fel d14)) (* 1 (fmo d14)) ))
  (setq f24 (+ (* 1 (fgr m2 m4 d24)) (* 1 (fre m2 m4 d24)) (* 1 (fel d24)) (* 1 (fmo d24)) ))
  (setq f34 (+ (* 1 (fgr m3 m4 d34)) (* 1 (fre m3 m4 d34)) (* 1 (fel d34)) (* 1 (fmo d34)) ))
  (setq f15 (+ (* 1 (fgr m1 m5 d15)) (* 1 (fre m1 m5 d15)) (* 1 (fel d15)) (* 1 (fmo d15)) ))
  (setq f25 (+ (* 1 (fgr m2 m5 d25)) (* 1 (fre m2 m5 d25)) (* 1 (fel d25)) (* 1 (fmo d25)) ))
  (setq f35 (+ (* 1 (fgr m3 m5 d35)) (* 1 (fre m3 m5 d35)) (* 1 (fel d35)) (* 1 (fmo d35)) ))
  (setq f45 (+ (* 1 (fgr m4 m5 d45)) (* 1 (fre m4 m5 d45)) (* 1 (fel d45)) (* 1 (fmo d45)) ))
  (setq f16 (+ (* 1 (fgr m1 m6 d16)) (* 1 (fre m1 m6 d16)) (* 1 (fel d16)) (* 1 (fmo d16)) ))
  (setq f26 (+ (* 1 (fgr m2 m6 d26)) (* 1 (fre m2 m6 d26)) (* 1 (fel d26)) (* 1 (fmo d26)) ))
  (setq f36 (+ (* 1 (fgr m3 m6 d36)) (* 1 (fre m3 m6 d36)) (* 1 (fel d36)) (* 1 (fmo d36)) ))
  (setq f46 (+ (* 1 (fgr m4 m6 d46)) (* 1 (fre m4 m6 d46)) (* 1 (fel d46)) (* 1 (fmo d46)) ))
  (setq f56 (+ (* 1 (fgr m5 m6 d56)) (* 1 (fre m5 m6 d56)) (* 1 (fel d56)) (* 1 (fmo d56)) ))
  (setq f17 (+ (* 1 (fgr m1 m7 d17)) (* 1 (fre m1 m7 d17)) (* 1 (fel d17)) (* 1 (fmo d17)) ))
  (setq f27 (+ (* 1 (fgr m2 m7 d27)) (* 1 (fre m2 m7 d27)) (* 1 (fel d27)) (* 1 (fmo d27)) ))
  (setq f37 (+ (* 1 (fgr m3 m7 d37)) (* 1 (fre m3 m7 d37)) (* 1 (fel d37)) (* 1 (fmo d37)) ))
  (setq f47 (+ (* 1 (fgr m4 m7 d47)) (* 1 (fre m4 m7 d47)) (* 1 (fel d47)) (* 1 (fmo d47)) ))
  (setq f57 (+ (* 1 (fgr m5 m7 d57)) (* 1 (fre m5 m7 d57)) (* 1 (fel d57)) (* 1 (fmo d57)) ))
  (setq f67 (+ (* 1 (fgr m6 m7 d67)) (* 1 (fre m6 m7 d67)) (* 1 (fel d67)) (* 1 (fmo d67)) ))
  (setq f18 (+ (* 1 (fgr m1 m8 d18)) (* 1 (fre m1 m8 d18)) (* 1 (fel d18)) (* 1 (fmo d18)) ))
  (setq f28 (+ (* 1 (fgr m2 m8 d28)) (* 1 (fre m2 m8 d28)) (* 1 (fel d28)) (* 1 (fmo d28)) ))
  (setq f38 (+ (* 1 (fgr m3 m8 d38)) (* 1 (fre m3 m8 d38)) (* 1 (fel d38)) (* 1 (fmo d38)) ))
  (setq f48 (+ (* 1 (fgr m4 m8 d48)) (* 1 (fre m4 m8 d48)) (* 1 (fel d48)) (* 1 (fmo d48)) ))
  (setq f58 (+ (* 1 (fgr m5 m8 d58)) (* 1 (fre m5 m8 d58)) (* 1 (fel d58)) (* 1 (fmo d58)) ))
  (setq f68 (+ (* 1 (fgr m6 m8 d68)) (* 1 (fre m6 m8 d68)) (* 1 (fel d68)) (* 1 (fmo d68)) ))
  (setq f78 (+ (* 1 (fgr m7 m8 d78)) (* 1 (fre m7 m8 d78)) (* 1 (fel d78)) (* 1 (fmo d78)) ))
  (setq f19 (+ (* 1 (fgr m1 m9 d19)) (* 1 (fre m1 m9 d19)) (* 1 (fel d19)) (* 1 (fmo d19)) ))
  (setq f29 (+ (* 1 (fgr m2 m9 d29)) (* 1 (fre m2 m9 d29)) (* 1 (fel d29)) (* 1 (fmo d29)) ))
  (setq f39 (+ (* 1 (fgr m3 m9 d39)) (* 1 (fre m3 m9 d39)) (* 1 (fel d39)) (* 1 (fmo d39)) ))
  (setq f49 (+ (* 1 (fgr m4 m9 d49)) (* 1 (fre m4 m9 d49)) (* 1 (fel d49)) (* 1 (fmo d49)) ))
  (setq f59 (+ (* 1 (fgr m5 m9 d59)) (* 1 (fre m5 m9 d59)) (* 1 (fel d59)) (* 1 (fmo d59)) ))
  (setq f69 (+ (* 1 (fgr m6 m9 d69)) (* 1 (fre m6 m9 d69)) (* 1 (fel d69)) (* 1 (fmo d69)) ))
  (setq f79 (+ (* 1 (fgr m7 m9 d79)) (* 1 (fre m7 m9 d79)) (* 1 (fel d79)) (* 1 (fmo d79)) ))
  (setq f89 (+ (* 1 (fgr m8 m9 d89)) (* 1 (fre m8 m9 d89)) (* 1 (fel d89)) (* 1 (fmo d89)) ))
  (setq f10 (+ (* 1 (fgr m1 m0 d10)) (* 1 (fre m1 m0 d10)) (* 1 (fel d10)) (* 1 (fmo d10)) ))
  (setq f20 (+ (* 1 (fgr m2 m0 d20)) (* 1 (fre m2 m0 d20)) (* 1 (fel d20)) (* 1 (fmo d20)) ))
  (setq f30 (+ (* 1 (fgr m3 m0 d30)) (* 1 (fre m3 m0 d30)) (* 1 (fel d30)) (* 1 (fmo d30)) ))
  (setq f40 (+ (* 1 (fgr m4 m0 d40)) (* 1 (fre m4 m0 d40)) (* 1 (fel d40)) (* 1 (fmo d40)) ))
  (setq f50 (+ (* 1 (fgr m5 m0 d50)) (* 1 (fre m5 m0 d50)) (* 1 (fel d50)) (* 1 (fmo d50)) ))
  (setq f60 (+ (* 1 (fgr m6 m0 d60)) (* 1 (fre m6 m0 d60)) (* 1 (fel d60)) (* 1 (fmo d60)) ))
  (setq f70 (+ (* 1 (fgr m7 m0 d70)) (* 1 (fre m7 m0 d70)) (* 1 (fel d70)) (* 1 (fmo d70)) ))
  (setq f80 (+ (* 1 (fgr m8 m0 d80)) (* 1 (fre m8 m0 d80)) (* 1 (fel d80)) (* 1 (fmo d80)) ))
  (setq f90 (+ (* 1 (fgr m9 m0 d90)) (* 1 (fre m9 m0 d90)) (* 1 (fel d90)) (* 1 (fmo d90)) ))
  (setq f1a (+ (* 1 (fgr m1 ma d1a)) (* 1 (fre m1 ma d1a)) (* 1 (fel d1a)) (* 1 (fmo d1a)) ))
  (setq f2a (+ (* 1 (fgr m2 ma d2a)) (* 1 (fre m2 ma d2a)) (* 1 (fel d2a)) (* 1 (fmo d2a)) ))
  (setq f3a (+ (* 1 (fgr m3 ma d3a)) (* 1 (fre m3 ma d3a)) (* 1 (fel d3a)) (* 1 (fmo d3a)) ))
  (setq f4a (+ (* 1 (fgr m4 ma d4a)) (* 1 (fre m4 ma d4a)) (* 1 (fel d4a)) (* 1 (fmo d4a)) ))
  (setq f5a (+ (* 1 (fgr m5 ma d5a)) (* 1 (fre m5 ma d5a)) (* 1 (fel d5a)) (* 1 (fmo d5a)) ))
  (setq f6a (+ (* 1 (fgr m6 ma d6a)) (* 1 (fre m6 ma d6a)) (* 1 (fel d6a)) (* 1 (fmo d6a)) ))
  (setq f7a (+ (* 1 (fgr m7 ma d7a)) (* 1 (fre m7 ma d7a)) (* 1 (fel d7a)) (* 1 (fmo d7a)) ))
  (setq f8a (+ (* 1 (fgr m8 ma d8a)) (* 1 (fre m8 ma d8a)) (* 1 (fel d8a)) (* 1 (fmo d8a)) ))
  (setq f9a (+ (* 1 (fgr m9 ma d9a)) (* 1 (fre m9 ma d9a)) (* 1 (fel d9a)) (* 1 (fmo d9a)) ))
  (setq f0a (+ (* 1 (fgr m0 ma d0a)) (* 1 (fre m0 ma d0a)) (* 1 (fel d0a)) (* 1 (fmo d0a)) ))

  (setq a12 (/ f12 m1))  (setq a21 (* -1 (/ f12 m2)))
  (setq a13 (/ f13 m1))  (setq a31 (* -1 (/ f13 m3)))
  (setq a23 (/ f23 m2))  (setq a32 (* -1 (/ f23 m3)))
  (setq a14 (/ f14 m1))  (setq a41 (* -1 (/ f14 m4)))
  (setq a24 (/ f24 m2))  (setq a42 (* -1 (/ f24 m4)))
  (setq a34 (/ f34 m3))  (setq a43 (* -1 (/ f34 m4)))
  (setq a15 (/ f15 m1))  (setq a51 (* -1 (/ f15 m5)))
  (setq a25 (/ f25 m2))  (setq a52 (* -1 (/ f25 m5)))
  (setq a35 (/ f35 m3))  (setq a53 (* -1 (/ f35 m5)))
  (setq a45 (/ f45 m4))  (setq a54 (* -1 (/ f45 m5)))
  (setq a16 (/ f16 m1))  (setq a61 (* -1 (/ f16 m6)))
  (setq a26 (/ f26 m2))  (setq a62 (* -1 (/ f26 m6)))
  (setq a36 (/ f36 m3))  (setq a63 (* -1 (/ f36 m6)))
  (setq a46 (/ f46 m4))  (setq a64 (* -1 (/ f46 m6)))
  (setq a56 (/ f56 m5))  (setq a65 (* -1 (/ f56 m6)))
  (setq a17 (/ f17 m1))  (setq a71 (* -1 (/ f17 m7)))
  (setq a27 (/ f27 m2))  (setq a72 (* -1 (/ f27 m7)))
  (setq a37 (/ f37 m3))  (setq a73 (* -1 (/ f37 m7)))
  (setq a47 (/ f47 m4))  (setq a74 (* -1 (/ f47 m7)))
  (setq a57 (/ f57 m5))  (setq a75 (* -1 (/ f57 m7)))
  (setq a67 (/ f67 m6))  (setq a76 (* -1 (/ f67 m7)))
  (setq a18 (/ f18 m1))  (setq a81 (* -1 (/ f18 m8)))
  (setq a28 (/ f28 m2))  (setq a82 (* -1 (/ f28 m8)))
  (setq a38 (/ f38 m3))  (setq a83 (* -1 (/ f38 m8)))
  (setq a48 (/ f48 m4))  (setq a84 (* -1 (/ f48 m8)))
  (setq a58 (/ f58 m5))  (setq a85 (* -1 (/ f58 m8)))
  (setq a68 (/ f68 m6))  (setq a86 (* -1 (/ f68 m8)))
  (setq a78 (/ f78 m7))  (setq a87 (* -1 (/ f78 m8)))
  (setq a19 (/ f19 m1))  (setq a91 (* -1 (/ f19 m9)))
  (setq a29 (/ f29 m2))  (setq a92 (* -1 (/ f29 m9)))
  (setq a39 (/ f39 m3))  (setq a93 (* -1 (/ f39 m9)))
  (setq a49 (/ f49 m4))  (setq a94 (* -1 (/ f49 m9)))
  (setq a59 (/ f59 m5))  (setq a95 (* -1 (/ f59 m9)))
  (setq a69 (/ f69 m6))  (setq a96 (* -1 (/ f69 m9)))
  (setq a79 (/ f79 m7))  (setq a97 (* -1 (/ f79 m9)))
  (setq a89 (/ f89 m8))  (setq a98 (* -1 (/ f89 m9)))
  (setq a10 (/ f10 m1))  (setq a01 (* -1 (/ f10 m0)))
  (setq a20 (/ f20 m2))  (setq a02 (* -1 (/ f20 m0)))
  (setq a30 (/ f30 m3))  (setq a03 (* -1 (/ f30 m0)))
  (setq a40 (/ f40 m4))  (setq a04 (* -1 (/ f40 m0)))
  (setq a50 (/ f50 m5))  (setq a05 (* -1 (/ f50 m0)))
  (setq a60 (/ f60 m6))  (setq a06 (* -1 (/ f60 m0)))
  (setq a70 (/ f70 m7))  (setq a07 (* -1 (/ f70 m0)))
  (setq a80 (/ f80 m8))  (setq a08 (* -1 (/ f80 m0)))
  (setq a90 (/ f90 m9))  (setq a09 (* -1 (/ f90 m0)))
  (setq a1a (/ f1a m1))  (setq aa1 (* -1 (/ f1a ma)))
  (setq a2a (/ f2a m2))  (setq aa2 (* -1 (/ f2a ma)))
  (setq a3a (/ f3a m3))  (setq aa3 (* -1 (/ f3a ma)))
  (setq a4a (/ f4a m4))  (setq aa4 (* -1 (/ f4a ma)))
  (setq a5a (/ f5a m5))  (setq aa5 (* -1 (/ f5a ma)))
  (setq a6a (/ f6a m6))  (setq aa6 (* -1 (/ f6a ma)))
  (setq a7a (/ f7a m7))  (setq aa7 (* -1 (/ f7a ma)))
  (setq a8a (/ f8a m8))  (setq aa8 (* -1 (/ f8a ma)))
  (setq a9a (/ f9a m9))  (setq aa9 (* -1 (/ f9a ma)))
  (setq a0a (/ f0a m0))  (setq aa0 (* -1 (/ f0a ma)))
 
  (setq a1x (+ (* 1 (/ (fsx x1 y1 z1) m1)) (* 1 (/ (fwx r1) m1)) (* 1 v1x (/ (fvi m1 r1 v1) m1)) (/ (* a12 dx12) d12) (/ (* a13 dx13) d13) (/ (* a14 dx14) d14) (/ (* a15 dx15) d15) (/ (* a16 dx16) d16) (/ (* a17 dx17) d17) (/ (* a18 dx18) d18) (/ (* a19 dx19) d19) (/ (* a10 dx10) d10) (/ (* a1a dx1a) d1a) ))
  (setq a1y (+ (* 1 (/ (fsy x1 y1 z1) m1)) (* 1 (/ (fwy r1) m1)) (* 1 v1y (/ (fvi m1 r1 v1) m1)) (/ (* a12 dy12) d12) (/ (* a13 dy13) d13) (/ (* a14 dy14) d14) (/ (* a15 dy15) d15) (/ (* a16 dy16) d16) (/ (* a17 dy17) d17) (/ (* a18 dy18) d18) (/ (* a19 dy19) d19) (/ (* a10 dy10) d10) (/ (* a1a dy1a) d1a) ))
  (setq a1z (+ (* 1 (/ (fsz x1 y1 z1) m1)) (* 1 (/ (fwz r1) m1)) (* 1 v1z (/ (fvi m1 r1 v1) m1)) (/ (* a12 dz12) d12) (/ (* a13 dz13) d13) (/ (* a14 dz14) d14) (/ (* a15 dz15) d15) (/ (* a16 dz16) d16) (/ (* a17 dz17) d17) (/ (* a18 dz18) d18) (/ (* a19 dz19) d19) (/ (* a10 dz10) d10) (/ (* a1a dz1a) d1a) ))
  (setq a2x (+ (* 1 (/ (fsx x2 y2 z2) m2)) (* 1 (/ (fwx r2) m2)) (* 1 v2x (/ (fvi m2 r2 v2) m2)) (/ (* a21 dx12) d12) (/ (* a23 dx23) d23) (/ (* a24 dx24) d24) (/ (* a25 dx25) d25) (/ (* a26 dx26) d26) (/ (* a27 dx27) d27) (/ (* a28 dx28) d28) (/ (* a29 dx29) d29) (/ (* a20 dx20) d20) (/ (* a2a dx2a) d2a) ))
  (setq a2y (+ (* 1 (/ (fsy x2 y2 z2) m2)) (* 1 (/ (fwy r2) m2)) (* 1 v2y (/ (fvi m2 r2 v2) m2)) (/ (* a21 dy12) d12) (/ (* a23 dy23) d23) (/ (* a24 dy24) d24) (/ (* a25 dy25) d25) (/ (* a26 dy26) d26) (/ (* a27 dy27) d27) (/ (* a28 dy28) d28) (/ (* a29 dy29) d29) (/ (* a20 dy20) d20) (/ (* a2a dy2a) d2a) ))
  (setq a2z (+ (* 1 (/ (fsz x2 y2 z2) m2)) (* 1 (/ (fwz r2) m2)) (* 1 v2z (/ (fvi m2 r2 v2) m2)) (/ (* a21 dz12) d12) (/ (* a23 dz23) d23) (/ (* a24 dz24) d24) (/ (* a25 dz25) d25) (/ (* a26 dz26) d26) (/ (* a27 dz27) d27) (/ (* a28 dz28) d28) (/ (* a29 dz29) d29) (/ (* a20 dz20) d20) (/ (* a2a dz2a) d2a) ))
  (setq a3x (+ (* 1 (/ (fsx x3 y3 z3) m3)) (* 1 (/ (fwx r3) m3)) (* 1 v3x (/ (fvi m3 r3 v3) m3)) (/ (* a31 dx13) d13) (/ (* a32 dx23) d23) (/ (* a34 dx34) d34) (/ (* a35 dx35) d35) (/ (* a36 dx36) d36) (/ (* a37 dx37) d37) (/ (* a38 dx38) d38) (/ (* a39 dx39) d39) (/ (* a30 dx30) d30) (/ (* a3a dx3a) d3a) ))
  (setq a3y (+ (* 1 (/ (fsy x3 y3 z3) m3)) (* 1 (/ (fwy r3) m3)) (* 1 v3y (/ (fvi m3 r3 v3) m3)) (/ (* a31 dy13) d13) (/ (* a32 dy23) d23) (/ (* a34 dy34) d34) (/ (* a35 dy35) d35) (/ (* a36 dy36) d36) (/ (* a37 dy37) d37) (/ (* a38 dy38) d38) (/ (* a39 dy39) d39) (/ (* a30 dy30) d30) (/ (* a3a dy3a) d3a) ))
  (setq a3z (+ (* 1 (/ (fsz x3 y3 z3) m3)) (* 1 (/ (fwz r3) m3)) (* 1 v3z (/ (fvi m3 r3 v3) m3)) (/ (* a31 dz13) d13) (/ (* a32 dz23) d23) (/ (* a34 dz34) d34) (/ (* a35 dz35) d35) (/ (* a36 dz36) d36) (/ (* a37 dz37) d37) (/ (* a38 dz38) d38) (/ (* a39 dz39) d39) (/ (* a30 dz30) d30) (/ (* a3a dz3a) d3a) ))
  (setq a4x (+ (* 1 (/ (fsx x4 y4 z4) m4)) (* 1 (/ (fwx r4) m4)) (* 1 v4x (/ (fvi m4 r4 v4) m4)) (/ (* a41 dx14) d14) (/ (* a42 dx24) d24) (/ (* a43 dx34) d34) (/ (* a45 dx45) d45) (/ (* a46 dx46) d46) (/ (* a47 dx47) d47) (/ (* a48 dx48) d48) (/ (* a49 dx49) d49) (/ (* a40 dx40) d40) (/ (* a4a dx4a) d4a) ))
  (setq a4y (+ (* 1 (/ (fsy x4 y4 z4) m4)) (* 1 (/ (fwy r4) m4)) (* 1 v4y (/ (fvi m4 r4 v4) m4)) (/ (* a41 dy14) d14) (/ (* a42 dy24) d24) (/ (* a43 dy34) d34) (/ (* a45 dy45) d45) (/ (* a46 dy46) d46) (/ (* a47 dy47) d47) (/ (* a48 dy48) d48) (/ (* a49 dy49) d49) (/ (* a40 dy40) d40) (/ (* a4a dy4a) d4a) ))
  (setq a4z (+ (* 1 (/ (fsz x4 y4 z4) m4)) (* 1 (/ (fwz r4) m4)) (* 1 v4z (/ (fvi m4 r4 v4) m4)) (/ (* a41 dz14) d14) (/ (* a42 dz24) d24) (/ (* a43 dz34) d34) (/ (* a45 dz45) d45) (/ (* a46 dz46) d46) (/ (* a47 dz47) d47) (/ (* a48 dz48) d48) (/ (* a49 dz49) d49) (/ (* a40 dz40) d40) (/ (* a4a dz4a) d4a) ))
  (setq a5x (+ (* 1 (/ (fsx x5 y5 z5) m5)) (* 1 (/ (fwx r5) m5)) (* 1 v5x (/ (fvi m5 r5 v5) m5)) (/ (* a51 dx15) d15) (/ (* a52 dx25) d25) (/ (* a53 dx35) d35) (/ (* a54 dx45) d45) (/ (* a56 dx56) d56) (/ (* a57 dx57) d57) (/ (* a58 dx58) d58) (/ (* a59 dx59) d59) (/ (* a50 dx50) d50) (/ (* a5a dx5a) d5a) ))
  (setq a5y (+ (* 1 (/ (fsy x5 y5 z5) m5)) (* 1 (/ (fwy r5) m5)) (* 1 v5y (/ (fvi m5 r5 v5) m5)) (/ (* a51 dy15) d15) (/ (* a52 dy25) d25) (/ (* a53 dy35) d35) (/ (* a54 dy45) d45) (/ (* a56 dy56) d56) (/ (* a57 dy57) d57) (/ (* a58 dy58) d58) (/ (* a59 dy59) d59) (/ (* a50 dy50) d50) (/ (* a5a dy5a) d5a) ))
  (setq a5z (+ (* 1 (/ (fsz x5 y5 z5) m5)) (* 1 (/ (fwz r5) m5)) (* 1 v5z (/ (fvi m5 r5 v5) m5)) (/ (* a51 dz15) d15) (/ (* a52 dz25) d25) (/ (* a53 dz35) d35) (/ (* a54 dz45) d45) (/ (* a56 dz56) d56) (/ (* a57 dz57) d57) (/ (* a58 dz58) d58) (/ (* a59 dz59) d59) (/ (* a50 dz50) d50) (/ (* a5a dz5a) d5a) ))
  (setq a6x (+ (* 1 (/ (fsx x6 y6 z6) m6)) (* 1 (/ (fwx r6) m6)) (* 1 v6x (/ (fvi m6 r6 v6) m6)) (/ (* a61 dx16) d16) (/ (* a62 dx26) d26) (/ (* a63 dx36) d36) (/ (* a64 dx46) d46) (/ (* a65 dx56) d56) (/ (* a67 dx67) d67) (/ (* a68 dx68) d68) (/ (* a69 dx69) d69) (/ (* a60 dx60) d60) (/ (* a6a dx6a) d6a) ))
  (setq a6y (+ (* 1 (/ (fsy x6 y6 z6) m6)) (* 1 (/ (fwy r6) m6)) (* 1 v6y (/ (fvi m6 r6 v6) m6)) (/ (* a61 dy16) d16) (/ (* a62 dy26) d26) (/ (* a63 dy36) d36) (/ (* a64 dy46) d46) (/ (* a65 dy56) d56) (/ (* a67 dy67) d67) (/ (* a68 dy68) d68) (/ (* a69 dy69) d69) (/ (* a60 dy60) d60) (/ (* a6a dy6a) d6a) ))
  (setq a6z (+ (* 1 (/ (fsz x6 y6 z6) m6)) (* 1 (/ (fwz r6) m6)) (* 1 v6z (/ (fvi m6 r6 v6) m6)) (/ (* a61 dz16) d16) (/ (* a62 dz26) d26) (/ (* a63 dz36) d36) (/ (* a64 dz46) d46) (/ (* a65 dz56) d56) (/ (* a67 dz67) d67) (/ (* a68 dz68) d68) (/ (* a69 dz69) d69) (/ (* a60 dz60) d60) (/ (* a6a dz6a) d6a) ))
  (setq a7x (+ (* 1 (/ (fsx x7 y7 z7) m7)) (* 1 (/ (fwx r7) m7)) (* 1 v7x (/ (fvi m7 r7 v7) m7)) (/ (* a71 dx17) d17) (/ (* a72 dx27) d27) (/ (* a73 dx37) d37) (/ (* a74 dx47) d47) (/ (* a75 dx57) d57) (/ (* a76 dx67) d67) (/ (* a78 dx78) d78) (/ (* a79 dx79) d79) (/ (* a70 dx70) d70) (/ (* a7a dx7a) d7a) ))
  (setq a7y (+ (* 1 (/ (fsy x7 y7 z7) m7)) (* 1 (/ (fwy r7) m7)) (* 1 v7y (/ (fvi m7 r7 v7) m7)) (/ (* a71 dy17) d17) (/ (* a72 dy27) d27) (/ (* a73 dy37) d37) (/ (* a74 dy47) d47) (/ (* a75 dy57) d57) (/ (* a76 dy67) d67) (/ (* a78 dy78) d78) (/ (* a79 dy79) d79) (/ (* a70 dy70) d70) (/ (* a7a dy7a) d7a) ))
  (setq a7z (+ (* 1 (/ (fsz x7 y7 z7) m7)) (* 1 (/ (fwz r7) m7)) (* 1 v7z (/ (fvi m7 r7 v7) m7)) (/ (* a71 dz17) d17) (/ (* a72 dz27) d27) (/ (* a73 dz37) d37) (/ (* a74 dz47) d47) (/ (* a75 dz57) d57) (/ (* a76 dz67) d67) (/ (* a78 dz78) d78) (/ (* a79 dz79) d79) (/ (* a70 dz70) d70) (/ (* a7a dz7a) d7a) ))
  (setq a8x (+ (* 1 (/ (fsx x8 y8 z8) m8)) (* 1 (/ (fwx r8) m8)) (* 1 v8x (/ (fvi m8 r8 v8) m8)) (/ (* a81 dx18) d18) (/ (* a82 dx28) d28) (/ (* a83 dx38) d38) (/ (* a84 dx48) d48) (/ (* a85 dx58) d58) (/ (* a86 dx68) d68) (/ (* a87 dx78) d78) (/ (* a89 dx89) d89) (/ (* a80 dx80) d80) (/ (* a8a dx8a) d8a) ))
  (setq a8y (+ (* 1 (/ (fsy x8 y8 z8) m8)) (* 1 (/ (fwy r8) m8)) (* 1 v8y (/ (fvi m8 r8 v8) m8)) (/ (* a81 dy18) d18) (/ (* a82 dy28) d28) (/ (* a83 dy38) d38) (/ (* a84 dy48) d48) (/ (* a85 dy58) d58) (/ (* a86 dy68) d68) (/ (* a87 dy78) d78) (/ (* a89 dy89) d89) (/ (* a80 dy80) d80) (/ (* a8a dy8a) d8a) ))
  (setq a8z (+ (* 1 (/ (fsz x8 y8 z8) m8)) (* 1 (/ (fwz r8) m8)) (* 1 v8z (/ (fvi m8 r8 v8) m8)) (/ (* a81 dz18) d18) (/ (* a82 dz28) d28) (/ (* a83 dz38) d38) (/ (* a84 dz48) d48) (/ (* a85 dz58) d58) (/ (* a86 dz68) d68) (/ (* a87 dz78) d78) (/ (* a89 dz89) d89) (/ (* a80 dz80) d80) (/ (* a8a dz8a) d8a) ))
  (setq a9x (+ (* 1 (/ (fsx x9 y9 z9) m9)) (* 1 (/ (fwx r9) m9)) (* 1 v9x (/ (fvi m9 r9 v9) m9)) (/ (* a91 dx19) d19) (/ (* a92 dx29) d29) (/ (* a93 dx39) d39) (/ (* a94 dx49) d49) (/ (* a95 dx59) d59) (/ (* a96 dx69) d69) (/ (* a97 dx79) d79) (/ (* a98 dx89) d89) (/ (* a90 dx90) d90) (/ (* a9a dx9a) d9a) ))
  (setq a9y (+ (* 1 (/ (fsy x9 y9 z9) m9)) (* 1 (/ (fwy r9) m9)) (* 1 v9y (/ (fvi m9 r9 v9) m9)) (/ (* a91 dy19) d19) (/ (* a92 dy29) d29) (/ (* a93 dy39) d39) (/ (* a94 dy49) d49) (/ (* a95 dy59) d59) (/ (* a96 dy69) d69) (/ (* a97 dy79) d79) (/ (* a98 dy89) d89) (/ (* a90 dy90) d90) (/ (* a9a dy9a) d9a) ))
  (setq a9z (+ (* 1 (/ (fsz x9 y9 z9) m9)) (* 1 (/ (fwz r9) m9)) (* 1 v9z (/ (fvi m9 r9 v9) m9)) (/ (* a91 dz19) d19) (/ (* a92 dz29) d29) (/ (* a93 dz39) d39) (/ (* a94 dz49) d49) (/ (* a95 dz59) d59) (/ (* a96 dz69) d69) (/ (* a97 dz79) d79) (/ (* a98 dz89) d89) (/ (* a90 dz90) d90) (/ (* a9a dz9a) d9a) ))
  (setq a0x (+ (* 1 (/ (fsx x0 y0 z0) m0)) (* 1 (/ (fwx r0) m0)) (* 1 v0x (/ (fvi m0 r0 v0) m0)) (/ (* a01 dx10) d10) (/ (* a02 dx20) d20) (/ (* a03 dx30) d30) (/ (* a04 dx40) d40) (/ (* a05 dx50) d50) (/ (* a06 dx60) d60) (/ (* a07 dx70) d70) (/ (* a08 dx80) d80) (/ (* a09 dx90) d90) (/ (* a0a dx0a) d0a) ))
  (setq a0y (+ (* 1 (/ (fsy x0 y0 z0) m0)) (* 1 (/ (fwy r0) m0)) (* 1 v0y (/ (fvi m0 r0 v0) m0)) (/ (* a01 dy10) d10) (/ (* a02 dy20) d20) (/ (* a03 dy30) d30) (/ (* a04 dy40) d40) (/ (* a05 dy50) d50) (/ (* a06 dy60) d60) (/ (* a07 dy70) d70) (/ (* a08 dy80) d80) (/ (* a09 dy90) d90) (/ (* a0a dy0a) d0a) ))
  (setq a0z (+ (* 1 (/ (fsz x0 y0 z0) m0)) (* 1 (/ (fwz r0) m0)) (* 1 v0z (/ (fvi m0 r0 v0) m0)) (/ (* a01 dz10) d10) (/ (* a02 dz20) d20) (/ (* a03 dz30) d30) (/ (* a04 dz40) d40) (/ (* a05 dz50) d50) (/ (* a06 dz60) d60) (/ (* a07 dz70) d70) (/ (* a08 dz80) d80) (/ (* a09 dz90) d90) (/ (* a0a dz0a) d0a) ))
  (setq aax (+ (* 1 (/ (fsx xa ya za) ma)) (* 1 (/ (fwx ra) ma)) (* 1 vax (/ (fvi ma ra va) ma)) (/ (* aa1 dx1a) d1a) (/ (* aa2 dx2a) d2a) (/ (* aa3 dx3a) d3a) (/ (* aa4 dx4a) d4a) (/ (* aa5 dx5a) d5a) (/ (* aa6 dx6a) d6a) (/ (* aa7 dx7a) d7a) (/ (* aa8 dx8a) d8a) (/ (* aa9 dx9a) d9a) (/ (* aa0 dx0a) d0a) ))
  (setq aay (+ (* 1 (/ (fsy xa ya za) ma)) (* 1 (/ (fwy ra) ma)) (* 1 vay (/ (fvi ma ra va) ma)) (/ (* aa1 dy1a) d1a) (/ (* aa2 dy2a) d2a) (/ (* aa3 dy3a) d3a) (/ (* aa4 dy4a) d4a) (/ (* aa5 dy5a) d5a) (/ (* aa6 dy6a) d6a) (/ (* aa7 dy7a) d7a) (/ (* aa8 dy8a) d8a) (/ (* aa9 dy9a) d9a) (/ (* aa0 dy0a) d0a) ))
  (setq aaz (+ (* 1 (/ (fsz xa ya za) ma)) (* 1 (/ (fwz ra) ma)) (* 1 vaz (/ (fvi ma ra va) ma)) (/ (* aa1 dz1a) d1a) (/ (* aa2 dz2a) d2a) (/ (* aa3 dz3a) d3a) (/ (* aa4 dz4a) d4a) (/ (* aa5 dz5a) d5a) (/ (* aa6 dz6a) d6a) (/ (* aa7 dz7a) d7a) (/ (* aa8 dz8a) d8a) (/ (* aa9 dz9a) d9a) (/ (* aa0 dz0a) d0a) ))

  (if (> d12 r12)
   (progn 
    (setq v1x (+ v1x (* a1x t)))  (setq v1y (+ v1y (* a1y t)))  (setq v1z (+ v1z (* a1z t)))
    (setq v2x (+ v2x (* a2x t)))  (setq v2y (+ v2y (* a2y t)))  (setq v2z (+ v2z (* a2z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v1i (list v1x v1y v1z)) ;velocita 1 prima dello scontro
     (setq v2i (list v2x v2y v2z)) ;velocita 2 prima dello scontro
     (setq v1i* (trans v1i 0 (list dx12 dy12 dz12)))
     (setq v2i* (trans v2i 0 (list dx12 dy12 dz12)))
     (setq v1i*x (car v1i*) v1i*y (cadr v1i*) v1i*z (caddr v1i*))
     (setq v2i*x (car v2i*) v2i*y (cadr v2i*) v2i*z (caddr v2i*))
     (setq v1f*z (* kur (/ (+ (* (- m1 m2) v1i*z) (* 2 m2 v2i*z)) (+ m1 m2))))
     (setq v2f*z (* kur (/ (+ (* (- m2 m1) v2i*z) (* 2 m1 v1i*z)) (+ m1 m2))))
     (setq v1f* (list v1i*x v1i*y v1f*z))
     (setq v2f* (list v2i*x v2i*y v2f*z))
     (setq v1f (trans v1f* (list dx12 dy12 dz12) 0))
     (setq v2f (trans v2f* (list dx12 dy12 dz12) 0))
     (setq v1x (car v1f) v1y (cadr v1f) v1z (caddr v1f))
     (setq v2x (car v2f) v2y (cadr v2f) v2z (caddr v2f))
    )
   )
  )
  (if (> d13 r13)
   (progn 
    (setq v1x (+ v1x (* a1x t)))  (setq v1y (+ v1y (* a1y t)))  (setq v1z (+ v1z (* a1z t)))
    (setq v3x (+ v3x (* a3x t)))  (setq v3y (+ v3y (* a3y t)))  (setq v3z (+ v3z (* a3z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v1i (list v1x v1y v1z)) ;velocita 1 prima dello scontro
     (setq v3i (list v3x v3y v3z)) ;velocita 3 prima dello scontro
     (setq v1i* (trans v1i 0 (list dx13 dy13 dz13)))
     (setq v3i* (trans v3i 0 (list dx13 dy13 dz13)))
     (setq v1i*x (car v1i*) v1i*y (cadr v1i*) v1i*z (caddr v1i*))
     (setq v3i*x (car v3i*) v3i*y (cadr v3i*) v3i*z (caddr v3i*))
     (setq v1f*z (* kur (/ (+ (* (- m1 m3) v1i*z) (* 2 m3 v3i*z)) (+ m1 m3))))
     (setq v3f*z (* kur (/ (+ (* (- m3 m1) v3i*z) (* 2 m1 v1i*z)) (+ m1 m3))))
     (setq v1f* (list v1i*x v1i*y v1f*z))
     (setq v3f* (list v3i*x v3i*y v3f*z))
     (setq v1f (trans v1f* (list dx13 dy13 dz13) 0))
     (setq v3f (trans v3f* (list dx13 dy13 dz13) 0))
     (setq v1x (car v1f) v1y (cadr v1f) v1z (caddr v1f))
     (setq v3x (car v3f) v3y (cadr v3f) v3z (caddr v3f))
    )
   )
  )
  (if (> d23 r23)
   (progn 
    (setq v2x (+ v2x (* a2x t)))  (setq v2y (+ v2y (* a2y t)))  (setq v2z (+ v2z (* a2z t)))
    (setq v3x (+ v3x (* a3x t)))  (setq v3y (+ v3y (* a3y t)))  (setq v3z (+ v3z (* a3z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v2i (list v2x v2y v2z)) ;velocita 2 prima dello scontro
     (setq v3i (list v3x v3y v3z)) ;velocita 3 prima dello scontro
     (setq v2i* (trans v2i 0 (list dx23 dy23 dz23)))
     (setq v3i* (trans v3i 0 (list dx23 dy23 dz23)))
     (setq v2i*x (car v2i*) v2i*y (cadr v2i*) v2i*z (caddr v2i*))
     (setq v3i*x (car v3i*) v3i*y (cadr v3i*) v3i*z (caddr v3i*))
     (setq v2f*z (* kur (/ (+ (* (- m2 m3) v2i*z) (* 2 m3 v3i*z)) (+ m2 m3))))
     (setq v3f*z (* kur (/ (+ (* (- m3 m2) v3i*z) (* 2 m2 v2i*z)) (+ m2 m3))))
     (setq v2f* (list v2i*x v2i*y v2f*z))
     (setq v3f* (list v3i*x v3i*y v3f*z))
     (setq v2f (trans v2f* (list dx23 dy23 dz23) 0))
     (setq v3f (trans v3f* (list dx23 dy23 dz23) 0))
     (setq v2x (car v2f) v2y (cadr v2f) v2z (caddr v2f))
     (setq v3x (car v3f) v3y (cadr v3f) v3z (caddr v3f))
    )
   )
  )
  (if (> d14 r14)
   (progn 
    (setq v1x (+ v1x (* a1x t)))  (setq v1y (+ v1y (* a1y t)))  (setq v1z (+ v1z (* a1z t)))
    (setq v4x (+ v4x (* a4x t)))  (setq v4y (+ v4y (* a4y t)))  (setq v4z (+ v4z (* a4z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v1i (list v1x v1y v1z)) ;velocita 1 prima dello scontro
     (setq v4i (list v4x v4y v4z)) ;velocita 4 prima dello scontro
     (setq v1i* (trans v1i 0 (list dx14 dy14 dz14)))
     (setq v4i* (trans v4i 0 (list dx14 dy14 dz14)))
     (setq v1i*x (car v1i*) v1i*y (cadr v1i*) v1i*z (caddr v1i*))
     (setq v4i*x (car v4i*) v4i*y (cadr v4i*) v4i*z (caddr v4i*))
     (setq v1f*z (* kur (/ (+ (* (- m1 m4) v1i*z) (* 2 m4 v4i*z)) (+ m1 m4))))
     (setq v4f*z (* kur (/ (+ (* (- m4 m1) v4i*z) (* 2 m1 v1i*z)) (+ m1 m4))))
     (setq v1f* (list v1i*x v1i*y v1f*z))
     (setq v4f* (list v4i*x v4i*y v4f*z))
     (setq v1f (trans v1f* (list dx14 dy14 dz14) 0))
     (setq v4f (trans v4f* (list dx14 dy14 dz14) 0))
     (setq v1x (car v1f) v1y (cadr v1f) v1z (caddr v1f))
     (setq v4x (car v4f) v4y (cadr v4f) v4z (caddr v4f))
    )
   )
  )
  (if (> d24 r24)
   (progn 
    (setq v2x (+ v2x (* a2x t)))  (setq v2y (+ v2y (* a2y t)))  (setq v2z (+ v2z (* a2z t)))
    (setq v4x (+ v4x (* a4x t)))  (setq v4y (+ v4y (* a4y t)))  (setq v4z (+ v4z (* a4z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v2i (list v2x v2y v2z)) ;velocita 2 prima dello scontro
     (setq v4i (list v4x v4y v4z)) ;velocita 4 prima dello scontro
     (setq v2i* (trans v2i 0 (list dx24 dy24 dz24)))
     (setq v4i* (trans v4i 0 (list dx24 dy24 dz24)))
     (setq v2i*x (car v2i*) v2i*y (cadr v2i*) v2i*z (caddr v2i*))
     (setq v4i*x (car v4i*) v4i*y (cadr v4i*) v4i*z (caddr v4i*))
     (setq v2f*z (* kur (/ (+ (* (- m2 m4) v2i*z) (* 2 m4 v4i*z)) (+ m2 m4))))
     (setq v4f*z (* kur (/ (+ (* (- m4 m2) v4i*z) (* 2 m2 v2i*z)) (+ m2 m4))))
     (setq v2f* (list v2i*x v2i*y v2f*z))
     (setq v4f* (list v4i*x v4i*y v4f*z))
     (setq v2f (trans v2f* (list dx24 dy24 dz24) 0))
     (setq v4f (trans v4f* (list dx24 dy24 dz24) 0))
     (setq v2x (car v2f) v2y (cadr v2f) v2z (caddr v2f))
     (setq v4x (car v4f) v4y (cadr v4f) v4z (caddr v4f))
    )
   )
  )
  (if (> d34 r34)
   (progn 
    (setq v3x (+ v3x (* a3x t)))  (setq v3y (+ v3y (* a3y t)))  (setq v3z (+ v3z (* a3z t)))
    (setq v4x (+ v4x (* a4x t)))  (setq v4y (+ v4y (* a4y t)))  (setq v4z (+ v4z (* a4z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v3i (list v3x v3y v3z)) ;velocita 3 prima dello scontro
     (setq v4i (list v4x v4y v4z)) ;velocita 4 prima dello scontro
     (setq v3i* (trans v3i 0 (list dx34 dy34 dz34)))
     (setq v4i* (trans v4i 0 (list dx34 dy34 dz34)))
     (setq v3i*x (car v3i*) v3i*y (cadr v3i*) v3i*z (caddr v3i*))
     (setq v4i*x (car v4i*) v4i*y (cadr v4i*) v4i*z (caddr v4i*))
     (setq v3f*z (* kur (/ (+ (* (- m3 m4) v3i*z) (* 2 m4 v4i*z)) (+ m3 m4))))
     (setq v4f*z (* kur (/ (+ (* (- m4 m3) v4i*z) (* 2 m3 v3i*z)) (+ m3 m4))))
     (setq v3f* (list v3i*x v3i*y v3f*z))
     (setq v4f* (list v4i*x v4i*y v4f*z))
     (setq v3f (trans v3f* (list dx34 dy34 dz34) 0))
     (setq v4f (trans v4f* (list dx34 dy34 dz34) 0))
     (setq v3x (car v3f) v3y (cadr v3f) v3z (caddr v3f))
     (setq v4x (car v4f) v4y (cadr v4f) v4z (caddr v4f))
    )
   )
  )
  (if (> d15 r15)
   (progn 
    (setq v1x (+ v1x (* a1x t)))  (setq v1y (+ v1y (* a1y t)))  (setq v1z (+ v1z (* a1z t)))
    (setq v5x (+ v5x (* a5x t)))  (setq v5y (+ v5y (* a5y t)))  (setq v5z (+ v5z (* a5z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v1i (list v1x v1y v1z)) ;velocita 1 prima dello scontro
     (setq v5i (list v5x v5y v5z)) ;velocita 5 prima dello scontro
     (setq v1i* (trans v1i 0 (list dx15 dy15 dz15)))
     (setq v5i* (trans v5i 0 (list dx15 dy15 dz15)))
     (setq v1i*x (car v1i*) v1i*y (cadr v1i*) v1i*z (caddr v1i*))
     (setq v5i*x (car v5i*) v5i*y (cadr v5i*) v5i*z (caddr v5i*))
     (setq v1f*z (* kur (/ (+ (* (- m1 m5) v1i*z) (* 2 m5 v5i*z)) (+ m1 m5))))
     (setq v5f*z (* kur (/ (+ (* (- m5 m1) v5i*z) (* 2 m1 v1i*z)) (+ m1 m5))))
     (setq v1f* (list v1i*x v1i*y v1f*z))
     (setq v5f* (list v5i*x v5i*y v5f*z))
     (setq v1f (trans v1f* (list dx15 dy15 dz15) 0))
     (setq v5f (trans v5f* (list dx15 dy15 dz15) 0))
     (setq v1x (car v1f) v1y (cadr v1f) v1z (caddr v1f))
     (setq v5x (car v5f) v5y (cadr v5f) v5z (caddr v5f))
    )
   )
  )
  (if (> d25 r25)
   (progn 
    (setq v2x (+ v2x (* a2x t)))  (setq v2y (+ v2y (* a2y t)))  (setq v2z (+ v2z (* a2z t)))
    (setq v5x (+ v5x (* a5x t)))  (setq v5y (+ v5y (* a5y t)))  (setq v5z (+ v5z (* a5z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v2i (list v2x v2y v2z)) ;velocita 2 prima dello scontro
     (setq v5i (list v5x v5y v5z)) ;velocita 5 prima dello scontro
     (setq v2i* (trans v2i 0 (list dx25 dy25 dz25)))
     (setq v5i* (trans v5i 0 (list dx25 dy25 dz25)))
     (setq v2i*x (car v2i*) v2i*y (cadr v2i*) v2i*z (caddr v2i*))
     (setq v5i*x (car v5i*) v5i*y (cadr v5i*) v5i*z (caddr v5i*))
     (setq v2f*z (* kur (/ (+ (* (- m2 m5) v2i*z) (* 2 m5 v5i*z)) (+ m2 m5))))
     (setq v5f*z (* kur (/ (+ (* (- m5 m2) v5i*z) (* 2 m2 v2i*z)) (+ m2 m5))))
     (setq v2f* (list v2i*x v2i*y v2f*z))
     (setq v5f* (list v5i*x v5i*y v5f*z))
     (setq v2f (trans v2f* (list dx25 dy25 dz25) 0))
     (setq v5f (trans v5f* (list dx25 dy25 dz25) 0))
     (setq v2x (car v2f) v2y (cadr v2f) v2z (caddr v2f))
     (setq v5x (car v5f) v5y (cadr v5f) v5z (caddr v5f))
    )
   )
  )
  (if (> d35 r35)
   (progn 
    (setq v3x (+ v3x (* a3x t)))  (setq v3y (+ v3y (* a3y t)))  (setq v3z (+ v3z (* a3z t)))
    (setq v5x (+ v5x (* a5x t)))  (setq v5y (+ v5y (* a5y t)))  (setq v5z (+ v5z (* a5z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v3i (list v3x v3y v3z)) ;velocita 3 prima dello scontro
     (setq v5i (list v5x v5y v5z)) ;velocita 5 prima dello scontro
     (setq v3i* (trans v3i 0 (list dx35 dy35 dz35)))
     (setq v5i* (trans v5i 0 (list dx35 dy35 dz35)))
     (setq v3i*x (car v3i*) v3i*y (cadr v3i*) v3i*z (caddr v3i*))
     (setq v5i*x (car v5i*) v5i*y (cadr v5i*) v5i*z (caddr v5i*))
     (setq v3f*z (* kur (/ (+ (* (- m3 m5) v3i*z) (* 2 m5 v5i*z)) (+ m3 m5))))
     (setq v5f*z (* kur (/ (+ (* (- m5 m3) v5i*z) (* 2 m3 v3i*z)) (+ m3 m5))))
     (setq v3f* (list v3i*x v3i*y v3f*z))
     (setq v5f* (list v5i*x v5i*y v5f*z))
     (setq v3f (trans v3f* (list dx35 dy35 dz35) 0))
     (setq v5f (trans v5f* (list dx35 dy35 dz35) 0))
     (setq v3x (car v3f) v3y (cadr v3f) v3z (caddr v3f))
     (setq v5x (car v5f) v5y (cadr v5f) v5z (caddr v5f))
    )
   )
  )
  (if (> d45 r45)
   (progn 
    (setq v4x (+ v4x (* a4x t)))  (setq v4y (+ v4y (* a4y t)))  (setq v4z (+ v4z (* a4z t)))
    (setq v5x (+ v5x (* a5x t)))  (setq v5y (+ v5y (* a5y t)))  (setq v5z (+ v5z (* a5z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v4i (list v4x v4y v4z)) ;velocita 4 prima dello scontro
     (setq v5i (list v5x v5y v5z)) ;velocita 5 prima dello scontro
     (setq v4i* (trans v4i 0 (list dx45 dy45 dz45)))
     (setq v5i* (trans v5i 0 (list dx45 dy45 dz45)))
     (setq v4i*x (car v4i*) v4i*y (cadr v4i*) v4i*z (caddr v4i*))
     (setq v5i*x (car v5i*) v5i*y (cadr v5i*) v5i*z (caddr v5i*))
     (setq v4f*z (* kur (/ (+ (* (- m4 m5) v4i*z) (* 2 m5 v5i*z)) (+ m4 m5))))
     (setq v5f*z (* kur (/ (+ (* (- m5 m4) v5i*z) (* 2 m4 v4i*z)) (+ m4 m5))))
     (setq v4f* (list v4i*x v4i*y v4f*z))
     (setq v5f* (list v5i*x v5i*y v5f*z))
     (setq v4f (trans v4f* (list dx45 dy45 dz45) 0))
     (setq v5f (trans v5f* (list dx45 dy45 dz45) 0))
     (setq v4x (car v4f) v4y (cadr v4f) v4z (caddr v4f))
     (setq v5x (car v5f) v5y (cadr v5f) v5z (caddr v5f))
    )
   )
  )
  (if (> d16 r16)
   (progn 
    (setq v1x (+ v1x (* a1x t)))  (setq v1y (+ v1y (* a1y t)))  (setq v1z (+ v1z (* a1z t)))
    (setq v6x (+ v6x (* a6x t)))  (setq v6y (+ v6y (* a6y t)))  (setq v6z (+ v6z (* a6z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v1i (list v1x v1y v1z)) ;velocita 1 prima dello scontro
     (setq v6i (list v6x v6y v6z)) ;velocita 6 prima dello scontro
     (setq v1i* (trans v1i 0 (list dx16 dy16 dz16)))
     (setq v6i* (trans v6i 0 (list dx16 dy16 dz16)))
     (setq v1i*x (car v1i*) v1i*y (cadr v1i*) v1i*z (caddr v1i*))
     (setq v6i*x (car v6i*) v6i*y (cadr v6i*) v6i*z (caddr v6i*))
     (setq v1f*z (* kur (/ (+ (* (- m1 m6) v1i*z) (* 2 m6 v6i*z)) (+ m1 m6))))
     (setq v6f*z (* kur (/ (+ (* (- m6 m1) v6i*z) (* 2 m1 v1i*z)) (+ m1 m6))))
     (setq v1f* (list v1i*x v1i*y v1f*z))
     (setq v6f* (list v6i*x v6i*y v6f*z))
     (setq v1f (trans v1f* (list dx16 dy16 dz16) 0))
     (setq v6f (trans v6f* (list dx16 dy16 dz16) 0))
     (setq v1x (car v1f) v1y (cadr v1f) v1z (caddr v1f))
     (setq v6x (car v6f) v6y (cadr v6f) v6z (caddr v6f))
    )
   )
  )
  (if (> d26 r26)
   (progn 
    (setq v2x (+ v2x (* a2x t)))  (setq v2y (+ v2y (* a2y t)))  (setq v2z (+ v2z (* a2z t)))
    (setq v6x (+ v6x (* a6x t)))  (setq v6y (+ v6y (* a6y t)))  (setq v6z (+ v6z (* a6z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v2i (list v2x v2y v2z)) ;velocita 2 prima dello scontro
     (setq v6i (list v6x v6y v6z)) ;velocita 6 prima dello scontro
     (setq v2i* (trans v2i 0 (list dx26 dy26 dz26)))
     (setq v6i* (trans v6i 0 (list dx26 dy26 dz26)))
     (setq v2i*x (car v2i*) v2i*y (cadr v2i*) v2i*z (caddr v2i*))
     (setq v6i*x (car v6i*) v6i*y (cadr v6i*) v6i*z (caddr v6i*))
     (setq v2f*z (* kur (/ (+ (* (- m2 m6) v2i*z) (* 2 m6 v6i*z)) (+ m2 m6))))
     (setq v6f*z (* kur (/ (+ (* (- m6 m2) v6i*z) (* 2 m2 v2i*z)) (+ m2 m6))))
     (setq v2f* (list v2i*x v2i*y v2f*z))
     (setq v6f* (list v6i*x v6i*y v6f*z))
     (setq v2f (trans v2f* (list dx26 dy26 dz26) 0))
     (setq v6f (trans v6f* (list dx26 dy26 dz26) 0))
     (setq v2x (car v2f) v2y (cadr v2f) v2z (caddr v2f))
     (setq v6x (car v6f) v6y (cadr v6f) v6z (caddr v6f))
    )
   )
  )
  (if (> d36 r36)
   (progn 
    (setq v3x (+ v3x (* a3x t)))  (setq v3y (+ v3y (* a3y t)))  (setq v3z (+ v3z (* a3z t)))
    (setq v6x (+ v6x (* a6x t)))  (setq v6y (+ v6y (* a6y t)))  (setq v6z (+ v6z (* a6z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v3i (list v3x v3y v3z)) ;velocita 3 prima dello scontro
     (setq v6i (list v6x v6y v6z)) ;velocita 6 prima dello scontro
     (setq v3i* (trans v3i 0 (list dx36 dy36 dz36)))
     (setq v6i* (trans v6i 0 (list dx36 dy36 dz36)))
     (setq v3i*x (car v3i*) v3i*y (cadr v3i*) v3i*z (caddr v3i*))
     (setq v6i*x (car v6i*) v6i*y (cadr v6i*) v6i*z (caddr v6i*))
     (setq v3f*z (* kur (/ (+ (* (- m3 m6) v3i*z) (* 2 m6 v6i*z)) (+ m3 m6))))
     (setq v6f*z (* kur (/ (+ (* (- m6 m3) v6i*z) (* 2 m3 v3i*z)) (+ m3 m6))))
     (setq v3f* (list v3i*x v3i*y v3f*z))
     (setq v6f* (list v6i*x v6i*y v6f*z))
     (setq v3f (trans v3f* (list dx36 dy36 dz36) 0))
     (setq v6f (trans v6f* (list dx36 dy36 dz36) 0))
     (setq v3x (car v3f) v3y (cadr v3f) v3z (caddr v3f))
     (setq v6x (car v6f) v6y (cadr v6f) v6z (caddr v6f))
    )
   )
  )
  (if (> d46 r46)
   (progn 
    (setq v4x (+ v4x (* a4x t)))  (setq v4y (+ v4y (* a4y t)))  (setq v4z (+ v4z (* a4z t)))
    (setq v6x (+ v6x (* a6x t)))  (setq v6y (+ v6y (* a6y t)))  (setq v6z (+ v6z (* a6z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v4i (list v4x v4y v4z)) ;velocita 4 prima dello scontro
     (setq v6i (list v6x v6y v6z)) ;velocita 6 prima dello scontro
     (setq v4i* (trans v4i 0 (list dx46 dy46 dz46)))
     (setq v6i* (trans v6i 0 (list dx46 dy46 dz46)))
     (setq v4i*x (car v4i*) v4i*y (cadr v4i*) v4i*z (caddr v4i*))
     (setq v6i*x (car v6i*) v6i*y (cadr v6i*) v6i*z (caddr v6i*))
     (setq v4f*z (* kur (/ (+ (* (- m4 m6) v4i*z) (* 2 m6 v6i*z)) (+ m4 m6))))
     (setq v6f*z (* kur (/ (+ (* (- m6 m4) v6i*z) (* 2 m4 v4i*z)) (+ m4 m6))))
     (setq v4f* (list v4i*x v4i*y v4f*z))
     (setq v6f* (list v6i*x v6i*y v6f*z))
     (setq v4f (trans v4f* (list dx46 dy46 dz46) 0))
     (setq v6f (trans v6f* (list dx46 dy46 dz46) 0))
     (setq v4x (car v4f) v4y (cadr v4f) v4z (caddr v4f))
     (setq v6x (car v6f) v6y (cadr v6f) v6z (caddr v6f))
    )
   )
  )
  (if (> d56 r56)
   (progn 
    (setq v5x (+ v5x (* a5x t)))  (setq v5y (+ v5y (* a5y t)))  (setq v5z (+ v5z (* a5z t)))
    (setq v6x (+ v6x (* a6x t)))  (setq v6y (+ v6y (* a6y t)))  (setq v6z (+ v6z (* a6z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v5i (list v5x v5y v5z)) ;velocita 5 prima dello scontro
     (setq v6i (list v6x v6y v6z)) ;velocita 6 prima dello scontro
     (setq v5i* (trans v5i 0 (list dx56 dy56 dz56)))
     (setq v6i* (trans v6i 0 (list dx56 dy56 dz56)))
     (setq v5i*x (car v5i*) v5i*y (cadr v5i*) v5i*z (caddr v5i*))
     (setq v6i*x (car v6i*) v6i*y (cadr v6i*) v6i*z (caddr v6i*))
     (setq v5f*z (* kur (/ (+ (* (- m5 m6) v5i*z) (* 2 m6 v6i*z)) (+ m5 m6))))
     (setq v6f*z (* kur (/ (+ (* (- m6 m5) v6i*z) (* 2 m5 v5i*z)) (+ m5 m6))))
     (setq v5f* (list v5i*x v5i*y v5f*z))
     (setq v6f* (list v6i*x v6i*y v6f*z))
     (setq v5f (trans v5f* (list dx56 dy56 dz56) 0))
     (setq v6f (trans v6f* (list dx56 dy56 dz56) 0))
     (setq v5x (car v5f) v5y (cadr v5f) v5z (caddr v5f))
     (setq v6x (car v6f) v6y (cadr v6f) v6z (caddr v6f))
    )
   )
  )
  (if (> d17 r17)
   (progn 
    (setq v1x (+ v1x (* a1x t)))  (setq v1y (+ v1y (* a1y t)))  (setq v1z (+ v1z (* a1z t)))
    (setq v7x (+ v7x (* a7x t)))  (setq v7y (+ v7y (* a7y t)))  (setq v7z (+ v7z (* a7z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v1i (list v1x v1y v1z)) ;velocita 1 prima dello scontro
     (setq v7i (list v7x v7y v7z)) ;velocita 7 prima dello scontro
     (setq v1i* (trans v1i 0 (list dx17 dy17 dz17)))
     (setq v7i* (trans v7i 0 (list dx17 dy17 dz17)))
     (setq v1i*x (car v1i*) v1i*y (cadr v1i*) v1i*z (caddr v1i*))
     (setq v7i*x (car v7i*) v7i*y (cadr v7i*) v7i*z (caddr v7i*))
     (setq v1f*z (* kur (/ (+ (* (- m1 m7) v1i*z) (* 2 m7 v7i*z)) (+ m1 m7))))
     (setq v7f*z (* kur (/ (+ (* (- m7 m1) v7i*z) (* 2 m1 v1i*z)) (+ m1 m7))))
     (setq v1f* (list v1i*x v1i*y v1f*z))
     (setq v7f* (list v7i*x v7i*y v7f*z))
     (setq v1f (trans v1f* (list dx17 dy17 dz17) 0))
     (setq v7f (trans v7f* (list dx17 dy17 dz17) 0))
     (setq v1x (car v1f) v1y (cadr v1f) v1z (caddr v1f))
     (setq v7x (car v7f) v7y (cadr v7f) v7z (caddr v7f))
    )
   )
  )
  (if (> d27 r27)
   (progn 
    (setq v2x (+ v2x (* a2x t)))  (setq v2y (+ v2y (* a2y t)))  (setq v2z (+ v2z (* a2z t)))
    (setq v7x (+ v7x (* a7x t)))  (setq v7y (+ v7y (* a7y t)))  (setq v7z (+ v7z (* a7z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v2i (list v2x v2y v2z)) ;velocita 2 prima dello scontro
     (setq v7i (list v7x v7y v7z)) ;velocita 7 prima dello scontro
     (setq v2i* (trans v2i 0 (list dx27 dy27 dz27)))
     (setq v7i* (trans v7i 0 (list dx27 dy27 dz27)))
     (setq v2i*x (car v2i*) v2i*y (cadr v2i*) v2i*z (caddr v2i*))
     (setq v7i*x (car v7i*) v7i*y (cadr v7i*) v7i*z (caddr v7i*))
     (setq v2f*z (* kur (/ (+ (* (- m2 m7) v2i*z) (* 2 m7 v7i*z)) (+ m2 m7))))
     (setq v7f*z (* kur (/ (+ (* (- m7 m2) v7i*z) (* 2 m2 v2i*z)) (+ m2 m7))))
     (setq v2f* (list v2i*x v2i*y v2f*z))
     (setq v7f* (list v7i*x v7i*y v7f*z))
     (setq v2f (trans v2f* (list dx27 dy27 dz27) 0))
     (setq v7f (trans v7f* (list dx27 dy27 dz27) 0))
     (setq v2x (car v2f) v2y (cadr v2f) v2z (caddr v2f))
     (setq v7x (car v7f) v7y (cadr v7f) v7z (caddr v7f))
    )
   )
  )
  (if (> d37 r37)
   (progn 
    (setq v3x (+ v3x (* a3x t)))  (setq v3y (+ v3y (* a3y t)))  (setq v3z (+ v3z (* a3z t)))
    (setq v7x (+ v7x (* a7x t)))  (setq v7y (+ v7y (* a7y t)))  (setq v7z (+ v7z (* a7z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v3i (list v3x v3y v3z)) ;velocita 3 prima dello scontro
     (setq v7i (list v7x v7y v7z)) ;velocita 7 prima dello scontro
     (setq v3i* (trans v3i 0 (list dx37 dy37 dz37)))
     (setq v7i* (trans v7i 0 (list dx37 dy37 dz37)))
     (setq v3i*x (car v3i*) v3i*y (cadr v3i*) v3i*z (caddr v3i*))
     (setq v7i*x (car v7i*) v7i*y (cadr v7i*) v7i*z (caddr v7i*))
     (setq v3f*z (* kur (/ (+ (* (- m3 m7) v3i*z) (* 2 m7 v7i*z)) (+ m3 m7))))
     (setq v7f*z (* kur (/ (+ (* (- m7 m3) v7i*z) (* 2 m3 v3i*z)) (+ m3 m7))))
     (setq v3f* (list v3i*x v3i*y v3f*z))
     (setq v7f* (list v7i*x v7i*y v7f*z))
     (setq v3f (trans v3f* (list dx37 dy37 dz37) 0))
     (setq v7f (trans v7f* (list dx37 dy37 dz37) 0))
     (setq v3x (car v3f) v3y (cadr v3f) v3z (caddr v3f))
     (setq v7x (car v7f) v7y (cadr v7f) v7z (caddr v7f))
    )
   )
  )
  (if (> d47 r47)
   (progn 
    (setq v4x (+ v4x (* a4x t)))  (setq v4y (+ v4y (* a4y t)))  (setq v4z (+ v4z (* a4z t)))
    (setq v7x (+ v7x (* a7x t)))  (setq v7y (+ v7y (* a7y t)))  (setq v7z (+ v7z (* a7z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v4i (list v4x v4y v4z)) ;velocita 4 prima dello scontro
     (setq v7i (list v7x v7y v7z)) ;velocita 7 prima dello scontro
     (setq v4i* (trans v4i 0 (list dx47 dy47 dz47)))
     (setq v7i* (trans v7i 0 (list dx47 dy47 dz47)))
     (setq v4i*x (car v4i*) v4i*y (cadr v4i*) v4i*z (caddr v4i*))
     (setq v7i*x (car v7i*) v7i*y (cadr v7i*) v7i*z (caddr v7i*))
     (setq v4f*z (* kur (/ (+ (* (- m4 m7) v4i*z) (* 2 m7 v7i*z)) (+ m4 m7))))
     (setq v7f*z (* kur (/ (+ (* (- m7 m4) v7i*z) (* 2 m4 v4i*z)) (+ m4 m7))))
     (setq v4f* (list v4i*x v4i*y v4f*z))
     (setq v7f* (list v7i*x v7i*y v7f*z))
     (setq v4f (trans v4f* (list dx47 dy47 dz47) 0))
     (setq v7f (trans v7f* (list dx47 dy47 dz47) 0))
     (setq v4x (car v4f) v4y (cadr v4f) v4z (caddr v4f))
     (setq v7x (car v7f) v7y (cadr v7f) v7z (caddr v7f))
    )
   )
  )
  (if (> d57 r57)
   (progn 
    (setq v5x (+ v5x (* a5x t)))  (setq v5y (+ v5y (* a5y t)))  (setq v5z (+ v5z (* a5z t)))
    (setq v7x (+ v7x (* a7x t)))  (setq v7y (+ v7y (* a7y t)))  (setq v7z (+ v7z (* a7z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v5i (list v5x v5y v5z)) ;velocita 5 prima dello scontro
     (setq v7i (list v7x v7y v7z)) ;velocita 7 prima dello scontro
     (setq v5i* (trans v5i 0 (list dx57 dy57 dz57)))
     (setq v7i* (trans v7i 0 (list dx57 dy57 dz57)))
     (setq v5i*x (car v5i*) v5i*y (cadr v5i*) v5i*z (caddr v5i*))
     (setq v7i*x (car v7i*) v7i*y (cadr v7i*) v7i*z (caddr v7i*))
     (setq v5f*z (* kur (/ (+ (* (- m5 m7) v5i*z) (* 2 m7 v7i*z)) (+ m5 m7))))
     (setq v7f*z (* kur (/ (+ (* (- m7 m5) v7i*z) (* 2 m5 v5i*z)) (+ m5 m7))))
     (setq v5f* (list v5i*x v5i*y v5f*z))
     (setq v7f* (list v7i*x v7i*y v7f*z))
     (setq v5f (trans v5f* (list dx57 dy57 dz57) 0))
     (setq v7f (trans v7f* (list dx57 dy57 dz57) 0))
     (setq v5x (car v5f) v5y (cadr v5f) v5z (caddr v5f))
     (setq v7x (car v7f) v7y (cadr v7f) v7z (caddr v7f))
    )
   )
  )
  (if (> d67 r67)
   (progn 
    (setq v6x (+ v6x (* a6x t)))  (setq v6y (+ v6y (* a6y t)))  (setq v6z (+ v6z (* a6z t)))
    (setq v7x (+ v7x (* a7x t)))  (setq v7y (+ v7y (* a7y t)))  (setq v7z (+ v7z (* a7z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v6i (list v6x v6y v6z)) ;velocita 6 prima dello scontro
     (setq v7i (list v7x v7y v7z)) ;velocita 7 prima dello scontro
     (setq v6i* (trans v6i 0 (list dx67 dy67 dz67)))
     (setq v7i* (trans v7i 0 (list dx67 dy67 dz67)))
     (setq v6i*x (car v6i*) v6i*y (cadr v6i*) v6i*z (caddr v6i*))
     (setq v7i*x (car v7i*) v7i*y (cadr v7i*) v7i*z (caddr v7i*))
     (setq v6f*z (* kur (/ (+ (* (- m6 m7) v6i*z) (* 2 m7 v7i*z)) (+ m6 m7))))
     (setq v7f*z (* kur (/ (+ (* (- m7 m6) v7i*z) (* 2 m6 v6i*z)) (+ m6 m7))))
     (setq v6f* (list v6i*x v6i*y v6f*z))
     (setq v7f* (list v7i*x v7i*y v7f*z))
     (setq v6f (trans v6f* (list dx67 dy67 dz67) 0))
     (setq v7f (trans v7f* (list dx67 dy67 dz67) 0))
     (setq v6x (car v6f) v6y (cadr v6f) v6z (caddr v6f))
     (setq v7x (car v7f) v7y (cadr v7f) v7z (caddr v7f))
    )
   )
  )
  (if (> d18 r18)
   (progn 
    (setq v1x (+ v1x (* a1x t)))  (setq v1y (+ v1y (* a1y t)))  (setq v1z (+ v1z (* a1z t)))
    (setq v8x (+ v8x (* a8x t)))  (setq v8y (+ v8y (* a8y t)))  (setq v8z (+ v8z (* a8z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v1i (list v1x v1y v1z)) ;velocita 1 prima dello scontro
     (setq v8i (list v8x v8y v8z)) ;velocita 8 prima dello scontro
     (setq v1i* (trans v1i 0 (list dx18 dy18 dz18)))
     (setq v8i* (trans v8i 0 (list dx18 dy18 dz18)))
     (setq v1i*x (car v1i*) v1i*y (cadr v1i*) v1i*z (caddr v1i*))
     (setq v8i*x (car v8i*) v8i*y (cadr v8i*) v8i*z (caddr v8i*))
     (setq v1f*z (* kur (/ (+ (* (- m1 m8) v1i*z) (* 2 m8 v8i*z)) (+ m1 m8))))
     (setq v8f*z (* kur (/ (+ (* (- m8 m1) v8i*z) (* 2 m1 v1i*z)) (+ m1 m8))))
     (setq v1f* (list v1i*x v1i*y v1f*z))
     (setq v8f* (list v8i*x v8i*y v8f*z))
     (setq v1f (trans v1f* (list dx18 dy18 dz18) 0))
     (setq v8f (trans v8f* (list dx18 dy18 dz18) 0))
     (setq v1x (car v1f) v1y (cadr v1f) v1z (caddr v1f))
     (setq v8x (car v8f) v8y (cadr v8f) v8z (caddr v8f))
    )
   )
  )
  (if (> d28 r28)
   (progn 
    (setq v2x (+ v2x (* a2x t)))  (setq v2y (+ v2y (* a2y t)))  (setq v2z (+ v2z (* a2z t)))
    (setq v8x (+ v8x (* a8x t)))  (setq v8y (+ v8y (* a8y t)))  (setq v8z (+ v8z (* a8z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v2i (list v2x v2y v2z)) ;velocita 2 prima dello scontro
     (setq v8i (list v8x v8y v8z)) ;velocita 8 prima dello scontro
     (setq v2i* (trans v2i 0 (list dx28 dy28 dz28)))
     (setq v8i* (trans v8i 0 (list dx28 dy28 dz28)))
     (setq v2i*x (car v2i*) v2i*y (cadr v2i*) v2i*z (caddr v2i*))
     (setq v8i*x (car v8i*) v8i*y (cadr v8i*) v8i*z (caddr v8i*))
     (setq v2f*z (* kur (/ (+ (* (- m2 m8) v2i*z) (* 2 m8 v8i*z)) (+ m2 m8))))
     (setq v8f*z (* kur (/ (+ (* (- m8 m2) v8i*z) (* 2 m2 v2i*z)) (+ m2 m8))))
     (setq v2f* (list v2i*x v2i*y v2f*z))
     (setq v8f* (list v8i*x v8i*y v8f*z))
     (setq v2f (trans v2f* (list dx28 dy28 dz28) 0))
     (setq v8f (trans v8f* (list dx28 dy28 dz28) 0))
     (setq v2x (car v2f) v2y (cadr v2f) v2z (caddr v2f))
     (setq v8x (car v8f) v8y (cadr v8f) v8z (caddr v8f))
    )
   )
  )
  (if (> d38 r38)
   (progn 
    (setq v3x (+ v3x (* a3x t)))  (setq v3y (+ v3y (* a3y t)))  (setq v3z (+ v3z (* a3z t)))
    (setq v8x (+ v8x (* a8x t)))  (setq v8y (+ v8y (* a8y t)))  (setq v8z (+ v8z (* a8z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v3i (list v3x v3y v3z)) ;velocita 3 prima dello scontro
     (setq v8i (list v8x v8y v8z)) ;velocita 8 prima dello scontro
     (setq v3i* (trans v3i 0 (list dx38 dy38 dz38)))
     (setq v8i* (trans v8i 0 (list dx38 dy38 dz38)))
     (setq v3i*x (car v3i*) v3i*y (cadr v3i*) v3i*z (caddr v3i*))
     (setq v8i*x (car v8i*) v8i*y (cadr v8i*) v8i*z (caddr v8i*))
     (setq v3f*z (* kur (/ (+ (* (- m3 m8) v3i*z) (* 2 m8 v8i*z)) (+ m3 m8))))
     (setq v8f*z (* kur (/ (+ (* (- m8 m3) v8i*z) (* 2 m3 v3i*z)) (+ m3 m8))))
     (setq v3f* (list v3i*x v3i*y v3f*z))
     (setq v8f* (list v8i*x v8i*y v8f*z))
     (setq v3f (trans v3f* (list dx38 dy38 dz38) 0))
     (setq v8f (trans v8f* (list dx38 dy38 dz38) 0))
     (setq v3x (car v3f) v3y (cadr v3f) v3z (caddr v3f))
     (setq v8x (car v8f) v8y (cadr v8f) v8z (caddr v8f))
    )
   )
  )
  (if (> d48 r48)
   (progn 
    (setq v4x (+ v4x (* a4x t)))  (setq v4y (+ v4y (* a4y t)))  (setq v4z (+ v4z (* a4z t)))
    (setq v8x (+ v8x (* a8x t)))  (setq v8y (+ v8y (* a8y t)))  (setq v8z (+ v8z (* a8z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v4i (list v4x v4y v4z)) ;velocita 4 prima dello scontro
     (setq v8i (list v8x v8y v8z)) ;velocita 8 prima dello scontro
     (setq v4i* (trans v4i 0 (list dx48 dy48 dz48)))
     (setq v8i* (trans v8i 0 (list dx48 dy48 dz48)))
     (setq v4i*x (car v4i*) v4i*y (cadr v4i*) v4i*z (caddr v4i*))
     (setq v8i*x (car v8i*) v8i*y (cadr v8i*) v8i*z (caddr v8i*))
     (setq v4f*z (* kur (/ (+ (* (- m4 m8) v4i*z) (* 2 m8 v8i*z)) (+ m4 m8))))
     (setq v8f*z (* kur (/ (+ (* (- m8 m4) v8i*z) (* 2 m4 v4i*z)) (+ m4 m8))))
     (setq v4f* (list v4i*x v4i*y v4f*z))
     (setq v8f* (list v8i*x v8i*y v8f*z))
     (setq v4f (trans v4f* (list dx48 dy48 dz48) 0))
     (setq v8f (trans v8f* (list dx48 dy48 dz48) 0))
     (setq v4x (car v4f) v4y (cadr v4f) v4z (caddr v4f))
     (setq v8x (car v8f) v8y (cadr v8f) v8z (caddr v8f))
    )
   )
  )
  (if (> d58 r58)
   (progn 
    (setq v5x (+ v5x (* a5x t)))  (setq v5y (+ v5y (* a5y t)))  (setq v5z (+ v5z (* a5z t)))
    (setq v8x (+ v8x (* a8x t)))  (setq v8y (+ v8y (* a8y t)))  (setq v8z (+ v8z (* a8z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v5i (list v5x v5y v5z)) ;velocita 5 prima dello scontro
     (setq v8i (list v8x v8y v8z)) ;velocita 8 prima dello scontro
     (setq v5i* (trans v5i 0 (list dx58 dy58 dz58)))
     (setq v8i* (trans v8i 0 (list dx58 dy58 dz58)))
     (setq v5i*x (car v5i*) v5i*y (cadr v5i*) v5i*z (caddr v5i*))
     (setq v8i*x (car v8i*) v8i*y (cadr v8i*) v8i*z (caddr v8i*))
     (setq v5f*z (* kur (/ (+ (* (- m5 m8) v5i*z) (* 2 m8 v8i*z)) (+ m5 m8))))
     (setq v8f*z (* kur (/ (+ (* (- m8 m5) v8i*z) (* 2 m5 v5i*z)) (+ m5 m8))))
     (setq v5f* (list v5i*x v5i*y v5f*z))
     (setq v8f* (list v8i*x v8i*y v8f*z))
     (setq v5f (trans v5f* (list dx58 dy58 dz58) 0))
     (setq v8f (trans v8f* (list dx58 dy58 dz58) 0))
     (setq v5x (car v5f) v5y (cadr v5f) v5z (caddr v5f))
     (setq v8x (car v8f) v8y (cadr v8f) v8z (caddr v8f))
    )
   )
  )
  (if (> d68 r68)
   (progn 
    (setq v6x (+ v6x (* a6x t)))  (setq v6y (+ v6y (* a6y t)))  (setq v6z (+ v6z (* a6z t)))
    (setq v8x (+ v8x (* a8x t)))  (setq v8y (+ v8y (* a8y t)))  (setq v8z (+ v8z (* a8z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v6i (list v6x v6y v6z)) ;velocita 6 prima dello scontro
     (setq v8i (list v8x v8y v8z)) ;velocita 8 prima dello scontro
     (setq v6i* (trans v6i 0 (list dx68 dy68 dz68)))
     (setq v8i* (trans v8i 0 (list dx68 dy68 dz68)))
     (setq v6i*x (car v6i*) v6i*y (cadr v6i*) v6i*z (caddr v6i*))
     (setq v8i*x (car v8i*) v8i*y (cadr v8i*) v8i*z (caddr v8i*))
     (setq v6f*z (* kur (/ (+ (* (- m6 m8) v6i*z) (* 2 m8 v8i*z)) (+ m6 m8))))
     (setq v8f*z (* kur (/ (+ (* (- m8 m6) v8i*z) (* 2 m6 v6i*z)) (+ m6 m8))))
     (setq v6f* (list v6i*x v6i*y v6f*z))
     (setq v8f* (list v8i*x v8i*y v8f*z))
     (setq v6f (trans v6f* (list dx68 dy68 dz68) 0))
     (setq v8f (trans v8f* (list dx68 dy68 dz68) 0))
     (setq v6x (car v6f) v6y (cadr v6f) v6z (caddr v6f))
     (setq v8x (car v8f) v8y (cadr v8f) v8z (caddr v8f))
    )
   )
  )
  (if (> d78 r78)
   (progn 
    (setq v7x (+ v7x (* a7x t)))  (setq v7y (+ v7y (* a7y t)))  (setq v7z (+ v7z (* a7z t)))
    (setq v8x (+ v8x (* a8x t)))  (setq v8y (+ v8y (* a8y t)))  (setq v8z (+ v8z (* a8z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v7i (list v7x v7y v7z)) ;velocita 7 prima dello scontro
     (setq v8i (list v8x v8y v8z)) ;velocita 8 prima dello scontro
     (setq v7i* (trans v7i 0 (list dx78 dy78 dz78)))
     (setq v8i* (trans v8i 0 (list dx78 dy78 dz78)))
     (setq v7i*x (car v7i*) v7i*y (cadr v7i*) v7i*z (caddr v7i*))
     (setq v8i*x (car v8i*) v8i*y (cadr v8i*) v8i*z (caddr v8i*))
     (setq v7f*z (* kur (/ (+ (* (- m7 m8) v7i*z) (* 2 m8 v8i*z)) (+ m7 m8))))
     (setq v8f*z (* kur (/ (+ (* (- m8 m7) v8i*z) (* 2 m7 v7i*z)) (+ m7 m8))))
     (setq v7f* (list v7i*x v7i*y v7f*z))
     (setq v8f* (list v8i*x v8i*y v8f*z))
     (setq v7f (trans v7f* (list dx78 dy78 dz78) 0))
     (setq v8f (trans v8f* (list dx78 dy78 dz78) 0))
     (setq v7x (car v7f) v7y (cadr v7f) v7z (caddr v7f))
     (setq v8x (car v8f) v8y (cadr v8f) v8z (caddr v8f))
    )
   )
  )
  (if (> d19 r19)
   (progn 
    (setq v1x (+ v1x (* a1x t)))  (setq v1y (+ v1y (* a1y t)))  (setq v1z (+ v1z (* a1z t)))
    (setq v9x (+ v9x (* a9x t)))  (setq v9y (+ v9y (* a9y t)))  (setq v9z (+ v9z (* a9z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v1i (list v1x v1y v1z)) ;velocita 1 prima dello scontro
     (setq v9i (list v9x v9y v9z)) ;velocita 9 prima dello scontro
     (setq v1i* (trans v1i 0 (list dx19 dy19 dz19)))
     (setq v9i* (trans v9i 0 (list dx19 dy19 dz19)))
     (setq v1i*x (car v1i*) v1i*y (cadr v1i*) v1i*z (caddr v1i*))
     (setq v9i*x (car v9i*) v9i*y (cadr v9i*) v9i*z (caddr v9i*))
     (setq v1f*z (* kur (/ (+ (* (- m1 m9) v1i*z) (* 2 m9 v9i*z)) (+ m1 m9))))
     (setq v9f*z (* kur (/ (+ (* (- m9 m1) v9i*z) (* 2 m1 v1i*z)) (+ m1 m9))))
     (setq v1f* (list v1i*x v1i*y v1f*z))
     (setq v9f* (list v9i*x v9i*y v9f*z))
     (setq v1f (trans v1f* (list dx19 dy19 dz19) 0))
     (setq v9f (trans v9f* (list dx19 dy19 dz19) 0))
     (setq v1x (car v1f) v1y (cadr v1f) v1z (caddr v1f))
     (setq v9x (car v9f) v9y (cadr v9f) v9z (caddr v9f))
    )
   )
  )
  (if (> d29 r29)
   (progn 
    (setq v2x (+ v2x (* a2x t)))  (setq v2y (+ v2y (* a2y t)))  (setq v2z (+ v2z (* a2z t)))
    (setq v9x (+ v9x (* a9x t)))  (setq v9y (+ v9y (* a9y t)))  (setq v9z (+ v9z (* a9z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v2i (list v2x v2y v2z)) ;velocita 2 prima dello scontro
     (setq v9i (list v9x v9y v9z)) ;velocita 9 prima dello scontro
     (setq v2i* (trans v2i 0 (list dx29 dy29 dz29)))
     (setq v9i* (trans v9i 0 (list dx29 dy29 dz29)))
     (setq v2i*x (car v2i*) v2i*y (cadr v2i*) v2i*z (caddr v2i*))
     (setq v9i*x (car v9i*) v9i*y (cadr v9i*) v9i*z (caddr v9i*))
     (setq v2f*z (* kur (/ (+ (* (- m2 m9) v2i*z) (* 2 m9 v9i*z)) (+ m2 m9))))
     (setq v9f*z (* kur (/ (+ (* (- m9 m2) v9i*z) (* 2 m2 v2i*z)) (+ m2 m9))))
     (setq v2f* (list v2i*x v2i*y v2f*z))
     (setq v9f* (list v9i*x v9i*y v9f*z))
     (setq v2f (trans v2f* (list dx29 dy29 dz29) 0))
     (setq v9f (trans v9f* (list dx29 dy29 dz29) 0))
     (setq v2x (car v2f) v2y (cadr v2f) v2z (caddr v2f))
     (setq v9x (car v9f) v9y (cadr v9f) v9z (caddr v9f))
    )
   )
  )
  (if (> d39 r39)
   (progn 
    (setq v3x (+ v3x (* a3x t)))  (setq v3y (+ v3y (* a3y t)))  (setq v3z (+ v3z (* a3z t)))
    (setq v9x (+ v9x (* a9x t)))  (setq v9y (+ v9y (* a9y t)))  (setq v9z (+ v9z (* a9z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v3i (list v3x v3y v3z)) ;velocita 3 prima dello scontro
     (setq v9i (list v9x v9y v9z)) ;velocita 9 prima dello scontro
     (setq v3i* (trans v3i 0 (list dx39 dy39 dz39)))
     (setq v9i* (trans v9i 0 (list dx39 dy39 dz39)))
     (setq v3i*x (car v3i*) v3i*y (cadr v3i*) v3i*z (caddr v3i*))
     (setq v9i*x (car v9i*) v9i*y (cadr v9i*) v9i*z (caddr v9i*))
     (setq v3f*z (* kur (/ (+ (* (- m3 m9) v3i*z) (* 2 m9 v9i*z)) (+ m3 m9))))
     (setq v9f*z (* kur (/ (+ (* (- m9 m3) v9i*z) (* 2 m3 v3i*z)) (+ m3 m9))))
     (setq v3f* (list v3i*x v3i*y v3f*z))
     (setq v9f* (list v9i*x v9i*y v9f*z))
     (setq v3f (trans v3f* (list dx39 dy39 dz39) 0))
     (setq v9f (trans v9f* (list dx39 dy39 dz39) 0))
     (setq v3x (car v3f) v3y (cadr v3f) v3z (caddr v3f))
     (setq v9x (car v9f) v9y (cadr v9f) v9z (caddr v9f))
    )
   )
  )
  (if (> d49 r49)
   (progn 
    (setq v4x (+ v4x (* a4x t)))  (setq v4y (+ v4y (* a4y t)))  (setq v4z (+ v4z (* a4z t)))
    (setq v9x (+ v9x (* a9x t)))  (setq v9y (+ v9y (* a9y t)))  (setq v9z (+ v9z (* a9z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v4i (list v4x v4y v4z)) ;velocita 4 prima dello scontro
     (setq v9i (list v9x v9y v9z)) ;velocita 9 prima dello scontro
     (setq v4i* (trans v4i 0 (list dx49 dy49 dz49)))
     (setq v9i* (trans v9i 0 (list dx49 dy49 dz49)))
     (setq v4i*x (car v4i*) v4i*y (cadr v4i*) v4i*z (caddr v4i*))
     (setq v9i*x (car v9i*) v9i*y (cadr v9i*) v9i*z (caddr v9i*))
     (setq v4f*z (* kur (/ (+ (* (- m4 m9) v4i*z) (* 2 m9 v9i*z)) (+ m4 m9))))
     (setq v9f*z (* kur (/ (+ (* (- m9 m4) v9i*z) (* 2 m4 v4i*z)) (+ m4 m9))))
     (setq v4f* (list v4i*x v4i*y v4f*z))
     (setq v9f* (list v9i*x v9i*y v9f*z))
     (setq v4f (trans v4f* (list dx49 dy49 dz49) 0))
     (setq v9f (trans v9f* (list dx49 dy49 dz49) 0))
     (setq v4x (car v4f) v4y (cadr v4f) v4z (caddr v4f))
     (setq v9x (car v9f) v9y (cadr v9f) v9z (caddr v9f))
    )
   )
  )
  (if (> d59 r59)
   (progn 
    (setq v5x (+ v5x (* a5x t)))  (setq v5y (+ v5y (* a5y t)))  (setq v5z (+ v5z (* a5z t)))
    (setq v9x (+ v9x (* a9x t)))  (setq v9y (+ v9y (* a9y t)))  (setq v9z (+ v9z (* a9z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v5i (list v5x v5y v5z)) ;velocita 5 prima dello scontro
     (setq v9i (list v9x v9y v9z)) ;velocita 9 prima dello scontro
     (setq v5i* (trans v5i 0 (list dx59 dy59 dz59)))
     (setq v9i* (trans v9i 0 (list dx59 dy59 dz59)))
     (setq v5i*x (car v5i*) v5i*y (cadr v5i*) v5i*z (caddr v5i*))
     (setq v9i*x (car v9i*) v9i*y (cadr v9i*) v9i*z (caddr v9i*))
     (setq v5f*z (* kur (/ (+ (* (- m5 m9) v5i*z) (* 2 m9 v9i*z)) (+ m5 m9))))
     (setq v9f*z (* kur (/ (+ (* (- m9 m5) v9i*z) (* 2 m5 v5i*z)) (+ m5 m9))))
     (setq v5f* (list v5i*x v5i*y v5f*z))
     (setq v9f* (list v9i*x v9i*y v9f*z))
     (setq v5f (trans v5f* (list dx59 dy59 dz59) 0))
     (setq v9f (trans v9f* (list dx59 dy59 dz59) 0))
     (setq v5x (car v5f) v5y (cadr v5f) v5z (caddr v5f))
     (setq v9x (car v9f) v9y (cadr v9f) v9z (caddr v9f))
    )
   )
  )
  (if (> d69 r69)
   (progn 
    (setq v6x (+ v6x (* a6x t)))  (setq v6y (+ v6y (* a6y t)))  (setq v6z (+ v6z (* a6z t)))
    (setq v9x (+ v9x (* a9x t)))  (setq v9y (+ v9y (* a9y t)))  (setq v9z (+ v9z (* a9z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v6i (list v6x v6y v6z)) ;velocita 6 prima dello scontro
     (setq v9i (list v9x v9y v9z)) ;velocita 9 prima dello scontro
     (setq v6i* (trans v6i 0 (list dx69 dy69 dz69)))
     (setq v9i* (trans v9i 0 (list dx69 dy69 dz69)))
     (setq v6i*x (car v6i*) v6i*y (cadr v6i*) v6i*z (caddr v6i*))
     (setq v9i*x (car v9i*) v9i*y (cadr v9i*) v9i*z (caddr v9i*))
     (setq v6f*z (* kur (/ (+ (* (- m6 m9) v6i*z) (* 2 m9 v9i*z)) (+ m6 m9))))
     (setq v9f*z (* kur (/ (+ (* (- m9 m6) v9i*z) (* 2 m6 v6i*z)) (+ m6 m9))))
     (setq v6f* (list v6i*x v6i*y v6f*z))
     (setq v9f* (list v9i*x v9i*y v9f*z))
     (setq v6f (trans v6f* (list dx69 dy69 dz69) 0))
     (setq v9f (trans v9f* (list dx69 dy69 dz69) 0))
     (setq v6x (car v6f) v6y (cadr v6f) v6z (caddr v6f))
     (setq v9x (car v9f) v9y (cadr v9f) v9z (caddr v9f))
    )
   )
  )
  (if (> d79 r79)
   (progn 
    (setq v7x (+ v7x (* a7x t)))  (setq v7y (+ v7y (* a7y t)))  (setq v7z (+ v7z (* a7z t)))
    (setq v9x (+ v9x (* a9x t)))  (setq v9y (+ v9y (* a9y t)))  (setq v9z (+ v9z (* a9z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v7i (list v7x v7y v7z)) ;velocita 7 prima dello scontro
     (setq v9i (list v9x v9y v9z)) ;velocita 9 prima dello scontro
     (setq v7i* (trans v7i 0 (list dx79 dy79 dz79)))
     (setq v9i* (trans v9i 0 (list dx79 dy79 dz79)))
     (setq v7i*x (car v7i*) v7i*y (cadr v7i*) v7i*z (caddr v7i*))
     (setq v9i*x (car v9i*) v9i*y (cadr v9i*) v9i*z (caddr v9i*))
     (setq v7f*z (* kur (/ (+ (* (- m7 m9) v7i*z) (* 2 m9 v9i*z)) (+ m7 m9))))
     (setq v9f*z (* kur (/ (+ (* (- m9 m7) v9i*z) (* 2 m7 v7i*z)) (+ m7 m9))))
     (setq v7f* (list v7i*x v7i*y v7f*z))
     (setq v9f* (list v9i*x v9i*y v9f*z))
     (setq v7f (trans v7f* (list dx79 dy79 dz79) 0))
     (setq v9f (trans v9f* (list dx79 dy79 dz79) 0))
     (setq v7x (car v7f) v7y (cadr v7f) v7z (caddr v7f))
     (setq v9x (car v9f) v9y (cadr v9f) v9z (caddr v9f))
    )
   )
  )
  (if (> d89 r89)
   (progn 
    (setq v8x (+ v8x (* a8x t)))  (setq v8y (+ v8y (* a8y t)))  (setq v8z (+ v8z (* a8z t)))
    (setq v9x (+ v9x (* a9x t)))  (setq v9y (+ v9y (* a9y t)))  (setq v9z (+ v9z (* a9z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v8i (list v8x v8y v8z)) ;velocita 8 prima dello scontro
     (setq v9i (list v9x v9y v9z)) ;velocita 9 prima dello scontro
     (setq v8i* (trans v8i 0 (list dx89 dy89 dz89)))
     (setq v9i* (trans v9i 0 (list dx89 dy89 dz89)))
     (setq v8i*x (car v8i*) v8i*y (cadr v8i*) v8i*z (caddr v8i*))
     (setq v9i*x (car v9i*) v9i*y (cadr v9i*) v9i*z (caddr v9i*))
     (setq v8f*z (* kur (/ (+ (* (- m8 m9) v8i*z) (* 2 m9 v9i*z)) (+ m8 m9))))
     (setq v9f*z (* kur (/ (+ (* (- m9 m8) v9i*z) (* 2 m8 v8i*z)) (+ m8 m9))))
     (setq v8f* (list v8i*x v8i*y v8f*z))
     (setq v9f* (list v9i*x v9i*y v9f*z))
     (setq v8f (trans v8f* (list dx89 dy89 dz89) 0))
     (setq v9f (trans v9f* (list dx89 dy89 dz89) 0))
     (setq v8x (car v8f) v8y (cadr v8f) v8z (caddr v8f))
     (setq v9x (car v9f) v9y (cadr v9f) v9z (caddr v9f))
    )
   )
  )
  (if (> d10 r10)
   (progn 
    (setq v1x (+ v1x (* a1x t)))  (setq v1y (+ v1y (* a1y t)))  (setq v1z (+ v1z (* a1z t)))
    (setq v0x (+ v0x (* a0x t)))  (setq v0y (+ v0y (* a0y t)))  (setq v0z (+ v0z (* a0z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v1i (list v1x v1y v1z)) ;velocita 1 prima dello scontro
     (setq v0i (list v0x v0y v0z)) ;velocita 0 prima dello scontro
     (setq v1i* (trans v1i 0 (list dx10 dy10 dz10)))
     (setq v0i* (trans v0i 0 (list dx10 dy10 dz10)))
     (setq v1i*x (car v1i*) v1i*y (cadr v1i*) v1i*z (caddr v1i*))
     (setq v0i*x (car v0i*) v0i*y (cadr v0i*) v0i*z (caddr v0i*))
     (setq v1f*z (* kur (/ (+ (* (- m1 m0) v1i*z) (* 2 m0 v0i*z)) (+ m1 m0))))
     (setq v0f*z (* kur (/ (+ (* (- m0 m1) v0i*z) (* 2 m1 v1i*z)) (+ m1 m0))))
     (setq v1f* (list v1i*x v1i*y v1f*z))
     (setq v0f* (list v0i*x v0i*y v0f*z))
     (setq v1f (trans v1f* (list dx10 dy10 dz10) 0))
     (setq v0f (trans v0f* (list dx10 dy10 dz10) 0))
     (setq v1x (car v1f) v1y (cadr v1f) v1z (caddr v1f))
     (setq v0x (car v0f) v0y (cadr v0f) v0z (caddr v0f))
    )
   )
  )
  (if (> d20 r20)
   (progn 
    (setq v2x (+ v2x (* a2x t)))  (setq v2y (+ v2y (* a2y t)))  (setq v2z (+ v2z (* a2z t)))
    (setq v0x (+ v0x (* a0x t)))  (setq v0y (+ v0y (* a0y t)))  (setq v0z (+ v0z (* a0z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v2i (list v2x v2y v2z)) ;velocita 2 prima dello scontro
     (setq v0i (list v0x v0y v0z)) ;velocita 0 prima dello scontro
     (setq v2i* (trans v2i 0 (list dx20 dy20 dz20)))
     (setq v0i* (trans v0i 0 (list dx20 dy20 dz20)))
     (setq v2i*x (car v2i*) v2i*y (cadr v2i*) v2i*z (caddr v2i*))
     (setq v0i*x (car v0i*) v0i*y (cadr v0i*) v0i*z (caddr v0i*))
     (setq v2f*z (* kur (/ (+ (* (- m2 m0) v2i*z) (* 2 m0 v0i*z)) (+ m2 m0))))
     (setq v0f*z (* kur (/ (+ (* (- m0 m2) v0i*z) (* 2 m2 v2i*z)) (+ m2 m0))))
     (setq v2f* (list v2i*x v2i*y v2f*z))
     (setq v0f* (list v0i*x v0i*y v0f*z))
     (setq v2f (trans v2f* (list dx20 dy20 dz20) 0))
     (setq v0f (trans v0f* (list dx20 dy20 dz20) 0))
     (setq v2x (car v2f) v2y (cadr v2f) v2z (caddr v2f))
     (setq v0x (car v0f) v0y (cadr v0f) v0z (caddr v0f))
    )
   )
  )
  (if (> d30 r30)
   (progn 
    (setq v3x (+ v3x (* a3x t)))  (setq v3y (+ v3y (* a3y t)))  (setq v3z (+ v3z (* a3z t)))
    (setq v0x (+ v0x (* a0x t)))  (setq v0y (+ v0y (* a0y t)))  (setq v0z (+ v0z (* a0z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v3i (list v3x v3y v3z)) ;velocita 3 prima dello scontro
     (setq v0i (list v0x v0y v0z)) ;velocita 0 prima dello scontro
     (setq v3i* (trans v3i 0 (list dx30 dy30 dz30)))
     (setq v0i* (trans v0i 0 (list dx30 dy30 dz30)))
     (setq v3i*x (car v3i*) v3i*y (cadr v3i*) v3i*z (caddr v3i*))
     (setq v0i*x (car v0i*) v0i*y (cadr v0i*) v0i*z (caddr v0i*))
     (setq v3f*z (* kur (/ (+ (* (- m3 m0) v3i*z) (* 2 m0 v0i*z)) (+ m3 m0))))
     (setq v0f*z (* kur (/ (+ (* (- m0 m3) v0i*z) (* 2 m3 v3i*z)) (+ m3 m0))))
     (setq v3f* (list v3i*x v3i*y v3f*z))
     (setq v0f* (list v0i*x v0i*y v0f*z))
     (setq v3f (trans v3f* (list dx30 dy30 dz30) 0))
     (setq v0f (trans v0f* (list dx30 dy30 dz30) 0))
     (setq v3x (car v3f) v3y (cadr v3f) v3z (caddr v3f))
     (setq v0x (car v0f) v0y (cadr v0f) v0z (caddr v0f))
    )
   )
  )
  (if (> d40 r40)
   (progn 
    (setq v4x (+ v4x (* a4x t)))  (setq v4y (+ v4y (* a4y t)))  (setq v4z (+ v4z (* a4z t)))
    (setq v0x (+ v0x (* a0x t)))  (setq v0y (+ v0y (* a0y t)))  (setq v0z (+ v0z (* a0z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v4i (list v4x v4y v4z)) ;velocita 4 prima dello scontro
     (setq v0i (list v0x v0y v0z)) ;velocita 0 prima dello scontro
     (setq v4i* (trans v4i 0 (list dx40 dy40 dz40)))
     (setq v0i* (trans v0i 0 (list dx40 dy40 dz40)))
     (setq v4i*x (car v4i*) v4i*y (cadr v4i*) v4i*z (caddr v4i*))
     (setq v0i*x (car v0i*) v0i*y (cadr v0i*) v0i*z (caddr v0i*))
     (setq v4f*z (* kur (/ (+ (* (- m4 m0) v4i*z) (* 2 m0 v0i*z)) (+ m4 m0))))
     (setq v0f*z (* kur (/ (+ (* (- m0 m4) v0i*z) (* 2 m4 v4i*z)) (+ m4 m0))))
     (setq v4f* (list v4i*x v4i*y v4f*z))
     (setq v0f* (list v0i*x v0i*y v0f*z))
     (setq v4f (trans v4f* (list dx40 dy40 dz40) 0))
     (setq v0f (trans v0f* (list dx40 dy40 dz40) 0))
     (setq v4x (car v4f) v4y (cadr v4f) v4z (caddr v4f))
     (setq v0x (car v0f) v0y (cadr v0f) v0z (caddr v0f))
    )
   )
  )
  (if (> d50 r50)
   (progn 
    (setq v5x (+ v5x (* a5x t)))  (setq v5y (+ v5y (* a5y t)))  (setq v5z (+ v5z (* a5z t)))
    (setq v0x (+ v0x (* a0x t)))  (setq v0y (+ v0y (* a0y t)))  (setq v0z (+ v0z (* a0z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v5i (list v5x v5y v5z)) ;velocita 5 prima dello scontro
     (setq v0i (list v0x v0y v0z)) ;velocita 0 prima dello scontro
     (setq v5i* (trans v5i 0 (list dx50 dy50 dz50)))
     (setq v0i* (trans v0i 0 (list dx50 dy50 dz50)))
     (setq v5i*x (car v5i*) v5i*y (cadr v5i*) v5i*z (caddr v5i*))
     (setq v0i*x (car v0i*) v0i*y (cadr v0i*) v0i*z (caddr v0i*))
     (setq v5f*z (* kur (/ (+ (* (- m5 m0) v5i*z) (* 2 m0 v0i*z)) (+ m5 m0))))
     (setq v0f*z (* kur (/ (+ (* (- m0 m5) v0i*z) (* 2 m5 v5i*z)) (+ m5 m0))))
     (setq v5f* (list v5i*x v5i*y v5f*z))
     (setq v0f* (list v0i*x v0i*y v0f*z))
     (setq v5f (trans v5f* (list dx50 dy50 dz50) 0))
     (setq v0f (trans v0f* (list dx50 dy50 dz50) 0))
     (setq v5x (car v5f) v5y (cadr v5f) v5z (caddr v5f))
     (setq v0x (car v0f) v0y (cadr v0f) v0z (caddr v0f))
    )
   )
  )
  (if (> d60 r60)
   (progn 
    (setq v6x (+ v6x (* a6x t)))  (setq v6y (+ v6y (* a6y t)))  (setq v6z (+ v6z (* a6z t)))
    (setq v0x (+ v0x (* a0x t)))  (setq v0y (+ v0y (* a0y t)))  (setq v0z (+ v0z (* a0z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v6i (list v6x v6y v6z)) ;velocita 6 prima dello scontro
     (setq v0i (list v0x v0y v0z)) ;velocita 0 prima dello scontro
     (setq v6i* (trans v6i 0 (list dx60 dy60 dz60)))
     (setq v0i* (trans v0i 0 (list dx60 dy60 dz60)))
     (setq v6i*x (car v6i*) v6i*y (cadr v6i*) v6i*z (caddr v6i*))
     (setq v0i*x (car v0i*) v0i*y (cadr v0i*) v0i*z (caddr v0i*))
     (setq v6f*z (* kur (/ (+ (* (- m6 m0) v6i*z) (* 2 m0 v0i*z)) (+ m6 m0))))
     (setq v0f*z (* kur (/ (+ (* (- m0 m6) v0i*z) (* 2 m6 v6i*z)) (+ m6 m0))))
     (setq v6f* (list v6i*x v6i*y v6f*z))
     (setq v0f* (list v0i*x v0i*y v0f*z))
     (setq v6f (trans v6f* (list dx60 dy60 dz60) 0))
     (setq v0f (trans v0f* (list dx60 dy60 dz60) 0))
     (setq v6x (car v6f) v6y (cadr v6f) v6z (caddr v6f))
     (setq v0x (car v0f) v0y (cadr v0f) v0z (caddr v0f))
    )
   )
  )
  (if (> d70 r70)
   (progn 
    (setq v7x (+ v7x (* a7x t)))  (setq v7y (+ v7y (* a7y t)))  (setq v7z (+ v7z (* a7z t)))
    (setq v0x (+ v0x (* a0x t)))  (setq v0y (+ v0y (* a0y t)))  (setq v0z (+ v0z (* a0z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v7i (list v7x v7y v7z)) ;velocita 7 prima dello scontro
     (setq v0i (list v0x v0y v0z)) ;velocita 0 prima dello scontro
     (setq v7i* (trans v7i 0 (list dx70 dy70 dz70)))
     (setq v0i* (trans v0i 0 (list dx70 dy70 dz70)))
     (setq v7i*x (car v7i*) v7i*y (cadr v7i*) v7i*z (caddr v7i*))
     (setq v0i*x (car v0i*) v0i*y (cadr v0i*) v0i*z (caddr v0i*))
     (setq v7f*z (* kur (/ (+ (* (- m7 m0) v7i*z) (* 2 m0 v0i*z)) (+ m7 m0))))
     (setq v0f*z (* kur (/ (+ (* (- m0 m7) v0i*z) (* 2 m7 v7i*z)) (+ m7 m0))))
     (setq v7f* (list v7i*x v7i*y v7f*z))
     (setq v0f* (list v0i*x v0i*y v0f*z))
     (setq v7f (trans v7f* (list dx70 dy70 dz70) 0))
     (setq v0f (trans v0f* (list dx70 dy70 dz70) 0))
     (setq v7x (car v7f) v7y (cadr v7f) v7z (caddr v7f))
     (setq v0x (car v0f) v0y (cadr v0f) v0z (caddr v0f))
    )
   )
  )
  (if (> d80 r80)
   (progn 
    (setq v8x (+ v8x (* a8x t)))  (setq v8y (+ v8y (* a8y t)))  (setq v8z (+ v8z (* a8z t)))
    (setq v0x (+ v0x (* a0x t)))  (setq v0y (+ v0y (* a0y t)))  (setq v0z (+ v0z (* a0z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v8i (list v8x v8y v8z)) ;velocita 8 prima dello scontro
     (setq v0i (list v0x v0y v0z)) ;velocita 0 prima dello scontro
     (setq v8i* (trans v8i 0 (list dx80 dy80 dz80)))
     (setq v0i* (trans v0i 0 (list dx80 dy80 dz80)))
     (setq v8i*x (car v8i*) v8i*y (cadr v8i*) v8i*z (caddr v8i*))
     (setq v0i*x (car v0i*) v0i*y (cadr v0i*) v0i*z (caddr v0i*))
     (setq v8f*z (* kur (/ (+ (* (- m8 m0) v8i*z) (* 2 m0 v0i*z)) (+ m8 m0))))
     (setq v0f*z (* kur (/ (+ (* (- m0 m8) v0i*z) (* 2 m8 v8i*z)) (+ m8 m0))))
     (setq v8f* (list v8i*x v8i*y v8f*z))
     (setq v0f* (list v0i*x v0i*y v0f*z))
     (setq v8f (trans v8f* (list dx80 dy80 dz80) 0))
     (setq v0f (trans v0f* (list dx80 dy80 dz80) 0))
     (setq v8x (car v8f) v8y (cadr v8f) v8z (caddr v8f))
     (setq v0x (car v0f) v0y (cadr v0f) v0z (caddr v0f))
    )
   )
  )
  (if (> d90 r90)
   (progn 
    (setq v9x (+ v9x (* a9x t)))  (setq v9y (+ v9y (* a9y t)))  (setq v9z (+ v9z (* a9z t)))
    (setq v0x (+ v0x (* a0x t)))  (setq v0y (+ v0y (* a0y t)))  (setq v0z (+ v0z (* a0z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v9i (list v9x v9y v9z)) ;velocita 9 prima dello scontro
     (setq v0i (list v0x v0y v0z)) ;velocita 0 prima dello scontro
     (setq v9i* (trans v9i 0 (list dx90 dy90 dz90)))
     (setq v0i* (trans v0i 0 (list dx90 dy90 dz90)))
     (setq v9i*x (car v9i*) v9i*y (cadr v9i*) v9i*z (caddr v9i*))
     (setq v0i*x (car v0i*) v0i*y (cadr v0i*) v0i*z (caddr v0i*))
     (setq v9f*z (* kur (/ (+ (* (- m9 m0) v9i*z) (* 2 m0 v0i*z)) (+ m9 m0))))
     (setq v0f*z (* kur (/ (+ (* (- m0 m9) v0i*z) (* 2 m9 v9i*z)) (+ m9 m0))))
     (setq v9f* (list v9i*x v9i*y v9f*z))
     (setq v0f* (list v0i*x v0i*y v0f*z))
     (setq v9f (trans v9f* (list dx90 dy90 dz90) 0))
     (setq v0f (trans v0f* (list dx90 dy90 dz90) 0))
     (setq v9x (car v9f) v9y (cadr v9f) v9z (caddr v9f))
     (setq v0x (car v0f) v0y (cadr v0f) v0z (caddr v0f))
    )
   )
  )

  (if (> d1a r1a)
   (progn 
    (setq v1x (+ v1x (* a1x t)))  (setq v1y (+ v1y (* a1y t)))  (setq v1z (+ v1z (* a1z t)))
    (setq vax (+ vax (* aax t)))  (setq vay (+ vay (* aay t)))  (setq vaz (+ vaz (* aaz t)))
   )
   (if (/= kur 0)
    (progn
     (setq v1i (list v1x v1y v1z)) ;velocita 1 prima dello scontro
     (setq vai (list vax vay vaz)) ;velocita a prima dello scontro
     (setq v1i* (trans v1i 0 (list dx1a dy1a dz1a)))
     (setq vai* (trans vai 0 (list dx1a dy1a dz1a)))
     (setq v1i*x (car v1i*) v1i*y (cadr v1i*) v1i*z (caddr v1i*))
     (setq vai*x (car vai*) vai*y (cadr vai*) vai*z (caddr vai*))
     (setq v1f*z (* kur (/ (+ (* (- m1 ma) v1i*z) (* 2 ma vai*z)) (+ m1 ma))))
     (setq vaf*z (* kur (/ (+ (* (- ma m1) vai*z) (* 2 m1 v1i*z)) (+ m1 ma))))
     (setq v1f* (list v1i*x v1i*y v1f*z))
     (setq vaf* (list vai*x vai*y vaf*z))
     (setq v1f (trans v1f* (list dx1a dy1a dz1a) 0))
     (setq vaf (trans vaf* (list dx1a dy1a dz1a) 0))
     (setq v1x (car v1f) v1y (cadr v1f) v1z (caddr v1f))
     (setq vax (car vaf) vay (cadr vaf) vaz (caddr vaf))
    )
   )
  )
  (if (> d2a r2a)
   (progn 
    (setq v2x (+ v2x (* a2x t)))  (setq v2y (+ v2y (* a2y t)))  (setq v2z (+ v2z (* a2z t)))
    (setq vax (+ vax (* aax t)))  (setq vay (+ vay (* aay t)))  (setq vaz (+ vaz (* aaz t)))
   )
   (if (/= kur 0)
    (progn
     (setq v2i (list v2x v2y v2z)) ;velocita 2 prima dello scontro
     (setq vai (list vax vay vaz)) ;velocita a prima dello scontro
     (setq v2i* (trans v2i 0 (list dx2a dy2a dz2a)))
     (setq vai* (trans vai 0 (list dx2a dy2a dz2a)))
     (setq v2i*x (car v2i*) v2i*y (cadr v2i*) v2i*z (caddr v2i*))
     (setq vai*x (car vai*) vai*y (cadr vai*) vai*z (caddr vai*))
     (setq v2f*z (* kur (/ (+ (* (- m2 ma) v2i*z) (* 2 ma vai*z)) (+ m2 ma))))
     (setq vaf*z (* kur (/ (+ (* (- ma m2) vai*z) (* 2 m2 v2i*z)) (+ m2 ma))))
     (setq v2f* (list v2i*x v2i*y v2f*z))
     (setq vaf* (list vai*x vai*y vaf*z))
     (setq v2f (trans v2f* (list dx2a dy2a dz2a) 0))
     (setq vaf (trans vaf* (list dx2a dy2a dz2a) 0))
     (setq v2x (car v2f) v2y (cadr v2f) v2z (caddr v2f))
     (setq vax (car vaf) vay (cadr vaf) vaz (caddr vaf))
    )
   )
  )
  (if (> d3a r3a)
   (progn 
    (setq v3x (+ v3x (* a3x t)))  (setq v3y (+ v3y (* a3y t)))  (setq v3z (+ v3z (* a3z t)))
    (setq vax (+ vax (* aax t)))  (setq vay (+ vay (* aay t)))  (setq vaz (+ vaz (* aaz t)))
   )
   (if (/= kur 0)
    (progn
     (setq v3i (list v3x v3y v3z)) ;velocita 3 prima dello scontro
     (setq vai (list vax vay vaz)) ;velocita a prima dello scontro
     (setq v3i* (trans v3i 0 (list dx3a dy3a dz3a)))
     (setq vai* (trans vai 0 (list dx3a dy3a dz3a)))
     (setq v3i*x (car v3i*) v3i*y (cadr v3i*) v3i*z (caddr v3i*))
     (setq vai*x (car vai*) vai*y (cadr vai*) vai*z (caddr vai*))
     (setq v3f*z (* kur (/ (+ (* (- m3 ma) v3i*z) (* 2 ma vai*z)) (+ m3 ma))))
     (setq vaf*z (* kur (/ (+ (* (- ma m3) vai*z) (* 2 m3 v3i*z)) (+ m3 ma))))
     (setq v3f* (list v3i*x v3i*y v3f*z))
     (setq vaf* (list vai*x vai*y vaf*z))
     (setq v3f (trans v3f* (list dx3a dy3a dz3a) 0))
     (setq vaf (trans vaf* (list dx3a dy3a dz3a) 0))
     (setq v3x (car v3f) v3y (cadr v3f) v3z (caddr v3f))
     (setq vax (car vaf) vay (cadr vaf) vaz (caddr vaf))
    )
   )
  )
  (if (> d4a r4a)
   (progn 
    (setq v4x (+ v4x (* a4x t)))  (setq v4y (+ v4y (* a4y t)))  (setq v4z (+ v4z (* a4z t)))
    (setq vax (+ vax (* aax t)))  (setq vay (+ vay (* aay t)))  (setq vaz (+ vaz (* aaz t)))
   )
   (if (/= kur 0)
    (progn
     (setq v4i (list v4x v4y v4z)) ;velocita 4 prima dello scontro
     (setq vai (list vax vay vaz)) ;velocita a prima dello scontro
     (setq v4i* (trans v4i 0 (list dx4a dy4a dz4a)))
     (setq vai* (trans vai 0 (list dx4a dy4a dz4a)))
     (setq v4i*x (car v4i*) v4i*y (cadr v4i*) v4i*z (caddr v4i*))
     (setq vai*x (car vai*) vai*y (cadr vai*) vai*z (caddr vai*))
     (setq v4f*z (* kur (/ (+ (* (- m4 ma) v4i*z) (* 2 ma vai*z)) (+ m4 ma))))
     (setq vaf*z (* kur (/ (+ (* (- ma m4) vai*z) (* 2 m4 v4i*z)) (+ m4 ma))))
     (setq v4f* (list v4i*x v4i*y v4f*z))
     (setq vaf* (list vai*x vai*y vaf*z))
     (setq v4f (trans v4f* (list dx4a dy4a dz4a) 0))
     (setq vaf (trans vaf* (list dx4a dy4a dz4a) 0))
     (setq v4x (car v4f) v4y (cadr v4f) v4z (caddr v4f))
     (setq vax (car vaf) vay (cadr vaf) vaz (caddr vaf))
    )
   )
  )
  (if (> d5a r5a)
   (progn 
    (setq v5x (+ v5x (* a5x t)))  (setq v5y (+ v5y (* a5y t)))  (setq v5z (+ v5z (* a5z t)))
    (setq vax (+ vax (* aax t)))  (setq vay (+ vay (* aay t)))  (setq vaz (+ vaz (* aaz t)))
   )
   (if (/= kur 0)
    (progn
     (setq v5i (list v5x v5y v5z)) ;velocita 5 prima dello scontro
     (setq vai (list vax vay vaz)) ;velocita a prima dello scontro
     (setq v5i* (trans v5i 0 (list dx5a dy5a dz5a)))
     (setq vai* (trans vai 0 (list dx5a dy5a dz5a)))
     (setq v5i*x (car v5i*) v5i*y (cadr v5i*) v5i*z (caddr v5i*))
     (setq vai*x (car vai*) vai*y (cadr vai*) vai*z (caddr vai*))
     (setq v5f*z (* kur (/ (+ (* (- m5 ma) v5i*z) (* 2 ma vai*z)) (+ m5 ma))))
     (setq vaf*z (* kur (/ (+ (* (- ma m5) vai*z) (* 2 m5 v5i*z)) (+ m5 ma))))
     (setq v5f* (list v5i*x v5i*y v5f*z))
     (setq vaf* (list vai*x vai*y vaf*z))
     (setq v5f (trans v5f* (list dx5a dy5a dz5a) 0))
     (setq vaf (trans vaf* (list dx5a dy5a dz5a) 0))
     (setq v5x (car v5f) v5y (cadr v5f) v5z (caddr v5f))
     (setq vax (car vaf) vay (cadr vaf) vaz (caddr vaf))
    )
   )
  )
  (if (> d6a r6a)
   (progn 
    (setq v6x (+ v6x (* a6x t)))  (setq v6y (+ v6y (* a6y t)))  (setq v6z (+ v6z (* a6z t)))
    (setq vax (+ vax (* aax t)))  (setq vay (+ vay (* aay t)))  (setq vaz (+ vaz (* aaz t)))
   )
   (if (/= kur 0)
    (progn
     (setq v6i (list v6x v6y v6z)) ;velocita 6 prima dello scontro
     (setq vai (list vax vay vaz)) ;velocita a prima dello scontro
     (setq v6i* (trans v6i 0 (list dx6a dy6a dz6a)))
     (setq vai* (trans vai 0 (list dx6a dy6a dz6a)))
     (setq v6i*x (car v6i*) v6i*y (cadr v6i*) v6i*z (caddr v6i*))
     (setq vai*x (car vai*) vai*y (cadr vai*) vai*z (caddr vai*))
     (setq v6f*z (* kur (/ (+ (* (- m6 ma) v6i*z) (* 2 ma vai*z)) (+ m6 ma))))
     (setq vaf*z (* kur (/ (+ (* (- ma m6) vai*z) (* 2 m6 v6i*z)) (+ m6 ma))))
     (setq v6f* (list v6i*x v6i*y v6f*z))
     (setq vaf* (list vai*x vai*y vaf*z))
     (setq v6f (trans v6f* (list dx6a dy6a dz6a) 0))
     (setq vaf (trans vaf* (list dx6a dy6a dz6a) 0))
     (setq v6x (car v6f) v6y (cadr v6f) v6z (caddr v6f))
     (setq vax (car vaf) vay (cadr vaf) vaz (caddr vaf))
    )
   )
  )
  (if (> d7a r7a)
   (progn 
    (setq v7x (+ v7x (* a7x t)))  (setq v7y (+ v7y (* a7y t)))  (setq v7z (+ v7z (* a7z t)))
    (setq vax (+ vax (* aax t)))  (setq vay (+ vay (* aay t)))  (setq vaz (+ vaz (* aaz t)))
   )
   (if (/= kur 0)
    (progn
     (setq v7i (list v7x v7y v7z)) ;velocita 7 prima dello scontro
     (setq vai (list vax vay vaz)) ;velocita a prima dello scontro
     (setq v7i* (trans v7i 0 (list dx7a dy7a dz7a)))
     (setq vai* (trans vai 0 (list dx7a dy7a dz7a)))
     (setq v7i*x (car v7i*) v7i*y (cadr v7i*) v7i*z (caddr v7i*))
     (setq vai*x (car vai*) vai*y (cadr vai*) vai*z (caddr vai*))
     (setq v7f*z (* kur (/ (+ (* (- m7 ma) v7i*z) (* 2 ma vai*z)) (+ m7 ma))))
     (setq vaf*z (* kur (/ (+ (* (- ma m7) vai*z) (* 2 m7 v7i*z)) (+ m7 ma))))
     (setq v7f* (list v7i*x v7i*y v7f*z))
     (setq vaf* (list vai*x vai*y vaf*z))
     (setq v7f (trans v7f* (list dx7a dy7a dz7a) 0))
     (setq vaf (trans vaf* (list dx7a dy7a dz7a) 0))
     (setq v7x (car v7f) v7y (cadr v7f) v7z (caddr v7f))
     (setq vax (car vaf) vay (cadr vaf) vaz (caddr vaf))
    )
   )
  )
  (if (> d8a r8a)
   (progn 
    (setq v8x (+ v8x (* a8x t)))  (setq v8y (+ v8y (* a8y t)))  (setq v8z (+ v8z (* a8z t)))
    (setq vax (+ vax (* aax t)))  (setq vay (+ vay (* aay t)))  (setq vaz (+ vaz (* aaz t)))
   )
   (if (/= kur 0)
    (progn
     (setq v8i (list v8x v8y v8z)) ;velocita 8 prima dello scontro
     (setq vai (list vax vay vaz)) ;velocita a prima dello scontro
     (setq v8i* (trans v8i 0 (list dx8a dy8a dz8a)))
     (setq vai* (trans vai 0 (list dx8a dy8a dz8a)))
     (setq v8i*x (car v8i*) v8i*y (cadr v8i*) v8i*z (caddr v8i*))
     (setq vai*x (car vai*) vai*y (cadr vai*) vai*z (caddr vai*))
     (setq v8f*z (* kur (/ (+ (* (- m8 ma) v8i*z) (* 2 ma vai*z)) (+ m8 ma))))
     (setq vaf*z (* kur (/ (+ (* (- ma m8) vai*z) (* 2 m8 v8i*z)) (+ m8 ma))))
     (setq v8f* (list v8i*x v8i*y v8f*z))
     (setq vaf* (list vai*x vai*y vaf*z))
     (setq v8f (trans v8f* (list dx8a dy8a dz8a) 0))
     (setq vaf (trans vaf* (list dx8a dy8a dz8a) 0))
     (setq v8x (car v8f) v8y (cadr v8f) v8z (caddr v8f))
     (setq vax (car vaf) vay (cadr vaf) vaz (caddr vaf))
    )
   )
  )
  (if (> d9a r9a)
   (progn 
    (setq v9x (+ v9x (* a9x t)))  (setq v9y (+ v9y (* a9y t)))  (setq v9z (+ v9z (* a9z t)))
    (setq vax (+ vax (* aax t)))  (setq vay (+ vay (* aay t)))  (setq vaz (+ vaz (* aaz t)))
   )
   (if (/= kur 0)
    (progn
     (setq v9i (list v9x v9y v9z)) ;velocita 9 prima dello scontro
     (setq vai (list vax vay vaz)) ;velocita a prima dello scontro
     (setq v9i* (trans v9i 0 (list dx9a dy9a dz9a)))
     (setq vai* (trans vai 0 (list dx9a dy9a dz9a)))
     (setq v9i*x (car v9i*) v9i*y (cadr v9i*) v9i*z (caddr v9i*))
     (setq vai*x (car vai*) vai*y (cadr vai*) vai*z (caddr vai*))
     (setq v9f*z (* kur (/ (+ (* (- m9 ma) v9i*z) (* 2 ma vai*z)) (+ m9 ma))))
     (setq vaf*z (* kur (/ (+ (* (- ma m9) vai*z) (* 2 m9 v9i*z)) (+ m9 ma))))
     (setq v9f* (list v9i*x v9i*y v9f*z))
     (setq vaf* (list vai*x vai*y vaf*z))
     (setq v9f (trans v9f* (list dx9a dy9a dz9a) 0))
     (setq vaf (trans vaf* (list dx9a dy9a dz9a) 0))
     (setq v9x (car v9f) v9y (cadr v9f) v9z (caddr v9f))
     (setq vax (car vaf) vay (cadr vaf) vaz (caddr vaf))
    )
   )
  )
  (if (> d0a r0a)
   (progn 
    (setq v0x (+ v0x (* a0x t)))  (setq v0y (+ v0y (* a0y t)))  (setq v0z (+ v0z (* a0z t)))
    (setq vax (+ vax (* aax t)))  (setq vay (+ vay (* aay t)))  (setq vaz (+ vaz (* aaz t)))
   )
   (if (/= kur 0)
    (progn
     (setq v0i (list v0x v0y v0z)) ;velocita 0 prima dello scontro
     (setq vai (list vax vay vaz)) ;velocita a prima dello scontro
     (setq v0i* (trans v0i 0 (list dx0a dy0a dz0a)))
     (setq vai* (trans vai 0 (list dx0a dy0a dz0a)))
     (setq v0i*x (car v0i*) v0i*y (cadr v0i*) v0i*z (caddr v0i*))
     (setq vai*x (car vai*) vai*y (cadr vai*) vai*z (caddr vai*))
     (setq v0f*z (* kur (/ (+ (* (- m0 ma) v0i*z) (* 2 ma vai*z)) (+ m0 ma))))
     (setq vaf*z (* kur (/ (+ (* (- ma m0) vai*z) (* 2 m0 v0i*z)) (+ m0 ma))))
     (setq v0f* (list v0i*x v0i*y v0f*z))
     (setq vaf* (list vai*x vai*y vaf*z))
     (setq v0f (trans v0f* (list dx0a dy0a dz0a) 0))
     (setq vaf (trans vaf* (list dx0a dy0a dz0a) 0))
     (setq v0x (car v0f) v0y (cadr v0f) v0z (caddr v0f))
     (setq vax (car vaf) vay (cadr vaf) vaz (caddr vaf))
    )
   )
  )

  (if (< (- x1 r1) xsa) (setq v1x (* (+ (* -2 kbi) 1) v1x) ) )
  (if (< (- y1 r1) ysa) (setq v1y (* (+ (* -2 kbi) 1) v1y) ) )   
  (if (< (- z1 r1) zsa) (setq v1z (* (+ (* -2 kbi) 1) v1z) ) )   
  (if (> (+ x1 r1) xsb) (setq v1x (* (+ (* -2 kbi) 1) v1x) ) )   
  (if (> (+ y1 r1) ysb) (setq v1y (* (+ (* -2 kbi) 1) v1y) ) )   
  (if (> (+ z1 r1) zsb) (setq v1z (* (+ (* -2 kbi) 1) v1z) ) )   
  (if (< (- x2 r2) xsa) (setq v2x (* (+ (* -2 kbi) 1) v2x) ) )   
  (if (< (- y2 r2) ysa) (setq v2y (* (+ (* -2 kbi) 1) v2y) ) )   
  (if (< (- z2 r2) zsa) (setq v2z (* (+ (* -2 kbi) 1) v2z) ) )   
  (if (> (+ x2 r2) xsb) (setq v2x (* (+ (* -2 kbi) 1) v2x) ) )   
  (if (> (+ y2 r2) ysb) (setq v2y (* (+ (* -2 kbi) 1) v2y) ) )   
  (if (> (+ z2 r2) zsb) (setq v2z (* (+ (* -2 kbi) 1) v2z) ) )   
  (if (< (- x3 r3) xsa) (setq v3x (* (+ (* -2 kbi) 1) v3x) ) )   
  (if (< (- y3 r3) ysa) (setq v3y (* (+ (* -2 kbi) 1) v3y) ) )   
  (if (< (- z3 r3) zsa) (setq v3z (* (+ (* -2 kbi) 1) v3z) ) )   
  (if (> (+ x3 r3) xsb) (setq v3x (* (+ (* -2 kbi) 1) v3x) ) )   
  (if (> (+ y3 r3) ysb) (setq v3y (* (+ (* -2 kbi) 1) v3y) ) )   
  (if (> (+ z3 r3) zsb) (setq v3z (* (+ (* -2 kbi) 1) v3z) ) )   
  (if (< (- x4 r4) xsa) (setq v4x (* (+ (* -2 kbi) 1) v4x) ) )   
  (if (< (- y4 r4) ysa) (setq v4y (* (+ (* -2 kbi) 1) v4y) ) )   
  (if (< (- z4 r4) zsa) (setq v4z (* (+ (* -2 kbi) 1) v4z) ) )   
  (if (> (+ x4 r4) xsb) (setq v4x (* (+ (* -2 kbi) 1) v4x) ) )   
  (if (> (+ y4 r4) ysb) (setq v4y (* (+ (* -2 kbi) 1) v4y) ) )   
  (if (> (+ z4 r4) zsb) (setq v4z (* (+ (* -2 kbi) 1) v4z) ) )   
  (if (< (- x5 r5) xsa) (setq v5x (* (+ (* -2 kbi) 1) v5x) ) )   
  (if (< (- y5 r5) ysa) (setq v5y (* (+ (* -2 kbi) 1) v5y) ) )   
  (if (< (- z5 r5) zsa) (setq v5z (* (+ (* -2 kbi) 1) v5z) ) )   
  (if (> (+ x5 r5) xsb) (setq v5x (* (+ (* -2 kbi) 1) v5x) ) )   
  (if (> (+ y5 r5) ysb) (setq v5y (* (+ (* -2 kbi) 1) v5y) ) )   
  (if (> (+ z5 r5) zsb) (setq v5z (* (+ (* -2 kbi) 1) v5z) ) )   
  (if (< (- x6 r6) xsa) (setq v6x (* (+ (* -2 kbi) 1) v6x) ) )   
  (if (< (- y6 r6) ysa) (setq v6y (* (+ (* -2 kbi) 1) v6y) ) )   
  (if (< (- z6 r6) zsa) (setq v6z (* (+ (* -2 kbi) 1) v6z) ) )   
  (if (> (+ x6 r6) xsb) (setq v6x (* (+ (* -2 kbi) 1) v6x) ) )   
  (if (> (+ y6 r6) ysb) (setq v6y (* (+ (* -2 kbi) 1) v6y) ) )   
  (if (> (+ z6 r6) zsb) (setq v6z (* (+ (* -2 kbi) 1) v6z) ) )   
  (if (< (- x7 r7) xsa) (setq v7x (* (+ (* -2 kbi) 1) v7x) ) )   
  (if (< (- y7 r7) ysa) (setq v7y (* (+ (* -2 kbi) 1) v7y) ) )   
  (if (< (- z7 r7) zsa) (setq v7z (* (+ (* -2 kbi) 1) v7z) ) )   
  (if (> (+ x7 r7) xsb) (setq v7x (* (+ (* -2 kbi) 1) v7x) ) )   
  (if (> (+ y7 r7) ysb) (setq v7y (* (+ (* -2 kbi) 1) v7y) ) )   
  (if (> (+ z7 r7) zsb) (setq v7z (* (+ (* -2 kbi) 1) v7z) ) )   
  (if (< (- x8 r8) xsa) (setq v8x (* (+ (* -2 kbi) 1) v8x) ) )   
  (if (< (- y8 r8) ysa) (setq v8y (* (+ (* -2 kbi) 1) v8y) ) )   
  (if (< (- z8 r8) zsa) (setq v8z (* (+ (* -2 kbi) 1) v8z) ) )   
  (if (> (+ x8 r8) xsb) (setq v8x (* (+ (* -2 kbi) 1) v8x) ) )   
  (if (> (+ y8 r8) ysb) (setq v8y (* (+ (* -2 kbi) 1) v8y) ) )   
  (if (> (+ z8 r8) zsb) (setq v8z (* (+ (* -2 kbi) 1) v8z) ) )   
  (if (< (- x9 r9) xsa) (setq v9x (* (+ (* -2 kbi) 1) v9x) ) )   
  (if (< (- y9 r9) ysa) (setq v9y (* (+ (* -2 kbi) 1) v9y) ) )   
  (if (< (- z9 r9) zsa) (setq v9z (* (+ (* -2 kbi) 1) v9z) ) )   
  (if (> (+ x9 r9) xsb) (setq v9x (* (+ (* -2 kbi) 1) v9x) ) )   
  (if (> (+ y9 r9) ysb) (setq v9y (* (+ (* -2 kbi) 1) v9y) ) )   
  (if (> (+ z9 r9) zsb) (setq v9z (* (+ (* -2 kbi) 1) v9z) ) )   
  (if (< (- x0 r0) xsa) (setq v0x (* (+ (* -2 kbi) 1) v0x) ) )   
  (if (< (- y0 r0) ysa) (setq v0y (* (+ (* -2 kbi) 1) v0y) ) )   
  (if (< (- z0 r0) zsa) (setq v0z (* (+ (* -2 kbi) 1) v0z) ) )   
  (if (> (+ x0 r0) xsb) (setq v0x (* (+ (* -2 kbi) 1) v0x) ) )   
  (if (> (+ y0 r0) ysb) (setq v0y (* (+ (* -2 kbi) 1) v0y) ) )   
  (if (> (+ z0 r0) zsb) (setq v0z (* (+ (* -2 kbi) 1) v0z) ) )   
  (if (< (- xa ra) xsa) (setq vax (* (+ (* -2 kbi) 1) vax) ) )   
  (if (< (- ya ra) ysa) (setq vay (* (+ (* -2 kbi) 1) vay) ) )   
  (if (< (- za ra) zsa) (setq vaz (* (+ (* -2 kbi) 1) vaz) ) )   
  (if (> (+ xa ra) xsb) (setq vax (* (+ (* -2 kbi) 1) vax) ) )   
  (if (> (+ ya ra) ysb) (setq vay (* (+ (* -2 kbi) 1) vay) ) )   
  (if (> (+ za ra) zsb) (setq vaz (* (+ (* -2 kbi) 1) vaz) ) )   

  (setq s1x (+ (* v1x t) (* 0.5 a1x t t)))  (setq s1y (+ (* v1y t) (* 0.5 a1y t t)))  (setq s1z (+ (* v1z t) (* 0.5 a1z t t)))
  (setq s2x (+ (* v2x t) (* 0.5 a2x t t)))  (setq s2y (+ (* v2y t) (* 0.5 a2y t t)))  (setq s2z (+ (* v2z t) (* 0.5 a2z t t)))
  (setq s3x (+ (* v3x t) (* 0.5 a3x t t)))  (setq s3y (+ (* v3y t) (* 0.5 a3y t t)))  (setq s3z (+ (* v3z t) (* 0.5 a3z t t)))
  (setq s4x (+ (* v4x t) (* 0.5 a4x t t)))  (setq s4y (+ (* v4y t) (* 0.5 a4y t t)))  (setq s4z (+ (* v4z t) (* 0.5 a4z t t)))
  (setq s5x (+ (* v5x t) (* 0.5 a5x t t)))  (setq s5y (+ (* v5y t) (* 0.5 a5y t t)))  (setq s5z (+ (* v5z t) (* 0.5 a5z t t)))
  (setq s6x (+ (* v6x t) (* 0.5 a6x t t)))  (setq s6y (+ (* v6y t) (* 0.5 a6y t t)))  (setq s6z (+ (* v6z t) (* 0.5 a6z t t)))
  (setq s7x (+ (* v7x t) (* 0.5 a7x t t)))  (setq s7y (+ (* v7y t) (* 0.5 a7y t t)))  (setq s7z (+ (* v7z t) (* 0.5 a7z t t)))
  (setq s8x (+ (* v8x t) (* 0.5 a8x t t)))  (setq s8y (+ (* v8y t) (* 0.5 a8y t t)))  (setq s8z (+ (* v8z t) (* 0.5 a8z t t)))
  (setq s9x (+ (* v9x t) (* 0.5 a9x t t)))  (setq s9y (+ (* v9y t) (* 0.5 a9y t t)))  (setq s9z (+ (* v9z t) (* 0.5 a9z t t)))
  (setq s0x (+ (* v0x t) (* 0.5 a0x t t)))  (setq s0y (+ (* v0y t) (* 0.5 a0y t t)))  (setq s0z (+ (* v0z t) (* 0.5 a0z t t)))
  (setq sax (+ (* vax t) (* 0.5 aax t t)))  (setq say (+ (* vay t) (* 0.5 aay t t)))  (setq saz (+ (* vaz t) (* 0.5 aaz t t)))

  (setq x1 (+ x1 (* k1 s1x)))  (setq y1 (+ y1 (* k1 s1y)))  (setq z1 (+ z1 (* k1 s1z)))
  (setq x2 (+ x2 (* k2 s2x)))  (setq y2 (+ y2 (* k2 s2y)))  (setq z2 (+ z2 (* k2 s2z)))
  (setq x3 (+ x3 (* k3 s3x)))  (setq y3 (+ y3 (* k3 s3y)))  (setq z3 (+ z3 (* k3 s3z)))
  (setq x4 (+ x4 (* k4 s4x)))  (setq y4 (+ y4 (* k4 s4y)))  (setq z4 (+ z4 (* k4 s4z)))
  (setq x5 (+ x5 (* k5 s5x)))  (setq y5 (+ y5 (* k5 s5y)))  (setq z5 (+ z5 (* k5 s5z)))
  (setq x6 (+ x6 (* k6 s6x)))  (setq y6 (+ y6 (* k6 s6y)))  (setq z6 (+ z6 (* k6 s6z)))
  (setq x7 (+ x7 (* k7 s7x)))  (setq y7 (+ y7 (* k7 s7y)))  (setq z7 (+ z7 (* k7 s7z)))
  (setq x8 (+ x8 (* k8 s8x)))  (setq y8 (+ y8 (* k8 s8y)))  (setq z8 (+ z8 (* k8 s8z)))
  (setq x9 (+ x9 (* k9 s9x)))  (setq y9 (+ y9 (* k9 s9y)))  (setq z9 (+ z9 (* k9 s9z)))
  (setq x0 (+ x0 (* k0 s0x)))  (setq y0 (+ y0 (* k0 s0y)))  (setq z0 (+ z0 (* k0 s0z)))
  (setq xa (+ xa (* ka sax)))  (setq ya (+ ya (* ka say)))  (setq za (+ za (* ka saz)))

  (setq a1 (sqrt (+ (* a1x a1x) (* a1y a1y) (* a1z a1z))))
  (setq a2 (sqrt (+ (* a2x a2x) (* a2y a2y) (* a2z a2z))))
  (setq a3 (sqrt (+ (* a3x a3x) (* a3y a3y) (* a3z a3z))))
  (setq a4 (sqrt (+ (* a4x a4x) (* a4y a4y) (* a4z a4z))))
  (setq a5 (sqrt (+ (* a5x a5x) (* a5y a5y) (* a5z a5z))))
  (setq a6 (sqrt (+ (* a6x a6x) (* a6y a6y) (* a6z a6z))))
  (setq a7 (sqrt (+ (* a7x a7x) (* a7y a7y) (* a7z a7z))))
  (setq a8 (sqrt (+ (* a8x a8x) (* a8y a8y) (* a8z a8z))))
  (setq a9 (sqrt (+ (* a9x a9x) (* a9y a9y) (* a9z a9z))))
  (setq a0 (sqrt (+ (* a0x a0x) (* a0y a0y) (* a0z a0z))))
  (setq aa (sqrt (+ (* aax aax) (* aay aay) (* aaz aaz))))

  (setq va (+ (abs a1) (abs a2) (abs a3) (abs a4) (abs a5) (abs a6) (abs a7) (abs a8) (abs a9) (abs a0) (abs aa)
              (abs v1) (abs v2) (abs v3) (abs v4) (abs v5) (abs v6) (abs v7) (abs v8) (abs v9) (abs v0) (abs va)
           )
  )
  (princ "\n")
  (princ va)
  (princ)

  (setq q1 (list x1 y1 z1))
  (setq q2 (list x2 y2 z2))
  (setq q3 (list x3 y3 z3))
  (setq q4 (list x4 y4 z4))
  (setq q5 (list x5 y5 z5))
  (setq q6 (list x6 y6 z6))
  (setq q7 (list x7 y7 z7))
  (setq q8 (list x8 y8 z8))
  (setq q9 (list x9 y9 z9))
  (setq q0 (list x0 y0 z0))
  (setq qa (list xa ya za))

  (if (= iscan 0)
   (progn
 
   (if (= ker 0)
    (progn
    (if (= pc "p")
        (progn
         (setvar "clayer" "m1") (command "_point" p1)
         (setvar "clayer" "m2") (command "_point" p2)
         (setvar "clayer" "m3") (command "_point" p3)
         (setvar "clayer" "m4") (command "_point" p4)
         (setvar "clayer" "m5") (command "_point" p5)
         (setvar "clayer" "m6") (command "_point" p6)
         (setvar "clayer" "m7") (command "_point" p7)
         (setvar "clayer" "m8") (command "_point" p8)
         (setvar "clayer" "m9") (command "_point" p9)
         (setvar "clayer" "m0") (command "_point" p0)
         (setvar "clayer" "ma") (command "_point" pa)
        )
        (if (= pc "c")
            (progn
             (setvar "clayer" "m1") (command "_circle" p1 r1)
             (setvar "clayer" "m2") (command "_circle" p2 r2)
             (setvar "clayer" "m3") (command "_circle" p3 r3)
             (setvar "clayer" "m4") (command "_circle" p4 r4)
             (setvar "clayer" "m5") (command "_circle" p5 r5)
             (setvar "clayer" "m6") (command "_circle" p6 r6)
             (setvar "clayer" "m7") (command "_circle" p7 r7)
             (setvar "clayer" "m8") (command "_circle" p8 r8)
             (setvar "clayer" "m9") (command "_circle" p9 r9)
             (setvar "clayer" "m0") (command "_circle" p0 r0)
             (setvar "clayer" "ma") (command "_circle" pa ra)
            )
            (if (= pc "s")
                (progn
                 (setvar "clayer" "m1") (command "_sphere" p1 r1)
                 (setvar "clayer" "m2") (command "_sphere" p2 r2)
                 (setvar "clayer" "m3") (command "_sphere" p3 r3)
                 (setvar "clayer" "m4") (command "_sphere" p4 r4)
                 (setvar "clayer" "m5") (command "_sphere" p5 r5)
                 (setvar "clayer" "m6") (command "_sphere" p6 r6)
                 (setvar "clayer" "m7") (command "_sphere" p7 r7)
                 (setvar "clayer" "m8") (command "_sphere" p8 r8)
                 (setvar "clayer" "m9") (command "_sphere" p9 r9)
                 (setvar "clayer" "m0") (command "_sphere" p0 r0)
                 (setvar "clayer" "ma") (command "_sphere" pa ra)
                )
            )
        )
    )
    )
    (progn
             (command "_move" o1 "" p1 q1)
             (command "_move" o2 "" p2 q2)
             (command "_move" o3 "" p3 q3)
             (command "_move" o4 "" p4 q4)
             (command "_move" o5 "" p5 q5)
             (command "_move" o6 "" p6 q6)
             (command "_move" o7 "" p7 q7)
             (command "_move" o8 "" p8 q8)
             (command "_move" o9 "" p9 q9)
             (command "_move" o0 "" p0 q0)
             (command "_move" oa "" pa qa)
    )    
   )
    
   )

  )
 
  (setq p1 q1)
  (setq p2 q2)  
  (setq p3 q3)  
  (setq p4 q4)  
  (setq p5 q5)  
  (setq p6 q6)  
  (setq p7 q7)  
  (setq p8 q8)  
  (setq p9 q9)  
  (setq p0 q0)  
  (setq pa qa)  

  (setq iscan (+ 1 iscan))
  (if (= iscan scan) (setq iscan 0))

 )
 (setvar "clayer" "0")
 (command "_pline" p1 p2 p3 p4 p5 p6 p7 p8 p9 p0 pa p1 "")
)


;;;*****************************************************************
;simula il moto di 10 oggetti sottoposti a forza gravitazionale
;gravita12 ver 1.5 23/07/2010
;Dott. Ing. Emanuele Ballasina
;cell 349-1813748
;mail ballacr75@libero.it

(defun c:gravita12 ()
(setvar "osmode" 0)
(setvar "dimzin" 0)
(setvar "cmdecho" 0)

(command "_-layer" "n" "m1" "_c" 10 "m1" "_s" "m1" "")
(command "_-layer" "n" "m2" "_c" 30 "m2" "_s" "m2" "")
(command "_-layer" "n" "m3" "_c" 50 "m3" "_s" "m3" "")
(command "_-layer" "n" "m4" "_c" 70 "m4" "_s" "m4" "")
(command "_-layer" "n" "m5" "_c" 90 "m5" "_s" "m5" "")
(command "_-layer" "n" "m6" "_c" 110 "m6" "_s" "m6" "")
(command "_-layer" "n" "m7" "_c" 130 "m7" "_s" "m7" "")
(command "_-layer" "n" "m8" "_c" 150 "m8" "_s" "m8" "")
(command "_-layer" "n" "m9" "_c" 170 "m9" "_s" "m9" "")
(command "_-layer" "n" "m0" "_c" 190 "m0" "_s" "m0" "")
(command "_-layer" "n" "ma" "_c" 210 "ma" "_s" "ma" "")
(command "_-layer" "n" "mb" "_c" 230 "mb" "_s" "mb" "")

(setq t 1) ;scansione tempo
(setq kdi 1) ;riduzione diametro cilindri
(setq scan 1) ;scansione posizione (non funziona >1 se ker=1)

(setq m1 100.0) ;massa
(setq m2 100.0)
(setq m3 100.0)
(setq m4 100.0)
(setq m5 100.0)
(setq m6 100.0)
(setq m7 100.0)
(setq m8 100.0)
(setq m9 100.0)
(setq m0 100.0)
(setq ma 100.0)
(setq mb 100.0)
(setq d1 0.1) ;densita
(setq d2 0.1)
(setq d3 0.1) 
(setq d4 0.1)
(setq d5 0.1)
(setq d6 0.1)
(setq d7 0.1)
(setq d8 0.1)
(setq d9 0.1)
(setq d0 0.1)
(setq da 0.1)
(setq db 0.1)
(setq r1 (expt (/ m1 d1) 0.3333)) ;raggio
(setq r2 (expt (/ m2 d2) 0.3333))
(setq r3 (expt (/ m3 d3) 0.3333))
(setq r4 (expt (/ m4 d4) 0.3333))
(setq r5 (expt (/ m5 d5) 0.3333))
(setq r6 (expt (/ m6 d6) 0.3333))
(setq r7 (expt (/ m7 d7) 0.3333))
(setq r8 (expt (/ m8 d8) 0.3333))
(setq r9 (expt (/ m9 d9) 0.3333))
(setq r0 (expt (/ m0 d0) 0.3333))
(setq ra (expt (/ ma da) 0.3333))
(setq rb (expt (/ mb db) 0.3333))
(setq r12 (+ r1 r2)) ;distanza di sfioro
(setq r13 (+ r1 r3))
(setq r23 (+ r2 r3))
(setq r14 (+ r1 r4))
(setq r24 (+ r2 r4))
(setq r34 (+ r3 r4))
(setq r15 (+ r1 r5))
(setq r25 (+ r2 r5))
(setq r35 (+ r3 r5))
(setq r45 (+ r4 r5))
(setq r16 (+ r1 r6))
(setq r26 (+ r2 r6))
(setq r36 (+ r3 r6))
(setq r46 (+ r4 r6))
(setq r56 (+ r5 r6))
(setq r17 (+ r1 r7))
(setq r27 (+ r2 r7))
(setq r37 (+ r3 r7))
(setq r47 (+ r4 r7))
(setq r57 (+ r5 r7))
(setq r67 (+ r6 r7))
(setq r18 (+ r1 r8))
(setq r28 (+ r2 r8))
(setq r38 (+ r3 r8))
(setq r48 (+ r4 r8))
(setq r58 (+ r5 r8))
(setq r68 (+ r6 r8))
(setq r78 (+ r7 r8))
(setq r19 (+ r1 r9))
(setq r29 (+ r2 r9))
(setq r39 (+ r3 r9))
(setq r49 (+ r4 r9))
(setq r59 (+ r5 r9))
(setq r69 (+ r6 r9))
(setq r79 (+ r7 r9))
(setq r89 (+ r8 r9))
(setq r10 (+ r1 r0))
(setq r20 (+ r2 r0))
(setq r30 (+ r3 r0))
(setq r40 (+ r4 r0))
(setq r50 (+ r5 r0))
(setq r60 (+ r6 r0))
(setq r70 (+ r7 r0))
(setq r80 (+ r8 r0))
(setq r90 (+ r9 r0))
(setq r1a (+ r1 ra))
(setq r2a (+ r2 ra))
(setq r3a (+ r3 ra))
(setq r4a (+ r4 ra))
(setq r5a (+ r5 ra))
(setq r6a (+ r6 ra))
(setq r7a (+ r7 ra))
(setq r8a (+ r8 ra))
(setq r9a (+ r9 ra))
(setq r0a (+ r0 ra))
(setq r1b (+ r1 rb))
(setq r2b (+ r2 rb))
(setq r3b (+ r3 rb))
(setq r4b (+ r4 rb))
(setq r5b (+ r5 rb))
(setq r6b (+ r6 rb))
(setq r7b (+ r7 rb))
(setq r8b (+ r8 rb))
(setq r9b (+ r9 rb))
(setq r0b (+ r0 rb))
(setq rab (+ ra rb))

(setq k1 1) ;abilita movimento pianeta
(setq k2 1)
(setq k3 1)
(setq k4 1)
(setq k5 1)
(setq k6 1)
(setq k7 1)
(setq k8 1)
(setq k9 1)
(setq k0 1)
(setq ka 1)
(setq kb 1)
(setq kur 1) ;abilita urti, con coefficente di rimbalzo, <1 smorza
(setq kbi 1) ;abilita rimbalzo tipo biliardo contro pareti dello schermo, <1 smorza
(setq ker 1) ;1=cancella pianeti vecchi, 0=mantiene tutti i pianeti
(setq c (getvar "VIEWCTR"))
(setq xsc (car c))
(setq ysc (cadr c))
(setq zsc (caddr c))
(setq currh (getvar "viewsize"))
(setq sizex (nth 0 (getvar "screensize")))
(setq sizey (nth 1 (getvar "screensize")))
(setq j (/ sizex sizey))
(setq currw (* j currh))
(setq h2 (/ currh 2.0))
(setq w2 (/ currw 2.0))
(setq xsa (- xsc w2))
(setq ysa (- ysc h2))
(setq zsa (- zsc h2))
(setq xsb (+ xsc w2))
(setq ysb (+ ysc h2))
(setq zsb (+ zsc h2))
(if (/= kbi 0) (command "_rectangle" (list xsa ysa) (list xsb ysb)))

(setq pc "c") ;punti,cerchi,sfere
(setq lc "n") ;abilita disegno linee tra un pianeta e gli altri
(setq tc "n") ;abilita disegno linee traiettoria

(setq x1 0) ;posizione
(setq y1 0)
(setq z1 0)
(setq x2 100)
(setq y2 0)
(setq z2 0)
(setq x3 200)
(setq y3 0)
(setq z3 0)
(setq x4 300)
(setq y4 0)
(setq z4 0)
(setq x5 400)
(setq y5 0)
(setq z5 0)
(setq x6 500)
(setq y6 0)
(setq z6 0)
(setq x7 600)
(setq y7 0) 
(setq z7 0) 
(setq x8 700) 
(setq y8 0) 
(setq z8 0) 
(setq x9 800) 
(setq y9 0) 
(setq z9 0) 
(setq x0 900) 
(setq y0 0) 
(setq z0 0) 
(setq xa 1000) 
(setq ya 0) 
(setq za 0) 
(setq xb 1100) 
(setq yb 0) 
(setq zb 0) 

(setq v1x 0.0) ;velocita
(setq v1y 0.0)
(setq v1z 0.0)
(setq v2x 0.0)
(setq v2y 0.0)
(setq v2z 0.0)
(setq v3x 0.0)
(setq v3y 0.0)
(setq v3z 0.0)
(setq v4x 0.0)
(setq v4y 0.0)
(setq v4z 0.0)
(setq v5x 0.0)
(setq v5y 0.0)
(setq v5z 0.0) 
(setq v6x 0.0)
(setq v6y 0.0)
(setq v6z 0.0)
(setq v7x 0.0)
(setq v7y 0.0)
(setq v7z 0.0)
(setq v8x 0.0)
(setq v8y 0.0)
(setq v8z 0.0)
(setq v9x 0.0)
(setq v9y 0.0)
(setq v9z 0.0)
(setq v0x 0.0)
(setq v0y 0.0)
(setq v0z 0.0)
(setq vax 0.0)
(setq vay 0.0)
(setq vaz 0.0)
(setq vbx 0.0)
(setq vby 0.0)
(setq vbz 0.0)

(setq p1 (list x1 y1 z1))
(setq p2 (list x2 y2 z2))
(setq p3 (list x3 y3 z3))
(setq p4 (list x4 y4 z4))
(setq p5 (list x5 y5 z5))
(setq p6 (list x6 y6 z6))
(setq p7 (list x7 y7 z7))
(setq p8 (list x8 y8 z8))
(setq p9 (list x9 y9 z9))
(setq p0 (list x0 y0 z0))
(setq pa (list xa ya za))
(setq pb (list xb yb zb))

(if (= pc "p")
    (progn
     (setvar "clayer" "m1") (command "_point" p1) (setq o1 (cdr (car (entget (entlast)))))
     (setvar "clayer" "m2") (command "_point" p2) (setq o2 (cdr (car (entget (entlast)))))
     (setvar "clayer" "m3") (command "_point" p3) (setq o3 (cdr (car (entget (entlast)))))
     (setvar "clayer" "m4") (command "_point" p4) (setq o4 (cdr (car (entget (entlast)))))
     (setvar "clayer" "m5") (command "_point" p5) (setq o5 (cdr (car (entget (entlast)))))
     (setvar "clayer" "m6") (command "_point" p6) (setq o6 (cdr (car (entget (entlast)))))
     (setvar "clayer" "m7") (command "_point" p7) (setq o7 (cdr (car (entget (entlast)))))
     (setvar "clayer" "m8") (command "_point" p8) (setq o8 (cdr (car (entget (entlast)))))
     (setvar "clayer" "m9") (command "_point" p9) (setq o9 (cdr (car (entget (entlast)))))
     (setvar "clayer" "m0") (command "_point" p0) (setq o0 (cdr (car (entget (entlast)))))
     (setvar "clayer" "ma") (command "_point" pa) (setq oa (cdr (car (entget (entlast)))))
     (setvar "clayer" "mb") (command "_point" pb) (setq ob (cdr (car (entget (entlast)))))
    )
    (if (= pc "c")
        (progn
         (setvar "clayer" "m1") (command "_circle" p1 r1) (setq o1 (cdr (car (entget (entlast)))))
         (setvar "clayer" "m2") (command "_circle" p2 r2) (setq o2 (cdr (car (entget (entlast)))))
         (setvar "clayer" "m3") (command "_circle" p3 r3) (setq o3 (cdr (car (entget (entlast)))))
         (setvar "clayer" "m4") (command "_circle" p4 r4) (setq o4 (cdr (car (entget (entlast)))))
         (setvar "clayer" "m5") (command "_circle" p5 r5) (setq o5 (cdr (car (entget (entlast)))))
         (setvar "clayer" "m6") (command "_circle" p6 r6) (setq o6 (cdr (car (entget (entlast)))))
         (setvar "clayer" "m7") (command "_circle" p7 r7) (setq o7 (cdr (car (entget (entlast)))))
         (setvar "clayer" "m8") (command "_circle" p8 r8) (setq o8 (cdr (car (entget (entlast)))))
         (setvar "clayer" "m9") (command "_circle" p9 r9) (setq o9 (cdr (car (entget (entlast)))))
         (setvar "clayer" "m0") (command "_circle" p0 r0) (setq o0 (cdr (car (entget (entlast)))))
         (setvar "clayer" "ma") (command "_circle" pa ra) (setq oa (cdr (car (entget (entlast)))))
         (setvar "clayer" "mb") (command "_circle" pb rb) (setq ob (cdr (car (entget (entlast)))))
        )
        (if (= pc "s")
            (progn
             (setvar "clayer" "m1") (command "_sphere" p1 r1) (setq o1 (cdr (car (entget (entlast)))))
             (setvar "clayer" "m2") (command "_sphere" p2 r2) (setq o2 (cdr (car (entget (entlast)))))
             (setvar "clayer" "m3") (command "_sphere" p3 r3) (setq o3 (cdr (car (entget (entlast)))))
             (setvar "clayer" "m4") (command "_sphere" p4 r4) (setq o4 (cdr (car (entget (entlast)))))
             (setvar "clayer" "m5") (command "_sphere" p5 r5) (setq o5 (cdr (car (entget (entlast)))))
             (setvar "clayer" "m6") (command "_sphere" p6 r6) (setq o6 (cdr (car (entget (entlast)))))
             (setvar "clayer" "m7") (command "_sphere" p7 r7) (setq o7 (cdr (car (entget (entlast)))))
             (setvar "clayer" "m8") (command "_sphere" p8 r8) (setq o8 (cdr (car (entget (entlast)))))
             (setvar "clayer" "m9") (command "_sphere" p9 r9) (setq o9 (cdr (car (entget (entlast)))))
             (setvar "clayer" "m0") (command "_sphere" p0 r0) (setq o0 (cdr (car (entget (entlast)))))
             (setvar "clayer" "ma") (command "_sphere" pa ra) (setq oa (cdr (car (entget (entlast)))))
             (setvar "clayer" "mb") (command "_sphere" pb rb) (setq ob (cdr (car (entget (entlast)))))
            )
        )
    )
)

(setq va 1000)
(setq iscan 0)
 (while (> va 0.0001) ;scansione velocit ed accelerazione, se = 0 si ferma il lisp

  (setq v1 (sqrt (+ (* v1x v1x) (* v1y v1y) (* v1z v1z))))
  (setq v2 (sqrt (+ (* v2x v2x) (* v2y v2y) (* v2z v2z))))
  (setq v3 (sqrt (+ (* v3x v3x) (* v3y v3y) (* v3z v3z))))
  (setq v4 (sqrt (+ (* v4x v4x) (* v4y v4y) (* v4z v4z))))
  (setq v5 (sqrt (+ (* v5x v5x) (* v5y v5y) (* v5z v5z))))
  (setq v6 (sqrt (+ (* v6x v6x) (* v6y v6y) (* v6z v6z))))
  (setq v7 (sqrt (+ (* v7x v7x) (* v7y v7y) (* v7z v7z))))
  (setq v8 (sqrt (+ (* v8x v8x) (* v8y v8y) (* v8z v8z))))
  (setq v9 (sqrt (+ (* v9x v9x) (* v9y v9y) (* v9z v9z))))
  (setq v0 (sqrt (+ (* v0x v0x) (* v0y v0y) (* v0z v0z))))
  (setq va (sqrt (+ (* vax vax) (* vay vay) (* vaz vaz))))
  (setq vb (sqrt (+ (* vbx vbx) (* vby vby) (* vbz vbz))))
  
  (setq d12 (distance p1 p2))
  (setq d13 (distance p1 p3))
  (setq d23 (distance p2 p3))
  (setq d14 (distance p1 p4))
  (setq d24 (distance p2 p4))
  (setq d34 (distance p3 p4))
  (setq d15 (distance p1 p5))
  (setq d25 (distance p2 p5))
  (setq d35 (distance p3 p5))
  (setq d45 (distance p4 p5))
  (setq d16 (distance p1 p6))
  (setq d26 (distance p2 p6))
  (setq d36 (distance p3 p6))
  (setq d46 (distance p4 p6))
  (setq d56 (distance p5 p6))
  (setq d17 (distance p1 p7))
  (setq d27 (distance p2 p7))
  (setq d37 (distance p3 p7))
  (setq d47 (distance p4 p7))
  (setq d57 (distance p5 p7))
  (setq d67 (distance p6 p7))
  (setq d18 (distance p1 p8))
  (setq d28 (distance p2 p8))
  (setq d38 (distance p3 p8))
  (setq d48 (distance p4 p8))
  (setq d58 (distance p5 p8))
  (setq d68 (distance p6 p8))
  (setq d78 (distance p7 p8))
  (setq d19 (distance p1 p9))
  (setq d29 (distance p2 p9))
  (setq d39 (distance p3 p9))
  (setq d49 (distance p4 p9))
  (setq d59 (distance p5 p9))
  (setq d69 (distance p6 p9))
  (setq d79 (distance p7 p9))
  (setq d89 (distance p8 p9))
  (setq d10 (distance p1 p0))
  (setq d20 (distance p2 p0))
  (setq d30 (distance p3 p0))
  (setq d40 (distance p4 p0))
  (setq d50 (distance p5 p0))
  (setq d60 (distance p6 p0))
  (setq d70 (distance p7 p0))
  (setq d80 (distance p8 p0))
  (setq d90 (distance p9 p0))
  (setq d1a (distance p1 pa))
  (setq d2a (distance p2 pa))
  (setq d3a (distance p3 pa))
  (setq d4a (distance p4 pa))
  (setq d5a (distance p5 pa))
  (setq d6a (distance p6 pa))
  (setq d7a (distance p7 pa))
  (setq d8a (distance p8 pa))
  (setq d9a (distance p9 pa))
  (setq d0a (distance p0 pa))
  (setq d1b (distance p1 pb))
  (setq d2b (distance p2 pb))
  (setq d3b (distance p3 pb))
  (setq d4b (distance p4 pb))
  (setq d5b (distance p5 pb))
  (setq d6b (distance p6 pb))
  (setq d7b (distance p7 pb))
  (setq d8b (distance p8 pb))
  (setq d9b (distance p9 pb))
  (setq d0b (distance p0 pb))
  (setq dab (distance pa pb))

  (setq dx12 (- x2 x1))  (setq dy12 (- y2 y1))  (setq dz12 (- z2 z1))
  (setq dx13 (- x3 x1))  (setq dy13 (- y3 y1))  (setq dz13 (- z3 z1))
  (setq dx23 (- x3 x2))  (setq dy23 (- y3 y2))  (setq dz23 (- z3 z2))
  (setq dx14 (- x4 x1))  (setq dy14 (- y4 y1))  (setq dz14 (- z4 z1))
  (setq dx24 (- x4 x2))  (setq dy24 (- y4 y2))  (setq dz24 (- z4 z2))
  (setq dx34 (- x4 x3))  (setq dy34 (- y4 y3))  (setq dz34 (- z4 z3))
  (setq dx15 (- x5 x1))  (setq dy15 (- y5 y1))  (setq dz15 (- z5 z1))
  (setq dx25 (- x5 x2))  (setq dy25 (- y5 y2))  (setq dz25 (- z5 z2))
  (setq dx35 (- x5 x3))  (setq dy35 (- y5 y3))  (setq dz35 (- z5 z3))
  (setq dx45 (- x5 x4))  (setq dy45 (- y5 y4))  (setq dz45 (- z5 z4))
  (setq dx16 (- x6 x1))  (setq dy16 (- y6 y1))  (setq dz16 (- z6 z1))
  (setq dx26 (- x6 x2))  (setq dy26 (- y6 y2))  (setq dz26 (- z6 z2))
  (setq dx36 (- x6 x3))  (setq dy36 (- y6 y3))  (setq dz36 (- z6 z3))
  (setq dx46 (- x6 x4))  (setq dy46 (- y6 y4))  (setq dz46 (- z6 z4))
  (setq dx56 (- x6 x5))  (setq dy56 (- y6 y5))  (setq dz56 (- z6 z5))
  (setq dx17 (- x7 x1))  (setq dy17 (- y7 y1))  (setq dz17 (- z7 z1))
  (setq dx27 (- x7 x2))  (setq dy27 (- y7 y2))  (setq dz27 (- z7 z2))
  (setq dx37 (- x7 x3))  (setq dy37 (- y7 y3))  (setq dz37 (- z7 z3))
  (setq dx47 (- x7 x4))  (setq dy47 (- y7 y4))  (setq dz47 (- z7 z4))
  (setq dx57 (- x7 x5))  (setq dy57 (- y7 y5))  (setq dz57 (- z7 z5))
  (setq dx67 (- x7 x6))  (setq dy67 (- y7 y6))  (setq dz67 (- z7 z6))
  (setq dx18 (- x8 x1))  (setq dy18 (- y8 y1))  (setq dz18 (- z8 z1))
  (setq dx28 (- x8 x2))  (setq dy28 (- y8 y2))  (setq dz28 (- z8 z2))
  (setq dx38 (- x8 x3))  (setq dy38 (- y8 y3))  (setq dz38 (- z8 z3))
  (setq dx48 (- x8 x4))  (setq dy48 (- y8 y4))  (setq dz48 (- z8 z4))
  (setq dx58 (- x8 x5))  (setq dy58 (- y8 y5))  (setq dz58 (- z8 z5))
  (setq dx68 (- x8 x6))  (setq dy68 (- y8 y6))  (setq dz68 (- z8 z6))
  (setq dx78 (- x8 x7))  (setq dy78 (- y8 y7))  (setq dz78 (- z8 z7))
  (setq dx19 (- x9 x1))  (setq dy19 (- y9 y1))  (setq dz19 (- z9 z1))
  (setq dx29 (- x9 x2))  (setq dy29 (- y9 y2))  (setq dz29 (- z9 z2))
  (setq dx39 (- x9 x3))  (setq dy39 (- y9 y3))  (setq dz39 (- z9 z3))
  (setq dx49 (- x9 x4))  (setq dy49 (- y9 y4))  (setq dz49 (- z9 z4))
  (setq dx59 (- x9 x5))  (setq dy59 (- y9 y5))  (setq dz59 (- z9 z5))
  (setq dx69 (- x9 x6))  (setq dy69 (- y9 y6))  (setq dz69 (- z9 z6))
  (setq dx79 (- x9 x7))  (setq dy79 (- y9 y7))  (setq dz79 (- z9 z7))
  (setq dx89 (- x9 x8))  (setq dy89 (- y9 y8))  (setq dz89 (- z9 z8))
  (setq dx10 (- x0 x1))  (setq dy10 (- y0 y1))  (setq dz10 (- z0 z1))
  (setq dx20 (- x0 x2))  (setq dy20 (- y0 y2))  (setq dz20 (- z0 z2))
  (setq dx30 (- x0 x3))  (setq dy30 (- y0 y3))  (setq dz30 (- z0 z3))
  (setq dx40 (- x0 x4))  (setq dy40 (- y0 y4))  (setq dz40 (- z0 z4))
  (setq dx50 (- x0 x5))  (setq dy50 (- y0 y5))  (setq dz50 (- z0 z5))
  (setq dx60 (- x0 x6))  (setq dy60 (- y0 y6))  (setq dz60 (- z0 z6))
  (setq dx70 (- x0 x7))  (setq dy70 (- y0 y7))  (setq dz70 (- z0 z7))
  (setq dx80 (- x0 x8))  (setq dy80 (- y0 y8))  (setq dz80 (- z0 z8))
  (setq dx90 (- x0 x9))  (setq dy90 (- y0 y9))  (setq dz90 (- z0 z9))
  (setq dx1a (- xa x1))  (setq dy1a (- ya y1))  (setq dz1a (- za z1))
  (setq dx2a (- xa x2))  (setq dy2a (- ya y2))  (setq dz2a (- za z2))
  (setq dx3a (- xa x3))  (setq dy3a (- ya y3))  (setq dz3a (- za z3))
  (setq dx4a (- xa x4))  (setq dy4a (- ya y4))  (setq dz4a (- za z4))
  (setq dx5a (- xa x5))  (setq dy5a (- ya y5))  (setq dz5a (- za z5))
  (setq dx6a (- xa x6))  (setq dy6a (- ya y6))  (setq dz6a (- za z6))
  (setq dx7a (- xa x7))  (setq dy7a (- ya y7))  (setq dz7a (- za z7))
  (setq dx8a (- xa x8))  (setq dy8a (- ya y8))  (setq dz8a (- za z8))
  (setq dx9a (- xa x9))  (setq dy9a (- ya y9))  (setq dz9a (- za z9))
  (setq dx0a (- xa x0))  (setq dy0a (- ya y0))  (setq dz0a (- za z0))
  (setq dx1b (- xb x1))  (setq dy1b (- yb y1))  (setq dz1b (- zb z1))
  (setq dx2b (- xb x2))  (setq dy2b (- yb y2))  (setq dz2b (- zb z2))
  (setq dx3b (- xb x3))  (setq dy3b (- yb y3))  (setq dz3b (- zb z3))
  (setq dx4b (- xb x4))  (setq dy4b (- yb y4))  (setq dz4b (- zb z4))
  (setq dx5b (- xb x5))  (setq dy5b (- yb y5))  (setq dz5b (- zb z5))
  (setq dx6b (- xb x6))  (setq dy6b (- yb y6))  (setq dz6b (- zb z6))
  (setq dx7b (- xb x7))  (setq dy7b (- yb y7))  (setq dz7b (- zb z7))
  (setq dx8b (- xb x8))  (setq dy8b (- yb y8))  (setq dz8b (- zb z8))
  (setq dx9b (- xb x9))  (setq dy9b (- yb y9))  (setq dz9b (- zb z9))
  (setq dx0b (- xb x0))  (setq dy0b (- yb y0))  (setq dz0b (- zb z0))
  (setq dxab (- xb xa))  (setq dyab (- yb ya))  (setq dzab (- zb za))

;                   GRAVITA              REPULSIONE           ELASTICO       MOLLA
  (if (<= d12 r12) (setq d12 r12))
  (if (<= d13 r13) (setq d13 r13))
  (if (<= d23 r23) (setq d23 r23))
  (if (<= d14 r14) (setq d14 r14))
  (if (<= d24 r24) (setq d24 r24))
  (if (<= d34 r34) (setq d34 r34))
  (if (<= d15 r15) (setq d15 r15))
  (if (<= d25 r25) (setq d25 r25))
  (if (<= d35 r35) (setq d35 r35))
  (if (<= d45 r45) (setq d45 r45))
  (if (<= d16 r16) (setq d16 r16))
  (if (<= d26 r26) (setq d26 r26))
  (if (<= d36 r36) (setq d36 r36))
  (if (<= d46 r46) (setq d46 r46))
  (if (<= d56 r56) (setq d56 r56))
  (if (<= d17 r17) (setq d17 r17))
  (if (<= d27 r27) (setq d27 r27))
  (if (<= d37 r37) (setq d37 r37))
  (if (<= d47 r47) (setq d47 r47))
  (if (<= d57 r57) (setq d57 r57))
  (if (<= d67 r67) (setq d67 r67))
  (if (<= d18 r18) (setq d18 r18))
  (if (<= d28 r28) (setq d28 r28))
  (if (<= d38 r38) (setq d38 r38))
  (if (<= d48 r48) (setq d48 r48))
  (if (<= d58 r58) (setq d58 r58))
  (if (<= d68 r68) (setq d68 r68))
  (if (<= d78 r78) (setq d78 r78))
  (if (<= d19 r19) (setq d19 r19))
  (if (<= d29 r29) (setq d29 r29))
  (if (<= d39 r39) (setq d39 r39))
  (if (<= d49 r49) (setq d49 r49))
  (if (<= d59 r59) (setq d59 r59))
  (if (<= d69 r69) (setq d69 r69))
  (if (<= d79 r79) (setq d79 r79))
  (if (<= d89 r89) (setq d89 r89))
  (if (<= d10 r10) (setq d10 r10))
  (if (<= d20 r20) (setq d20 r20))
  (if (<= d30 r30) (setq d30 r30))
  (if (<= d40 r40) (setq d40 r40))
  (if (<= d50 r50) (setq d50 r50))
  (if (<= d60 r60) (setq d60 r60))
  (if (<= d70 r70) (setq d70 r70))
  (if (<= d80 r80) (setq d80 r80))
  (if (<= d90 r90) (setq d90 r90))
  (if (<= d1a r1a) (setq d1a r1a))
  (if (<= d2a r2a) (setq d2a r2a))
  (if (<= d3a r3a) (setq d3a r3a))
  (if (<= d4a r4a) (setq d4a r4a))
  (if (<= d5a r5a) (setq d5a r5a))
  (if (<= d6a r6a) (setq d6a r6a))
  (if (<= d7a r7a) (setq d7a r7a))
  (if (<= d8a r8a) (setq d8a r8a))
  (if (<= d9a r9a) (setq d9a r9a))
  (if (<= d0a r0a) (setq d0a r0a))
  (if (<= d1b r1b) (setq d1b r1b))
  (if (<= d2b r2b) (setq d2b r2b))
  (if (<= d3b r3b) (setq d3b r3b))
  (if (<= d4b r4b) (setq d4b r4b))
  (if (<= d5b r5b) (setq d5b r5b))
  (if (<= d6b r6b) (setq d6b r6b))
  (if (<= d7b r7b) (setq d7b r7b))
  (if (<= d8b r8b) (setq d8b r8b))
  (if (<= d9b r9b) (setq d9b r9b))
  (if (<= d0b r0b) (setq d0b r0b))
  (if (<= dab rab) (setq dab rab))
  (setq f12 (+ (* 1 (fgr m1 m2 d12)) (* 1 (fre m1 m2 d12)) (* 1 (fel d12)) (* 1 (fmo d12)) ))
  (setq f13 (+ (* 1 (fgr m1 m3 d13)) (* 1 (fre m1 m3 d13)) (* 1 (fel d13)) (* 1 (fmo d13)) ))
  (setq f23 (+ (* 1 (fgr m2 m3 d23)) (* 1 (fre m2 m3 d23)) (* 1 (fel d23)) (* 1 (fmo d23)) ))
  (setq f14 (+ (* 1 (fgr m1 m4 d14)) (* 1 (fre m1 m4 d14)) (* 1 (fel d14)) (* 1 (fmo d14)) ))
  (setq f24 (+ (* 1 (fgr m2 m4 d24)) (* 1 (fre m2 m4 d24)) (* 1 (fel d24)) (* 1 (fmo d24)) ))
  (setq f34 (+ (* 1 (fgr m3 m4 d34)) (* 1 (fre m3 m4 d34)) (* 1 (fel d34)) (* 1 (fmo d34)) ))
  (setq f15 (+ (* 1 (fgr m1 m5 d15)) (* 1 (fre m1 m5 d15)) (* 1 (fel d15)) (* 1 (fmo d15)) ))
  (setq f25 (+ (* 1 (fgr m2 m5 d25)) (* 1 (fre m2 m5 d25)) (* 1 (fel d25)) (* 1 (fmo d25)) ))
  (setq f35 (+ (* 1 (fgr m3 m5 d35)) (* 1 (fre m3 m5 d35)) (* 1 (fel d35)) (* 1 (fmo d35)) ))
  (setq f45 (+ (* 1 (fgr m4 m5 d45)) (* 1 (fre m4 m5 d45)) (* 1 (fel d45)) (* 1 (fmo d45)) ))
  (setq f16 (+ (* 1 (fgr m1 m6 d16)) (* 1 (fre m1 m6 d16)) (* 1 (fel d16)) (* 1 (fmo d16)) ))
  (setq f26 (+ (* 1 (fgr m2 m6 d26)) (* 1 (fre m2 m6 d26)) (* 1 (fel d26)) (* 1 (fmo d26)) ))
  (setq f36 (+ (* 1 (fgr m3 m6 d36)) (* 1 (fre m3 m6 d36)) (* 1 (fel d36)) (* 1 (fmo d36)) ))
  (setq f46 (+ (* 1 (fgr m4 m6 d46)) (* 1 (fre m4 m6 d46)) (* 1 (fel d46)) (* 1 (fmo d46)) ))
  (setq f56 (+ (* 1 (fgr m5 m6 d56)) (* 1 (fre m5 m6 d56)) (* 1 (fel d56)) (* 1 (fmo d56)) ))
  (setq f17 (+ (* 1 (fgr m1 m7 d17)) (* 1 (fre m1 m7 d17)) (* 1 (fel d17)) (* 1 (fmo d17)) ))
  (setq f27 (+ (* 1 (fgr m2 m7 d27)) (* 1 (fre m2 m7 d27)) (* 1 (fel d27)) (* 1 (fmo d27)) ))
  (setq f37 (+ (* 1 (fgr m3 m7 d37)) (* 1 (fre m3 m7 d37)) (* 1 (fel d37)) (* 1 (fmo d37)) ))
  (setq f47 (+ (* 1 (fgr m4 m7 d47)) (* 1 (fre m4 m7 d47)) (* 1 (fel d47)) (* 1 (fmo d47)) ))
  (setq f57 (+ (* 1 (fgr m5 m7 d57)) (* 1 (fre m5 m7 d57)) (* 1 (fel d57)) (* 1 (fmo d57)) ))
  (setq f67 (+ (* 1 (fgr m6 m7 d67)) (* 1 (fre m6 m7 d67)) (* 1 (fel d67)) (* 1 (fmo d67)) ))
  (setq f18 (+ (* 1 (fgr m1 m8 d18)) (* 1 (fre m1 m8 d18)) (* 1 (fel d18)) (* 1 (fmo d18)) ))
  (setq f28 (+ (* 1 (fgr m2 m8 d28)) (* 1 (fre m2 m8 d28)) (* 1 (fel d28)) (* 1 (fmo d28)) ))
  (setq f38 (+ (* 1 (fgr m3 m8 d38)) (* 1 (fre m3 m8 d38)) (* 1 (fel d38)) (* 1 (fmo d38)) ))
  (setq f48 (+ (* 1 (fgr m4 m8 d48)) (* 1 (fre m4 m8 d48)) (* 1 (fel d48)) (* 1 (fmo d48)) ))
  (setq f58 (+ (* 1 (fgr m5 m8 d58)) (* 1 (fre m5 m8 d58)) (* 1 (fel d58)) (* 1 (fmo d58)) ))
  (setq f68 (+ (* 1 (fgr m6 m8 d68)) (* 1 (fre m6 m8 d68)) (* 1 (fel d68)) (* 1 (fmo d68)) ))
  (setq f78 (+ (* 1 (fgr m7 m8 d78)) (* 1 (fre m7 m8 d78)) (* 1 (fel d78)) (* 1 (fmo d78)) ))
  (setq f19 (+ (* 1 (fgr m1 m9 d19)) (* 1 (fre m1 m9 d19)) (* 1 (fel d19)) (* 1 (fmo d19)) ))
  (setq f29 (+ (* 1 (fgr m2 m9 d29)) (* 1 (fre m2 m9 d29)) (* 1 (fel d29)) (* 1 (fmo d29)) ))
  (setq f39 (+ (* 1 (fgr m3 m9 d39)) (* 1 (fre m3 m9 d39)) (* 1 (fel d39)) (* 1 (fmo d39)) ))
  (setq f49 (+ (* 1 (fgr m4 m9 d49)) (* 1 (fre m4 m9 d49)) (* 1 (fel d49)) (* 1 (fmo d49)) ))
  (setq f59 (+ (* 1 (fgr m5 m9 d59)) (* 1 (fre m5 m9 d59)) (* 1 (fel d59)) (* 1 (fmo d59)) ))
  (setq f69 (+ (* 1 (fgr m6 m9 d69)) (* 1 (fre m6 m9 d69)) (* 1 (fel d69)) (* 1 (fmo d69)) ))
  (setq f79 (+ (* 1 (fgr m7 m9 d79)) (* 1 (fre m7 m9 d79)) (* 1 (fel d79)) (* 1 (fmo d79)) ))
  (setq f89 (+ (* 1 (fgr m8 m9 d89)) (* 1 (fre m8 m9 d89)) (* 1 (fel d89)) (* 1 (fmo d89)) ))
  (setq f10 (+ (* 1 (fgr m1 m0 d10)) (* 1 (fre m1 m0 d10)) (* 1 (fel d10)) (* 1 (fmo d10)) ))
  (setq f20 (+ (* 1 (fgr m2 m0 d20)) (* 1 (fre m2 m0 d20)) (* 1 (fel d20)) (* 1 (fmo d20)) ))
  (setq f30 (+ (* 1 (fgr m3 m0 d30)) (* 1 (fre m3 m0 d30)) (* 1 (fel d30)) (* 1 (fmo d30)) ))
  (setq f40 (+ (* 1 (fgr m4 m0 d40)) (* 1 (fre m4 m0 d40)) (* 1 (fel d40)) (* 1 (fmo d40)) ))
  (setq f50 (+ (* 1 (fgr m5 m0 d50)) (* 1 (fre m5 m0 d50)) (* 1 (fel d50)) (* 1 (fmo d50)) ))
  (setq f60 (+ (* 1 (fgr m6 m0 d60)) (* 1 (fre m6 m0 d60)) (* 1 (fel d60)) (* 1 (fmo d60)) ))
  (setq f70 (+ (* 1 (fgr m7 m0 d70)) (* 1 (fre m7 m0 d70)) (* 1 (fel d70)) (* 1 (fmo d70)) ))
  (setq f80 (+ (* 1 (fgr m8 m0 d80)) (* 1 (fre m8 m0 d80)) (* 1 (fel d80)) (* 1 (fmo d80)) ))
  (setq f90 (+ (* 1 (fgr m9 m0 d90)) (* 1 (fre m9 m0 d90)) (* 1 (fel d90)) (* 1 (fmo d90)) ))
  (setq f1a (+ (* 1 (fgr m1 ma d1a)) (* 1 (fre m1 ma d1a)) (* 1 (fel d1a)) (* 1 (fmo d1a)) ))
  (setq f2a (+ (* 1 (fgr m2 ma d2a)) (* 1 (fre m2 ma d2a)) (* 1 (fel d2a)) (* 1 (fmo d2a)) ))
  (setq f3a (+ (* 1 (fgr m3 ma d3a)) (* 1 (fre m3 ma d3a)) (* 1 (fel d3a)) (* 1 (fmo d3a)) ))
  (setq f4a (+ (* 1 (fgr m4 ma d4a)) (* 1 (fre m4 ma d4a)) (* 1 (fel d4a)) (* 1 (fmo d4a)) ))
  (setq f5a (+ (* 1 (fgr m5 ma d5a)) (* 1 (fre m5 ma d5a)) (* 1 (fel d5a)) (* 1 (fmo d5a)) ))
  (setq f6a (+ (* 1 (fgr m6 ma d6a)) (* 1 (fre m6 ma d6a)) (* 1 (fel d6a)) (* 1 (fmo d6a)) ))
  (setq f7a (+ (* 1 (fgr m7 ma d7a)) (* 1 (fre m7 ma d7a)) (* 1 (fel d7a)) (* 1 (fmo d7a)) ))
  (setq f8a (+ (* 1 (fgr m8 ma d8a)) (* 1 (fre m8 ma d8a)) (* 1 (fel d8a)) (* 1 (fmo d8a)) ))
  (setq f9a (+ (* 1 (fgr m9 ma d9a)) (* 1 (fre m9 ma d9a)) (* 1 (fel d9a)) (* 1 (fmo d9a)) ))
  (setq f0a (+ (* 1 (fgr m0 ma d0a)) (* 1 (fre m0 ma d0a)) (* 1 (fel d0a)) (* 1 (fmo d0a)) ))
  (setq f1b (+ (* 1 (fgr m1 mb d1b)) (* 1 (fre m1 mb d1b)) (* 1 (fel d1b)) (* 1 (fmo d1b)) ))
  (setq f2b (+ (* 1 (fgr m2 mb d2b)) (* 1 (fre m2 mb d2b)) (* 1 (fel d2b)) (* 1 (fmo d2b)) ))
  (setq f3b (+ (* 1 (fgr m3 mb d3b)) (* 1 (fre m3 mb d3b)) (* 1 (fel d3b)) (* 1 (fmo d3b)) ))
  (setq f4b (+ (* 1 (fgr m4 mb d4b)) (* 1 (fre m4 mb d4b)) (* 1 (fel d4b)) (* 1 (fmo d4b)) ))
  (setq f5b (+ (* 1 (fgr m5 mb d5b)) (* 1 (fre m5 mb d5b)) (* 1 (fel d5b)) (* 1 (fmo d5b)) ))
  (setq f6b (+ (* 1 (fgr m6 mb d6b)) (* 1 (fre m6 mb d6b)) (* 1 (fel d6b)) (* 1 (fmo d6b)) ))
  (setq f7b (+ (* 1 (fgr m7 mb d7b)) (* 1 (fre m7 mb d7b)) (* 1 (fel d7b)) (* 1 (fmo d7b)) ))
  (setq f8b (+ (* 1 (fgr m8 mb d8b)) (* 1 (fre m8 mb d8b)) (* 1 (fel d8b)) (* 1 (fmo d8b)) ))
  (setq f9b (+ (* 1 (fgr m9 mb d9b)) (* 1 (fre m9 mb d9b)) (* 1 (fel d9b)) (* 1 (fmo d9b)) ))
  (setq f0b (+ (* 1 (fgr m0 mb d0b)) (* 1 (fre m0 mb d0b)) (* 1 (fel d0b)) (* 1 (fmo d0b)) ))
  (setq fab (+ (* 1 (fgr ma mb dab)) (* 1 (fre ma mb dab)) (* 1 (fel dab)) (* 1 (fmo dab)) ))

  (setq a12 (/ f12 m1))  (setq a21 (* -1 (/ f12 m2)))
  (setq a13 (/ f13 m1))  (setq a31 (* -1 (/ f13 m3)))
  (setq a23 (/ f23 m2))  (setq a32 (* -1 (/ f23 m3)))
  (setq a14 (/ f14 m1))  (setq a41 (* -1 (/ f14 m4)))
  (setq a24 (/ f24 m2))  (setq a42 (* -1 (/ f24 m4)))
  (setq a34 (/ f34 m3))  (setq a43 (* -1 (/ f34 m4)))
  (setq a15 (/ f15 m1))  (setq a51 (* -1 (/ f15 m5)))
  (setq a25 (/ f25 m2))  (setq a52 (* -1 (/ f25 m5)))
  (setq a35 (/ f35 m3))  (setq a53 (* -1 (/ f35 m5)))
  (setq a45 (/ f45 m4))  (setq a54 (* -1 (/ f45 m5)))
  (setq a16 (/ f16 m1))  (setq a61 (* -1 (/ f16 m6)))
  (setq a26 (/ f26 m2))  (setq a62 (* -1 (/ f26 m6)))
  (setq a36 (/ f36 m3))  (setq a63 (* -1 (/ f36 m6)))
  (setq a46 (/ f46 m4))  (setq a64 (* -1 (/ f46 m6)))
  (setq a56 (/ f56 m5))  (setq a65 (* -1 (/ f56 m6)))
  (setq a17 (/ f17 m1))  (setq a71 (* -1 (/ f17 m7)))
  (setq a27 (/ f27 m2))  (setq a72 (* -1 (/ f27 m7)))
  (setq a37 (/ f37 m3))  (setq a73 (* -1 (/ f37 m7)))
  (setq a47 (/ f47 m4))  (setq a74 (* -1 (/ f47 m7)))
  (setq a57 (/ f57 m5))  (setq a75 (* -1 (/ f57 m7)))
  (setq a67 (/ f67 m6))  (setq a76 (* -1 (/ f67 m7)))
  (setq a18 (/ f18 m1))  (setq a81 (* -1 (/ f18 m8)))
  (setq a28 (/ f28 m2))  (setq a82 (* -1 (/ f28 m8)))
  (setq a38 (/ f38 m3))  (setq a83 (* -1 (/ f38 m8)))
  (setq a48 (/ f48 m4))  (setq a84 (* -1 (/ f48 m8)))
  (setq a58 (/ f58 m5))  (setq a85 (* -1 (/ f58 m8)))
  (setq a68 (/ f68 m6))  (setq a86 (* -1 (/ f68 m8)))
  (setq a78 (/ f78 m7))  (setq a87 (* -1 (/ f78 m8)))
  (setq a19 (/ f19 m1))  (setq a91 (* -1 (/ f19 m9)))
  (setq a29 (/ f29 m2))  (setq a92 (* -1 (/ f29 m9)))
  (setq a39 (/ f39 m3))  (setq a93 (* -1 (/ f39 m9)))
  (setq a49 (/ f49 m4))  (setq a94 (* -1 (/ f49 m9)))
  (setq a59 (/ f59 m5))  (setq a95 (* -1 (/ f59 m9)))
  (setq a69 (/ f69 m6))  (setq a96 (* -1 (/ f69 m9)))
  (setq a79 (/ f79 m7))  (setq a97 (* -1 (/ f79 m9)))
  (setq a89 (/ f89 m8))  (setq a98 (* -1 (/ f89 m9)))
  (setq a10 (/ f10 m1))  (setq a01 (* -1 (/ f10 m0)))
  (setq a20 (/ f20 m2))  (setq a02 (* -1 (/ f20 m0)))
  (setq a30 (/ f30 m3))  (setq a03 (* -1 (/ f30 m0)))
  (setq a40 (/ f40 m4))  (setq a04 (* -1 (/ f40 m0)))
  (setq a50 (/ f50 m5))  (setq a05 (* -1 (/ f50 m0)))
  (setq a60 (/ f60 m6))  (setq a06 (* -1 (/ f60 m0)))
  (setq a70 (/ f70 m7))  (setq a07 (* -1 (/ f70 m0)))
  (setq a80 (/ f80 m8))  (setq a08 (* -1 (/ f80 m0)))
  (setq a90 (/ f90 m9))  (setq a09 (* -1 (/ f90 m0)))
  (setq a1a (/ f1a m1))  (setq aa1 (* -1 (/ f1a ma)))
  (setq a2a (/ f2a m2))  (setq aa2 (* -1 (/ f2a ma)))
  (setq a3a (/ f3a m3))  (setq aa3 (* -1 (/ f3a ma)))
  (setq a4a (/ f4a m4))  (setq aa4 (* -1 (/ f4a ma)))
  (setq a5a (/ f5a m5))  (setq aa5 (* -1 (/ f5a ma)))
  (setq a6a (/ f6a m6))  (setq aa6 (* -1 (/ f6a ma)))
  (setq a7a (/ f7a m7))  (setq aa7 (* -1 (/ f7a ma)))
  (setq a8a (/ f8a m8))  (setq aa8 (* -1 (/ f8a ma)))
  (setq a9a (/ f9a m9))  (setq aa9 (* -1 (/ f9a ma)))
  (setq a0a (/ f0a m0))  (setq aa0 (* -1 (/ f0a ma)))
  (setq a1b (/ f1b m1))  (setq ab1 (* -1 (/ f1b mb)))
  (setq a2b (/ f2b m2))  (setq ab2 (* -1 (/ f2b mb)))
  (setq a3b (/ f3b m3))  (setq ab3 (* -1 (/ f3b mb)))
  (setq a4b (/ f4b m4))  (setq ab4 (* -1 (/ f4b mb)))
  (setq a5b (/ f5b m5))  (setq ab5 (* -1 (/ f5b mb)))
  (setq a6b (/ f6b m6))  (setq ab6 (* -1 (/ f6b mb)))
  (setq a7b (/ f7b m7))  (setq ab7 (* -1 (/ f7b mb)))
  (setq a8b (/ f8b m8))  (setq ab8 (* -1 (/ f8b mb)))
  (setq a9b (/ f9b m9))  (setq ab9 (* -1 (/ f9b mb)))
  (setq a0b (/ f0b m0))  (setq ab0 (* -1 (/ f0b mb)))
  (setq aab (/ fab ma))  (setq aba (* -1 (/ fab mb)))
 
  (setq a1x (+ (* 1 (/ (fsx x1 y1 z1) m1)) (* 1 (/ (fwx r1) m1)) (* 1 v1x (/ (fvi m1 r1 v1) m1)) (/ (* a12 dx12) d12) (/ (* a13 dx13) d13) (/ (* a14 dx14) d14) (/ (* a15 dx15) d15) (/ (* a16 dx16) d16) (/ (* a17 dx17) d17) (/ (* a18 dx18) d18) (/ (* a19 dx19) d19) (/ (* a10 dx10) d10) (/ (* a1a dx1a) d1a) (/ (* a1b dx1b) d1b)))
  (setq a1y (+ (* 1 (/ (fsy x1 y1 z1) m1)) (* 1 (/ (fwy r1) m1)) (* 1 v1y (/ (fvi m1 r1 v1) m1)) (/ (* a12 dy12) d12) (/ (* a13 dy13) d13) (/ (* a14 dy14) d14) (/ (* a15 dy15) d15) (/ (* a16 dy16) d16) (/ (* a17 dy17) d17) (/ (* a18 dy18) d18) (/ (* a19 dy19) d19) (/ (* a10 dy10) d10) (/ (* a1a dy1a) d1a) (/ (* a1b dy1b) d1b)))
  (setq a1z (+ (* 1 (/ (fsz x1 y1 z1) m1)) (* 1 (/ (fwz r1) m1)) (* 1 v1z (/ (fvi m1 r1 v1) m1)) (/ (* a12 dz12) d12) (/ (* a13 dz13) d13) (/ (* a14 dz14) d14) (/ (* a15 dz15) d15) (/ (* a16 dz16) d16) (/ (* a17 dz17) d17) (/ (* a18 dz18) d18) (/ (* a19 dz19) d19) (/ (* a10 dz10) d10) (/ (* a1a dz1a) d1a) (/ (* a1b dz1b) d1b)))
  (setq a2x (+ (* 1 (/ (fsx x2 y2 z2) m2)) (* 1 (/ (fwx r2) m2)) (* 1 v2x (/ (fvi m2 r2 v2) m2)) (/ (* a21 dx12) d12) (/ (* a23 dx23) d23) (/ (* a24 dx24) d24) (/ (* a25 dx25) d25) (/ (* a26 dx26) d26) (/ (* a27 dx27) d27) (/ (* a28 dx28) d28) (/ (* a29 dx29) d29) (/ (* a20 dx20) d20) (/ (* a2a dx2a) d2a) (/ (* a2b dx2b) d2b)))
  (setq a2y (+ (* 1 (/ (fsy x2 y2 z2) m2)) (* 1 (/ (fwy r2) m2)) (* 1 v2y (/ (fvi m2 r2 v2) m2)) (/ (* a21 dy12) d12) (/ (* a23 dy23) d23) (/ (* a24 dy24) d24) (/ (* a25 dy25) d25) (/ (* a26 dy26) d26) (/ (* a27 dy27) d27) (/ (* a28 dy28) d28) (/ (* a29 dy29) d29) (/ (* a20 dy20) d20) (/ (* a2a dy2a) d2a) (/ (* a2b dy2b) d2b)))
  (setq a2z (+ (* 1 (/ (fsz x2 y2 z2) m2)) (* 1 (/ (fwz r2) m2)) (* 1 v2z (/ (fvi m2 r2 v2) m2)) (/ (* a21 dz12) d12) (/ (* a23 dz23) d23) (/ (* a24 dz24) d24) (/ (* a25 dz25) d25) (/ (* a26 dz26) d26) (/ (* a27 dz27) d27) (/ (* a28 dz28) d28) (/ (* a29 dz29) d29) (/ (* a20 dz20) d20) (/ (* a2a dz2a) d2a) (/ (* a2b dz2b) d2b)))
  (setq a3x (+ (* 1 (/ (fsx x3 y3 z3) m3)) (* 1 (/ (fwx r3) m3)) (* 1 v3x (/ (fvi m3 r3 v3) m3)) (/ (* a31 dx13) d13) (/ (* a32 dx23) d23) (/ (* a34 dx34) d34) (/ (* a35 dx35) d35) (/ (* a36 dx36) d36) (/ (* a37 dx37) d37) (/ (* a38 dx38) d38) (/ (* a39 dx39) d39) (/ (* a30 dx30) d30) (/ (* a3a dx3a) d3a) (/ (* a3b dx3b) d3b)))
  (setq a3y (+ (* 1 (/ (fsy x3 y3 z3) m3)) (* 1 (/ (fwy r3) m3)) (* 1 v3y (/ (fvi m3 r3 v3) m3)) (/ (* a31 dy13) d13) (/ (* a32 dy23) d23) (/ (* a34 dy34) d34) (/ (* a35 dy35) d35) (/ (* a36 dy36) d36) (/ (* a37 dy37) d37) (/ (* a38 dy38) d38) (/ (* a39 dy39) d39) (/ (* a30 dy30) d30) (/ (* a3a dy3a) d3a) (/ (* a3b dy3b) d3b)))
  (setq a3z (+ (* 1 (/ (fsz x3 y3 z3) m3)) (* 1 (/ (fwz r3) m3)) (* 1 v3z (/ (fvi m3 r3 v3) m3)) (/ (* a31 dz13) d13) (/ (* a32 dz23) d23) (/ (* a34 dz34) d34) (/ (* a35 dz35) d35) (/ (* a36 dz36) d36) (/ (* a37 dz37) d37) (/ (* a38 dz38) d38) (/ (* a39 dz39) d39) (/ (* a30 dz30) d30) (/ (* a3a dz3a) d3a) (/ (* a3b dz3b) d3b)))
  (setq a4x (+ (* 1 (/ (fsx x4 y4 z4) m4)) (* 1 (/ (fwx r4) m4)) (* 1 v4x (/ (fvi m4 r4 v4) m4)) (/ (* a41 dx14) d14) (/ (* a42 dx24) d24) (/ (* a43 dx34) d34) (/ (* a45 dx45) d45) (/ (* a46 dx46) d46) (/ (* a47 dx47) d47) (/ (* a48 dx48) d48) (/ (* a49 dx49) d49) (/ (* a40 dx40) d40) (/ (* a4a dx4a) d4a) (/ (* a4b dx4b) d4b)))
  (setq a4y (+ (* 1 (/ (fsy x4 y4 z4) m4)) (* 1 (/ (fwy r4) m4)) (* 1 v4y (/ (fvi m4 r4 v4) m4)) (/ (* a41 dy14) d14) (/ (* a42 dy24) d24) (/ (* a43 dy34) d34) (/ (* a45 dy45) d45) (/ (* a46 dy46) d46) (/ (* a47 dy47) d47) (/ (* a48 dy48) d48) (/ (* a49 dy49) d49) (/ (* a40 dy40) d40) (/ (* a4a dy4a) d4a) (/ (* a4b dy4b) d4b)))
  (setq a4z (+ (* 1 (/ (fsz x4 y4 z4) m4)) (* 1 (/ (fwz r4) m4)) (* 1 v4z (/ (fvi m4 r4 v4) m4)) (/ (* a41 dz14) d14) (/ (* a42 dz24) d24) (/ (* a43 dz34) d34) (/ (* a45 dz45) d45) (/ (* a46 dz46) d46) (/ (* a47 dz47) d47) (/ (* a48 dz48) d48) (/ (* a49 dz49) d49) (/ (* a40 dz40) d40) (/ (* a4a dz4a) d4a) (/ (* a4b dz4b) d4b)))
  (setq a5x (+ (* 1 (/ (fsx x5 y5 z5) m5)) (* 1 (/ (fwx r5) m5)) (* 1 v5x (/ (fvi m5 r5 v5) m5)) (/ (* a51 dx15) d15) (/ (* a52 dx25) d25) (/ (* a53 dx35) d35) (/ (* a54 dx45) d45) (/ (* a56 dx56) d56) (/ (* a57 dx57) d57) (/ (* a58 dx58) d58) (/ (* a59 dx59) d59) (/ (* a50 dx50) d50) (/ (* a5a dx5a) d5a) (/ (* a5b dx5b) d5b)))
  (setq a5y (+ (* 1 (/ (fsy x5 y5 z5) m5)) (* 1 (/ (fwy r5) m5)) (* 1 v5y (/ (fvi m5 r5 v5) m5)) (/ (* a51 dy15) d15) (/ (* a52 dy25) d25) (/ (* a53 dy35) d35) (/ (* a54 dy45) d45) (/ (* a56 dy56) d56) (/ (* a57 dy57) d57) (/ (* a58 dy58) d58) (/ (* a59 dy59) d59) (/ (* a50 dy50) d50) (/ (* a5a dy5a) d5a) (/ (* a5b dy5b) d5b)))
  (setq a5z (+ (* 1 (/ (fsz x5 y5 z5) m5)) (* 1 (/ (fwz r5) m5)) (* 1 v5z (/ (fvi m5 r5 v5) m5)) (/ (* a51 dz15) d15) (/ (* a52 dz25) d25) (/ (* a53 dz35) d35) (/ (* a54 dz45) d45) (/ (* a56 dz56) d56) (/ (* a57 dz57) d57) (/ (* a58 dz58) d58) (/ (* a59 dz59) d59) (/ (* a50 dz50) d50) (/ (* a5a dz5a) d5a) (/ (* a5b dz5b) d5b)))
  (setq a6x (+ (* 1 (/ (fsx x6 y6 z6) m6)) (* 1 (/ (fwx r6) m6)) (* 1 v6x (/ (fvi m6 r6 v6) m6)) (/ (* a61 dx16) d16) (/ (* a62 dx26) d26) (/ (* a63 dx36) d36) (/ (* a64 dx46) d46) (/ (* a65 dx56) d56) (/ (* a67 dx67) d67) (/ (* a68 dx68) d68) (/ (* a69 dx69) d69) (/ (* a60 dx60) d60) (/ (* a6a dx6a) d6a) (/ (* a6b dx6b) d6b)))
  (setq a6y (+ (* 1 (/ (fsy x6 y6 z6) m6)) (* 1 (/ (fwy r6) m6)) (* 1 v6y (/ (fvi m6 r6 v6) m6)) (/ (* a61 dy16) d16) (/ (* a62 dy26) d26) (/ (* a63 dy36) d36) (/ (* a64 dy46) d46) (/ (* a65 dy56) d56) (/ (* a67 dy67) d67) (/ (* a68 dy68) d68) (/ (* a69 dy69) d69) (/ (* a60 dy60) d60) (/ (* a6a dy6a) d6a) (/ (* a6b dy6b) d6b)))
  (setq a6z (+ (* 1 (/ (fsz x6 y6 z6) m6)) (* 1 (/ (fwz r6) m6)) (* 1 v6z (/ (fvi m6 r6 v6) m6)) (/ (* a61 dz16) d16) (/ (* a62 dz26) d26) (/ (* a63 dz36) d36) (/ (* a64 dz46) d46) (/ (* a65 dz56) d56) (/ (* a67 dz67) d67) (/ (* a68 dz68) d68) (/ (* a69 dz69) d69) (/ (* a60 dz60) d60) (/ (* a6a dz6a) d6a) (/ (* a6b dz6b) d6b)))
  (setq a7x (+ (* 1 (/ (fsx x7 y7 z7) m7)) (* 1 (/ (fwx r7) m7)) (* 1 v7x (/ (fvi m7 r7 v7) m7)) (/ (* a71 dx17) d17) (/ (* a72 dx27) d27) (/ (* a73 dx37) d37) (/ (* a74 dx47) d47) (/ (* a75 dx57) d57) (/ (* a76 dx67) d67) (/ (* a78 dx78) d78) (/ (* a79 dx79) d79) (/ (* a70 dx70) d70) (/ (* a7a dx7a) d7a) (/ (* a7b dx7b) d7b)))
  (setq a7y (+ (* 1 (/ (fsy x7 y7 z7) m7)) (* 1 (/ (fwy r7) m7)) (* 1 v7y (/ (fvi m7 r7 v7) m7)) (/ (* a71 dy17) d17) (/ (* a72 dy27) d27) (/ (* a73 dy37) d37) (/ (* a74 dy47) d47) (/ (* a75 dy57) d57) (/ (* a76 dy67) d67) (/ (* a78 dy78) d78) (/ (* a79 dy79) d79) (/ (* a70 dy70) d70) (/ (* a7a dy7a) d7a) (/ (* a7b dy7b) d7b)))
  (setq a7z (+ (* 1 (/ (fsz x7 y7 z7) m7)) (* 1 (/ (fwz r7) m7)) (* 1 v7z (/ (fvi m7 r7 v7) m7)) (/ (* a71 dz17) d17) (/ (* a72 dz27) d27) (/ (* a73 dz37) d37) (/ (* a74 dz47) d47) (/ (* a75 dz57) d57) (/ (* a76 dz67) d67) (/ (* a78 dz78) d78) (/ (* a79 dz79) d79) (/ (* a70 dz70) d70) (/ (* a7a dz7a) d7a) (/ (* a7b dz7b) d7b)))
  (setq a8x (+ (* 1 (/ (fsx x8 y8 z8) m8)) (* 1 (/ (fwx r8) m8)) (* 1 v8x (/ (fvi m8 r8 v8) m8)) (/ (* a81 dx18) d18) (/ (* a82 dx28) d28) (/ (* a83 dx38) d38) (/ (* a84 dx48) d48) (/ (* a85 dx58) d58) (/ (* a86 dx68) d68) (/ (* a87 dx78) d78) (/ (* a89 dx89) d89) (/ (* a80 dx80) d80) (/ (* a8a dx8a) d8a) (/ (* a8b dx8b) d8b)))
  (setq a8y (+ (* 1 (/ (fsy x8 y8 z8) m8)) (* 1 (/ (fwy r8) m8)) (* 1 v8y (/ (fvi m8 r8 v8) m8)) (/ (* a81 dy18) d18) (/ (* a82 dy28) d28) (/ (* a83 dy38) d38) (/ (* a84 dy48) d48) (/ (* a85 dy58) d58) (/ (* a86 dy68) d68) (/ (* a87 dy78) d78) (/ (* a89 dy89) d89) (/ (* a80 dy80) d80) (/ (* a8a dy8a) d8a) (/ (* a8b dy8b) d8b)))
  (setq a8z (+ (* 1 (/ (fsz x8 y8 z8) m8)) (* 1 (/ (fwz r8) m8)) (* 1 v8z (/ (fvi m8 r8 v8) m8)) (/ (* a81 dz18) d18) (/ (* a82 dz28) d28) (/ (* a83 dz38) d38) (/ (* a84 dz48) d48) (/ (* a85 dz58) d58) (/ (* a86 dz68) d68) (/ (* a87 dz78) d78) (/ (* a89 dz89) d89) (/ (* a80 dz80) d80) (/ (* a8a dz8a) d8a) (/ (* a8b dz8b) d8b)))
  (setq a9x (+ (* 1 (/ (fsx x9 y9 z9) m9)) (* 1 (/ (fwx r9) m9)) (* 1 v9x (/ (fvi m9 r9 v9) m9)) (/ (* a91 dx19) d19) (/ (* a92 dx29) d29) (/ (* a93 dx39) d39) (/ (* a94 dx49) d49) (/ (* a95 dx59) d59) (/ (* a96 dx69) d69) (/ (* a97 dx79) d79) (/ (* a98 dx89) d89) (/ (* a90 dx90) d90) (/ (* a9a dx9a) d9a) (/ (* a9b dx9b) d9b)))
  (setq a9y (+ (* 1 (/ (fsy x9 y9 z9) m9)) (* 1 (/ (fwy r9) m9)) (* 1 v9y (/ (fvi m9 r9 v9) m9)) (/ (* a91 dy19) d19) (/ (* a92 dy29) d29) (/ (* a93 dy39) d39) (/ (* a94 dy49) d49) (/ (* a95 dy59) d59) (/ (* a96 dy69) d69) (/ (* a97 dy79) d79) (/ (* a98 dy89) d89) (/ (* a90 dy90) d90) (/ (* a9a dy9a) d9a) (/ (* a9b dy9b) d9b)))
  (setq a9z (+ (* 1 (/ (fsz x9 y9 z9) m9)) (* 1 (/ (fwz r9) m9)) (* 1 v9z (/ (fvi m9 r9 v9) m9)) (/ (* a91 dz19) d19) (/ (* a92 dz29) d29) (/ (* a93 dz39) d39) (/ (* a94 dz49) d49) (/ (* a95 dz59) d59) (/ (* a96 dz69) d69) (/ (* a97 dz79) d79) (/ (* a98 dz89) d89) (/ (* a90 dz90) d90) (/ (* a9a dz9a) d9a) (/ (* a9b dz9b) d9b)))
  (setq a0x (+ (* 1 (/ (fsx x0 y0 z0) m0)) (* 1 (/ (fwx r0) m0)) (* 1 v0x (/ (fvi m0 r0 v0) m0)) (/ (* a01 dx10) d10) (/ (* a02 dx20) d20) (/ (* a03 dx30) d30) (/ (* a04 dx40) d40) (/ (* a05 dx50) d50) (/ (* a06 dx60) d60) (/ (* a07 dx70) d70) (/ (* a08 dx80) d80) (/ (* a09 dx90) d90) (/ (* a0a dx0a) d0a) (/ (* a0b dx0b) d0b)))
  (setq a0y (+ (* 1 (/ (fsy x0 y0 z0) m0)) (* 1 (/ (fwy r0) m0)) (* 1 v0y (/ (fvi m0 r0 v0) m0)) (/ (* a01 dy10) d10) (/ (* a02 dy20) d20) (/ (* a03 dy30) d30) (/ (* a04 dy40) d40) (/ (* a05 dy50) d50) (/ (* a06 dy60) d60) (/ (* a07 dy70) d70) (/ (* a08 dy80) d80) (/ (* a09 dy90) d90) (/ (* a0a dy0a) d0a) (/ (* a0b dy0b) d0b)))
  (setq a0z (+ (* 1 (/ (fsz x0 y0 z0) m0)) (* 1 (/ (fwz r0) m0)) (* 1 v0z (/ (fvi m0 r0 v0) m0)) (/ (* a01 dz10) d10) (/ (* a02 dz20) d20) (/ (* a03 dz30) d30) (/ (* a04 dz40) d40) (/ (* a05 dz50) d50) (/ (* a06 dz60) d60) (/ (* a07 dz70) d70) (/ (* a08 dz80) d80) (/ (* a09 dz90) d90) (/ (* a0a dz0a) d0a) (/ (* a0b dz0b) d0b)))
  (setq aax (+ (* 1 (/ (fsx xa ya za) ma)) (* 1 (/ (fwx ra) ma)) (* 1 vax (/ (fvi ma ra va) ma)) (/ (* aa1 dx1a) d1a) (/ (* aa2 dx2a) d2a) (/ (* aa3 dx3a) d3a) (/ (* aa4 dx4a) d4a) (/ (* aa5 dx5a) d5a) (/ (* aa6 dx6a) d6a) (/ (* aa7 dx7a) d7a) (/ (* aa8 dx8a) d8a) (/ (* aa9 dx9a) d9a) (/ (* aa0 dx0a) d0a) (/ (* aab dxab) dab)))
  (setq aay (+ (* 1 (/ (fsy xa ya za) ma)) (* 1 (/ (fwy ra) ma)) (* 1 vay (/ (fvi ma ra va) ma)) (/ (* aa1 dy1a) d1a) (/ (* aa2 dy2a) d2a) (/ (* aa3 dy3a) d3a) (/ (* aa4 dy4a) d4a) (/ (* aa5 dy5a) d5a) (/ (* aa6 dy6a) d6a) (/ (* aa7 dy7a) d7a) (/ (* aa8 dy8a) d8a) (/ (* aa9 dy9a) d9a) (/ (* aa0 dy0a) d0a) (/ (* aab dyab) dab)))
  (setq aaz (+ (* 1 (/ (fsz xa ya za) ma)) (* 1 (/ (fwz ra) ma)) (* 1 vaz (/ (fvi ma ra va) ma)) (/ (* aa1 dz1a) d1a) (/ (* aa2 dz2a) d2a) (/ (* aa3 dz3a) d3a) (/ (* aa4 dz4a) d4a) (/ (* aa5 dz5a) d5a) (/ (* aa6 dz6a) d6a) (/ (* aa7 dz7a) d7a) (/ (* aa8 dz8a) d8a) (/ (* aa9 dz9a) d9a) (/ (* aa0 dz0a) d0a) (/ (* aab dzab) dab)))
  (setq abx (+ (* 1 (/ (fsx xb yb zb) mb)) (* 1 (/ (fwx rb) mb)) (* 1 vbx (/ (fvi mb rb vb) mb)) (/ (* ab1 dx1b) d1b) (/ (* ab2 dx2b) d2b) (/ (* ab3 dx3b) d3b) (/ (* ab4 dx4b) d4b) (/ (* ab5 dx5b) d5b) (/ (* ab6 dx6b) d6b) (/ (* ab7 dx7b) d7b) (/ (* ab8 dx8b) d8b) (/ (* ab9 dx9b) d9b) (/ (* ab0 dx0b) d0b) (/ (* aba dxab) dab)))
  (setq aby (+ (* 1 (/ (fsy xb yb zb) mb)) (* 1 (/ (fwy rb) mb)) (* 1 vby (/ (fvi mb rb vb) mb)) (/ (* ab1 dy1b) d1b) (/ (* ab2 dy2b) d2b) (/ (* ab3 dy3b) d3b) (/ (* ab4 dy4b) d4b) (/ (* ab5 dy5b) d5b) (/ (* ab6 dy6b) d6b) (/ (* ab7 dy7b) d7b) (/ (* ab8 dy8b) d8b) (/ (* ab9 dy9b) d9b) (/ (* ab0 dy0b) d0b) (/ (* aba dyab) dab)))
  (setq abz (+ (* 1 (/ (fsz xb yb zb) mb)) (* 1 (/ (fwz rb) mb)) (* 1 vbz (/ (fvi mb rb vb) mb)) (/ (* ab1 dz1b) d1b) (/ (* ab2 dz2b) d2b) (/ (* ab3 dz3b) d3b) (/ (* ab4 dz4b) d4b) (/ (* ab5 dz5b) d5b) (/ (* ab6 dz6b) d6b) (/ (* ab7 dz7b) d7b) (/ (* ab8 dz8b) d8b) (/ (* ab9 dz9b) d9b) (/ (* ab0 dz0b) d0b) (/ (* aba dzab) dab)))

  (if (> d12 r12)
   (progn 
    (setq v1x (+ v1x (* a1x t)))  (setq v1y (+ v1y (* a1y t)))  (setq v1z (+ v1z (* a1z t)))
    (setq v2x (+ v2x (* a2x t)))  (setq v2y (+ v2y (* a2y t)))  (setq v2z (+ v2z (* a2z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v1i (list v1x v1y v1z)) ;velocita 1 prima dello scontro
     (setq v2i (list v2x v2y v2z)) ;velocita 2 prima dello scontro
     (setq v1i* (trans v1i 0 (list dx12 dy12 dz12)))
     (setq v2i* (trans v2i 0 (list dx12 dy12 dz12)))
     (setq v1i*x (car v1i*) v1i*y (cadr v1i*) v1i*z (caddr v1i*))
     (setq v2i*x (car v2i*) v2i*y (cadr v2i*) v2i*z (caddr v2i*))
     (setq v1f*z (* kur (/ (+ (* (- m1 m2) v1i*z) (* 2 m2 v2i*z)) (+ m1 m2))))
     (setq v2f*z (* kur (/ (+ (* (- m2 m1) v2i*z) (* 2 m1 v1i*z)) (+ m1 m2))))
     (setq v1f* (list v1i*x v1i*y v1f*z))
     (setq v2f* (list v2i*x v2i*y v2f*z))
     (setq v1f (trans v1f* (list dx12 dy12 dz12) 0))
     (setq v2f (trans v2f* (list dx12 dy12 dz12) 0))
     (setq v1x (car v1f) v1y (cadr v1f) v1z (caddr v1f))
     (setq v2x (car v2f) v2y (cadr v2f) v2z (caddr v2f))
    )
   )
  )
  (if (> d13 r13)
   (progn 
    (setq v1x (+ v1x (* a1x t)))  (setq v1y (+ v1y (* a1y t)))  (setq v1z (+ v1z (* a1z t)))
    (setq v3x (+ v3x (* a3x t)))  (setq v3y (+ v3y (* a3y t)))  (setq v3z (+ v3z (* a3z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v1i (list v1x v1y v1z)) ;velocita 1 prima dello scontro
     (setq v3i (list v3x v3y v3z)) ;velocita 3 prima dello scontro
     (setq v1i* (trans v1i 0 (list dx13 dy13 dz13)))
     (setq v3i* (trans v3i 0 (list dx13 dy13 dz13)))
     (setq v1i*x (car v1i*) v1i*y (cadr v1i*) v1i*z (caddr v1i*))
     (setq v3i*x (car v3i*) v3i*y (cadr v3i*) v3i*z (caddr v3i*))
     (setq v1f*z (* kur (/ (+ (* (- m1 m3) v1i*z) (* 2 m3 v3i*z)) (+ m1 m3))))
     (setq v3f*z (* kur (/ (+ (* (- m3 m1) v3i*z) (* 2 m1 v1i*z)) (+ m1 m3))))
     (setq v1f* (list v1i*x v1i*y v1f*z))
     (setq v3f* (list v3i*x v3i*y v3f*z))
     (setq v1f (trans v1f* (list dx13 dy13 dz13) 0))
     (setq v3f (trans v3f* (list dx13 dy13 dz13) 0))
     (setq v1x (car v1f) v1y (cadr v1f) v1z (caddr v1f))
     (setq v3x (car v3f) v3y (cadr v3f) v3z (caddr v3f))
    )
   )
  )
  (if (> d23 r23)
   (progn 
    (setq v2x (+ v2x (* a2x t)))  (setq v2y (+ v2y (* a2y t)))  (setq v2z (+ v2z (* a2z t)))
    (setq v3x (+ v3x (* a3x t)))  (setq v3y (+ v3y (* a3y t)))  (setq v3z (+ v3z (* a3z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v2i (list v2x v2y v2z)) ;velocita 2 prima dello scontro
     (setq v3i (list v3x v3y v3z)) ;velocita 3 prima dello scontro
     (setq v2i* (trans v2i 0 (list dx23 dy23 dz23)))
     (setq v3i* (trans v3i 0 (list dx23 dy23 dz23)))
     (setq v2i*x (car v2i*) v2i*y (cadr v2i*) v2i*z (caddr v2i*))
     (setq v3i*x (car v3i*) v3i*y (cadr v3i*) v3i*z (caddr v3i*))
     (setq v2f*z (* kur (/ (+ (* (- m2 m3) v2i*z) (* 2 m3 v3i*z)) (+ m2 m3))))
     (setq v3f*z (* kur (/ (+ (* (- m3 m2) v3i*z) (* 2 m2 v2i*z)) (+ m2 m3))))
     (setq v2f* (list v2i*x v2i*y v2f*z))
     (setq v3f* (list v3i*x v3i*y v3f*z))
     (setq v2f (trans v2f* (list dx23 dy23 dz23) 0))
     (setq v3f (trans v3f* (list dx23 dy23 dz23) 0))
     (setq v2x (car v2f) v2y (cadr v2f) v2z (caddr v2f))
     (setq v3x (car v3f) v3y (cadr v3f) v3z (caddr v3f))
    )
   )
  )
  (if (> d14 r14)
   (progn 
    (setq v1x (+ v1x (* a1x t)))  (setq v1y (+ v1y (* a1y t)))  (setq v1z (+ v1z (* a1z t)))
    (setq v4x (+ v4x (* a4x t)))  (setq v4y (+ v4y (* a4y t)))  (setq v4z (+ v4z (* a4z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v1i (list v1x v1y v1z)) ;velocita 1 prima dello scontro
     (setq v4i (list v4x v4y v4z)) ;velocita 4 prima dello scontro
     (setq v1i* (trans v1i 0 (list dx14 dy14 dz14)))
     (setq v4i* (trans v4i 0 (list dx14 dy14 dz14)))
     (setq v1i*x (car v1i*) v1i*y (cadr v1i*) v1i*z (caddr v1i*))
     (setq v4i*x (car v4i*) v4i*y (cadr v4i*) v4i*z (caddr v4i*))
     (setq v1f*z (* kur (/ (+ (* (- m1 m4) v1i*z) (* 2 m4 v4i*z)) (+ m1 m4))))
     (setq v4f*z (* kur (/ (+ (* (- m4 m1) v4i*z) (* 2 m1 v1i*z)) (+ m1 m4))))
     (setq v1f* (list v1i*x v1i*y v1f*z))
     (setq v4f* (list v4i*x v4i*y v4f*z))
     (setq v1f (trans v1f* (list dx14 dy14 dz14) 0))
     (setq v4f (trans v4f* (list dx14 dy14 dz14) 0))
     (setq v1x (car v1f) v1y (cadr v1f) v1z (caddr v1f))
     (setq v4x (car v4f) v4y (cadr v4f) v4z (caddr v4f))
    )
   )
  )
  (if (> d24 r24)
   (progn 
    (setq v2x (+ v2x (* a2x t)))  (setq v2y (+ v2y (* a2y t)))  (setq v2z (+ v2z (* a2z t)))
    (setq v4x (+ v4x (* a4x t)))  (setq v4y (+ v4y (* a4y t)))  (setq v4z (+ v4z (* a4z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v2i (list v2x v2y v2z)) ;velocita 2 prima dello scontro
     (setq v4i (list v4x v4y v4z)) ;velocita 4 prima dello scontro
     (setq v2i* (trans v2i 0 (list dx24 dy24 dz24)))
     (setq v4i* (trans v4i 0 (list dx24 dy24 dz24)))
     (setq v2i*x (car v2i*) v2i*y (cadr v2i*) v2i*z (caddr v2i*))
     (setq v4i*x (car v4i*) v4i*y (cadr v4i*) v4i*z (caddr v4i*))
     (setq v2f*z (* kur (/ (+ (* (- m2 m4) v2i*z) (* 2 m4 v4i*z)) (+ m2 m4))))
     (setq v4f*z (* kur (/ (+ (* (- m4 m2) v4i*z) (* 2 m2 v2i*z)) (+ m2 m4))))
     (setq v2f* (list v2i*x v2i*y v2f*z))
     (setq v4f* (list v4i*x v4i*y v4f*z))
     (setq v2f (trans v2f* (list dx24 dy24 dz24) 0))
     (setq v4f (trans v4f* (list dx24 dy24 dz24) 0))
     (setq v2x (car v2f) v2y (cadr v2f) v2z (caddr v2f))
     (setq v4x (car v4f) v4y (cadr v4f) v4z (caddr v4f))
    )
   )
  )
  (if (> d34 r34)
   (progn 
    (setq v3x (+ v3x (* a3x t)))  (setq v3y (+ v3y (* a3y t)))  (setq v3z (+ v3z (* a3z t)))
    (setq v4x (+ v4x (* a4x t)))  (setq v4y (+ v4y (* a4y t)))  (setq v4z (+ v4z (* a4z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v3i (list v3x v3y v3z)) ;velocita 3 prima dello scontro
     (setq v4i (list v4x v4y v4z)) ;velocita 4 prima dello scontro
     (setq v3i* (trans v3i 0 (list dx34 dy34 dz34)))
     (setq v4i* (trans v4i 0 (list dx34 dy34 dz34)))
     (setq v3i*x (car v3i*) v3i*y (cadr v3i*) v3i*z (caddr v3i*))
     (setq v4i*x (car v4i*) v4i*y (cadr v4i*) v4i*z (caddr v4i*))
     (setq v3f*z (* kur (/ (+ (* (- m3 m4) v3i*z) (* 2 m4 v4i*z)) (+ m3 m4))))
     (setq v4f*z (* kur (/ (+ (* (- m4 m3) v4i*z) (* 2 m3 v3i*z)) (+ m3 m4))))
     (setq v3f* (list v3i*x v3i*y v3f*z))
     (setq v4f* (list v4i*x v4i*y v4f*z))
     (setq v3f (trans v3f* (list dx34 dy34 dz34) 0))
     (setq v4f (trans v4f* (list dx34 dy34 dz34) 0))
     (setq v3x (car v3f) v3y (cadr v3f) v3z (caddr v3f))
     (setq v4x (car v4f) v4y (cadr v4f) v4z (caddr v4f))
    )
   )
  )
  (if (> d15 r15)
   (progn 
    (setq v1x (+ v1x (* a1x t)))  (setq v1y (+ v1y (* a1y t)))  (setq v1z (+ v1z (* a1z t)))
    (setq v5x (+ v5x (* a5x t)))  (setq v5y (+ v5y (* a5y t)))  (setq v5z (+ v5z (* a5z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v1i (list v1x v1y v1z)) ;velocita 1 prima dello scontro
     (setq v5i (list v5x v5y v5z)) ;velocita 5 prima dello scontro
     (setq v1i* (trans v1i 0 (list dx15 dy15 dz15)))
     (setq v5i* (trans v5i 0 (list dx15 dy15 dz15)))
     (setq v1i*x (car v1i*) v1i*y (cadr v1i*) v1i*z (caddr v1i*))
     (setq v5i*x (car v5i*) v5i*y (cadr v5i*) v5i*z (caddr v5i*))
     (setq v1f*z (* kur (/ (+ (* (- m1 m5) v1i*z) (* 2 m5 v5i*z)) (+ m1 m5))))
     (setq v5f*z (* kur (/ (+ (* (- m5 m1) v5i*z) (* 2 m1 v1i*z)) (+ m1 m5))))
     (setq v1f* (list v1i*x v1i*y v1f*z))
     (setq v5f* (list v5i*x v5i*y v5f*z))
     (setq v1f (trans v1f* (list dx15 dy15 dz15) 0))
     (setq v5f (trans v5f* (list dx15 dy15 dz15) 0))
     (setq v1x (car v1f) v1y (cadr v1f) v1z (caddr v1f))
     (setq v5x (car v5f) v5y (cadr v5f) v5z (caddr v5f))
    )
   )
  )
  (if (> d25 r25)
   (progn 
    (setq v2x (+ v2x (* a2x t)))  (setq v2y (+ v2y (* a2y t)))  (setq v2z (+ v2z (* a2z t)))
    (setq v5x (+ v5x (* a5x t)))  (setq v5y (+ v5y (* a5y t)))  (setq v5z (+ v5z (* a5z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v2i (list v2x v2y v2z)) ;velocita 2 prima dello scontro
     (setq v5i (list v5x v5y v5z)) ;velocita 5 prima dello scontro
     (setq v2i* (trans v2i 0 (list dx25 dy25 dz25)))
     (setq v5i* (trans v5i 0 (list dx25 dy25 dz25)))
     (setq v2i*x (car v2i*) v2i*y (cadr v2i*) v2i*z (caddr v2i*))
     (setq v5i*x (car v5i*) v5i*y (cadr v5i*) v5i*z (caddr v5i*))
     (setq v2f*z (* kur (/ (+ (* (- m2 m5) v2i*z) (* 2 m5 v5i*z)) (+ m2 m5))))
     (setq v5f*z (* kur (/ (+ (* (- m5 m2) v5i*z) (* 2 m2 v2i*z)) (+ m2 m5))))
     (setq v2f* (list v2i*x v2i*y v2f*z))
     (setq v5f* (list v5i*x v5i*y v5f*z))
     (setq v2f (trans v2f* (list dx25 dy25 dz25) 0))
     (setq v5f (trans v5f* (list dx25 dy25 dz25) 0))
     (setq v2x (car v2f) v2y (cadr v2f) v2z (caddr v2f))
     (setq v5x (car v5f) v5y (cadr v5f) v5z (caddr v5f))
    )
   )
  )
  (if (> d35 r35)
   (progn 
    (setq v3x (+ v3x (* a3x t)))  (setq v3y (+ v3y (* a3y t)))  (setq v3z (+ v3z (* a3z t)))
    (setq v5x (+ v5x (* a5x t)))  (setq v5y (+ v5y (* a5y t)))  (setq v5z (+ v5z (* a5z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v3i (list v3x v3y v3z)) ;velocita 3 prima dello scontro
     (setq v5i (list v5x v5y v5z)) ;velocita 5 prima dello scontro
     (setq v3i* (trans v3i 0 (list dx35 dy35 dz35)))
     (setq v5i* (trans v5i 0 (list dx35 dy35 dz35)))
     (setq v3i*x (car v3i*) v3i*y (cadr v3i*) v3i*z (caddr v3i*))
     (setq v5i*x (car v5i*) v5i*y (cadr v5i*) v5i*z (caddr v5i*))
     (setq v3f*z (* kur (/ (+ (* (- m3 m5) v3i*z) (* 2 m5 v5i*z)) (+ m3 m5))))
     (setq v5f*z (* kur (/ (+ (* (- m5 m3) v5i*z) (* 2 m3 v3i*z)) (+ m3 m5))))
     (setq v3f* (list v3i*x v3i*y v3f*z))
     (setq v5f* (list v5i*x v5i*y v5f*z))
     (setq v3f (trans v3f* (list dx35 dy35 dz35) 0))
     (setq v5f (trans v5f* (list dx35 dy35 dz35) 0))
     (setq v3x (car v3f) v3y (cadr v3f) v3z (caddr v3f))
     (setq v5x (car v5f) v5y (cadr v5f) v5z (caddr v5f))
    )
   )
  )
  (if (> d45 r45)
   (progn 
    (setq v4x (+ v4x (* a4x t)))  (setq v4y (+ v4y (* a4y t)))  (setq v4z (+ v4z (* a4z t)))
    (setq v5x (+ v5x (* a5x t)))  (setq v5y (+ v5y (* a5y t)))  (setq v5z (+ v5z (* a5z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v4i (list v4x v4y v4z)) ;velocita 4 prima dello scontro
     (setq v5i (list v5x v5y v5z)) ;velocita 5 prima dello scontro
     (setq v4i* (trans v4i 0 (list dx45 dy45 dz45)))
     (setq v5i* (trans v5i 0 (list dx45 dy45 dz45)))
     (setq v4i*x (car v4i*) v4i*y (cadr v4i*) v4i*z (caddr v4i*))
     (setq v5i*x (car v5i*) v5i*y (cadr v5i*) v5i*z (caddr v5i*))
     (setq v4f*z (* kur (/ (+ (* (- m4 m5) v4i*z) (* 2 m5 v5i*z)) (+ m4 m5))))
     (setq v5f*z (* kur (/ (+ (* (- m5 m4) v5i*z) (* 2 m4 v4i*z)) (+ m4 m5))))
     (setq v4f* (list v4i*x v4i*y v4f*z))
     (setq v5f* (list v5i*x v5i*y v5f*z))
     (setq v4f (trans v4f* (list dx45 dy45 dz45) 0))
     (setq v5f (trans v5f* (list dx45 dy45 dz45) 0))
     (setq v4x (car v4f) v4y (cadr v4f) v4z (caddr v4f))
     (setq v5x (car v5f) v5y (cadr v5f) v5z (caddr v5f))
    )
   )
  )
  (if (> d16 r16)
   (progn 
    (setq v1x (+ v1x (* a1x t)))  (setq v1y (+ v1y (* a1y t)))  (setq v1z (+ v1z (* a1z t)))
    (setq v6x (+ v6x (* a6x t)))  (setq v6y (+ v6y (* a6y t)))  (setq v6z (+ v6z (* a6z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v1i (list v1x v1y v1z)) ;velocita 1 prima dello scontro
     (setq v6i (list v6x v6y v6z)) ;velocita 6 prima dello scontro
     (setq v1i* (trans v1i 0 (list dx16 dy16 dz16)))
     (setq v6i* (trans v6i 0 (list dx16 dy16 dz16)))
     (setq v1i*x (car v1i*) v1i*y (cadr v1i*) v1i*z (caddr v1i*))
     (setq v6i*x (car v6i*) v6i*y (cadr v6i*) v6i*z (caddr v6i*))
     (setq v1f*z (* kur (/ (+ (* (- m1 m6) v1i*z) (* 2 m6 v6i*z)) (+ m1 m6))))
     (setq v6f*z (* kur (/ (+ (* (- m6 m1) v6i*z) (* 2 m1 v1i*z)) (+ m1 m6))))
     (setq v1f* (list v1i*x v1i*y v1f*z))
     (setq v6f* (list v6i*x v6i*y v6f*z))
     (setq v1f (trans v1f* (list dx16 dy16 dz16) 0))
     (setq v6f (trans v6f* (list dx16 dy16 dz16) 0))
     (setq v1x (car v1f) v1y (cadr v1f) v1z (caddr v1f))
     (setq v6x (car v6f) v6y (cadr v6f) v6z (caddr v6f))
    )
   )
  )
  (if (> d26 r26)
   (progn 
    (setq v2x (+ v2x (* a2x t)))  (setq v2y (+ v2y (* a2y t)))  (setq v2z (+ v2z (* a2z t)))
    (setq v6x (+ v6x (* a6x t)))  (setq v6y (+ v6y (* a6y t)))  (setq v6z (+ v6z (* a6z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v2i (list v2x v2y v2z)) ;velocita 2 prima dello scontro
     (setq v6i (list v6x v6y v6z)) ;velocita 6 prima dello scontro
     (setq v2i* (trans v2i 0 (list dx26 dy26 dz26)))
     (setq v6i* (trans v6i 0 (list dx26 dy26 dz26)))
     (setq v2i*x (car v2i*) v2i*y (cadr v2i*) v2i*z (caddr v2i*))
     (setq v6i*x (car v6i*) v6i*y (cadr v6i*) v6i*z (caddr v6i*))
     (setq v2f*z (* kur (/ (+ (* (- m2 m6) v2i*z) (* 2 m6 v6i*z)) (+ m2 m6))))
     (setq v6f*z (* kur (/ (+ (* (- m6 m2) v6i*z) (* 2 m2 v2i*z)) (+ m2 m6))))
     (setq v2f* (list v2i*x v2i*y v2f*z))
     (setq v6f* (list v6i*x v6i*y v6f*z))
     (setq v2f (trans v2f* (list dx26 dy26 dz26) 0))
     (setq v6f (trans v6f* (list dx26 dy26 dz26) 0))
     (setq v2x (car v2f) v2y (cadr v2f) v2z (caddr v2f))
     (setq v6x (car v6f) v6y (cadr v6f) v6z (caddr v6f))
    )
   )
  )
  (if (> d36 r36)
   (progn 
    (setq v3x (+ v3x (* a3x t)))  (setq v3y (+ v3y (* a3y t)))  (setq v3z (+ v3z (* a3z t)))
    (setq v6x (+ v6x (* a6x t)))  (setq v6y (+ v6y (* a6y t)))  (setq v6z (+ v6z (* a6z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v3i (list v3x v3y v3z)) ;velocita 3 prima dello scontro
     (setq v6i (list v6x v6y v6z)) ;velocita 6 prima dello scontro
     (setq v3i* (trans v3i 0 (list dx36 dy36 dz36)))
     (setq v6i* (trans v6i 0 (list dx36 dy36 dz36)))
     (setq v3i*x (car v3i*) v3i*y (cadr v3i*) v3i*z (caddr v3i*))
     (setq v6i*x (car v6i*) v6i*y (cadr v6i*) v6i*z (caddr v6i*))
     (setq v3f*z (* kur (/ (+ (* (- m3 m6) v3i*z) (* 2 m6 v6i*z)) (+ m3 m6))))
     (setq v6f*z (* kur (/ (+ (* (- m6 m3) v6i*z) (* 2 m3 v3i*z)) (+ m3 m6))))
     (setq v3f* (list v3i*x v3i*y v3f*z))
     (setq v6f* (list v6i*x v6i*y v6f*z))
     (setq v3f (trans v3f* (list dx36 dy36 dz36) 0))
     (setq v6f (trans v6f* (list dx36 dy36 dz36) 0))
     (setq v3x (car v3f) v3y (cadr v3f) v3z (caddr v3f))
     (setq v6x (car v6f) v6y (cadr v6f) v6z (caddr v6f))
    )
   )
  )
  (if (> d46 r46)
   (progn 
    (setq v4x (+ v4x (* a4x t)))  (setq v4y (+ v4y (* a4y t)))  (setq v4z (+ v4z (* a4z t)))
    (setq v6x (+ v6x (* a6x t)))  (setq v6y (+ v6y (* a6y t)))  (setq v6z (+ v6z (* a6z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v4i (list v4x v4y v4z)) ;velocita 4 prima dello scontro
     (setq v6i (list v6x v6y v6z)) ;velocita 6 prima dello scontro
     (setq v4i* (trans v4i 0 (list dx46 dy46 dz46)))
     (setq v6i* (trans v6i 0 (list dx46 dy46 dz46)))
     (setq v4i*x (car v4i*) v4i*y (cadr v4i*) v4i*z (caddr v4i*))
     (setq v6i*x (car v6i*) v6i*y (cadr v6i*) v6i*z (caddr v6i*))
     (setq v4f*z (* kur (/ (+ (* (- m4 m6) v4i*z) (* 2 m6 v6i*z)) (+ m4 m6))))
     (setq v6f*z (* kur (/ (+ (* (- m6 m4) v6i*z) (* 2 m4 v4i*z)) (+ m4 m6))))
     (setq v4f* (list v4i*x v4i*y v4f*z))
     (setq v6f* (list v6i*x v6i*y v6f*z))
     (setq v4f (trans v4f* (list dx46 dy46 dz46) 0))
     (setq v6f (trans v6f* (list dx46 dy46 dz46) 0))
     (setq v4x (car v4f) v4y (cadr v4f) v4z (caddr v4f))
     (setq v6x (car v6f) v6y (cadr v6f) v6z (caddr v6f))
    )
   )
  )
  (if (> d56 r56)
   (progn 
    (setq v5x (+ v5x (* a5x t)))  (setq v5y (+ v5y (* a5y t)))  (setq v5z (+ v5z (* a5z t)))
    (setq v6x (+ v6x (* a6x t)))  (setq v6y (+ v6y (* a6y t)))  (setq v6z (+ v6z (* a6z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v5i (list v5x v5y v5z)) ;velocita 5 prima dello scontro
     (setq v6i (list v6x v6y v6z)) ;velocita 6 prima dello scontro
     (setq v5i* (trans v5i 0 (list dx56 dy56 dz56)))
     (setq v6i* (trans v6i 0 (list dx56 dy56 dz56)))
     (setq v5i*x (car v5i*) v5i*y (cadr v5i*) v5i*z (caddr v5i*))
     (setq v6i*x (car v6i*) v6i*y (cadr v6i*) v6i*z (caddr v6i*))
     (setq v5f*z (* kur (/ (+ (* (- m5 m6) v5i*z) (* 2 m6 v6i*z)) (+ m5 m6))))
     (setq v6f*z (* kur (/ (+ (* (- m6 m5) v6i*z) (* 2 m5 v5i*z)) (+ m5 m6))))
     (setq v5f* (list v5i*x v5i*y v5f*z))
     (setq v6f* (list v6i*x v6i*y v6f*z))
     (setq v5f (trans v5f* (list dx56 dy56 dz56) 0))
     (setq v6f (trans v6f* (list dx56 dy56 dz56) 0))
     (setq v5x (car v5f) v5y (cadr v5f) v5z (caddr v5f))
     (setq v6x (car v6f) v6y (cadr v6f) v6z (caddr v6f))
    )
   )
  )
  (if (> d17 r17)
   (progn 
    (setq v1x (+ v1x (* a1x t)))  (setq v1y (+ v1y (* a1y t)))  (setq v1z (+ v1z (* a1z t)))
    (setq v7x (+ v7x (* a7x t)))  (setq v7y (+ v7y (* a7y t)))  (setq v7z (+ v7z (* a7z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v1i (list v1x v1y v1z)) ;velocita 1 prima dello scontro
     (setq v7i (list v7x v7y v7z)) ;velocita 7 prima dello scontro
     (setq v1i* (trans v1i 0 (list dx17 dy17 dz17)))
     (setq v7i* (trans v7i 0 (list dx17 dy17 dz17)))
     (setq v1i*x (car v1i*) v1i*y (cadr v1i*) v1i*z (caddr v1i*))
     (setq v7i*x (car v7i*) v7i*y (cadr v7i*) v7i*z (caddr v7i*))
     (setq v1f*z (* kur (/ (+ (* (- m1 m7) v1i*z) (* 2 m7 v7i*z)) (+ m1 m7))))
     (setq v7f*z (* kur (/ (+ (* (- m7 m1) v7i*z) (* 2 m1 v1i*z)) (+ m1 m7))))
     (setq v1f* (list v1i*x v1i*y v1f*z))
     (setq v7f* (list v7i*x v7i*y v7f*z))
     (setq v1f (trans v1f* (list dx17 dy17 dz17) 0))
     (setq v7f (trans v7f* (list dx17 dy17 dz17) 0))
     (setq v1x (car v1f) v1y (cadr v1f) v1z (caddr v1f))
     (setq v7x (car v7f) v7y (cadr v7f) v7z (caddr v7f))
    )
   )
  )
  (if (> d27 r27)
   (progn 
    (setq v2x (+ v2x (* a2x t)))  (setq v2y (+ v2y (* a2y t)))  (setq v2z (+ v2z (* a2z t)))
    (setq v7x (+ v7x (* a7x t)))  (setq v7y (+ v7y (* a7y t)))  (setq v7z (+ v7z (* a7z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v2i (list v2x v2y v2z)) ;velocita 2 prima dello scontro
     (setq v7i (list v7x v7y v7z)) ;velocita 7 prima dello scontro
     (setq v2i* (trans v2i 0 (list dx27 dy27 dz27)))
     (setq v7i* (trans v7i 0 (list dx27 dy27 dz27)))
     (setq v2i*x (car v2i*) v2i*y (cadr v2i*) v2i*z (caddr v2i*))
     (setq v7i*x (car v7i*) v7i*y (cadr v7i*) v7i*z (caddr v7i*))
     (setq v2f*z (* kur (/ (+ (* (- m2 m7) v2i*z) (* 2 m7 v7i*z)) (+ m2 m7))))
     (setq v7f*z (* kur (/ (+ (* (- m7 m2) v7i*z) (* 2 m2 v2i*z)) (+ m2 m7))))
     (setq v2f* (list v2i*x v2i*y v2f*z))
     (setq v7f* (list v7i*x v7i*y v7f*z))
     (setq v2f (trans v2f* (list dx27 dy27 dz27) 0))
     (setq v7f (trans v7f* (list dx27 dy27 dz27) 0))
     (setq v2x (car v2f) v2y (cadr v2f) v2z (caddr v2f))
     (setq v7x (car v7f) v7y (cadr v7f) v7z (caddr v7f))
    )
   )
  )
  (if (> d37 r37)
   (progn 
    (setq v3x (+ v3x (* a3x t)))  (setq v3y (+ v3y (* a3y t)))  (setq v3z (+ v3z (* a3z t)))
    (setq v7x (+ v7x (* a7x t)))  (setq v7y (+ v7y (* a7y t)))  (setq v7z (+ v7z (* a7z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v3i (list v3x v3y v3z)) ;velocita 3 prima dello scontro
     (setq v7i (list v7x v7y v7z)) ;velocita 7 prima dello scontro
     (setq v3i* (trans v3i 0 (list dx37 dy37 dz37)))
     (setq v7i* (trans v7i 0 (list dx37 dy37 dz37)))
     (setq v3i*x (car v3i*) v3i*y (cadr v3i*) v3i*z (caddr v3i*))
     (setq v7i*x (car v7i*) v7i*y (cadr v7i*) v7i*z (caddr v7i*))
     (setq v3f*z (* kur (/ (+ (* (- m3 m7) v3i*z) (* 2 m7 v7i*z)) (+ m3 m7))))
     (setq v7f*z (* kur (/ (+ (* (- m7 m3) v7i*z) (* 2 m3 v3i*z)) (+ m3 m7))))
     (setq v3f* (list v3i*x v3i*y v3f*z))
     (setq v7f* (list v7i*x v7i*y v7f*z))
     (setq v3f (trans v3f* (list dx37 dy37 dz37) 0))
     (setq v7f (trans v7f* (list dx37 dy37 dz37) 0))
     (setq v3x (car v3f) v3y (cadr v3f) v3z (caddr v3f))
     (setq v7x (car v7f) v7y (cadr v7f) v7z (caddr v7f))
    )
   )
  )
  (if (> d47 r47)
   (progn 
    (setq v4x (+ v4x (* a4x t)))  (setq v4y (+ v4y (* a4y t)))  (setq v4z (+ v4z (* a4z t)))
    (setq v7x (+ v7x (* a7x t)))  (setq v7y (+ v7y (* a7y t)))  (setq v7z (+ v7z (* a7z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v4i (list v4x v4y v4z)) ;velocita 4 prima dello scontro
     (setq v7i (list v7x v7y v7z)) ;velocita 7 prima dello scontro
     (setq v4i* (trans v4i 0 (list dx47 dy47 dz47)))
     (setq v7i* (trans v7i 0 (list dx47 dy47 dz47)))
     (setq v4i*x (car v4i*) v4i*y (cadr v4i*) v4i*z (caddr v4i*))
     (setq v7i*x (car v7i*) v7i*y (cadr v7i*) v7i*z (caddr v7i*))
     (setq v4f*z (* kur (/ (+ (* (- m4 m7) v4i*z) (* 2 m7 v7i*z)) (+ m4 m7))))
     (setq v7f*z (* kur (/ (+ (* (- m7 m4) v7i*z) (* 2 m4 v4i*z)) (+ m4 m7))))
     (setq v4f* (list v4i*x v4i*y v4f*z))
     (setq v7f* (list v7i*x v7i*y v7f*z))
     (setq v4f (trans v4f* (list dx47 dy47 dz47) 0))
     (setq v7f (trans v7f* (list dx47 dy47 dz47) 0))
     (setq v4x (car v4f) v4y (cadr v4f) v4z (caddr v4f))
     (setq v7x (car v7f) v7y (cadr v7f) v7z (caddr v7f))
    )
   )
  )
  (if (> d57 r57)
   (progn 
    (setq v5x (+ v5x (* a5x t)))  (setq v5y (+ v5y (* a5y t)))  (setq v5z (+ v5z (* a5z t)))
    (setq v7x (+ v7x (* a7x t)))  (setq v7y (+ v7y (* a7y t)))  (setq v7z (+ v7z (* a7z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v5i (list v5x v5y v5z)) ;velocita 5 prima dello scontro
     (setq v7i (list v7x v7y v7z)) ;velocita 7 prima dello scontro
     (setq v5i* (trans v5i 0 (list dx57 dy57 dz57)))
     (setq v7i* (trans v7i 0 (list dx57 dy57 dz57)))
     (setq v5i*x (car v5i*) v5i*y (cadr v5i*) v5i*z (caddr v5i*))
     (setq v7i*x (car v7i*) v7i*y (cadr v7i*) v7i*z (caddr v7i*))
     (setq v5f*z (* kur (/ (+ (* (- m5 m7) v5i*z) (* 2 m7 v7i*z)) (+ m5 m7))))
     (setq v7f*z (* kur (/ (+ (* (- m7 m5) v7i*z) (* 2 m5 v5i*z)) (+ m5 m7))))
     (setq v5f* (list v5i*x v5i*y v5f*z))
     (setq v7f* (list v7i*x v7i*y v7f*z))
     (setq v5f (trans v5f* (list dx57 dy57 dz57) 0))
     (setq v7f (trans v7f* (list dx57 dy57 dz57) 0))
     (setq v5x (car v5f) v5y (cadr v5f) v5z (caddr v5f))
     (setq v7x (car v7f) v7y (cadr v7f) v7z (caddr v7f))
    )
   )
  )
  (if (> d67 r67)
   (progn 
    (setq v6x (+ v6x (* a6x t)))  (setq v6y (+ v6y (* a6y t)))  (setq v6z (+ v6z (* a6z t)))
    (setq v7x (+ v7x (* a7x t)))  (setq v7y (+ v7y (* a7y t)))  (setq v7z (+ v7z (* a7z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v6i (list v6x v6y v6z)) ;velocita 6 prima dello scontro
     (setq v7i (list v7x v7y v7z)) ;velocita 7 prima dello scontro
     (setq v6i* (trans v6i 0 (list dx67 dy67 dz67)))
     (setq v7i* (trans v7i 0 (list dx67 dy67 dz67)))
     (setq v6i*x (car v6i*) v6i*y (cadr v6i*) v6i*z (caddr v6i*))
     (setq v7i*x (car v7i*) v7i*y (cadr v7i*) v7i*z (caddr v7i*))
     (setq v6f*z (* kur (/ (+ (* (- m6 m7) v6i*z) (* 2 m7 v7i*z)) (+ m6 m7))))
     (setq v7f*z (* kur (/ (+ (* (- m7 m6) v7i*z) (* 2 m6 v6i*z)) (+ m6 m7))))
     (setq v6f* (list v6i*x v6i*y v6f*z))
     (setq v7f* (list v7i*x v7i*y v7f*z))
     (setq v6f (trans v6f* (list dx67 dy67 dz67) 0))
     (setq v7f (trans v7f* (list dx67 dy67 dz67) 0))
     (setq v6x (car v6f) v6y (cadr v6f) v6z (caddr v6f))
     (setq v7x (car v7f) v7y (cadr v7f) v7z (caddr v7f))
    )
   )
  )
  (if (> d18 r18)
   (progn 
    (setq v1x (+ v1x (* a1x t)))  (setq v1y (+ v1y (* a1y t)))  (setq v1z (+ v1z (* a1z t)))
    (setq v8x (+ v8x (* a8x t)))  (setq v8y (+ v8y (* a8y t)))  (setq v8z (+ v8z (* a8z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v1i (list v1x v1y v1z)) ;velocita 1 prima dello scontro
     (setq v8i (list v8x v8y v8z)) ;velocita 8 prima dello scontro
     (setq v1i* (trans v1i 0 (list dx18 dy18 dz18)))
     (setq v8i* (trans v8i 0 (list dx18 dy18 dz18)))
     (setq v1i*x (car v1i*) v1i*y (cadr v1i*) v1i*z (caddr v1i*))
     (setq v8i*x (car v8i*) v8i*y (cadr v8i*) v8i*z (caddr v8i*))
     (setq v1f*z (* kur (/ (+ (* (- m1 m8) v1i*z) (* 2 m8 v8i*z)) (+ m1 m8))))
     (setq v8f*z (* kur (/ (+ (* (- m8 m1) v8i*z) (* 2 m1 v1i*z)) (+ m1 m8))))
     (setq v1f* (list v1i*x v1i*y v1f*z))
     (setq v8f* (list v8i*x v8i*y v8f*z))
     (setq v1f (trans v1f* (list dx18 dy18 dz18) 0))
     (setq v8f (trans v8f* (list dx18 dy18 dz18) 0))
     (setq v1x (car v1f) v1y (cadr v1f) v1z (caddr v1f))
     (setq v8x (car v8f) v8y (cadr v8f) v8z (caddr v8f))
    )
   )
  )
  (if (> d28 r28)
   (progn 
    (setq v2x (+ v2x (* a2x t)))  (setq v2y (+ v2y (* a2y t)))  (setq v2z (+ v2z (* a2z t)))
    (setq v8x (+ v8x (* a8x t)))  (setq v8y (+ v8y (* a8y t)))  (setq v8z (+ v8z (* a8z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v2i (list v2x v2y v2z)) ;velocita 2 prima dello scontro
     (setq v8i (list v8x v8y v8z)) ;velocita 8 prima dello scontro
     (setq v2i* (trans v2i 0 (list dx28 dy28 dz28)))
     (setq v8i* (trans v8i 0 (list dx28 dy28 dz28)))
     (setq v2i*x (car v2i*) v2i*y (cadr v2i*) v2i*z (caddr v2i*))
     (setq v8i*x (car v8i*) v8i*y (cadr v8i*) v8i*z (caddr v8i*))
     (setq v2f*z (* kur (/ (+ (* (- m2 m8) v2i*z) (* 2 m8 v8i*z)) (+ m2 m8))))
     (setq v8f*z (* kur (/ (+ (* (- m8 m2) v8i*z) (* 2 m2 v2i*z)) (+ m2 m8))))
     (setq v2f* (list v2i*x v2i*y v2f*z))
     (setq v8f* (list v8i*x v8i*y v8f*z))
     (setq v2f (trans v2f* (list dx28 dy28 dz28) 0))
     (setq v8f (trans v8f* (list dx28 dy28 dz28) 0))
     (setq v2x (car v2f) v2y (cadr v2f) v2z (caddr v2f))
     (setq v8x (car v8f) v8y (cadr v8f) v8z (caddr v8f))
    )
   )
  )
  (if (> d38 r38)
   (progn 
    (setq v3x (+ v3x (* a3x t)))  (setq v3y (+ v3y (* a3y t)))  (setq v3z (+ v3z (* a3z t)))
    (setq v8x (+ v8x (* a8x t)))  (setq v8y (+ v8y (* a8y t)))  (setq v8z (+ v8z (* a8z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v3i (list v3x v3y v3z)) ;velocita 3 prima dello scontro
     (setq v8i (list v8x v8y v8z)) ;velocita 8 prima dello scontro
     (setq v3i* (trans v3i 0 (list dx38 dy38 dz38)))
     (setq v8i* (trans v8i 0 (list dx38 dy38 dz38)))
     (setq v3i*x (car v3i*) v3i*y (cadr v3i*) v3i*z (caddr v3i*))
     (setq v8i*x (car v8i*) v8i*y (cadr v8i*) v8i*z (caddr v8i*))
     (setq v3f*z (* kur (/ (+ (* (- m3 m8) v3i*z) (* 2 m8 v8i*z)) (+ m3 m8))))
     (setq v8f*z (* kur (/ (+ (* (- m8 m3) v8i*z) (* 2 m3 v3i*z)) (+ m3 m8))))
     (setq v3f* (list v3i*x v3i*y v3f*z))
     (setq v8f* (list v8i*x v8i*y v8f*z))
     (setq v3f (trans v3f* (list dx38 dy38 dz38) 0))
     (setq v8f (trans v8f* (list dx38 dy38 dz38) 0))
     (setq v3x (car v3f) v3y (cadr v3f) v3z (caddr v3f))
     (setq v8x (car v8f) v8y (cadr v8f) v8z (caddr v8f))
    )
   )
  )
  (if (> d48 r48)
   (progn 
    (setq v4x (+ v4x (* a4x t)))  (setq v4y (+ v4y (* a4y t)))  (setq v4z (+ v4z (* a4z t)))
    (setq v8x (+ v8x (* a8x t)))  (setq v8y (+ v8y (* a8y t)))  (setq v8z (+ v8z (* a8z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v4i (list v4x v4y v4z)) ;velocita 4 prima dello scontro
     (setq v8i (list v8x v8y v8z)) ;velocita 8 prima dello scontro
     (setq v4i* (trans v4i 0 (list dx48 dy48 dz48)))
     (setq v8i* (trans v8i 0 (list dx48 dy48 dz48)))
     (setq v4i*x (car v4i*) v4i*y (cadr v4i*) v4i*z (caddr v4i*))
     (setq v8i*x (car v8i*) v8i*y (cadr v8i*) v8i*z (caddr v8i*))
     (setq v4f*z (* kur (/ (+ (* (- m4 m8) v4i*z) (* 2 m8 v8i*z)) (+ m4 m8))))
     (setq v8f*z (* kur (/ (+ (* (- m8 m4) v8i*z) (* 2 m4 v4i*z)) (+ m4 m8))))
     (setq v4f* (list v4i*x v4i*y v4f*z))
     (setq v8f* (list v8i*x v8i*y v8f*z))
     (setq v4f (trans v4f* (list dx48 dy48 dz48) 0))
     (setq v8f (trans v8f* (list dx48 dy48 dz48) 0))
     (setq v4x (car v4f) v4y (cadr v4f) v4z (caddr v4f))
     (setq v8x (car v8f) v8y (cadr v8f) v8z (caddr v8f))
    )
   )
  )
  (if (> d58 r58)
   (progn 
    (setq v5x (+ v5x (* a5x t)))  (setq v5y (+ v5y (* a5y t)))  (setq v5z (+ v5z (* a5z t)))
    (setq v8x (+ v8x (* a8x t)))  (setq v8y (+ v8y (* a8y t)))  (setq v8z (+ v8z (* a8z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v5i (list v5x v5y v5z)) ;velocita 5 prima dello scontro
     (setq v8i (list v8x v8y v8z)) ;velocita 8 prima dello scontro
     (setq v5i* (trans v5i 0 (list dx58 dy58 dz58)))
     (setq v8i* (trans v8i 0 (list dx58 dy58 dz58)))
     (setq v5i*x (car v5i*) v5i*y (cadr v5i*) v5i*z (caddr v5i*))
     (setq v8i*x (car v8i*) v8i*y (cadr v8i*) v8i*z (caddr v8i*))
     (setq v5f*z (* kur (/ (+ (* (- m5 m8) v5i*z) (* 2 m8 v8i*z)) (+ m5 m8))))
     (setq v8f*z (* kur (/ (+ (* (- m8 m5) v8i*z) (* 2 m5 v5i*z)) (+ m5 m8))))
     (setq v5f* (list v5i*x v5i*y v5f*z))
     (setq v8f* (list v8i*x v8i*y v8f*z))
     (setq v5f (trans v5f* (list dx58 dy58 dz58) 0))
     (setq v8f (trans v8f* (list dx58 dy58 dz58) 0))
     (setq v5x (car v5f) v5y (cadr v5f) v5z (caddr v5f))
     (setq v8x (car v8f) v8y (cadr v8f) v8z (caddr v8f))
    )
   )
  )
  (if (> d68 r68)
   (progn 
    (setq v6x (+ v6x (* a6x t)))  (setq v6y (+ v6y (* a6y t)))  (setq v6z (+ v6z (* a6z t)))
    (setq v8x (+ v8x (* a8x t)))  (setq v8y (+ v8y (* a8y t)))  (setq v8z (+ v8z (* a8z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v6i (list v6x v6y v6z)) ;velocita 6 prima dello scontro
     (setq v8i (list v8x v8y v8z)) ;velocita 8 prima dello scontro
     (setq v6i* (trans v6i 0 (list dx68 dy68 dz68)))
     (setq v8i* (trans v8i 0 (list dx68 dy68 dz68)))
     (setq v6i*x (car v6i*) v6i*y (cadr v6i*) v6i*z (caddr v6i*))
     (setq v8i*x (car v8i*) v8i*y (cadr v8i*) v8i*z (caddr v8i*))
     (setq v6f*z (* kur (/ (+ (* (- m6 m8) v6i*z) (* 2 m8 v8i*z)) (+ m6 m8))))
     (setq v8f*z (* kur (/ (+ (* (- m8 m6) v8i*z) (* 2 m6 v6i*z)) (+ m6 m8))))
     (setq v6f* (list v6i*x v6i*y v6f*z))
     (setq v8f* (list v8i*x v8i*y v8f*z))
     (setq v6f (trans v6f* (list dx68 dy68 dz68) 0))
     (setq v8f (trans v8f* (list dx68 dy68 dz68) 0))
     (setq v6x (car v6f) v6y (cadr v6f) v6z (caddr v6f))
     (setq v8x (car v8f) v8y (cadr v8f) v8z (caddr v8f))
    )
   )
  )
  (if (> d78 r78)
   (progn 
    (setq v7x (+ v7x (* a7x t)))  (setq v7y (+ v7y (* a7y t)))  (setq v7z (+ v7z (* a7z t)))
    (setq v8x (+ v8x (* a8x t)))  (setq v8y (+ v8y (* a8y t)))  (setq v8z (+ v8z (* a8z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v7i (list v7x v7y v7z)) ;velocita 7 prima dello scontro
     (setq v8i (list v8x v8y v8z)) ;velocita 8 prima dello scontro
     (setq v7i* (trans v7i 0 (list dx78 dy78 dz78)))
     (setq v8i* (trans v8i 0 (list dx78 dy78 dz78)))
     (setq v7i*x (car v7i*) v7i*y (cadr v7i*) v7i*z (caddr v7i*))
     (setq v8i*x (car v8i*) v8i*y (cadr v8i*) v8i*z (caddr v8i*))
     (setq v7f*z (* kur (/ (+ (* (- m7 m8) v7i*z) (* 2 m8 v8i*z)) (+ m7 m8))))
     (setq v8f*z (* kur (/ (+ (* (- m8 m7) v8i*z) (* 2 m7 v7i*z)) (+ m7 m8))))
     (setq v7f* (list v7i*x v7i*y v7f*z))
     (setq v8f* (list v8i*x v8i*y v8f*z))
     (setq v7f (trans v7f* (list dx78 dy78 dz78) 0))
     (setq v8f (trans v8f* (list dx78 dy78 dz78) 0))
     (setq v7x (car v7f) v7y (cadr v7f) v7z (caddr v7f))
     (setq v8x (car v8f) v8y (cadr v8f) v8z (caddr v8f))
    )
   )
  )
  (if (> d19 r19)
   (progn 
    (setq v1x (+ v1x (* a1x t)))  (setq v1y (+ v1y (* a1y t)))  (setq v1z (+ v1z (* a1z t)))
    (setq v9x (+ v9x (* a9x t)))  (setq v9y (+ v9y (* a9y t)))  (setq v9z (+ v9z (* a9z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v1i (list v1x v1y v1z)) ;velocita 1 prima dello scontro
     (setq v9i (list v9x v9y v9z)) ;velocita 9 prima dello scontro
     (setq v1i* (trans v1i 0 (list dx19 dy19 dz19)))
     (setq v9i* (trans v9i 0 (list dx19 dy19 dz19)))
     (setq v1i*x (car v1i*) v1i*y (cadr v1i*) v1i*z (caddr v1i*))
     (setq v9i*x (car v9i*) v9i*y (cadr v9i*) v9i*z (caddr v9i*))
     (setq v1f*z (* kur (/ (+ (* (- m1 m9) v1i*z) (* 2 m9 v9i*z)) (+ m1 m9))))
     (setq v9f*z (* kur (/ (+ (* (- m9 m1) v9i*z) (* 2 m1 v1i*z)) (+ m1 m9))))
     (setq v1f* (list v1i*x v1i*y v1f*z))
     (setq v9f* (list v9i*x v9i*y v9f*z))
     (setq v1f (trans v1f* (list dx19 dy19 dz19) 0))
     (setq v9f (trans v9f* (list dx19 dy19 dz19) 0))
     (setq v1x (car v1f) v1y (cadr v1f) v1z (caddr v1f))
     (setq v9x (car v9f) v9y (cadr v9f) v9z (caddr v9f))
    )
   )
  )
  (if (> d29 r29)
   (progn 
    (setq v2x (+ v2x (* a2x t)))  (setq v2y (+ v2y (* a2y t)))  (setq v2z (+ v2z (* a2z t)))
    (setq v9x (+ v9x (* a9x t)))  (setq v9y (+ v9y (* a9y t)))  (setq v9z (+ v9z (* a9z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v2i (list v2x v2y v2z)) ;velocita 2 prima dello scontro
     (setq v9i (list v9x v9y v9z)) ;velocita 9 prima dello scontro
     (setq v2i* (trans v2i 0 (list dx29 dy29 dz29)))
     (setq v9i* (trans v9i 0 (list dx29 dy29 dz29)))
     (setq v2i*x (car v2i*) v2i*y (cadr v2i*) v2i*z (caddr v2i*))
     (setq v9i*x (car v9i*) v9i*y (cadr v9i*) v9i*z (caddr v9i*))
     (setq v2f*z (* kur (/ (+ (* (- m2 m9) v2i*z) (* 2 m9 v9i*z)) (+ m2 m9))))
     (setq v9f*z (* kur (/ (+ (* (- m9 m2) v9i*z) (* 2 m2 v2i*z)) (+ m2 m9))))
     (setq v2f* (list v2i*x v2i*y v2f*z))
     (setq v9f* (list v9i*x v9i*y v9f*z))
     (setq v2f (trans v2f* (list dx29 dy29 dz29) 0))
     (setq v9f (trans v9f* (list dx29 dy29 dz29) 0))
     (setq v2x (car v2f) v2y (cadr v2f) v2z (caddr v2f))
     (setq v9x (car v9f) v9y (cadr v9f) v9z (caddr v9f))
    )
   )
  )
  (if (> d39 r39)
   (progn 
    (setq v3x (+ v3x (* a3x t)))  (setq v3y (+ v3y (* a3y t)))  (setq v3z (+ v3z (* a3z t)))
    (setq v9x (+ v9x (* a9x t)))  (setq v9y (+ v9y (* a9y t)))  (setq v9z (+ v9z (* a9z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v3i (list v3x v3y v3z)) ;velocita 3 prima dello scontro
     (setq v9i (list v9x v9y v9z)) ;velocita 9 prima dello scontro
     (setq v3i* (trans v3i 0 (list dx39 dy39 dz39)))
     (setq v9i* (trans v9i 0 (list dx39 dy39 dz39)))
     (setq v3i*x (car v3i*) v3i*y (cadr v3i*) v3i*z (caddr v3i*))
     (setq v9i*x (car v9i*) v9i*y (cadr v9i*) v9i*z (caddr v9i*))
     (setq v3f*z (* kur (/ (+ (* (- m3 m9) v3i*z) (* 2 m9 v9i*z)) (+ m3 m9))))
     (setq v9f*z (* kur (/ (+ (* (- m9 m3) v9i*z) (* 2 m3 v3i*z)) (+ m3 m9))))
     (setq v3f* (list v3i*x v3i*y v3f*z))
     (setq v9f* (list v9i*x v9i*y v9f*z))
     (setq v3f (trans v3f* (list dx39 dy39 dz39) 0))
     (setq v9f (trans v9f* (list dx39 dy39 dz39) 0))
     (setq v3x (car v3f) v3y (cadr v3f) v3z (caddr v3f))
     (setq v9x (car v9f) v9y (cadr v9f) v9z (caddr v9f))
    )
   )
  )
  (if (> d49 r49)
   (progn 
    (setq v4x (+ v4x (* a4x t)))  (setq v4y (+ v4y (* a4y t)))  (setq v4z (+ v4z (* a4z t)))
    (setq v9x (+ v9x (* a9x t)))  (setq v9y (+ v9y (* a9y t)))  (setq v9z (+ v9z (* a9z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v4i (list v4x v4y v4z)) ;velocita 4 prima dello scontro
     (setq v9i (list v9x v9y v9z)) ;velocita 9 prima dello scontro
     (setq v4i* (trans v4i 0 (list dx49 dy49 dz49)))
     (setq v9i* (trans v9i 0 (list dx49 dy49 dz49)))
     (setq v4i*x (car v4i*) v4i*y (cadr v4i*) v4i*z (caddr v4i*))
     (setq v9i*x (car v9i*) v9i*y (cadr v9i*) v9i*z (caddr v9i*))
     (setq v4f*z (* kur (/ (+ (* (- m4 m9) v4i*z) (* 2 m9 v9i*z)) (+ m4 m9))))
     (setq v9f*z (* kur (/ (+ (* (- m9 m4) v9i*z) (* 2 m4 v4i*z)) (+ m4 m9))))
     (setq v4f* (list v4i*x v4i*y v4f*z))
     (setq v9f* (list v9i*x v9i*y v9f*z))
     (setq v4f (trans v4f* (list dx49 dy49 dz49) 0))
     (setq v9f (trans v9f* (list dx49 dy49 dz49) 0))
     (setq v4x (car v4f) v4y (cadr v4f) v4z (caddr v4f))
     (setq v9x (car v9f) v9y (cadr v9f) v9z (caddr v9f))
    )
   )
  )
  (if (> d59 r59)
   (progn 
    (setq v5x (+ v5x (* a5x t)))  (setq v5y (+ v5y (* a5y t)))  (setq v5z (+ v5z (* a5z t)))
    (setq v9x (+ v9x (* a9x t)))  (setq v9y (+ v9y (* a9y t)))  (setq v9z (+ v9z (* a9z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v5i (list v5x v5y v5z)) ;velocita 5 prima dello scontro
     (setq v9i (list v9x v9y v9z)) ;velocita 9 prima dello scontro
     (setq v5i* (trans v5i 0 (list dx59 dy59 dz59)))
     (setq v9i* (trans v9i 0 (list dx59 dy59 dz59)))
     (setq v5i*x (car v5i*) v5i*y (cadr v5i*) v5i*z (caddr v5i*))
     (setq v9i*x (car v9i*) v9i*y (cadr v9i*) v9i*z (caddr v9i*))
     (setq v5f*z (* kur (/ (+ (* (- m5 m9) v5i*z) (* 2 m9 v9i*z)) (+ m5 m9))))
     (setq v9f*z (* kur (/ (+ (* (- m9 m5) v9i*z) (* 2 m5 v5i*z)) (+ m5 m9))))
     (setq v5f* (list v5i*x v5i*y v5f*z))
     (setq v9f* (list v9i*x v9i*y v9f*z))
     (setq v5f (trans v5f* (list dx59 dy59 dz59) 0))
     (setq v9f (trans v9f* (list dx59 dy59 dz59) 0))
     (setq v5x (car v5f) v5y (cadr v5f) v5z (caddr v5f))
     (setq v9x (car v9f) v9y (cadr v9f) v9z (caddr v9f))
    )
   )
  )
  (if (> d69 r69)
   (progn 
    (setq v6x (+ v6x (* a6x t)))  (setq v6y (+ v6y (* a6y t)))  (setq v6z (+ v6z (* a6z t)))
    (setq v9x (+ v9x (* a9x t)))  (setq v9y (+ v9y (* a9y t)))  (setq v9z (+ v9z (* a9z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v6i (list v6x v6y v6z)) ;velocita 6 prima dello scontro
     (setq v9i (list v9x v9y v9z)) ;velocita 9 prima dello scontro
     (setq v6i* (trans v6i 0 (list dx69 dy69 dz69)))
     (setq v9i* (trans v9i 0 (list dx69 dy69 dz69)))
     (setq v6i*x (car v6i*) v6i*y (cadr v6i*) v6i*z (caddr v6i*))
     (setq v9i*x (car v9i*) v9i*y (cadr v9i*) v9i*z (caddr v9i*))
     (setq v6f*z (* kur (/ (+ (* (- m6 m9) v6i*z) (* 2 m9 v9i*z)) (+ m6 m9))))
     (setq v9f*z (* kur (/ (+ (* (- m9 m6) v9i*z) (* 2 m6 v6i*z)) (+ m6 m9))))
     (setq v6f* (list v6i*x v6i*y v6f*z))
     (setq v9f* (list v9i*x v9i*y v9f*z))
     (setq v6f (trans v6f* (list dx69 dy69 dz69) 0))
     (setq v9f (trans v9f* (list dx69 dy69 dz69) 0))
     (setq v6x (car v6f) v6y (cadr v6f) v6z (caddr v6f))
     (setq v9x (car v9f) v9y (cadr v9f) v9z (caddr v9f))
    )
   )
  )
  (if (> d79 r79)
   (progn 
    (setq v7x (+ v7x (* a7x t)))  (setq v7y (+ v7y (* a7y t)))  (setq v7z (+ v7z (* a7z t)))
    (setq v9x (+ v9x (* a9x t)))  (setq v9y (+ v9y (* a9y t)))  (setq v9z (+ v9z (* a9z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v7i (list v7x v7y v7z)) ;velocita 7 prima dello scontro
     (setq v9i (list v9x v9y v9z)) ;velocita 9 prima dello scontro
     (setq v7i* (trans v7i 0 (list dx79 dy79 dz79)))
     (setq v9i* (trans v9i 0 (list dx79 dy79 dz79)))
     (setq v7i*x (car v7i*) v7i*y (cadr v7i*) v7i*z (caddr v7i*))
     (setq v9i*x (car v9i*) v9i*y (cadr v9i*) v9i*z (caddr v9i*))
     (setq v7f*z (* kur (/ (+ (* (- m7 m9) v7i*z) (* 2 m9 v9i*z)) (+ m7 m9))))
     (setq v9f*z (* kur (/ (+ (* (- m9 m7) v9i*z) (* 2 m7 v7i*z)) (+ m7 m9))))
     (setq v7f* (list v7i*x v7i*y v7f*z))
     (setq v9f* (list v9i*x v9i*y v9f*z))
     (setq v7f (trans v7f* (list dx79 dy79 dz79) 0))
     (setq v9f (trans v9f* (list dx79 dy79 dz79) 0))
     (setq v7x (car v7f) v7y (cadr v7f) v7z (caddr v7f))
     (setq v9x (car v9f) v9y (cadr v9f) v9z (caddr v9f))
    )
   )
  )
  (if (> d89 r89)
   (progn 
    (setq v8x (+ v8x (* a8x t)))  (setq v8y (+ v8y (* a8y t)))  (setq v8z (+ v8z (* a8z t)))
    (setq v9x (+ v9x (* a9x t)))  (setq v9y (+ v9y (* a9y t)))  (setq v9z (+ v9z (* a9z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v8i (list v8x v8y v8z)) ;velocita 8 prima dello scontro
     (setq v9i (list v9x v9y v9z)) ;velocita 9 prima dello scontro
     (setq v8i* (trans v8i 0 (list dx89 dy89 dz89)))
     (setq v9i* (trans v9i 0 (list dx89 dy89 dz89)))
     (setq v8i*x (car v8i*) v8i*y (cadr v8i*) v8i*z (caddr v8i*))
     (setq v9i*x (car v9i*) v9i*y (cadr v9i*) v9i*z (caddr v9i*))
     (setq v8f*z (* kur (/ (+ (* (- m8 m9) v8i*z) (* 2 m9 v9i*z)) (+ m8 m9))))
     (setq v9f*z (* kur (/ (+ (* (- m9 m8) v9i*z) (* 2 m8 v8i*z)) (+ m8 m9))))
     (setq v8f* (list v8i*x v8i*y v8f*z))
     (setq v9f* (list v9i*x v9i*y v9f*z))
     (setq v8f (trans v8f* (list dx89 dy89 dz89) 0))
     (setq v9f (trans v9f* (list dx89 dy89 dz89) 0))
     (setq v8x (car v8f) v8y (cadr v8f) v8z (caddr v8f))
     (setq v9x (car v9f) v9y (cadr v9f) v9z (caddr v9f))
    )
   )
  )
  (if (> d10 r10)
   (progn 
    (setq v1x (+ v1x (* a1x t)))  (setq v1y (+ v1y (* a1y t)))  (setq v1z (+ v1z (* a1z t)))
    (setq v0x (+ v0x (* a0x t)))  (setq v0y (+ v0y (* a0y t)))  (setq v0z (+ v0z (* a0z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v1i (list v1x v1y v1z)) ;velocita 1 prima dello scontro
     (setq v0i (list v0x v0y v0z)) ;velocita 0 prima dello scontro
     (setq v1i* (trans v1i 0 (list dx10 dy10 dz10)))
     (setq v0i* (trans v0i 0 (list dx10 dy10 dz10)))
     (setq v1i*x (car v1i*) v1i*y (cadr v1i*) v1i*z (caddr v1i*))
     (setq v0i*x (car v0i*) v0i*y (cadr v0i*) v0i*z (caddr v0i*))
     (setq v1f*z (* kur (/ (+ (* (- m1 m0) v1i*z) (* 2 m0 v0i*z)) (+ m1 m0))))
     (setq v0f*z (* kur (/ (+ (* (- m0 m1) v0i*z) (* 2 m1 v1i*z)) (+ m1 m0))))
     (setq v1f* (list v1i*x v1i*y v1f*z))
     (setq v0f* (list v0i*x v0i*y v0f*z))
     (setq v1f (trans v1f* (list dx10 dy10 dz10) 0))
     (setq v0f (trans v0f* (list dx10 dy10 dz10) 0))
     (setq v1x (car v1f) v1y (cadr v1f) v1z (caddr v1f))
     (setq v0x (car v0f) v0y (cadr v0f) v0z (caddr v0f))
    )
   )
  )
  (if (> d20 r20)
   (progn 
    (setq v2x (+ v2x (* a2x t)))  (setq v2y (+ v2y (* a2y t)))  (setq v2z (+ v2z (* a2z t)))
    (setq v0x (+ v0x (* a0x t)))  (setq v0y (+ v0y (* a0y t)))  (setq v0z (+ v0z (* a0z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v2i (list v2x v2y v2z)) ;velocita 2 prima dello scontro
     (setq v0i (list v0x v0y v0z)) ;velocita 0 prima dello scontro
     (setq v2i* (trans v2i 0 (list dx20 dy20 dz20)))
     (setq v0i* (trans v0i 0 (list dx20 dy20 dz20)))
     (setq v2i*x (car v2i*) v2i*y (cadr v2i*) v2i*z (caddr v2i*))
     (setq v0i*x (car v0i*) v0i*y (cadr v0i*) v0i*z (caddr v0i*))
     (setq v2f*z (* kur (/ (+ (* (- m2 m0) v2i*z) (* 2 m0 v0i*z)) (+ m2 m0))))
     (setq v0f*z (* kur (/ (+ (* (- m0 m2) v0i*z) (* 2 m2 v2i*z)) (+ m2 m0))))
     (setq v2f* (list v2i*x v2i*y v2f*z))
     (setq v0f* (list v0i*x v0i*y v0f*z))
     (setq v2f (trans v2f* (list dx20 dy20 dz20) 0))
     (setq v0f (trans v0f* (list dx20 dy20 dz20) 0))
     (setq v2x (car v2f) v2y (cadr v2f) v2z (caddr v2f))
     (setq v0x (car v0f) v0y (cadr v0f) v0z (caddr v0f))
    )
   )
  )
  (if (> d30 r30)
   (progn 
    (setq v3x (+ v3x (* a3x t)))  (setq v3y (+ v3y (* a3y t)))  (setq v3z (+ v3z (* a3z t)))
    (setq v0x (+ v0x (* a0x t)))  (setq v0y (+ v0y (* a0y t)))  (setq v0z (+ v0z (* a0z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v3i (list v3x v3y v3z)) ;velocita 3 prima dello scontro
     (setq v0i (list v0x v0y v0z)) ;velocita 0 prima dello scontro
     (setq v3i* (trans v3i 0 (list dx30 dy30 dz30)))
     (setq v0i* (trans v0i 0 (list dx30 dy30 dz30)))
     (setq v3i*x (car v3i*) v3i*y (cadr v3i*) v3i*z (caddr v3i*))
     (setq v0i*x (car v0i*) v0i*y (cadr v0i*) v0i*z (caddr v0i*))
     (setq v3f*z (* kur (/ (+ (* (- m3 m0) v3i*z) (* 2 m0 v0i*z)) (+ m3 m0))))
     (setq v0f*z (* kur (/ (+ (* (- m0 m3) v0i*z) (* 2 m3 v3i*z)) (+ m3 m0))))
     (setq v3f* (list v3i*x v3i*y v3f*z))
     (setq v0f* (list v0i*x v0i*y v0f*z))
     (setq v3f (trans v3f* (list dx30 dy30 dz30) 0))
     (setq v0f (trans v0f* (list dx30 dy30 dz30) 0))
     (setq v3x (car v3f) v3y (cadr v3f) v3z (caddr v3f))
     (setq v0x (car v0f) v0y (cadr v0f) v0z (caddr v0f))
    )
   )
  )
  (if (> d40 r40)
   (progn 
    (setq v4x (+ v4x (* a4x t)))  (setq v4y (+ v4y (* a4y t)))  (setq v4z (+ v4z (* a4z t)))
    (setq v0x (+ v0x (* a0x t)))  (setq v0y (+ v0y (* a0y t)))  (setq v0z (+ v0z (* a0z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v4i (list v4x v4y v4z)) ;velocita 4 prima dello scontro
     (setq v0i (list v0x v0y v0z)) ;velocita 0 prima dello scontro
     (setq v4i* (trans v4i 0 (list dx40 dy40 dz40)))
     (setq v0i* (trans v0i 0 (list dx40 dy40 dz40)))
     (setq v4i*x (car v4i*) v4i*y (cadr v4i*) v4i*z (caddr v4i*))
     (setq v0i*x (car v0i*) v0i*y (cadr v0i*) v0i*z (caddr v0i*))
     (setq v4f*z (* kur (/ (+ (* (- m4 m0) v4i*z) (* 2 m0 v0i*z)) (+ m4 m0))))
     (setq v0f*z (* kur (/ (+ (* (- m0 m4) v0i*z) (* 2 m4 v4i*z)) (+ m4 m0))))
     (setq v4f* (list v4i*x v4i*y v4f*z))
     (setq v0f* (list v0i*x v0i*y v0f*z))
     (setq v4f (trans v4f* (list dx40 dy40 dz40) 0))
     (setq v0f (trans v0f* (list dx40 dy40 dz40) 0))
     (setq v4x (car v4f) v4y (cadr v4f) v4z (caddr v4f))
     (setq v0x (car v0f) v0y (cadr v0f) v0z (caddr v0f))
    )
   )
  )
  (if (> d50 r50)
   (progn 
    (setq v5x (+ v5x (* a5x t)))  (setq v5y (+ v5y (* a5y t)))  (setq v5z (+ v5z (* a5z t)))
    (setq v0x (+ v0x (* a0x t)))  (setq v0y (+ v0y (* a0y t)))  (setq v0z (+ v0z (* a0z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v5i (list v5x v5y v5z)) ;velocita 5 prima dello scontro
     (setq v0i (list v0x v0y v0z)) ;velocita 0 prima dello scontro
     (setq v5i* (trans v5i 0 (list dx50 dy50 dz50)))
     (setq v0i* (trans v0i 0 (list dx50 dy50 dz50)))
     (setq v5i*x (car v5i*) v5i*y (cadr v5i*) v5i*z (caddr v5i*))
     (setq v0i*x (car v0i*) v0i*y (cadr v0i*) v0i*z (caddr v0i*))
     (setq v5f*z (* kur (/ (+ (* (- m5 m0) v5i*z) (* 2 m0 v0i*z)) (+ m5 m0))))
     (setq v0f*z (* kur (/ (+ (* (- m0 m5) v0i*z) (* 2 m5 v5i*z)) (+ m5 m0))))
     (setq v5f* (list v5i*x v5i*y v5f*z))
     (setq v0f* (list v0i*x v0i*y v0f*z))
     (setq v5f (trans v5f* (list dx50 dy50 dz50) 0))
     (setq v0f (trans v0f* (list dx50 dy50 dz50) 0))
     (setq v5x (car v5f) v5y (cadr v5f) v5z (caddr v5f))
     (setq v0x (car v0f) v0y (cadr v0f) v0z (caddr v0f))
    )
   )
  )
  (if (> d60 r60)
   (progn 
    (setq v6x (+ v6x (* a6x t)))  (setq v6y (+ v6y (* a6y t)))  (setq v6z (+ v6z (* a6z t)))
    (setq v0x (+ v0x (* a0x t)))  (setq v0y (+ v0y (* a0y t)))  (setq v0z (+ v0z (* a0z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v6i (list v6x v6y v6z)) ;velocita 6 prima dello scontro
     (setq v0i (list v0x v0y v0z)) ;velocita 0 prima dello scontro
     (setq v6i* (trans v6i 0 (list dx60 dy60 dz60)))
     (setq v0i* (trans v0i 0 (list dx60 dy60 dz60)))
     (setq v6i*x (car v6i*) v6i*y (cadr v6i*) v6i*z (caddr v6i*))
     (setq v0i*x (car v0i*) v0i*y (cadr v0i*) v0i*z (caddr v0i*))
     (setq v6f*z (* kur (/ (+ (* (- m6 m0) v6i*z) (* 2 m0 v0i*z)) (+ m6 m0))))
     (setq v0f*z (* kur (/ (+ (* (- m0 m6) v0i*z) (* 2 m6 v6i*z)) (+ m6 m0))))
     (setq v6f* (list v6i*x v6i*y v6f*z))
     (setq v0f* (list v0i*x v0i*y v0f*z))
     (setq v6f (trans v6f* (list dx60 dy60 dz60) 0))
     (setq v0f (trans v0f* (list dx60 dy60 dz60) 0))
     (setq v6x (car v6f) v6y (cadr v6f) v6z (caddr v6f))
     (setq v0x (car v0f) v0y (cadr v0f) v0z (caddr v0f))
    )
   )
  )
  (if (> d70 r70)
   (progn 
    (setq v7x (+ v7x (* a7x t)))  (setq v7y (+ v7y (* a7y t)))  (setq v7z (+ v7z (* a7z t)))
    (setq v0x (+ v0x (* a0x t)))  (setq v0y (+ v0y (* a0y t)))  (setq v0z (+ v0z (* a0z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v7i (list v7x v7y v7z)) ;velocita 7 prima dello scontro
     (setq v0i (list v0x v0y v0z)) ;velocita 0 prima dello scontro
     (setq v7i* (trans v7i 0 (list dx70 dy70 dz70)))
     (setq v0i* (trans v0i 0 (list dx70 dy70 dz70)))
     (setq v7i*x (car v7i*) v7i*y (cadr v7i*) v7i*z (caddr v7i*))
     (setq v0i*x (car v0i*) v0i*y (cadr v0i*) v0i*z (caddr v0i*))
     (setq v7f*z (* kur (/ (+ (* (- m7 m0) v7i*z) (* 2 m0 v0i*z)) (+ m7 m0))))
     (setq v0f*z (* kur (/ (+ (* (- m0 m7) v0i*z) (* 2 m7 v7i*z)) (+ m7 m0))))
     (setq v7f* (list v7i*x v7i*y v7f*z))
     (setq v0f* (list v0i*x v0i*y v0f*z))
     (setq v7f (trans v7f* (list dx70 dy70 dz70) 0))
     (setq v0f (trans v0f* (list dx70 dy70 dz70) 0))
     (setq v7x (car v7f) v7y (cadr v7f) v7z (caddr v7f))
     (setq v0x (car v0f) v0y (cadr v0f) v0z (caddr v0f))
    )
   )
  )
  (if (> d80 r80)
   (progn 
    (setq v8x (+ v8x (* a8x t)))  (setq v8y (+ v8y (* a8y t)))  (setq v8z (+ v8z (* a8z t)))
    (setq v0x (+ v0x (* a0x t)))  (setq v0y (+ v0y (* a0y t)))  (setq v0z (+ v0z (* a0z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v8i (list v8x v8y v8z)) ;velocita 8 prima dello scontro
     (setq v0i (list v0x v0y v0z)) ;velocita 0 prima dello scontro
     (setq v8i* (trans v8i 0 (list dx80 dy80 dz80)))
     (setq v0i* (trans v0i 0 (list dx80 dy80 dz80)))
     (setq v8i*x (car v8i*) v8i*y (cadr v8i*) v8i*z (caddr v8i*))
     (setq v0i*x (car v0i*) v0i*y (cadr v0i*) v0i*z (caddr v0i*))
     (setq v8f*z (* kur (/ (+ (* (- m8 m0) v8i*z) (* 2 m0 v0i*z)) (+ m8 m0))))
     (setq v0f*z (* kur (/ (+ (* (- m0 m8) v0i*z) (* 2 m8 v8i*z)) (+ m8 m0))))
     (setq v8f* (list v8i*x v8i*y v8f*z))
     (setq v0f* (list v0i*x v0i*y v0f*z))
     (setq v8f (trans v8f* (list dx80 dy80 dz80) 0))
     (setq v0f (trans v0f* (list dx80 dy80 dz80) 0))
     (setq v8x (car v8f) v8y (cadr v8f) v8z (caddr v8f))
     (setq v0x (car v0f) v0y (cadr v0f) v0z (caddr v0f))
    )
   )
  )
  (if (> d90 r90)
   (progn 
    (setq v9x (+ v9x (* a9x t)))  (setq v9y (+ v9y (* a9y t)))  (setq v9z (+ v9z (* a9z t)))
    (setq v0x (+ v0x (* a0x t)))  (setq v0y (+ v0y (* a0y t)))  (setq v0z (+ v0z (* a0z t)))
   )
   (if (/= kur 0)
    (progn
     (setq v9i (list v9x v9y v9z)) ;velocita 9 prima dello scontro
     (setq v0i (list v0x v0y v0z)) ;velocita 0 prima dello scontro
     (setq v9i* (trans v9i 0 (list dx90 dy90 dz90)))
     (setq v0i* (trans v0i 0 (list dx90 dy90 dz90)))
     (setq v9i*x (car v9i*) v9i*y (cadr v9i*) v9i*z (caddr v9i*))
     (setq v0i*x (car v0i*) v0i*y (cadr v0i*) v0i*z (caddr v0i*))
     (setq v9f*z (* kur (/ (+ (* (- m9 m0) v9i*z) (* 2 m0 v0i*z)) (+ m9 m0))))
     (setq v0f*z (* kur (/ (+ (* (- m0 m9) v0i*z) (* 2 m9 v9i*z)) (+ m9 m0))))
     (setq v9f* (list v9i*x v9i*y v9f*z))
     (setq v0f* (list v0i*x v0i*y v0f*z))
     (setq v9f (trans v9f* (list dx90 dy90 dz90) 0))
     (setq v0f (trans v0f* (list dx90 dy90 dz90) 0))
     (setq v9x (car v9f) v9y (cadr v9f) v9z (caddr v9f))
     (setq v0x (car v0f) v0y (cadr v0f) v0z (caddr v0f))
    )
   )
  )

  (if (> d1a r1a)
   (progn 
    (setq v1x (+ v1x (* a1x t)))  (setq v1y (+ v1y (* a1y t)))  (setq v1z (+ v1z (* a1z t)))
    (setq vax (+ vax (* aax t)))  (setq vay (+ vay (* aay t)))  (setq vaz (+ vaz (* aaz t)))
   )
   (if (/= kur 0)
    (progn
     (setq v1i (list v1x v1y v1z)) ;velocita 1 prima dello scontro
     (setq vai (list vax vay vaz)) ;velocita a prima dello scontro
     (setq v1i* (trans v1i 0 (list dx1a dy1a dz1a)))
     (setq vai* (trans vai 0 (list dx1a dy1a dz1a)))
     (setq v1i*x (car v1i*) v1i*y (cadr v1i*) v1i*z (caddr v1i*))
     (setq vai*x (car vai*) vai*y (cadr vai*) vai*z (caddr vai*))
     (setq v1f*z (* kur (/ (+ (* (- m1 ma) v1i*z) (* 2 ma vai*z)) (+ m1 ma))))
     (setq vaf*z (* kur (/ (+ (* (- ma m1) vai*z) (* 2 m1 v1i*z)) (+ m1 ma))))
     (setq v1f* (list v1i*x v1i*y v1f*z))
     (setq vaf* (list vai*x vai*y vaf*z))
     (setq v1f (trans v1f* (list dx1a dy1a dz1a) 0))
     (setq vaf (trans vaf* (list dx1a dy1a dz1a) 0))
     (setq v1x (car v1f) v1y (cadr v1f) v1z (caddr v1f))
     (setq vax (car vaf) vay (cadr vaf) vaz (caddr vaf))
    )
   )
  )
  (if (> d2a r2a)
   (progn 
    (setq v2x (+ v2x (* a2x t)))  (setq v2y (+ v2y (* a2y t)))  (setq v2z (+ v2z (* a2z t)))
    (setq vax (+ vax (* aax t)))  (setq vay (+ vay (* aay t)))  (setq vaz (+ vaz (* aaz t)))
   )
   (if (/= kur 0)
    (progn
     (setq v2i (list v2x v2y v2z)) ;velocita 2 prima dello scontro
     (setq vai (list vax vay vaz)) ;velocita a prima dello scontro
     (setq v2i* (trans v2i 0 (list dx2a dy2a dz2a)))
     (setq vai* (trans vai 0 (list dx2a dy2a dz2a)))
     (setq v2i*x (car v2i*) v2i*y (cadr v2i*) v2i*z (caddr v2i*))
     (setq vai*x (car vai*) vai*y (cadr vai*) vai*z (caddr vai*))
     (setq v2f*z (* kur (/ (+ (* (- m2 ma) v2i*z) (* 2 ma vai*z)) (+ m2 ma))))
     (setq vaf*z (* kur (/ (+ (* (- ma m2) vai*z) (* 2 m2 v2i*z)) (+ m2 ma))))
     (setq v2f* (list v2i*x v2i*y v2f*z))
     (setq vaf* (list vai*x vai*y vaf*z))
     (setq v2f (trans v2f* (list dx2a dy2a dz2a) 0))
     (setq vaf (trans vaf* (list dx2a dy2a dz2a) 0))
     (setq v2x (car v2f) v2y (cadr v2f) v2z (caddr v2f))
     (setq vax (car vaf) vay (cadr vaf) vaz (caddr vaf))
    )
   )
  )
  (if (> d3a r3a)
   (progn 
    (setq v3x (+ v3x (* a3x t)))  (setq v3y (+ v3y (* a3y t)))  (setq v3z (+ v3z (* a3z t)))
    (setq vax (+ vax (* aax t)))  (setq vay (+ vay (* aay t)))  (setq vaz (+ vaz (* aaz t)))
   )
   (if (/= kur 0)
    (progn
     (setq v3i (list v3x v3y v3z)) ;velocita 3 prima dello scontro
     (setq vai (list vax vay vaz)) ;velocita a prima dello scontro
     (setq v3i* (trans v3i 0 (list dx3a dy3a dz3a)))
     (setq vai* (trans vai 0 (list dx3a dy3a dz3a)))
     (setq v3i*x (car v3i*) v3i*y (cadr v3i*) v3i*z (caddr v3i*))
     (setq vai*x (car vai*) vai*y (cadr vai*) vai*z (caddr vai*))
     (setq v3f*z (* kur (/ (+ (* (- m3 ma) v3i*z) (* 2 ma vai*z)) (+ m3 ma))))
     (setq vaf*z (* kur (/ (+ (* (- ma m3) vai*z) (* 2 m3 v3i*z)) (+ m3 ma))))
     (setq v3f* (list v3i*x v3i*y v3f*z))
     (setq vaf* (list vai*x vai*y vaf*z))
     (setq v3f (trans v3f* (list dx3a dy3a dz3a) 0))
     (setq vaf (trans vaf* (list dx3a dy3a dz3a) 0))
     (setq v3x (car v3f) v3y (cadr v3f) v3z (caddr v3f))
     (setq vax (car vaf) vay (cadr vaf) vaz (caddr vaf))
    )
   )
  )
  (if (> d4a r4a)
   (progn 
    (setq v4x (+ v4x (* a4x t)))  (setq v4y (+ v4y (* a4y t)))  (setq v4z (+ v4z (* a4z t)))
    (setq vax (+ vax (* aax t)))  (setq vay (+ vay (* aay t)))  (setq vaz (+ vaz (* aaz t)))
   )
   (if (/= kur 0)
    (progn
     (setq v4i (list v4x v4y v4z)) ;velocita 4 prima dello scontro
     (setq vai (list vax vay vaz)) ;velocita a prima dello scontro
     (setq v4i* (trans v4i 0 (list dx4a dy4a dz4a)))
     (setq vai* (trans vai 0 (list dx4a dy4a dz4a)))
     (setq v4i*x (car v4i*) v4i*y (cadr v4i*) v4i*z (caddr v4i*))
     (setq vai*x (car vai*) vai*y (cadr vai*) vai*z (caddr vai*))
     (setq v4f*z (* kur (/ (+ (* (- m4 ma) v4i*z) (* 2 ma vai*z)) (+ m4 ma))))
     (setq vaf*z (* kur (/ (+ (* (- ma m4) vai*z) (* 2 m4 v4i*z)) (+ m4 ma))))
     (setq v4f* (list v4i*x v4i*y v4f*z))
     (setq vaf* (list vai*x vai*y vaf*z))
     (setq v4f (trans v4f* (list dx4a dy4a dz4a) 0))
     (setq vaf (trans vaf* (list dx4a dy4a dz4a) 0))
     (setq v4x (car v4f) v4y (cadr v4f) v4z (caddr v4f))
     (setq vax (car vaf) vay (cadr vaf) vaz (caddr vaf))
    )
   )
  )
  (if (> d5a r5a)
   (progn 
    (setq v5x (+ v5x (* a5x t)))  (setq v5y (+ v5y (* a5y t)))  (setq v5z (+ v5z (* a5z t)))
    (setq vax (+ vax (* aax t)))  (setq vay (+ vay (* aay t)))  (setq vaz (+ vaz (* aaz t)))
   )
   (if (/= kur 0)
    (progn
     (setq v5i (list v5x v5y v5z)) ;velocita 5 prima dello scontro
     (setq vai (list vax vay vaz)) ;velocita a prima dello scontro
     (setq v5i* (trans v5i 0 (list dx5a dy5a dz5a)))
     (setq vai* (trans vai 0 (list dx5a dy5a dz5a)))
     (setq v5i*x (car v5i*) v5i*y (cadr v5i*) v5i*z (caddr v5i*))
     (setq vai*x (car vai*) vai*y (cadr vai*) vai*z (caddr vai*))
     (setq v5f*z (* kur (/ (+ (* (- m5 ma) v5i*z) (* 2 ma vai*z)) (+ m5 ma))))
     (setq vaf*z (* kur (/ (+ (* (- ma m5) vai*z) (* 2 m5 v5i*z)) (+ m5 ma))))
     (setq v5f* (list v5i*x v5i*y v5f*z))
     (setq vaf* (list vai*x vai*y vaf*z))
     (setq v5f (trans v5f* (list dx5a dy5a dz5a) 0))
     (setq vaf (trans vaf* (list dx5a dy5a dz5a) 0))
     (setq v5x (car v5f) v5y (cadr v5f) v5z (caddr v5f))
     (setq vax (car vaf) vay (cadr vaf) vaz (caddr vaf))
    )
   )
  )
  (if (> d6a r6a)
   (progn 
    (setq v6x (+ v6x (* a6x t)))  (setq v6y (+ v6y (* a6y t)))  (setq v6z (+ v6z (* a6z t)))
    (setq vax (+ vax (* aax t)))  (setq vay (+ vay (* aay t)))  (setq vaz (+ vaz (* aaz t)))
   )
   (if (/= kur 0)
    (progn
     (setq v6i (list v6x v6y v6z)) ;velocita 6 prima dello scontro
     (setq vai (list vax vay vaz)) ;velocita a prima dello scontro
     (setq v6i* (trans v6i 0 (list dx6a dy6a dz6a)))
     (setq vai* (trans vai 0 (list dx6a dy6a dz6a)))
     (setq v6i*x (car v6i*) v6i*y (cadr v6i*) v6i*z (caddr v6i*))
     (setq vai*x (car vai*) vai*y (cadr vai*) vai*z (caddr vai*))
     (setq v6f*z (* kur (/ (+ (* (- m6 ma) v6i*z) (* 2 ma vai*z)) (+ m6 ma))))
     (setq vaf*z (* kur (/ (+ (* (- ma m6) vai*z) (* 2 m6 v6i*z)) (+ m6 ma))))
     (setq v6f* (list v6i*x v6i*y v6f*z))
     (setq vaf* (list vai*x vai*y vaf*z))
     (setq v6f (trans v6f* (list dx6a dy6a dz6a) 0))
     (setq vaf (trans vaf* (list dx6a dy6a dz6a) 0))
     (setq v6x (car v6f) v6y (cadr v6f) v6z (caddr v6f))
     (setq vax (car vaf) vay (cadr vaf) vaz (caddr vaf))
    )
   )
  )
  (if (> d7a r7a)
   (progn 
    (setq v7x (+ v7x (* a7x t)))  (setq v7y (+ v7y (* a7y t)))  (setq v7z (+ v7z (* a7z t)))
    (setq vax (+ vax (* aax t)))  (setq vay (+ vay (* aay t)))  (setq vaz (+ vaz (* aaz t)))
   )
   (if (/= kur 0)
    (progn
     (setq v7i (list v7x v7y v7z)) ;velocita 7 prima dello scontro
     (setq vai (list vax vay vaz)) ;velocita a prima dello scontro
     (setq v7i* (trans v7i 0 (list dx7a dy7a dz7a)))
     (setq vai* (trans vai 0 (list dx7a dy7a dz7a)))
     (setq v7i*x (car v7i*) v7i*y (cadr v7i*) v7i*z (caddr v7i*))
     (setq vai*x (car vai*) vai*y (cadr vai*) vai*z (caddr vai*))
     (setq v7f*z (* kur (/ (+ (* (- m7 ma) v7i*z) (* 2 ma vai*z)) (+ m7 ma))))
     (setq vaf*z (* kur (/ (+ (* (- ma m7) vai*z) (* 2 m7 v7i*z)) (+ m7 ma))))
     (setq v7f* (list v7i*x v7i*y v7f*z))
     (setq vaf* (list vai*x vai*y vaf*z))
     (setq v7f (trans v7f* (list dx7a dy7a dz7a) 0))
     (setq vaf (trans vaf* (list dx7a dy7a dz7a) 0))
     (setq v7x (car v7f) v7y (cadr v7f) v7z (caddr v7f))
     (setq vax (car vaf) vay (cadr vaf) vaz (caddr vaf))
    )
   )
  )
  (if (> d8a r8a)
   (progn 
    (setq v8x (+ v8x (* a8x t)))  (setq v8y (+ v8y (* a8y t)))  (setq v8z (+ v8z (* a8z t)))
    (setq vax (+ vax (* aax t)))  (setq vay (+ vay (* aay t)))  (setq vaz (+ vaz (* aaz t)))
   )
   (if (/= kur 0)
    (progn
     (setq v8i (list v8x v8y v8z)) ;velocita 8 prima dello scontro
     (setq vai (list vax vay vaz)) ;velocita a prima dello scontro
     (setq v8i* (trans v8i 0 (list dx8a dy8a dz8a)))
     (setq vai* (trans vai 0 (list dx8a dy8a dz8a)))
     (setq v8i*x (car v8i*) v8i*y (cadr v8i*) v8i*z (caddr v8i*))
     (setq vai*x (car vai*) vai*y (cadr vai*) vai*z (caddr vai*))
     (setq v8f*z (* kur (/ (+ (* (- m8 ma) v8i*z) (* 2 ma vai*z)) (+ m8 ma))))
     (setq vaf*z (* kur (/ (+ (* (- ma m8) vai*z) (* 2 m8 v8i*z)) (+ m8 ma))))
     (setq v8f* (list v8i*x v8i*y v8f*z))
     (setq vaf* (list vai*x vai*y vaf*z))
     (setq v8f (trans v8f* (list dx8a dy8a dz8a) 0))
     (setq vaf (trans vaf* (list dx8a dy8a dz8a) 0))
     (setq v8x (car v8f) v8y (cadr v8f) v8z (caddr v8f))
     (setq vax (car vaf) vay (cadr vaf) vaz (caddr vaf))
    )
   )
  )
  (if (> d9a r9a)
   (progn 
    (setq v9x (+ v9x (* a9x t)))  (setq v9y (+ v9y (* a9y t)))  (setq v9z (+ v9z (* a9z t)))
    (setq vax (+ vax (* aax t)))  (setq vay (+ vay (* aay t)))  (setq vaz (+ vaz (* aaz t)))
   )
   (if (/= kur 0)
    (progn
     (setq v9i (list v9x v9y v9z)) ;velocita 9 prima dello scontro
     (setq vai (list vax vay vaz)) ;velocita a prima dello scontro
     (setq v9i* (trans v9i 0 (list dx9a dy9a dz9a)))
     (setq vai* (trans vai 0 (list dx9a dy9a dz9a)))
     (setq v9i*x (car v9i*) v9i*y (cadr v9i*) v9i*z (caddr v9i*))
     (setq vai*x (car vai*) vai*y (cadr vai*) vai*z (caddr vai*))
     (setq v9f*z (* kur (/ (+ (* (- m9 ma) v9i*z) (* 2 ma vai*z)) (+ m9 ma))))
     (setq vaf*z (* kur (/ (+ (* (- ma m9) vai*z) (* 2 m9 v9i*z)) (+ m9 ma))))
     (setq v9f* (list v9i*x v9i*y v9f*z))
     (setq vaf* (list vai*x vai*y vaf*z))
     (setq v9f (trans v9f* (list dx9a dy9a dz9a) 0))
     (setq vaf (trans vaf* (list dx9a dy9a dz9a) 0))
     (setq v9x (car v9f) v9y (cadr v9f) v9z (caddr v9f))
     (setq vax (car vaf) vay (cadr vaf) vaz (caddr vaf))
    )
   )
  )
  (if (> d0a r0a)
   (progn 
    (setq v0x (+ v0x (* a0x t)))  (setq v0y (+ v0y (* a0y t)))  (setq v0z (+ v0z (* a0z t)))
    (setq vax (+ vax (* aax t)))  (setq vay (+ vay (* aay t)))  (setq vaz (+ vaz (* aaz t)))
   )
   (if (/= kur 0)
    (progn
     (setq v0i (list v0x v0y v0z)) ;velocita 0 prima dello scontro
     (setq vai (list vax vay vaz)) ;velocita a prima dello scontro
     (setq v0i* (trans v0i 0 (list dx0a dy0a dz0a)))
     (setq vai* (trans vai 0 (list dx0a dy0a dz0a)))
     (setq v0i*x (car v0i*) v0i*y (cadr v0i*) v0i*z (caddr v0i*))
     (setq vai*x (car vai*) vai*y (cadr vai*) vai*z (caddr vai*))
     (setq v0f*z (* kur (/ (+ (* (- m0 ma) v0i*z) (* 2 ma vai*z)) (+ m0 ma))))
     (setq vaf*z (* kur (/ (+ (* (- ma m0) vai*z) (* 2 m0 v0i*z)) (+ m0 ma))))
     (setq v0f* (list v0i*x v0i*y v0f*z))
     (setq vaf* (list vai*x vai*y vaf*z))
     (setq v0f (trans v0f* (list dx0a dy0a dz0a) 0))
     (setq vaf (trans vaf* (list dx0a dy0a dz0a) 0))
     (setq v0x (car v0f) v0y (cadr v0f) v0z (caddr v0f))
     (setq vax (car vaf) vay (cadr vaf) vaz (caddr vaf))
    )
   )
  )
  (if (> d1b r1b)
   (progn 
    (setq v1x (+ v1x (* a1x t)))  (setq v1y (+ v1y (* a1y t)))  (setq v1z (+ v1z (* a1z t)))
    (setq vbx (+ vbx (* abx t)))  (setq vby (+ vby (* aby t)))  (setq vbz (+ vbz (* abz t)))
   )
   (if (/= kur 0)
    (progn
     (setq v1i (list v1x v1y v1z)) ;velocita 1 primb dello scontro
     (setq vbi (list vbx vby vbz)) ;velocita a primb dello scontro
     (setq v1i* (trans v1i 0 (list dx1b dy1b dz1b)))
     (setq vbi* (trans vbi 0 (list dx1b dy1b dz1b)))
     (setq v1i*x (car v1i*) v1i*y (cadr v1i*) v1i*z (caddr v1i*))
     (setq vbi*x (car vbi*) vbi*y (cadr vbi*) vbi*z (caddr vbi*))
     (setq v1f*z (* kur (/ (+ (* (- m1 mb) v1i*z) (* 2 mb vbi*z)) (+ m1 mb))))
     (setq vbf*z (* kur (/ (+ (* (- mb m1) vbi*z) (* 2 m1 v1i*z)) (+ m1 mb))))
     (setq v1f* (list v1i*x v1i*y v1f*z))
     (setq vbf* (list vbi*x vbi*y vbf*z))
     (setq v1f (trans v1f* (list dx1b dy1b dz1b) 0))
     (setq vbf (trans vbf* (list dx1b dy1b dz1b) 0))
     (setq v1x (car v1f) v1y (cadr v1f) v1z (caddr v1f))
     (setq vbx (car vbf) vby (cadr vbf) vbz (caddr vbf))
    )
   )
  )
  (if (> d2b r2b)
   (progn 
    (setq v2x (+ v2x (* a2x t)))  (setq v2y (+ v2y (* a2y t)))  (setq v2z (+ v2z (* a2z t)))
    (setq vbx (+ vbx (* abx t)))  (setq vby (+ vby (* aby t)))  (setq vbz (+ vbz (* abz t)))
   )
   (if (/= kur 0)
    (progn
     (setq v2i (list v2x v2y v2z)) ;velocita 2 primb dello scontro
     (setq vbi (list vbx vby vbz)) ;velocita a primb dello scontro
     (setq v2i* (trans v2i 0 (list dx2b dy2b dz2b)))
     (setq vbi* (trans vbi 0 (list dx2b dy2b dz2b)))
     (setq v2i*x (car v2i*) v2i*y (cadr v2i*) v2i*z (caddr v2i*))
     (setq vbi*x (car vbi*) vbi*y (cadr vbi*) vbi*z (caddr vbi*))
     (setq v2f*z (* kur (/ (+ (* (- m2 mb) v2i*z) (* 2 mb vbi*z)) (+ m2 mb))))
     (setq vbf*z (* kur (/ (+ (* (- mb m2) vbi*z) (* 2 m2 v2i*z)) (+ m2 mb))))
     (setq v2f* (list v2i*x v2i*y v2f*z))
     (setq vbf* (list vbi*x vbi*y vbf*z))
     (setq v2f (trans v2f* (list dx2b dy2b dz2b) 0))
     (setq vbf (trans vbf* (list dx2b dy2b dz2b) 0))
     (setq v2x (car v2f) v2y (cadr v2f) v2z (caddr v2f))
     (setq vbx (car vbf) vby (cadr vbf) vbz (caddr vbf))
    )
   )
  )
  (if (> d3b r3b)
   (progn 
    (setq v3x (+ v3x (* a3x t)))  (setq v3y (+ v3y (* a3y t)))  (setq v3z (+ v3z (* a3z t)))
    (setq vbx (+ vbx (* abx t)))  (setq vby (+ vby (* aby t)))  (setq vbz (+ vbz (* abz t)))
   )
   (if (/= kur 0)
    (progn
     (setq v3i (list v3x v3y v3z)) ;velocita 3 primb dello scontro
     (setq vbi (list vbx vby vbz)) ;velocita a primb dello scontro
     (setq v3i* (trans v3i 0 (list dx3b dy3b dz3b)))
     (setq vbi* (trans vbi 0 (list dx3b dy3b dz3b)))
     (setq v3i*x (car v3i*) v3i*y (cadr v3i*) v3i*z (caddr v3i*))
     (setq vbi*x (car vbi*) vbi*y (cadr vbi*) vbi*z (caddr vbi*))
     (setq v3f*z (* kur (/ (+ (* (- m3 mb) v3i*z) (* 2 mb vbi*z)) (+ m3 mb))))
     (setq vbf*z (* kur (/ (+ (* (- mb m3) vbi*z) (* 2 m3 v3i*z)) (+ m3 mb))))
     (setq v3f* (list v3i*x v3i*y v3f*z))
     (setq vbf* (list vbi*x vbi*y vbf*z))
     (setq v3f (trans v3f* (list dx3b dy3b dz3b) 0))
     (setq vbf (trans vbf* (list dx3b dy3b dz3b) 0))
     (setq v3x (car v3f) v3y (cadr v3f) v3z (caddr v3f))
     (setq vbx (car vbf) vby (cadr vbf) vbz (caddr vbf))
    )
   )
  )
  (if (> d4b r4b)
   (progn 
    (setq v4x (+ v4x (* a4x t)))  (setq v4y (+ v4y (* a4y t)))  (setq v4z (+ v4z (* a4z t)))
    (setq vbx (+ vbx (* abx t)))  (setq vby (+ vby (* aby t)))  (setq vbz (+ vbz (* abz t)))
   )
   (if (/= kur 0)
    (progn
     (setq v4i (list v4x v4y v4z)) ;velocita 4 primb dello scontro
     (setq vbi (list vbx vby vbz)) ;velocita a primb dello scontro
     (setq v4i* (trans v4i 0 (list dx4b dy4b dz4b)))
     (setq vbi* (trans vbi 0 (list dx4b dy4b dz4b)))
     (setq v4i*x (car v4i*) v4i*y (cadr v4i*) v4i*z (caddr v4i*))
     (setq vbi*x (car vbi*) vbi*y (cadr vbi*) vbi*z (caddr vbi*))
     (setq v4f*z (* kur (/ (+ (* (- m4 mb) v4i*z) (* 2 mb vbi*z)) (+ m4 mb))))
     (setq vbf*z (* kur (/ (+ (* (- mb m4) vbi*z) (* 2 m4 v4i*z)) (+ m4 mb))))
     (setq v4f* (list v4i*x v4i*y v4f*z))
     (setq vbf* (list vbi*x vbi*y vbf*z))
     (setq v4f (trans v4f* (list dx4b dy4b dz4b) 0))
     (setq vbf (trans vbf* (list dx4b dy4b dz4b) 0))
     (setq v4x (car v4f) v4y (cadr v4f) v4z (caddr v4f))
     (setq vbx (car vbf) vby (cadr vbf) vbz (caddr vbf))
    )
   )
  )
  (if (> d5b r5b)
   (progn 
    (setq v5x (+ v5x (* a5x t)))  (setq v5y (+ v5y (* a5y t)))  (setq v5z (+ v5z (* a5z t)))
    (setq vbx (+ vbx (* abx t)))  (setq vby (+ vby (* aby t)))  (setq vbz (+ vbz (* abz t)))
   )
   (if (/= kur 0)
    (progn
     (setq v5i (list v5x v5y v5z)) ;velocita 5 primb dello scontro
     (setq vbi (list vbx vby vbz)) ;velocita a primb dello scontro
     (setq v5i* (trans v5i 0 (list dx5b dy5b dz5b)))
     (setq vbi* (trans vbi 0 (list dx5b dy5b dz5b)))
     (setq v5i*x (car v5i*) v5i*y (cadr v5i*) v5i*z (caddr v5i*))
     (setq vbi*x (car vbi*) vbi*y (cadr vbi*) vbi*z (caddr vbi*))
     (setq v5f*z (* kur (/ (+ (* (- m5 mb) v5i*z) (* 2 mb vbi*z)) (+ m5 mb))))
     (setq vbf*z (* kur (/ (+ (* (- mb m5) vbi*z) (* 2 m5 v5i*z)) (+ m5 mb))))
     (setq v5f* (list v5i*x v5i*y v5f*z))
     (setq vbf* (list vbi*x vbi*y vbf*z))
     (setq v5f (trans v5f* (list dx5b dy5b dz5b) 0))
     (setq vbf (trans vbf* (list dx5b dy5b dz5b) 0))
     (setq v5x (car v5f) v5y (cadr v5f) v5z (caddr v5f))
     (setq vbx (car vbf) vby (cadr vbf) vbz (caddr vbf))
    )
   )
  )
  (if (> d6b r6b)
   (progn 
    (setq v6x (+ v6x (* a6x t)))  (setq v6y (+ v6y (* a6y t)))  (setq v6z (+ v6z (* a6z t)))
    (setq vbx (+ vbx (* abx t)))  (setq vby (+ vby (* aby t)))  (setq vbz (+ vbz (* abz t)))
   )
   (if (/= kur 0)
    (progn
     (setq v6i (list v6x v6y v6z)) ;velocita 6 primb dello scontro
     (setq vbi (list vbx vby vbz)) ;velocita a primb dello scontro
     (setq v6i* (trans v6i 0 (list dx6b dy6b dz6b)))
     (setq vbi* (trans vbi 0 (list dx6b dy6b dz6b)))
     (setq v6i*x (car v6i*) v6i*y (cadr v6i*) v6i*z (caddr v6i*))
     (setq vbi*x (car vbi*) vbi*y (cadr vbi*) vbi*z (caddr vbi*))
     (setq v6f*z (* kur (/ (+ (* (- m6 mb) v6i*z) (* 2 mb vbi*z)) (+ m6 mb))))
     (setq vbf*z (* kur (/ (+ (* (- mb m6) vbi*z) (* 2 m6 v6i*z)) (+ m6 mb))))
     (setq v6f* (list v6i*x v6i*y v6f*z))
     (setq vbf* (list vbi*x vbi*y vbf*z))
     (setq v6f (trans v6f* (list dx6b dy6b dz6b) 0))
     (setq vbf (trans vbf* (list dx6b dy6b dz6b) 0))
     (setq v6x (car v6f) v6y (cadr v6f) v6z (caddr v6f))
     (setq vbx (car vbf) vby (cadr vbf) vbz (caddr vbf))
    )
   )
  )
  (if (> d7b r7b)
   (progn 
    (setq v7x (+ v7x (* a7x t)))  (setq v7y (+ v7y (* a7y t)))  (setq v7z (+ v7z (* a7z t)))
    (setq vbx (+ vbx (* abx t)))  (setq vby (+ vby (* aby t)))  (setq vbz (+ vbz (* abz t)))
   )
   (if (/= kur 0)
    (progn
     (setq v7i (list v7x v7y v7z)) ;velocita 7 primb dello scontro
     (setq vbi (list vbx vby vbz)) ;velocita a primb dello scontro
     (setq v7i* (trans v7i 0 (list dx7b dy7b dz7b)))
     (setq vbi* (trans vbi 0 (list dx7b dy7b dz7b)))
     (setq v7i*x (car v7i*) v7i*y (cadr v7i*) v7i*z (caddr v7i*))
     (setq vbi*x (car vbi*) vbi*y (cadr vbi*) vbi*z (caddr vbi*))
     (setq v7f*z (* kur (/ (+ (* (- m7 mb) v7i*z) (* 2 mb vbi*z)) (+ m7 mb))))
     (setq vbf*z (* kur (/ (+ (* (- mb m7) vbi*z) (* 2 m7 v7i*z)) (+ m7 mb))))
     (setq v7f* (list v7i*x v7i*y v7f*z))
     (setq vbf* (list vbi*x vbi*y vbf*z))
     (setq v7f (trans v7f* (list dx7b dy7b dz7b) 0))
     (setq vbf (trans vbf* (list dx7b dy7b dz7b) 0))
     (setq v7x (car v7f) v7y (cadr v7f) v7z (caddr v7f))
     (setq vbx (car vbf) vby (cadr vbf) vbz (caddr vbf))
    )
   )
  )
  (if (> d8b r8b)
   (progn 
    (setq v8x (+ v8x (* a8x t)))  (setq v8y (+ v8y (* a8y t)))  (setq v8z (+ v8z (* a8z t)))
    (setq vbx (+ vbx (* abx t)))  (setq vby (+ vby (* aby t)))  (setq vbz (+ vbz (* abz t)))
   )
   (if (/= kur 0)
    (progn
     (setq v8i (list v8x v8y v8z)) ;velocita 8 primb dello scontro
     (setq vbi (list vbx vby vbz)) ;velocita a primb dello scontro
     (setq v8i* (trans v8i 0 (list dx8b dy8b dz8b)))
     (setq vbi* (trans vbi 0 (list dx8b dy8b dz8b)))
     (setq v8i*x (car v8i*) v8i*y (cadr v8i*) v8i*z (caddr v8i*))
     (setq vbi*x (car vbi*) vbi*y (cadr vbi*) vbi*z (caddr vbi*))
     (setq v8f*z (* kur (/ (+ (* (- m8 mb) v8i*z) (* 2 mb vbi*z)) (+ m8 mb))))
     (setq vbf*z (* kur (/ (+ (* (- mb m8) vbi*z) (* 2 m8 v8i*z)) (+ m8 mb))))
     (setq v8f* (list v8i*x v8i*y v8f*z))
     (setq vbf* (list vbi*x vbi*y vbf*z))
     (setq v8f (trans v8f* (list dx8b dy8b dz8b) 0))
     (setq vbf (trans vbf* (list dx8b dy8b dz8b) 0))
     (setq v8x (car v8f) v8y (cadr v8f) v8z (caddr v8f))
     (setq vbx (car vbf) vby (cadr vbf) vbz (caddr vbf))
    )
   )
  )
  (if (> d9b r9b)
   (progn 
    (setq v9x (+ v9x (* a9x t)))  (setq v9y (+ v9y (* a9y t)))  (setq v9z (+ v9z (* a9z t)))
    (setq vbx (+ vbx (* abx t)))  (setq vby (+ vby (* aby t)))  (setq vbz (+ vbz (* abz t)))
   )
   (if (/= kur 0)
    (progn
     (setq v9i (list v9x v9y v9z)) ;velocita 9 primb dello scontro
     (setq vbi (list vbx vby vbz)) ;velocita a primb dello scontro
     (setq v9i* (trans v9i 0 (list dx9b dy9b dz9b)))
     (setq vbi* (trans vbi 0 (list dx9b dy9b dz9b)))
     (setq v9i*x (car v9i*) v9i*y (cadr v9i*) v9i*z (caddr v9i*))
     (setq vbi*x (car vbi*) vbi*y (cadr vbi*) vbi*z (caddr vbi*))
     (setq v9f*z (* kur (/ (+ (* (- m9 mb) v9i*z) (* 2 mb vbi*z)) (+ m9 mb))))
     (setq vbf*z (* kur (/ (+ (* (- mb m9) vbi*z) (* 2 m9 v9i*z)) (+ m9 mb))))
     (setq v9f* (list v9i*x v9i*y v9f*z))
     (setq vbf* (list vbi*x vbi*y vbf*z))
     (setq v9f (trans v9f* (list dx9b dy9b dz9b) 0))
     (setq vbf (trans vbf* (list dx9b dy9b dz9b) 0))
     (setq v9x (car v9f) v9y (cadr v9f) v9z (caddr v9f))
     (setq vbx (car vbf) vby (cadr vbf) vbz (caddr vbf))
    )
   )
  )
  (if (> d0b r0b)
   (progn 
    (setq v0x (+ v0x (* a0x t)))  (setq v0y (+ v0y (* a0y t)))  (setq v0z (+ v0z (* a0z t)))
    (setq vbx (+ vbx (* abx t)))  (setq vby (+ vby (* aby t)))  (setq vbz (+ vbz (* abz t)))
   )
   (if (/= kur 0)
    (progn
     (setq v0i (list v0x v0y v0z)) ;velocita 0 primb dello scontro
     (setq vbi (list vbx vby vbz)) ;velocita b primb dello scontro
     (setq v0i* (trans v0i 0 (list dx0b dy0b dz0b)))
     (setq vbi* (trans vbi 0 (list dx0b dy0b dz0b)))
     (setq v0i*x (car v0i*) v0i*y (cadr v0i*) v0i*z (caddr v0i*))
     (setq vbi*x (car vbi*) vbi*y (cadr vbi*) vbi*z (caddr vbi*))
     (setq v0f*z (* kur (/ (+ (* (- m0 mb) v0i*z) (* 2 mb vbi*z)) (+ m0 mb))))
     (setq vbf*z (* kur (/ (+ (* (- mb m0) vbi*z) (* 2 m0 v0i*z)) (+ m0 mb))))
     (setq v0f* (list v0i*x v0i*y v0f*z))
     (setq vbf* (list vbi*x vbi*y vbf*z))
     (setq v0f (trans v0f* (list dx0b dy0b dz0b) 0))
     (setq vbf (trans vbf* (list dx0b dy0b dz0b) 0))
     (setq v0x (car v0f) v0y (cadr v0f) v0z (caddr v0f))
     (setq vbx (car vbf) vby (cadr vbf) vbz (caddr vbf))
    )
   )
  )
  (if (> dab rab)
   (progn 
    (setq vax (+ vax (* aax t)))  (setq vay (+ vay (* aay t)))  (setq vaz (+ vaz (* aaz t)))
    (setq vbx (+ vbx (* abx t)))  (setq vby (+ vby (* aby t)))  (setq vbz (+ vbz (* abz t)))
   )
   (if (/= kur 0)
    (progn
     (setq vai (list vax vay vaz)) ;velocita a primb dello scontro
     (setq vbi (list vbx vby vbz)) ;velocita b primb dello scontro
     (setq vai* (trans vai 0 (list dxab dyab dzab)))
     (setq vbi* (trans vbi 0 (list dxab dyab dzab)))
     (setq vai*x (car vai*) vai*y (cadr vai*) vai*z (caddr vai*))
     (setq vbi*x (car vbi*) vbi*y (cadr vbi*) vbi*z (caddr vbi*))
     (setq vaf*z (* kur (/ (+ (* (- ma mb) vai*z) (* 2 mb vbi*z)) (+ ma mb))))
     (setq vbf*z (* kur (/ (+ (* (- mb ma) vbi*z) (* 2 ma vai*z)) (+ ma mb))))
     (setq vaf* (list vai*x vai*y vaf*z))
     (setq vbf* (list vbi*x vbi*y vbf*z))
     (setq vaf (trans vaf* (list dxab dyab dzab) 0))
     (setq vbf (trans vbf* (list dxab dyab dzab) 0))
     (setq vax (car vaf) vay (cadr vaf) vaz (caddr vaf))
     (setq vbx (car vbf) vby (cadr vbf) vbz (caddr vbf))
    )
   )
  )

  (if (< (- x1 r1) xsa) (setq v1x (* (+ (* -2 kbi) 1) v1x) ) )
  (if (< (- y1 r1) ysa) (setq v1y (* (+ (* -2 kbi) 1) v1y) ) )   
  (if (< (- z1 r1) zsa) (setq v1z (* (+ (* -2 kbi) 1) v1z) ) )   
  (if (> (+ x1 r1) xsb) (setq v1x (* (+ (* -2 kbi) 1) v1x) ) )   
  (if (> (+ y1 r1) ysb) (setq v1y (* (+ (* -2 kbi) 1) v1y) ) )   
  (if (> (+ z1 r1) zsb) (setq v1z (* (+ (* -2 kbi) 1) v1z) ) )   
  (if (< (- x2 r2) xsa) (setq v2x (* (+ (* -2 kbi) 1) v2x) ) )   
  (if (< (- y2 r2) ysa) (setq v2y (* (+ (* -2 kbi) 1) v2y) ) )   
  (if (< (- z2 r2) zsa) (setq v2z (* (+ (* -2 kbi) 1) v2z) ) )   
  (if (> (+ x2 r2) xsb) (setq v2x (* (+ (* -2 kbi) 1) v2x) ) )   
  (if (> (+ y2 r2) ysb) (setq v2y (* (+ (* -2 kbi) 1) v2y) ) )   
  (if (> (+ z2 r2) zsb) (setq v2z (* (+ (* -2 kbi) 1) v2z) ) )   
  (if (< (- x3 r3) xsa) (setq v3x (* (+ (* -2 kbi) 1) v3x) ) )   
  (if (< (- y3 r3) ysa) (setq v3y (* (+ (* -2 kbi) 1) v3y) ) )   
  (if (< (- z3 r3) zsa) (setq v3z (* (+ (* -2 kbi) 1) v3z) ) )   
  (if (> (+ x3 r3) xsb) (setq v3x (* (+ (* -2 kbi) 1) v3x) ) )   
  (if (> (+ y3 r3) ysb) (setq v3y (* (+ (* -2 kbi) 1) v3y) ) )   
  (if (> (+ z3 r3) zsb) (setq v3z (* (+ (* -2 kbi) 1) v3z) ) )   
  (if (< (- x4 r4) xsa) (setq v4x (* (+ (* -2 kbi) 1) v4x) ) )   
  (if (< (- y4 r4) ysa) (setq v4y (* (+ (* -2 kbi) 1) v4y) ) )   
  (if (< (- z4 r4) zsa) (setq v4z (* (+ (* -2 kbi) 1) v4z) ) )   
  (if (> (+ x4 r4) xsb) (setq v4x (* (+ (* -2 kbi) 1) v4x) ) )   
  (if (> (+ y4 r4) ysb) (setq v4y (* (+ (* -2 kbi) 1) v4y) ) )   
  (if (> (+ z4 r4) zsb) (setq v4z (* (+ (* -2 kbi) 1) v4z) ) )   
  (if (< (- x5 r5) xsa) (setq v5x (* (+ (* -2 kbi) 1) v5x) ) )   
  (if (< (- y5 r5) ysa) (setq v5y (* (+ (* -2 kbi) 1) v5y) ) )   
  (if (< (- z5 r5) zsa) (setq v5z (* (+ (* -2 kbi) 1) v5z) ) )   
  (if (> (+ x5 r5) xsb) (setq v5x (* (+ (* -2 kbi) 1) v5x) ) )   
  (if (> (+ y5 r5) ysb) (setq v5y (* (+ (* -2 kbi) 1) v5y) ) )   
  (if (> (+ z5 r5) zsb) (setq v5z (* (+ (* -2 kbi) 1) v5z) ) )   
  (if (< (- x6 r6) xsa) (setq v6x (* (+ (* -2 kbi) 1) v6x) ) )   
  (if (< (- y6 r6) ysa) (setq v6y (* (+ (* -2 kbi) 1) v6y) ) )   
  (if (< (- z6 r6) zsa) (setq v6z (* (+ (* -2 kbi) 1) v6z) ) )   
  (if (> (+ x6 r6) xsb) (setq v6x (* (+ (* -2 kbi) 1) v6x) ) )   
  (if (> (+ y6 r6) ysb) (setq v6y (* (+ (* -2 kbi) 1) v6y) ) )   
  (if (> (+ z6 r6) zsb) (setq v6z (* (+ (* -2 kbi) 1) v6z) ) )   
  (if (< (- x7 r7) xsa) (setq v7x (* (+ (* -2 kbi) 1) v7x) ) )   
  (if (< (- y7 r7) ysa) (setq v7y (* (+ (* -2 kbi) 1) v7y) ) )   
  (if (< (- z7 r7) zsa) (setq v7z (* (+ (* -2 kbi) 1) v7z) ) )   
  (if (> (+ x7 r7) xsb) (setq v7x (* (+ (* -2 kbi) 1) v7x) ) )   
  (if (> (+ y7 r7) ysb) (setq v7y (* (+ (* -2 kbi) 1) v7y) ) )   
  (if (> (+ z7 r7) zsb) (setq v7z (* (+ (* -2 kbi) 1) v7z) ) )   
  (if (< (- x8 r8) xsa) (setq v8x (* (+ (* -2 kbi) 1) v8x) ) )   
  (if (< (- y8 r8) ysa) (setq v8y (* (+ (* -2 kbi) 1) v8y) ) )   
  (if (< (- z8 r8) zsa) (setq v8z (* (+ (* -2 kbi) 1) v8z) ) )   
  (if (> (+ x8 r8) xsb) (setq v8x (* (+ (* -2 kbi) 1) v8x) ) )   
  (if (> (+ y8 r8) ysb) (setq v8y (* (+ (* -2 kbi) 1) v8y) ) )   
  (if (> (+ z8 r8) zsb) (setq v8z (* (+ (* -2 kbi) 1) v8z) ) )   
  (if (< (- x9 r9) xsa) (setq v9x (* (+ (* -2 kbi) 1) v9x) ) )   
  (if (< (- y9 r9) ysa) (setq v9y (* (+ (* -2 kbi) 1) v9y) ) )   
  (if (< (- z9 r9) zsa) (setq v9z (* (+ (* -2 kbi) 1) v9z) ) )   
  (if (> (+ x9 r9) xsb) (setq v9x (* (+ (* -2 kbi) 1) v9x) ) )   
  (if (> (+ y9 r9) ysb) (setq v9y (* (+ (* -2 kbi) 1) v9y) ) )   
  (if (> (+ z9 r9) zsb) (setq v9z (* (+ (* -2 kbi) 1) v9z) ) )   
  (if (< (- x0 r0) xsa) (setq v0x (* (+ (* -2 kbi) 1) v0x) ) )   
  (if (< (- y0 r0) ysa) (setq v0y (* (+ (* -2 kbi) 1) v0y) ) )   
  (if (< (- z0 r0) zsa) (setq v0z (* (+ (* -2 kbi) 1) v0z) ) )   
  (if (> (+ x0 r0) xsb) (setq v0x (* (+ (* -2 kbi) 1) v0x) ) )   
  (if (> (+ y0 r0) ysb) (setq v0y (* (+ (* -2 kbi) 1) v0y) ) )   
  (if (> (+ z0 r0) zsb) (setq v0z (* (+ (* -2 kbi) 1) v0z) ) )   
  (if (< (- xa ra) xsa) (setq vax (* (+ (* -2 kbi) 1) vax) ) )   
  (if (< (- ya ra) ysa) (setq vay (* (+ (* -2 kbi) 1) vay) ) )   
  (if (< (- za ra) zsa) (setq vaz (* (+ (* -2 kbi) 1) vaz) ) )   
  (if (> (+ xa ra) xsb) (setq vax (* (+ (* -2 kbi) 1) vax) ) )   
  (if (> (+ ya ra) ysb) (setq vay (* (+ (* -2 kbi) 1) vay) ) )   
  (if (> (+ za ra) zsb) (setq vaz (* (+ (* -2 kbi) 1) vaz) ) )   
  (if (< (- xb rb) xsa) (setq vbx (* (+ (* -2 kbi) 1) vbx) ) )   
  (if (< (- yb rb) ysa) (setq vby (* (+ (* -2 kbi) 1) vby) ) )   
  (if (< (- zb rb) zsa) (setq vbz (* (+ (* -2 kbi) 1) vbz) ) )   
  (if (> (+ xb rb) xsb) (setq vbx (* (+ (* -2 kbi) 1) vbx) ) )   
  (if (> (+ yb rb) ysb) (setq vby (* (+ (* -2 kbi) 1) vby) ) )   
  (if (> (+ zb rb) zsb) (setq vbz (* (+ (* -2 kbi) 1) vbz) ) )   

  (setq s1x (+ (* v1x t) (* 0.5 a1x t t)))  (setq s1y (+ (* v1y t) (* 0.5 a1y t t)))  (setq s1z (+ (* v1z t) (* 0.5 a1z t t)))
  (setq s2x (+ (* v2x t) (* 0.5 a2x t t)))  (setq s2y (+ (* v2y t) (* 0.5 a2y t t)))  (setq s2z (+ (* v2z t) (* 0.5 a2z t t)))
  (setq s3x (+ (* v3x t) (* 0.5 a3x t t)))  (setq s3y (+ (* v3y t) (* 0.5 a3y t t)))  (setq s3z (+ (* v3z t) (* 0.5 a3z t t)))
  (setq s4x (+ (* v4x t) (* 0.5 a4x t t)))  (setq s4y (+ (* v4y t) (* 0.5 a4y t t)))  (setq s4z (+ (* v4z t) (* 0.5 a4z t t)))
  (setq s5x (+ (* v5x t) (* 0.5 a5x t t)))  (setq s5y (+ (* v5y t) (* 0.5 a5y t t)))  (setq s5z (+ (* v5z t) (* 0.5 a5z t t)))
  (setq s6x (+ (* v6x t) (* 0.5 a6x t t)))  (setq s6y (+ (* v6y t) (* 0.5 a6y t t)))  (setq s6z (+ (* v6z t) (* 0.5 a6z t t)))
  (setq s7x (+ (* v7x t) (* 0.5 a7x t t)))  (setq s7y (+ (* v7y t) (* 0.5 a7y t t)))  (setq s7z (+ (* v7z t) (* 0.5 a7z t t)))
  (setq s8x (+ (* v8x t) (* 0.5 a8x t t)))  (setq s8y (+ (* v8y t) (* 0.5 a8y t t)))  (setq s8z (+ (* v8z t) (* 0.5 a8z t t)))
  (setq s9x (+ (* v9x t) (* 0.5 a9x t t)))  (setq s9y (+ (* v9y t) (* 0.5 a9y t t)))  (setq s9z (+ (* v9z t) (* 0.5 a9z t t)))
  (setq s0x (+ (* v0x t) (* 0.5 a0x t t)))  (setq s0y (+ (* v0y t) (* 0.5 a0y t t)))  (setq s0z (+ (* v0z t) (* 0.5 a0z t t)))
  (setq sax (+ (* vax t) (* 0.5 aax t t)))  (setq say (+ (* vay t) (* 0.5 aay t t)))  (setq saz (+ (* vaz t) (* 0.5 aaz t t)))
  (setq sbx (+ (* vbx t) (* 0.5 abx t t)))  (setq sby (+ (* vby t) (* 0.5 aby t t)))  (setq sbz (+ (* vbz t) (* 0.5 abz t t)))

  (setq x1 (+ x1 (* k1 s1x)))  (setq y1 (+ y1 (* k1 s1y)))  (setq z1 (+ z1 (* k1 s1z)))
  (setq x2 (+ x2 (* k2 s2x)))  (setq y2 (+ y2 (* k2 s2y)))  (setq z2 (+ z2 (* k2 s2z)))
  (setq x3 (+ x3 (* k3 s3x)))  (setq y3 (+ y3 (* k3 s3y)))  (setq z3 (+ z3 (* k3 s3z)))
  (setq x4 (+ x4 (* k4 s4x)))  (setq y4 (+ y4 (* k4 s4y)))  (setq z4 (+ z4 (* k4 s4z)))
  (setq x5 (+ x5 (* k5 s5x)))  (setq y5 (+ y5 (* k5 s5y)))  (setq z5 (+ z5 (* k5 s5z)))
  (setq x6 (+ x6 (* k6 s6x)))  (setq y6 (+ y6 (* k6 s6y)))  (setq z6 (+ z6 (* k6 s6z)))
  (setq x7 (+ x7 (* k7 s7x)))  (setq y7 (+ y7 (* k7 s7y)))  (setq z7 (+ z7 (* k7 s7z)))
  (setq x8 (+ x8 (* k8 s8x)))  (setq y8 (+ y8 (* k8 s8y)))  (setq z8 (+ z8 (* k8 s8z)))
  (setq x9 (+ x9 (* k9 s9x)))  (setq y9 (+ y9 (* k9 s9y)))  (setq z9 (+ z9 (* k9 s9z)))
  (setq x0 (+ x0 (* k0 s0x)))  (setq y0 (+ y0 (* k0 s0y)))  (setq z0 (+ z0 (* k0 s0z)))
  (setq xa (+ xa (* ka sax)))  (setq ya (+ ya (* ka say)))  (setq za (+ za (* ka saz)))
  (setq xb (+ xb (* kb sbx)))  (setq yb (+ yb (* kb sby)))  (setq zb (+ zb (* kb sbz)))

  (setq a1 (sqrt (+ (* a1x a1x) (* a1y a1y) (* a1z a1z))))
  (setq a2 (sqrt (+ (* a2x a2x) (* a2y a2y) (* a2z a2z))))
  (setq a3 (sqrt (+ (* a3x a3x) (* a3y a3y) (* a3z a3z))))
  (setq a4 (sqrt (+ (* a4x a4x) (* a4y a4y) (* a4z a4z))))
  (setq a5 (sqrt (+ (* a5x a5x) (* a5y a5y) (* a5z a5z))))
  (setq a6 (sqrt (+ (* a6x a6x) (* a6y a6y) (* a6z a6z))))
  (setq a7 (sqrt (+ (* a7x a7x) (* a7y a7y) (* a7z a7z))))
  (setq a8 (sqrt (+ (* a8x a8x) (* a8y a8y) (* a8z a8z))))
  (setq a9 (sqrt (+ (* a9x a9x) (* a9y a9y) (* a9z a9z))))
  (setq a0 (sqrt (+ (* a0x a0x) (* a0y a0y) (* a0z a0z))))
  (setq aa (sqrt (+ (* aax aax) (* aay aay) (* aaz aaz))))
  (setq ab (sqrt (+ (* abx abx) (* aby aby) (* abz abz))))

  (setq va (+ (abs a1) (abs a2) (abs a3) (abs a4) (abs a5) (abs a6) (abs a7) (abs a8) (abs a9) (abs a0) (abs aa) (abs ab)
              (abs v1) (abs v2) (abs v3) (abs v4) (abs v5) (abs v6) (abs v7) (abs v8) (abs v9) (abs v0) (abs va) (abs vb)
           )
  )
  (princ "\n")
  (princ va)
  (princ)

  (setq q1 (list x1 y1 z1))
  (setq q2 (list x2 y2 z2))
  (setq q3 (list x3 y3 z3))
  (setq q4 (list x4 y4 z4))
  (setq q5 (list x5 y5 z5))
  (setq q6 (list x6 y6 z6))
  (setq q7 (list x7 y7 z7))
  (setq q8 (list x8 y8 z8))
  (setq q9 (list x9 y9 z9))
  (setq q0 (list x0 y0 z0))
  (setq qa (list xa ya za))
  (setq qb (list xb yb zb))

  (if (= iscan 0)
   (progn
 
   (if (= ker 0)
    (progn
    (if (= pc "p")
        (progn
         (setvar "clayer" "m1") (command "_point" p1)
         (setvar "clayer" "m2") (command "_point" p2)
         (setvar "clayer" "m3") (command "_point" p3)
         (setvar "clayer" "m4") (command "_point" p4)
         (setvar "clayer" "m5") (command "_point" p5)
         (setvar "clayer" "m6") (command "_point" p6)
         (setvar "clayer" "m7") (command "_point" p7)
         (setvar "clayer" "m8") (command "_point" p8)
         (setvar "clayer" "m9") (command "_point" p9)
         (setvar "clayer" "m0") (command "_point" p0)
         (setvar "clayer" "ma") (command "_point" pa)
         (setvar "clayer" "mb") (command "_point" pb)
        )
        (if (= pc "c")
            (progn
             (setvar "clayer" "m1") (command "_circle" p1 r1)
             (setvar "clayer" "m2") (command "_circle" p2 r2)
             (setvar "clayer" "m3") (command "_circle" p3 r3)
             (setvar "clayer" "m4") (command "_circle" p4 r4)
             (setvar "clayer" "m5") (command "_circle" p5 r5)
             (setvar "clayer" "m6") (command "_circle" p6 r6)
             (setvar "clayer" "m7") (command "_circle" p7 r7)
             (setvar "clayer" "m8") (command "_circle" p8 r8)
             (setvar "clayer" "m9") (command "_circle" p9 r9)
             (setvar "clayer" "m0") (command "_circle" p0 r0)
             (setvar "clayer" "ma") (command "_circle" pa ra)
             (setvar "clayer" "mb") (command "_circle" pb rb)
            )
            (if (= pc "s")
                (progn
                 (setvar "clayer" "m1") (command "_sphere" p1 r1)
                 (setvar "clayer" "m2") (command "_sphere" p2 r2)
                 (setvar "clayer" "m3") (command "_sphere" p3 r3)
                 (setvar "clayer" "m4") (command "_sphere" p4 r4)
                 (setvar "clayer" "m5") (command "_sphere" p5 r5)
                 (setvar "clayer" "m6") (command "_sphere" p6 r6)
                 (setvar "clayer" "m7") (command "_sphere" p7 r7)
                 (setvar "clayer" "m8") (command "_sphere" p8 r8)
                 (setvar "clayer" "m9") (command "_sphere" p9 r9)
                 (setvar "clayer" "m0") (command "_sphere" p0 r0)
                 (setvar "clayer" "ma") (command "_sphere" pa ra)
                 (setvar "clayer" "mb") (command "_sphere" pb rb)
                )
            )
        )
    )
    )
    (progn
             (command "_move" o1 "" p1 q1)
             (command "_move" o2 "" p2 q2)
             (command "_move" o3 "" p3 q3)
             (command "_move" o4 "" p4 q4)
             (command "_move" o5 "" p5 q5)
             (command "_move" o6 "" p6 q6)
             (command "_move" o7 "" p7 q7)
             (command "_move" o8 "" p8 q8)
             (command "_move" o9 "" p9 q9)
             (command "_move" o0 "" p0 q0)
             (command "_move" oa "" pa qa)
             (command "_move" ob "" pb qb)
    )    
   )
    
   )

  )
 
  (setq p1 q1)
  (setq p2 q2)  
  (setq p3 q3)  
  (setq p4 q4)  
  (setq p5 q5)  
  (setq p6 q6)  
  (setq p7 q7)  
  (setq p8 q8)  
  (setq p9 q9)  
  (setq p0 q0)  
  (setq pa qa)  
  (setq pb qb)  

  (setq iscan (+ 1 iscan))
  (if (= iscan scan) (setq iscan 0))

 )
 (setvar "clayer" "0")
 (command "_pline" p1 p2 p3 p4 p5 p6 p7 p8 p9 p0 pa pb p1 "")
)

;********************************************;
;FORZE INTERNE ED ESTERNE DEL SISTEMA GRAVITA;
;********************************************;

(defun fgr (mr1 mr2 d)                                           ;forze gravitazionali
 (setq kgr 0.000)       
 (/ (* kgr mr1 mr2) (* d d))                                    
 ;(/ (log d) (log 10000))
 ;(/ (* kgr mr1 mr2) (* d 1))                                    
)

(defun fre (mr1 mr2 d)                                           ;forze repulsive
 (setq kre -0.00)    ;-1000
 (/ (* kre mr1 mr2) (* d d))                                  
 ;(/ (* kre mr1 mr2) (sqrt d))                                  
 ;(/ (* kre mr1 mr2) (* 10 d))                                  
)

(defun fel (d)                                                 ;forze elastico
 (setq kel 0.00)
 (* kel d)                                                    
)

(defun fmo (d)                                                 ;forze molla
 (setq kmo1 -0.001)   ;d>lmo
 (setq kmo2 -0.001)     ;d<lmo
 (setq lmo 50)
 (if (>= d lmo) (* kmo1 (- lmo d)) (* kmo2 (- lmo d)))            
 ;(if (>= d lmo) (* -0.01 kmo1 (expt (- lmo d) 2)) (* 0.01 kmo2 (expt (- lmo d) 2)))            
)

(defun fvi (m r v)                                             ;forze esterne
 (setq kra -0.00)
 (setq kvi -0.005)
 (if (<= 0 v) (setq kra kra) (setq kti (* kra -1)))
 (+
  (* kra m)                                                  ;radente
  (* kvi (expt r 2.0) v)                              		;viscoso
 )
)

(defun fwx (r)                                                ;vento x
 (setq kwx -0.0000)
 (* kwx (expt r 2.0))
)

(defun fwy (r)                                                ;vento y
 (setq kwy -0.000)
 (* kwy (expt r 2.0))
)

(defun fwz (r)                                                ;vento z
 (setq kwz 0.0)
 (* kwz (expt r 2.0))
)

(defun fsx (x y z)                                             ;spazio x
 (setq ksx -0.0000)
 (* ksx (* 1 x))
 ;(* ksx (* -1.0 x (abs x)))
)

(defun fsy (x y z)                                             ;spazio y
 (setq ksy -0.0000)
 (* ksy (* 1 y))
 ;(* ksy (* -1.0 y (abs y)))
)

(defun fsz (x y z)                                             ;spazio z
 (setq ksz -0.00)
 (* ksz (* 1 z))
 ;(* ksz (* -1.0 z (abs z)))
)
